 /* ++ BUILD Version: 0003                                            */
 /*    -- Increment this if a change has global effects               */
 /*                                                                   */
 /* Copyright 1991-1998 Microsoft Corporation                         */
 /*                                                                   */
 /* Module Name:                                                      */
 /*                                                                   */
 /*   lmalert.cpy                                                     */
 /*                                                                   */
 /* Abstract:                                                         */
 /*                                                                   */
 /*   This file contains structures for communication with the        */
 /*   Alerter service.                                                */
 /*                                                                   */
 /* Environment:                                                      */
 /*                                                                   */
 /*   User Mode - Win32                                               */
 /*                                                                   */
 /* Notes:                                                            */
 /*                                                                   */
 /*   You must include LmCons.cpy before this file, since this file   */
 /*   depends on values defined in LmCons.cpy.                        */
 /*                                                                   */
 /* --                                                                */

 %dcl #ALERT_ char ext;
 %if #ALERT_ = '' %then %do;
 %#ALERT_ = 'Y';

 /* Function Prototypes */

 dcl NetAlertRaise
     entry (WCHAR(*) varz byaddr nonasgn,
            type LPVOID,
            type DWORD)
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetAlertRaise');

 dcl NetAlertRaiseEx
     entry (WCHAR(*) varz byaddr nonasgn,
            type LPVOID,
            type DWORD,
            WCHAR(*) varz byaddr nonasgn)
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetAlertRaiseEx');


 /*  Data Structures */

 define structure
   1 STD_ALERT,
     2 alrt_timestamp   type DWORD,
     2 alrt_eventname   WCHAR (EVLEN) varz,
     2 alrt_servicename WCHAR (SNLEN) varz;
 define alias  PSTD_ALERT handle STD_ALERT;
 define alias LPSTD_ALERT handle STD_ALERT;

 define structure
   1 ADMIN_OTHER_INFO,
     2 alrtad_errcode    type DWORD,
     2 alrtad_numstrings type DWORD;
 define alias  PADMIN_OTHER_INFO handle ADMIN_OTHER_INFO;
 define alias LPADMIN_OTHER_INFO handle ADMIN_OTHER_INFO;

 define structure
   1 ERRLOG_OTHER_INFO,
     2 alrter_errcode type DWORD,
     2 alrter_offset  type DWORD;
 define alias  PERRLOG_OTHER_INFO handle ERRLOG_OTHER_INFO;
 define alias LPERRLOG_OTHER_INFO handle ERRLOG_OTHER_INFO;

 define structure
   1 PRINT_OTHER_INFO,
     2 alrtpr_jobid     type DWORD,
     2 alrtpr_status    type DWORD,
     2 alrtpr_submitted type DWORD,
     2 alrtpr_size      type DWORD;
 define alias  PPRINT_OTHER_INFO handle PRINT_OTHER_INFO;
 define alias LPPRINT_OTHER_INFO handle PRINT_OTHER_INFO;

 define structure
   1 USER_OTHER_INFO,
     2 alrtus_errcode    type DWORD,
     2 alrtus_numstrings type DWORD;
 define alias  PUSER_OTHER_INFO handle USER_OTHER_INFO;
 define alias LPUSER_OTHER_INFO handle USER_OTHER_INFO;


 /* Special Values and Constants */


 /* Name of mailslot to send alert notifications */

 dcl ALERTER_MAILSLOT WCHAR value('\\.\MAILSLOT\Alerter');


 /* The following macro gives a pointer to the other_info data.    */
 /* It takes an alert structure and returns a pointer to structure */
 /* beyond the standard portion.                                   */

 ALERT_OTHER_INFO: proc (x)
                   returns (pointer byvalue)
                   options(inline reorder) internal;
   dcl x type STD_ALERT byaddr;
   dcl (addr, ptradd) builtin;
   return (ptradd (addr (x), size (: STD_ALERT :) ));
 end ALERT_OTHER_INFO;

 /* The following macro gives a pointer to the variable-length data.  */
 /* It takes a handle to one of the other-info structs and returns a  */
 /* pointer to the variable data portion.                             */

 %ALERT_VAR_DATA: proc (p) returns (char);
   dcl p char; /* relevant handle - not pointer */
               /* to one of the other structures */
   return ('ptradd (ptrvalue (' || p || '), ' ||
                   'size (: type (' || p || ') :) )');
 %end ALERT_VAR_DATA;
 %activate ALERT_VAR_DATA;


 /* Names of standard Microsoft-defined alert events. */

 dcl ALERT_PRINT_EVENT    WCHAR value('PRINTING');
 dcl ALERT_MESSAGE_EVENT  WCHAR value('MESSAGE');
 dcl ALERT_ERRORLOG_EVENT WCHAR value('ERRORLOG');
 dcl ALERT_ADMIN_EVENT    WCHAR value('ADMIN');
 dcl ALERT_USER_EVENT     WCHAR value('USER');


 /* Bitmap masks for prjob_status field of PRINTJOB. */

 /* 2-7 bits also used in device status */

 dcl PRJOB_QSTATUS     fixed bin(31) value('3'xn);   /* Bits 0,1 */
 dcl PRJOB_DEVSTATUS   fixed bin(31) value('1fc'xn); /* 2-8 bits */
 dcl PRJOB_COMPLETE    fixed bin(31) value('4'xn);   /* Bit 2 */
 dcl PRJOB_INTERV      fixed bin(31) value('8'xn);   /* Bit 3 */
 dcl PRJOB_ERROR       fixed bin(31) value('10'xn);  /* Bit 4 */
 dcl PRJOB_DESTOFFLINE fixed bin(31) value('20'xn);  /* Bit 5 */
 dcl PRJOB_DESTPAUSED  fixed bin(31) value('40'xn);  /* Bit 6 */
 dcl PRJOB_NOTIFY      fixed bin(31) value('80'xn);  /* BIT 7 */
 dcl PRJOB_DESTNOPAPER fixed bin(31) value('100'xn); /* BIT 8 */
 dcl PRJOB_DELETED     fixed bin(31) value('8000'xn);/* BIT 15 */


 /* Values of PRJOB_QSTATUS bits in prjob_status field of PRINTJOB. */

 dcl PRJOB_QS_QUEUED   fixed bin(31) value(0);
 dcl PRJOB_QS_PAUSED   fixed bin(31) value(1);
 dcl PRJOB_QS_SPOOLING fixed bin(31) value(2);
 dcl PRJOB_QS_PRINTING fixed bin(31) value(3);

 %end; /* _ALERT_ */
