 /* ++ BUILD Version: 0001                                            */
 /*    -- Increment this if a change has global effects               */
 /*                                                                   */
 /* Copyright 1991-1998 Microsoft Corporation                         */
 /*                                                                   */
 /* Module Name:                                                      */
 /*                                                                   */
 /*   lmdfs.cpy                                                       */
 /*                                                                   */
 /* Abstract:                                                         */
 /*                                                                   */
 /*   This file contains structures, function prototypes, and         */
 /*   definitions for the NetDfs API                                  */
 /*                                                                   */
 /* Environment:                                                      */
 /*                                                                   */
 /*   User Mode - Win32                                               */
 /*                                                                   */
 /* Notes:                                                            */
 /*                                                                   */
 /*   You must include windef.cpy and lmcons.cpy before this file.    */
 /*                                                                   */
 /* --                                                                */

 %dcl #LMDFS_ char ext;
 %if #LMDFS_ = '' %then %do;
 %#LMDFS_ = 'Y';


 /* DFS Volume state */

 dcl DFS_VOLUME_STATE_OK           fixed bin(31) value(1);
 dcl DFS_VOLUME_STATE_INCONSISTENT fixed bin(31) value(2);
 dcl DFS_VOLUME_STATE_OFFLINE      fixed bin(31) value(3);
 dcl DFS_VOLUME_STATE_ONLINE       fixed bin(31) value(4);

 /* DFS Storage State */

 dcl DFS_STORAGE_STATE_OFFLINE     fixed bin(31) value(1);
 dcl DFS_STORAGE_STATE_ONLINE      fixed bin(31) value(2);

 /* Level 1: */

 define structure
   1 DFS_INFO_1,
     2 EntryPath type LPWSTR;
                 /* Dfs name for the top of this piece of storage */
 define alias  PDFS_INFO_1 handle DFS_INFO_1;
 define alias LPDFS_INFO_1 handle DFS_INFO_1;

 /* Level 2: */

 define structure
   1 DFS_INFO_2,
     2 EntryPath type LPWSTR,/* Dfs name for the top of this volume */
     2 Comment   type LPWSTR,/* Comment for this volume */
     2 State     type DWORD,
                 /* State of this volume, one of DFS_VOLUME_STATE_* */
     2 NumberOfStorages type DWORD;
                 /* Number of storages for this volume */
 define alias  PDFS_INFO_2 handle DFS_INFO_2;
 define alias LPDFS_INFO_2 handle DFS_INFO_2;

 define structure
   1 DFS_STORAGE_INFO,
     2 State      type ULONG,
                 /* State of this storage, one of DFS_STORAGE_STATE_* */
     2 ServerName type LPWSTR,/* Name of server hosting this storage */
     2 ShareName  type LPWSTR;/* Name of share hosting this storage */
 define alias  PDFS_STORAGE_INFO handle DFS_STORAGE_INFO;
 define alias LPDFS_STORAGE_INFO handle DFS_STORAGE_INFO;


 /* Level 3: */

 define structure
   1 DFS_INFO_3,
     2 EntryPath type LPWSTR,/* Dfs name for the top of this volume */
     2 Comment   type LPWSTR,/* Comment for this volume */
     2 State     type DWORD,
                 /* State of this volume, one of DFS_VOLUME_STATE_* */
     2 NumberOfStorages type DWORD,
                 /* Number of storage servers for this volume */
     2 Storage type LPDFS_STORAGE_INFO;
                 /* An array (of NumberOfStorages elements) of */
                 /* storage-specific information.              */
 define alias  PDFS_INFO_3 handle DFS_INFO_3;
 define alias LPDFS_INFO_3 handle DFS_INFO_3;

 /* Level 4: */

 define structure
   1 DFS_INFO_4,
     2 EntryPath type LPWSTR,/* Dfs name for the top of this volume */
     2 Comment   type LPWSTR,/* Comment for this volume */
     2 State     type DWORD,
                 /* State of this volume, one of DFS_VOLUME_STATE_* */
     2 Timeout   type ULONG,
                 /* Timeout, in seconds, of this junction point */
     2 Guid      type GUID,  /* Guid of this junction point */
     2 NumberOfStorages type DWORD,
                 /* Number of storage servers for this volume */
     2 Storage type LPDFS_STORAGE_INFO;
                 /* An array (of NumberOfStorages elements) of */
                 /* storage-specific information.              */
 define alias  PDFS_INFO_4 handle DFS_INFO_4;
 define alias LPDFS_INFO_4 handle DFS_INFO_4;

 /* Level 100: */

 define structure
   1 DFS_INFO_100,
     2 Comment type LPWSTR;/* Comment for this volume or storage */
 define alias  PDFS_INFO_100 handle DFS_INFO_100;
 define alias LPDFS_INFO_100 handle DFS_INFO_100;


 /* Level 101: */

 define structure
   1 DFS_INFO_101,
     2 State type DWORD;
             /* State of this storage, one of DFS_STORAGE_STATE_* */
 define alias  PDFS_INFO_101 handle DFS_INFO_101;
 define alias LPDFS_INFO_101 handle DFS_INFO_101;

 /* Level 102: */

 define structure
   1 DFS_INFO_102,
     2 Timeout type ULONG; /* Timeout, in seconds, of the junction */
 define alias  PDFS_INFO_102 handle DFS_INFO_102;
 define alias LPDFS_INFO_102 handle DFS_INFO_102;


 /* Level 200: */

 define structure
   1 DFS_INFO_200,
     2 FtDfsName type LPWSTR; /* FtDfs name */
 define alias  PDFS_INFO_200 handle DFS_INFO_200;
 define alias LPDFS_INFO_200 handle DFS_INFO_200;


 /* Add a new volume or additional storage for an existing volume at */
 /* DfsEntryPath. */

 dcl NetDfsAdd
     entry (WCHAR(*) varz byaddr,
               /* DFS entry path for this added volume or storage */
            WCHAR(*) varz byaddr,
               /* Name of server hosting the storage */
            WCHAR(*) varz byaddr,
               /* Existing share name for the storage */
            WCHAR(*) varz byaddr optional,
               /* Optional comment for this volume or storage */
            type DWORD)
               /* See below. Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsAdd');


 /* Flags: */

 dcl DFS_ADD_VOLUME     type DWORD value(1);
     /* Add a new volume to the DFS if not already there */
 dcl DFS_RESTORE_VOLUME type DWORD value(2);
     /* Volume/Replica is being restored - do not verify share etc. */


 /* Setup/teardown API's for standard and FtDfs roots. */

 dcl NetDfsAddStdRoot
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* Share to make Dfs root */
            WCHAR(*) varz byaddr optional, /* Comment */
            type DWORD)   /* Flags for operation.  Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsAddStdRoot');


 dcl NetDfsRemoveStdRoot
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* Share that host Dfs root */
            type DWORD)   /* Flags for operation.  Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsRemoveStdRoot');


 dcl NetDfsAddFtRoot
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* Share to make Dfs root */
            WCHAR(*) varz byaddr, /* Name of FtDfs to create/join */
            WCHAR(*) varz byaddr optional, /* Comment */
            type DWORD)   /* Flags for operation.  Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsAddFtRoot');


 dcl NetDfsRemoveFtRoot
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* Share that host Dfs root */
            WCHAR(*) varz byaddr,
                          /* Name of FtDfs to remove or unjoin from. */
            type DWORD)   /* Flags for operation.  Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsRemoveFtRoot');


 dcl NetDfsRemoveFtRootForced
     entry (WCHAR(*) varz byaddr, /* Name of domain the server is in */
            WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* Share that host Dfs root */
            WCHAR(*) varz byaddr,
                          /* Name of FtDfs to remove or unjoin from. */
            type DWORD)   /* Flags for operation.  Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsRemoveFtRootForced');


 /* Call to reinitialize the dfsmanager on a machine */

 dcl NetDfsManagerInitialize
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            type DWORD)   /* Flags for operation.  Zero for no flags. */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsManagerInitialize');


 dcl NetDfsAddStdRootForced
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* Share to make Dfs root */
            WCHAR(*) varz byaddr optional, /* Comment */
            WCHAR(*) varz byaddr) /* Drive:\dir backing the share */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsAddStdRootForced');


 dcl NetDfsGetDcAddress
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            pointer byaddr,       /* The IP address of the DC to use */
            type BOOLEAN byaddr,
                    /* TRUE if server is a Dfs root, FALSE otherwise */
            type ULONG byaddr)
                          /* Time, in sec, that we stay with this DC */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsGetDcAddress');


 dcl NetDfsSetDcAddress
     entry (WCHAR(*) varz byaddr, /* Server to remote to */
            WCHAR(*) varz byaddr, /* The IP address of the DC to use */
            type ULONG,         /* Time, in sec, to stay with this DC */
            type DWORD)         /* See below */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsSetDcAddress');


 /* Flags for NetDfsSetDcAddress() */

 dcl NET_DFS_SETDC_FLAGS   type DWORD value('00000000'xu);
 dcl NET_DFS_SETDC_TIMEOUT type DWORD value('00000001'xu);
 dcl NET_DFS_SETDC_INITPKT type DWORD value('00000002'xu);


 /* Structures used for site reporting */

 define structure
   1 DFS_SITENAME_INFO,
    2 SiteFlags type ULONG,    /* Below */
    2 SiteName  type LPWSTR;
 define alias  PDFS_SITENAME_INFO handle DFS_SITENAME_INFO;
 define alias LPDFS_SITENAME_INFO handle DFS_SITENAME_INFO;

 /* SiteFlags */

 dcl DFS_SITE_PRIMARY type ULONG value('1'xu);
     /* This site returned by DsGetSiteName() */

 define structure
   1 DFS_SITELIST_INFO,
     2 cSites  type ULONG,
     2 Site(1) type DFS_SITENAME_INFO; /* refer */
 define alias  PDFS_SITELIST_INFO handle DFS_SITELIST_INFO;
 define alias LPDFS_SITELIST_INFO handle DFS_SITELIST_INFO;

 /* Remove a volume or additional storage for volume from the Dfs  */
 /* at DfsEntryPath. When applied to the last storage in a volume, */
 /* removes the volume from the DFS.                               */

 dcl NetDfsRemove
     entry (WCHAR(*) varz byaddr,
               /* DFS entry path for this added volume or storage */
            WCHAR(*) varz byaddr,
               /* Name of server hosting the storage */
            WCHAR(*) varz byaddr)
               /* Name of share hosting the storage */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsRemove');


 /* Get information about all of the volumes in the Dfs.       */
 /* DfsName is the "server" part of the UNC name used to refer */
 /* to this particular Dfs.                                    */
 /* Valid levels are 1-4, 200.                                 */

 dcl NetDfsEnum
     entry (WCHAR(*) varz byaddr,
               /* Name of the Dfs for enumeration */
            type DWORD,
               /* Level of information requested */
            type DWORD,
               /* Advisory, but -1 means "get it all" */
            type LPBYTE byaddr,
               /* API allocates and returns buffer with requested info*/
            type DWORD byaddr,
               /* Number of entries returned */
            type DWORD byaddr)
               /* Must be 0 on first call, reused on subsequent calls */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsEnum');


 /* Get information about the volume or storage.                      */
 /* If ServerName and ShareName are specified, the information        */
 /* returned is specific to that server and share, else the           */
 /* information is specific to the volume as a whole.                 */
 /* Valid levels are 1-4, 200.                                        */

 dcl NetDfsGetInfo
     entry (WCHAR(*) varz byaddr,
               /* DFS entry path for the volume */
            WCHAR(*) varz byaddr optional,
               /* Name of server hosting a storage */
            WCHAR(*) varz byaddr optional,
               /* Name of share on server serving the volume */
            type DWORD,
               /* Level of information requested */
            type LPBYTE byaddr)
               /* API allocates and returns buffer with requested info*/
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsGetInfo');


 /* Set info about the volume or storage.                             */
 /* If ServerName and ShareName are specified, the information set    */
 /* is specific to that server and share, else the information is     */
 /* specific to the volume as a whole.                                */
 /* Valid levels are 100, 101 and 102                                 */

 dcl NetDfsSetInfo
     entry (WCHAR(*) varz byaddr,
               /* DFS entry path for the volume */
            WCHAR(*) varz byaddr optional,
               /* Name of server hosting a storage */
            WCHAR(*) varz byaddr optional,
               /* Name of share hosting a storage */
            type DWORD,
               /* Level of information to be set */
            type LPBYTE)
               /* Buffer holding information */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsSetInfo');


 /* Get client's cached information about the volume or storage.      */
 /* If ServerName and ShareName are specified, the information        */
 /* returned is specific to that server and share, else the           */
 /* information is specific to the volume as a whole.                 */
 /* Valid levels are 1-4                                              */

 dcl NetDfsGetClientInfo
     entry (WCHAR(*) varz byaddr,
               /* DFS entry path for the volume    */
            WCHAR(*) varz byaddr optional,
               /* Name of server hosting a storage           */
            WCHAR(*) varz byaddr optional,
               /* Name of share on server serving the volume */
            type DWORD,
               /* Level of information requested   */
            type LPBYTE byaddr)
               /* API allocates and returns buffer with requested info*/
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsGetClientInfo');


 /* Set client's cached info about the volume or storage.             */
 /* If ServerName and ShareName are specified, the information set is */
 /* specific to that server and share, else the information is        */
 /* specific to the volume as a whole.                                */
 /* Valid levels are 101 and 102.                                     */

 dcl NetDfsSetClientInfo
     entry (WCHAR(*) varz byaddr,
               /* DFS entry path for the volume */
            WCHAR(*) varz byaddr optional,
               /* Name of server hosting a storage */
            WCHAR(*) varz byaddr optional,
               /* Name of share hosting a storage */
            type DWORD,
               /* Level of information to be set */
            type LPBYTE)
               /* Buffer holding information */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsSetClientInfo');


 /* Move a DFS volume and all subordinate volumes from one place */
 /* in the DFS to another place in the DFS.                      */

 dcl NetDfsMove
     entry (WCHAR(*) varz byaddr,
               /* Current DFS entry path for this volume */
            WCHAR(*) varz byaddr)
               /* New DFS entry path for this volume */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsMove');

 dcl NetDfsRename
     entry (WCHAR(*) varz byaddr,
               /* Current Win32 path in a Dfs */
            WCHAR(*) varz byaddr)
               /* New Win32 path in the same Dfs */
     returns (type NET_API_STATUS byvalue optional)
     NET_API_FUNCTION external('NetDfsRename');

 %end; /* _LMDFS_ */
