 /*********************************************************************/
 /*                                                                   */
 /*  THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY   */
 /*  OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT      */
 /*  LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR      */
 /*  FITNESS FOR A PARTICULAR PURPOSE.                                */
 /*                                                                   */
 /*                                                                   */
 /* Copyright (C) Microsoft Corporation 1991-1996.                    */
 /*               All rights reserved.                                */
 /*                                                                   */
 /* Title: mciavi.cpy - Multimedia Systems Media Control Interface    */
 /* AVI driver external header file                                   */
 /*                                                                   */
 /* Version: 1.00                                                     */
 /*                                                                   */
 /* Date:    16-JUL-1992                                              */
 /*                                                                   */
 /* Depends on MMSYSTEM.CPY and WINDOWS.CPY                           */
 /*                                                                   */
 /*********************************************************************/

 %dcl #MCIAVI_ char ext;
 %if #MCIAVI_ = '' %then %do; /* C doesn't care, PL/I does: protect   */
 %#MCIAVI_ = 'Y';

 %dcl #INC_MMSYSTEM char ext;
 %if #INC_MMSYSTEM = '' %then %do;
 %include mmsystem;
 %end;

 /* These three flags apply to the 'play' command:                    */
 /* play <alias> window     Play in normal window                     */
 /* play <alias> fullscreen    Play in 320x240 full-screen mode       */
 /* play <alias> fullscreen by 2  Play fullscreen, zoomed by 2        */

 dcl MCI_MCIAVI_PLAY_WINDOW           fixed bin(31) value('01000000'xn);
 dcl MCI_MCIAVI_PLAY_FULLSCREEN       fixed bin(31) value('02000000'xn);
 dcl MCI_MCIAVI_PLAY_FULLBY2          fixed bin(31) value('04000000'xn);

 /* Debugging constants for AVI diagnostics */

 /* Returns number of frames not drawn during last play. If this      */
 /* number is more than a small fraction of the number of frames      */
 /* that should have been displayed, things aren't looking good.      */

 dcl MCI_AVI_STATUS_FRAMES_SKIPPED    fixed bin(31) value('8001'xn);

 /* Returns a number representing how well the last AVI play worked.  */
 /* A result of 1000 indicates that the AVI sequence took the amount  */
 /* of time to play that it should have - a result of 2000, for       */
 /* instance, would indicate that a 5-second AVI sequence took 10     */
 /* seconds to play, implying that the audio and video were badly     */
 /* broken up.                                                        */

 dcl MCI_AVI_STATUS_LAST_PLAY_SPEED   fixed bin(31) value('8002'xn);

 /* Returns the number of times that the audio definitely broke up.   */
 /* (We count one for every time we're about to write some audio data */
 /* to the driver, and we notice that it's already played all of the  */
 /* data we have.                                                     */

 dcl MCI_AVI_STATUS_AUDIO_BREAKS      fixed bin(31) value('8003'xn);

 dcl MCI_AVI_SETVIDEO_DRAW_PROCEDURE  fixed bin(31) value('8000'xn);

 dcl MCI_AVI_SETVIDEO_PALETTE_COLOR   fixed bin(31) value('8100'xn);


 /* This constant specifies that the "halftone" palette should be     */
 /* used, rather than the default palette.                            */

 dcl MCI_AVI_SETVIDEO_PALETTE_HALFTONE
                                      fixed bin(31) value('0000FFFF'xn);

 dcl /* Custom error return values */
 ( MCIERR_AVI_OLDAVIFORMAT       value(MCIERR_CUSTOM_DRIVER_BASE + 100)
 , MCIERR_AVI_NOTINTERLEAVED     value(MCIERR_CUSTOM_DRIVER_BASE + 101)
 , MCIERR_AVI_NODISPDIB          value(MCIERR_CUSTOM_DRIVER_BASE + 102)
 , MCIERR_AVI_CANTPLAYFULLSCREEN value(MCIERR_CUSTOM_DRIVER_BASE + 103)
 , MCIERR_AVI_TOOBIGFORVGA       value(MCIERR_CUSTOM_DRIVER_BASE + 104)
 , MCIERR_AVI_NOCOMPRESSOR       value(MCIERR_CUSTOM_DRIVER_BASE + 105)
 , MCIERR_AVI_DISPLAYERROR       value(MCIERR_CUSTOM_DRIVER_BASE + 106)
 , MCIERR_AVI_AUDIOERROR         value(MCIERR_CUSTOM_DRIVER_BASE + 107)
 , MCIERR_AVI_BADPALETTE         value(MCIERR_CUSTOM_DRIVER_BASE + 108)
 ) fixed bin(31);
 %end; /* #MCIAVI_ */
