 /* ++                                                                */
 /*                                                                   */
 /* Copyright (c) 1991-1998 Microsoft Corporation                     */
 /*                                                                   */
 /* Module Name:                                                      */
 /*                                                                   */
 /*   rpcdcep.cpy                                                     */
 /*                                                                   */
 /* Abstract:                                                         */
 /*                                                                   */
 /*   This module contains the private RPC runtime APIs for use by    */
 /*   the stubs and by support libraries. Applications must not call  */
 /*   these routines.                                                 */
 /*                                                                   */
 /* --                                                                */

 %dcl #_RPCDCEP_H__ char ext;
 %if #_RPCDCEP_H__ = '' %then %do;
 %#_RPCDCEP_H__ = 'Y';

 %dcl UNICODE char ext;
 %dcl RPC_UNICODE_SUPPORTED char ext;
 %dcl WINNT char ext;

 define structure
   1 RPC_VERSION,
     2 MajorVersion unsigned fixed bin(16),
     2 MinorVersion unsigned fixed bin(16);


 define structure
   1 RPC_SYNTAX_IDENTIFIER,
     2 SyntaxGUID    type GUID,
     2 SyntaxVersion type RPC_VERSION;
 define alias PRPC_SYNTAX_IDENTIFIER handle RPC_SYNTAX_IDENTIFIER;

 define structure
   1 RPC_MESSAGE,
     2 Handle                  type RPC_BINDING_HANDLE,
     2 DataRepresentation      fixed bin(31),
     2 Buffer                  pointer,
     2 BufferLength            fixed bin(31),
     2 ProcNum                 fixed bin(31),
     2 TransferSyntax          type PRPC_SYNTAX_IDENTIFIER,
     2 RpcInterfaceInformation pointer,
     2 ReservedForRuntime      pointer,
     2 ManagerEpv              pointer,
     2 ImportContext           pointer,
     2 RpcFlags                fixed bin(31);
 define alias PRPC_MESSAGE handle RPC_MESSAGE;

 define alias RPC_FORWARD_FUNCTION
        entry (type UUID byaddr,
               type RPC_VERSION byaddr,
               type UUID byaddr,
               pointer, /* to char (*) varz */
               pointer byaddr)
       returns (type RPC_STATUS byvalue optional)
       limited RPCRTAPI RPC_ENTRY;

 /* New context handle flavors. */

 dcl RPC_CONTEXT_HANDLE_DEFAULT_GUARD pointer
     value(ptrvalue('FFFFF00D'xn));

 dcl RPC_CONTEXT_HANDLE_DEFAULT_FLAGS fixed bin(31) value('00000000'xn);
 dcl RPC_CONTEXT_HANDLE_FLAGS         fixed bin(31) value('30000000'xn);
 dcl RPC_CONTEXT_HANDLE_SERIALIZE     fixed bin(31) value('10000000'xn);
 dcl RPC_CONTEXT_HANDLE_DONT_SERIALIZE
                                      fixed bin(31) value('20000000'xn);

 /* Types of function calls for datagram rpc */

 dcl RPC_NCA_FLAGS_DEFAULT            fixed bin(31) value('00000000'xn);
     /* 0b000...000 */
 dcl RPC_NCA_FLAGS_IDEMPOTENT         fixed bin(31) value('00000001'xn);
     /* 0b000...001 */
 dcl RPC_NCA_FLAGS_BROADCAST          fixed bin(31) value('00000002'xn);
     /* 0b000...010 */
 dcl RPC_NCA_FLAGS_MAYBE              fixed bin(31) value('00000004'xn);
     /* 0b000...100 */

 dcl RPC_BUFFER_COMPLETE              fixed bin(31) value('00001000'xn);
     /* used by pipes */
 dcl RPC_BUFFER_PARTIAL               fixed bin(31) value('00002000'xn);
     /* used by pipes */
 dcl RPC_BUFFER_EXTRA                 fixed bin(31) value('00004000'xn);
     /* used by pipes */
 dcl RPC_BUFFER_ASYNC                 fixed bin(31) value('00008000'xn);
     /* used by async rpc */
 dcl RPC_BUFFER_NONOTIFY              fixed bin(31) value('00010000'xn);
     /* used by async pipes */

 dcl RPCFLG_MESSAGE                   fixed bin(31) value('01000000'xn);
 dcl RPCFLG_AUTO_COMPLETE             fixed bin(31) value('08000000'xn);
 dcl RPCFLG_LOCAL_CALL                fixed bin(31) value('10000000'xn);
 dcl RPCFLG_INPUT_SYNCHRONOUS         fixed bin(31) value('20000000'xn);
 dcl RPCFLG_ASYNCHRONOUS              fixed bin(31) value('40000000'xn);
 dcl RPCFLG_NON_NDR                   fixed bin(31) value('80000000'xn);

 dcl RPC_FLAGS_VALID_BIT              fixed bin(31) value('00008000'xn);

 define alias RPC_DISPATCH_FUNCTION
        entry (type RPC_MESSAGE byaddr)
        limited #_RPC_STUB;

 define structure
   1 RPC_DISPATCH_TABLE,
     2 DispatchTableCount fixed bin(31),
     2 DispatchTable      pointer,
     2 Reserved           type LONG_PTR;
 define alias PRPC_DISPATCH_TABLE handle RPC_DISPATCH_TABLE;

 define structure
   1 RPC_PROTSEQ_ENDPOINT,
     2 RpcProtocolSequence pointer,
     2 Endpoint            pointer;
 define alias PRPC_PROTSEQ_ENDPOINT handle RPC_PROTSEQ_ENDPOINT;

 /* Both of these types MUST start with the InterfaceId and           */
 /* TransferSyntax. Look at RpcIfInqId and I_RpcIfInqTransferSyntaxes */
 /* to see why.                                                       */
 dcl NT351_INTERFACE_SIZE    fixed bin(15) value('40'xn);
 dcl RPC_INTERFACE_HAS_PIPES fixed bin(15) value('0001'xn);

 define structure
   1 RPC_SERVER_INTERFACE,
     2 Length                  fixed bin(31),
     2 InterfaceId             type RPC_SYNTAX_IDENTIFIER,
     2 TransferSyntax          type RPC_SYNTAX_IDENTIFIER,
     2 DispatchTable           type PRPC_DISPATCH_TABLE,
     2 RpcProtseqEndpointCount fixed bin(31),
     2 RpcProtseqEndpoint      type PRPC_PROTSEQ_ENDPOINT,
     2 DefaultManagerEpv       pointer,
     2 InterpreterInfo         pointer,
     2 Flags                   fixed bin(31);
 define alias PRPC_SERVER_INTERFACE handle RPC_SERVER_INTERFACE;

 define structure
   1 RPC_CLIENT_INTERFACE,
     2 Length                  fixed bin(31),
     2 InterfaceId             type RPC_SYNTAX_IDENTIFIER,
     2 TransferSyntax          type RPC_SYNTAX_IDENTIFIER,
     2 DispatchTable           type PRPC_DISPATCH_TABLE,
     2 RpcProtseqEndpointCount fixed bin(31),
     2 RpcProtseqEndpoint      type PRPC_PROTSEQ_ENDPOINT,
     2 Reserved                type ULONG_PTR,
     2 InterpreterInfo         pointer,
     2 Flags                   fixed bin(31);
 define alias PRPC_CLIENT_INTERFACE handle RPC_CLIENT_INTERFACE;

 dcl I_RpcGetBuffer
     entry (type RPC_MESSAGE)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcGetBuffer');

 dcl I_RpcGetBufferWithObject
     entry (type RPC_MESSAGE byaddr,
            type UUID byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcGetBufferWithObject');

 dcl I_RpcSendReceive
     entry (type RPC_MESSAGE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcSendReceive');

 dcl I_RpcFreeBuffer
     entry (type RPC_MESSAGE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcFreeBuffer');

 dcl I_RpcSend
     entry (type RPC_MESSAGE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcSend');

 dcl I_RpcReceive
     entry (type RPC_MESSAGE byaddr,
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcReceive');

 dcl I_RpcFreePipeBuffer
     entry (type RPC_MESSAGE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcFreePipeBuffer');

 dcl I_RpcReallocPipeBuffer
     entry (type RPC_MESSAGE byaddr,
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcReallocPipeBuffer');

 define alias I_RPC_MUTEX pointer;

 dcl I_RpcRequestMutex
     entry (type I_RPC_MUTEX byaddr)
     RPCRTAPI RPC_ENTRY external('I_RpcRequestMutex');

 dcl I_RpcClearMutex
     entry (type I_RPC_MUTEX)
     RPCRTAPI RPC_ENTRY external('I_RpcClearMutex');

 dcl I_RpcDeleteMutex
     entry (type I_RPC_MUTEX)
     RPCRTAPI RPC_ENTRY external('I_RpcDeleteMutex');

 dcl I_RpcAllocate
     entry (fixed bin(31))
     returns (ptr byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcAllocate');

 dcl I_RpcFree
     entry (pointer)
     RPCRTAPI RPC_ENTRY external('I_RpcFree');

 dcl I_RpcPauseExecution
     entry (fixed bin(31))
     RPCRTAPI RPC_ENTRY external('I_RpcPauseExecution');

 dcl I_RpcGetExtendedError
     entry ()
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcGetExtendedError');

 define alias PRPC_RUNDOWN
        entry (pointer)
        limited #_RPC_USER;

 dcl I_RpcMonitorAssociation
     entry (type RPC_BINDING_HANDLE,
            type PRPC_RUNDOWN,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcMonitorAssociation');

 dcl I_RpcStopMonitorAssociation
     entry (type RPC_BINDING_HANDLE)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcStopMonitorAssociation');

 dcl I_RpcGetCurrentCallHandle
     entry ()
     returns (type RPC_BINDING_HANDLE byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcGetCurrentCallHandle');

 dcl I_RpcGetAssociationContext
     entry (type RPC_BINDING_HANDLE,
            pointer byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcGetAssociationContext');

 dcl I_RpcGetServerContextList
     entry (type RPC_BINDING_HANDLE)
     returns (ptr byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcGetServerContextList');

 dcl I_RpcSetServerContextList
     entry (type RPC_BINDING_HANDLE,
            pointer)
     RPCRTAPI RPC_ENTRY external('I_RpcSetServerContextList');

 dcl I_RpcNsInterfaceExported
     entry (fixed bin(31),
            Wchar (*) varz byaddr,
            type RPC_SERVER_INTERFACE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcNsInterfaceExported');

 dcl I_RpcNsInterfaceUnexported
     entry (fixed bin(31),
            Wchar (*) varz byaddr,
            type RPC_SERVER_INTERFACE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcNsInterfaceUnexported');

 dcl I_RpcBindingToStaticStringBindingW
     entry (type RPC_BINDING_HANDLE,
            pointer byaddr) /* to WCHAR(*) varz byaddr */
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingToStaticStringBindingW');

 %if RPC_UNICODE_SUPPORTED ^= '' %then %do;

 dcl I_RpcNsBindingSetEntryNameW
     entry (type RPC_BINDING_HANDLE,
            fixed bin(31),
            WCHAR(*) varz byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcNsBindingSetEntryNameW');

 dcl I_RpcNsBindingSetEntryNameA
     entry (type RPC_BINDING_HANDLE,
            fixed bin(31),
            char(*) varz byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcNsBindingSetEntryNameA');

 dcl I_RpcServerUseProtseqEp2A
     entry (char(*) varz byaddr,
            char(*) varz byaddr,
            fixed bin(31),
            char(*) varz byaddr,
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUseProtseqEp2A');

 dcl I_RpcServerUseProtseqEp2W
     entry (WCHAR(*) varz byaddr,
            WCHAR(*) varz byaddr,
            fixed bin(31),
            WCHAR(*) varz byaddr,
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUseProtseqEp2W');

 dcl I_RpcServerUseProtseq2W
     entry (WCHAR(*) varz byaddr,
            WCHAR(*) varz byaddr,
            fixed bin(31),
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUseProtseq2W');

 dcl I_RpcServerUseProtseq2A
     entry (char(*) varz byaddr,
            char(*) varz byaddr,
            fixed bin(31),
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUseProtseq2A');

 %dcl I_RpcNsBindingSetEntryName char ext;
 %dcl I_RpcServerUseProtseqEp2   char ext;
 %dcl I_RpcServerUseProtseq2     char ext;
 %if UNICODE ^= '' %then %do;
   %I_RpcNsBindingSetEntryName='I_RpcNsBindingSetEntryNameW';
   %I_RpcServerUseProtseqEp2  ='I_RpcServerUseProtseqEp2W';
   %I_RpcServerUseProtseq2    ='I_RpcServerUseProtseq2W';
 %end; %else %do;
   %I_RpcNsBindingSetEntryName='I_RpcNsBindingSetEntryNameA';
   %I_RpcServerUseProtseqEp2  ='I_RpcServerUseProtseqEp2A';
   %I_RpcServerUseProtseq2    ='I_RpcServerUseProtseq2A';
 %end;

 %end; %else %do;

 dcl I_RpcNsBindingSetEntryName
     entry (type RPC_BINDING_HANDLE,
            fixed bin(31),
            char(*) varz byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcNsBindingSetEntryName');

 dcl I_RpcServerUseProtseq2
     entry (char(*) varz byaddr,
            char(*) varz byaddr,
            fixed bin(31),
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUseProtseq2');

 dcl I_RpcServerUseProtseqEp2
     entry (char(*) varz byaddr,
            char(*) varz byaddr,
            fixed bin(31),
            char(*) varz byaddr,
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUseProtseqEp2');
 %end;

 %if RPC_UNICODE_SUPPORTED ^= '' %then %do;

 dcl I_RpcBindingInqDynamicEndpointW
     entry (type RPC_BINDING_HANDLE,
            pointer byaddr) /* to WCHAR(*) varz */
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingInqDynamicEndpointW');

 dcl I_RpcBindingInqDynamicEndpointA
     entry (type RPC_BINDING_HANDLE,
            pointer byaddr) /* to char(*) varz */
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingInqDynamicEndpointA');

 %dcl I_RpcBindingInqDynamicEndpoint char ext;
 %if UNICODE ^= '' %then  %do;
   %I_RpcBindingInqDynamicEndpoint='I_RpcBindingInqDynamicEndpointW';
 %end; %else %do;
   %I_RpcBindingInqDynamicEndpoint='I_RpcBindingInqDynamicEndpointA';
 %end;

 %end; %else %do;

 dcl I_RpcBindingInqDynamicEndpoint
     entry (type RPC_BINDING_HANDLE,
            pointer byaddr) /* to char(*) varz */
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingInqDynamicEndpoint');

 %end;

 dcl TRANSPORT_TYPE_CN   fixed bin(15) value('01'xn);
 dcl TRANSPORT_TYPE_DG   fixed bin(15) value('02'xn);
 dcl TRANSPORT_TYPE_LPC  fixed bin(15) value('04'xn);
 dcl TRANSPORT_TYPE_WMSG fixed bin(15) value('08'xn);

 dcl I_RpcBindingInqTransportType
     entry (type RPC_BINDING_HANDLE,
            fixed bin(31) byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingInqTransportType');

 define structure
   1 RPC_TRANSFER_SYNTAX,
    2 Uuid      type UUID,
    2 VersMajor unsigned fixed bin(16),
    2 VersMinor unsigned fixed bin(16) ;

 dcl I_RpcIfInqTransferSyntaxes
     entry (type RPC_IF_HANDLE,
            type RPC_TRANSFER_SYNTAX byaddr,
            fixed bin(31),
            fixed bin(31) byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcIfInqTransferSyntaxes');

 dcl I_UuidCreate
     entry (type UUID byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_UuidCreate');

 dcl I_RpcBindingCopy
     entry (type RPC_BINDING_HANDLE,
            type RPC_BINDING_HANDLE byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingCopy');

 dcl I_RpcBindingIsClientLocal
     entry (type RPC_BINDING_HANDLE,
            fixed bin(31) byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingIsClientLocal');

 dcl I_RpcBindingInqConnId
     entry (type RPC_BINDING_HANDLE,
            pointer byaddr,
            fixed bin (31) byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingInqConnId');

 dcl I_RpcSsDontSerializeContext
     entry ()
     RPCRTAPI RPC_ENTRY external('I_RpcSsDontSerializeContext');

 dcl I_RpcLaunchDatagramReceiveThread
     entry (pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcLaunchDatagramReceiveThread');

 dcl I_RpcServerRegisterForwardFunction
     entry (type RPC_FORWARD_FUNCTION byvalue optional)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerRegisterForwardFunction');

 dcl I_RpcConnectionInqSockBuffSize
     entry (fixed bin(31) byaddr,
            fixed bin(31) byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcConnectionInqSockBuffSize');

 dcl I_RpcConnectionSetSockBuffSize
     entry (fixed bin(31),
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcConnectionSetSockBuffSize');

 /* no linkage convention specified in original - assume stdcall! */
 define alias RPCLT_PDU_FILTER_FUNC
        entry (pointer,
               fixed bin(31),
               fixed bin(31))
        limited options (byvalue nodescriptor linkage(stdcall)) ;

 define alias RPC_SETFILTER_FUNC
        entry (type RPCLT_PDU_FILTER_FUNC)
        limited options (byvalue nodescriptor linkage(cdecl));

 %if WINNT = '' %then %do;
 dcl I_RpcServerStartListening
     entry (pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerStartListening');

 dcl I_RpcServerStopListening
     entry ()
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerStopListening');

 /* no linkage convention specified in original - assume stdcall! */
 define alias RPC_BLOCKING_FN
        entry (pointer,
               pointer,
               pointer)
        returns (type RPC_STATUS byvalue optional)
        limited options (byvalue nodescriptor linkage(stdcall)) ;

 dcl I_RpcBindingSetAsync
     entry (type RPC_BINDING_HANDLE,
            type RPC_BLOCKING_FN,
            fixed bin(31))
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcBindingSetAsync');

 dcl I_RpcSetThreadParams
     entry (fixed bin(31),
            pointer,
            pointer)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcSetThreadParams');

 dcl I_RpcWindowProc
     entry (pointer,
            fixed bin(31),
            fixed bin(31),
            fixed bin(31))
     returns (fixed bin(31) byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcWindowProc');

 dcl I_RpcServerUnregisterEndpointA
     entry (char(*) varz byaddr,
            char(*) varz byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUnregisterEndpointA');

 dcl I_RpcServerUnregisterEndpointW
     entry (WCHAR(*) varz byaddr,
            WCHAR(*) varz byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerUnregisterEndpointW');

 %dcl I_RpcServerUnregisterEndpoint char ext;
 %if UNICODE ^= '' %then %do;
   %I_RpcServerUnregisterEndpoint='I_RpcServerUnregisterEndpointW';
 %end; %else %do;
   %I_RpcServerUnregisterEndpoint='I_RpcServerUnregisterEndpointA';
 %end;
 %end; /* WINNT */

 dcl I_RpcServerInqTransportType
     entry (fixed bin(31) byaddr)
     returns (type RPC_STATUS byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcServerInqTransportType');

 dcl I_RpcMapWin32Status
     entry (type RPC_STATUS)
     returns (fixed bin(31) byvalue optional)
     RPCRTAPI RPC_ENTRY external('I_RpcMapWin32Status');

 %end; /* __RPCDCEP_H__ */
