 /*********************************************************************/
 /*                                                                   */
 /* Source File Name = SQLMON.CPY                                     */
 /*                                                                   */
 /* (C) COPYRIGHT International Business Machines Corp. 1993, 1997    */
 /* All Rights Reserved                                               */
 /* Licensed Materials - Property of IBM                              */
 /*                                                                   */
 /* US Government Users Restricted Rights - Use, duplication or       */
 /* disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
 /*                                                                   */
 /* Function = Include File defining:                                 */
 /*              Database System Monitor - Constants                  */
 /*              Database System Monitor - Structures                 */
 /*              Database System Monitor - Function Prototypes        */
 /*                                                                   */
 /* Operating System: Common C Include File                           */
 /*                                                                   */
 /* Notes:                                                            */
 /*   structures returned as output to the 'Get Snapshot' function,   */
 /*   'sqlmonss()' are of the form: 'sqlm_xxxx', for example:         */
 /*   sqlm_dbase.                                                     */
 /*                                                                   */
 /*   sqlm_xxxx_event structures are logged to a trace by DB2 Event   */
 /*   Monitors, which can be defined and activated using SQL          */
 /*   commands (CREATE EVENT MONITOR, SET EVENT MONITOR).             */
 /*                                                                   */
 /* PL/I Conversion note (Mark Yudkin, June 2000)                     */
 /*   Char fields in the structures have been defined as fixed length */
 /*   fields rather than nul-terminated char varz as this is what     */
 /*   DB2 actually returns (C programmers beware!)                    */
 /*                                                                   */
 /*********************************************************************/

 %dcl SQL_H_SQLMON char ext;
 %if SQL_H_SQLMON = '' %then %do;
 %SQL_H_SQLMON = 'Y'; /* Permit duplicate Includes */

 %dcl SQL_H_SQLSYSTM char ext;
 %if SQL_H_SQLSYSTM = '' %then %do;
 %include sqlsystm;   /* System dependent defines  */
 %end;

 %dcl #SQLCA_T_INC char ext;
 %if #SQLCA_T_INC = '' %then %do;
 %include sqlca_t;    /* SQL API - Communication Area */
 %end;

 %dcl SQL_H_SQLENV char ext;
 %if SQL_H_SQLENV = '' %then %do;
 %include sqlenv;     /* DB2 Environment commands     */
 %end;

 /*********************************************************************/
 /* Database System Monitor Version (version, server_version)         */
 /*********************************************************************/
 dcl SQLM_DBMON_VERSION1       fixed bin(31) value(1);
 dcl SQLM_DBMON_VERSION2       fixed bin(31) value(2);
 dcl SQLM_DBMON_VERSION5       fixed bin(31) value(3);
 dcl SQLM_DBMON_VERSION5_2     fixed bin(31) value(4);
 dcl SQLM_DBMON_VERSION6       fixed bin(31) value(5);
 dcl SQLM_DBMON_VERSION7       fixed bin(31) value(6);
 dcl SQLM_CURRENT_VERSION      fixed bin(31) value(SQLM_DBMON_VERSION7);

 /*********************************************************************/
 /* Snapshot requests (sqlm_obj_struct.obj_type in sqlma)             */
 /*********************************************************************/

 /* Database Manager snapshot */
 dcl SQLMA_DB2                   fixed bin(31) value(1);
                                 /* Database Manager information      */

 /* List of connections */
 dcl SQLMA_DBASE_APPLINFO        fixed bin(31) value(7);
                                 /* List of connections to a database */
 dcl SQLMA_APPLINFO_ALL          fixed bin(31) value(11);
                                 /* List of connections to DB2        */
 dcl SQLMA_DCS_APPLINFO_ALL      fixed bin(31) value(12);
                                 /* List of DDCS connections to DB2   */

 /* Database snapshot */
 dcl SQLMA_DBASE                 fixed bin(31) value(2);
                                 /* Database level information        */
 dcl SQLMA_DBASE_ALL             fixed bin(31) value(9);
                                 /* DB info for all active databases  */
 dcl SQLMA_DCS_DBASE             fixed bin(31) value(34);
                                 /* DCS Database level information    */
 dcl SQLMA_DCS_DBASE_ALL         fixed bin(31) value(35);
                                 /* DCS DB info for all active dbs    */
 dcl SQLMA_DBASE_REMOTE          fixed bin(31) value(37);
                                 /* remote access info for a database */
 dcl SQLMA_DBASE_REMOTE_ALL      fixed bin(31) value(38);
                                 /* remote access info for all DBs    */

 /* Application snapshot */
 dcl SQLMA_APPL_ALL              fixed bin(31) value(10);
                                 /* Appl level info - all connections */
 dcl SQLMA_APPL                  fixed bin(31) value(3);
                                 /* Appl level info - for appl_id     */
 dcl SQLMA_AGENT_ID              fixed bin(31) value(4);
                                 /* Appl level info - for appl-handle */
 dcl SQLMA_DBASE_APPLS           fixed bin(31) value(6);
                                 /* Appl level info - all conns to db */
 dcl SQLMA_DCS_APPL_ALL          fixed bin(31) value(30);
                                 /* DCS appl info - all connections   */
 dcl SQLMA_DCS_APPL              fixed bin(31) value(31);
                                 /* DCS appl info - for appl_id       */
 dcl SQLMA_DCS_APPL_HANDLE       fixed bin(31) value(32);
                                 /* DCS appl info - for appl-handle   */
 dcl SQLMA_DCS_DBASE_APPLS       fixed bin(31) value(33);
                                 /* DCS appl info - all cons to db    */
 dcl SQLMA_DBASE_APPLS_REMOTE    fixed bin(31) value(39);
                                 /* remote access info for an appl    */
 dcl SQLMA_APPL_REMOTE_ALL       fixed bin(31) value(40);
                                 /* remote access info for all appls  */

 /* Table snapshot */
 dcl SQLMA_DBASE_TABLES          fixed bin(31) value(5);
                                 /* Table related info for a database */

 /* Tablespace snapshot */
 dcl SQLMA_DBASE_TABLESPACES     fixed bin(31) value(13);
                                 /* Tablespace related info for dbase */

 /* Snapshot for locks */
 dcl SQLMA_APPL_LOCKS            fixed bin(31) value(20);
                                 /* List of locks held - for appl_id  */
 dcl SQLMA_APPL_LOCKS_AGENT_ID   fixed bin(31) value(21);
                              /* List of locks held - for appl-handle */
 dcl SQLMA_DBASE_LOCKS           fixed bin(31) value(8);
                                 /* List of locks - all appls for db  */

 /* Bufferpool snapshot */
 dcl SQLMA_DBASE_BUFFERPOOLS     fixed bin(31) value(22);
                                 /* Bufferpool info - for a database  */
 dcl SQLMA_BUFFERPOOLS_ALL       fixed bin(31) value(23);
                                 /* Bufferpool info - all bufferpools */

 /* Dynamic sql snapshot */
 dcl SQLMA_DYNAMIC_SQL           fixed bin(31) value(36);
                                 /* Dynamic SQL statement info        */

 /*********************************************************************/
 /* Snapshot output structure type identifiers                        */
 /*                                                                   */
 /* (info_type element in the sqlm_xxx structures that are returned   */
 /* in the sqlmonss() output buffer.)                                 */
 /*********************************************************************/

 dcl SQLM_DB2_SS              char value('1');
                              /* DB2 info (sqlm_db2)                  */
 dcl SQLM_FCM_SS              char value('E');
                              /* DB2 FCM info (sqlm_fcm)              */
 dcl SQLM_NODE_SS             char value('G');
                              /* DB2 FCM Node info (sqlm_fcm_node)    */
 dcl SQLM_APPLINFO_SS         char value('4');
                              /* Summary appl info (sqlm_applinfo)    */
 dcl SQLM_DCS_APPLINFO_SS     char value('A');
                              /* DCS appl info (sqlm_dcs_applinfo)    */
 dcl SQLM_DBASE_SS            char value('2');
                              /* DB info (sqlm_dbase)                 */
 dcl SQLM_TABLE_HEADER_SS     char value('5');
                              /* DB table info (sqlm_table_header)    */
 dcl SQLM_TABLE_SS            char value('6');
                              /* Table info (sqlm_table)              */
 dcl SQLM_DBASE_LOCK_SS       char value('7');
                              /* DB lock info (sqlm_dbase_lock)       */
 dcl SQLM_APPL_LOCK_SS        char value('8');
                              /* Appl lock info (sqlm_appl_lock)      */
 dcl SQLM_LOCK_SS             char value('9');
                              /* Lock info (sqlm_lock)                */
 dcl SQLM_TABLESPACE_HEADER_SS char value('B');
                              /* DB tspaces (sqlm_tablespace_header)  */
 dcl SQLM_TABLESPACE_SS       char value('C');
                              /* Tablespace info (sqlm_tablespace)    */
 dcl SQLM_APPL_SS             char value('3');
                              /* Appl info (sqlm_appl)                */
 dcl SQLM_DBASE_ROLLFWD_SS    char value('H');
                              /* Rollfwd info  (sqlm_rollfwd_info)    */
 dcl SQLM_DBASE_ROLLFWD_TS_SS char value('I');
                              /* Rollfwd tablespace information       */
                              /*               (sqlm_rollfwd_ts_info) */
 dcl SQLM_BUFFERPOOL_SS       char value('J');
                              /* Bufferpool info (sqlm_bufferpool)    */
 dcl SQLM_LOCK_WAIT_SS        char value('K');
                              /* Lock wait info (sqlm_lock_wait)      */
 dcl SQLM_STMT_SS             char value('L');
                              /* Statement info (sqlm_stmt)           */
 dcl SQLM_SUBSECTION_SS       char value('M');
                              /* Subsection info (sqlm_subsection)    */
 dcl SQLM_AGENT_SS            char value('N');
                              /* Agent info (sqlm_agent)              */
 dcl SQLM_DCS_APPL_SS         char value('O');
                              /* DCS appl info (sqlm_dcs_appl)        */
 dcl SQLM_DCS_APPLID_SS       char value('P');
                              /* DCS appl ident.(sqlm_dcs_applid_info)*/
 dcl SQLM_DCS_APPL_STATS_SS   char value('Q');
                          /* DCS appl stats.(sqlm_dcs_appl_snap_stats)*/
 dcl SQLM_APPL_XID_SS         char value('R');
                              /* 2PC transaction ID (sqlm_appl_xid)   */
 dcl SQLM_TPMON_INFO_SS       char value('S');
                              /* 3-tier client info (sqlm_tpmon_info) */
 dcl SQLM_DCS_STMT_SS         char value('T');
                              /* DCS statement info (sqlm_dcs_stmt)   */
 dcl SQLM_DCS_DBASE_SS        char value('U');
                              /* DCS database info (sqlm_dcs_dbase)   */
 dcl SQLM_COLLECTED_SS        char value('V');
                              /* Collected info    (sqlm_collected)   */
                              /* Used as input to the                 */
                              /* db2ConvToOldMonFormat api            */
 dcl SQLM_DBASE_REMOTE_SS     char value('W');
                              /* Remote datasource access info        */
 dcl SQLM_APPL_REMOTE_SS      char value('X');
                              /* Remote access info by application    */

 /*********************************************************************/
 /* stream type id                                                    */
 /*********************************************************************/
 dcl SQLM_STREAM_SNAPSHOT     fixed bin(31) value(1);
 dcl SQLM_STREAM_EVMON        fixed bin(31) value(2);

 /*********************************************************************/
 /* size constants                                                    */
 /*********************************************************************/

 dcl SQLM_APPLID_SZ               fixed bin(31) value(32);
                                  /* size of the application id       */
 dcl SQLM_SEQ_SZ                  fixed bin(31) value(4);
                                  /* sequence number size             */
 dcl SQLM_SH_IDENT_SZ             fixed bin(31) value(8);
                                  /* Small identifier size            */
 dcl SQLM_IDENT_SZ                fixed bin(31) value(20);
                                  /* General identifier size          */
 dcl SQLM_LG_IDENT_SZ             fixed bin(31) value(32);
                                  /* Long identifier size             */
 dcl SQLM_OBJECT_SZ               fixed bin(31) value(36);
                                  /* object size in sqlma structure   */
 dcl SQLM_DBPATH_SZ               fixed bin(31) value(256);
                                  /* Database Path size               */
 dcl SQLM_COMM_ADDR_SZ            fixed bin(31) value(32);
                                  /* Communication address size       */
 dcl SQLM_SERVERNAME_SZ           fixed bin(31) value(128);
                                  /* DJ server_name       @d138658rps */

 /*********************************************************************/
 /* Information group state switches (sqlmon and sqlmonss functions)  */
 /*********************************************************************/

 dcl SQLM_OFF              fixed bin(31) value(0);
                           /* Turn monitoring group OFF               */
 dcl SQLM_ON               fixed bin(31) value(1);
                           /* Turn monitoring group ON                */
 dcl SQLM_HOLD             fixed bin(31) value(2);
                           /* leave monitoring group in current state */

 /*********************************************************************/
 /* flag constant for sqlmrset()                                      */
 /*********************************************************************/
 dcl SQLM_UDB_DBASE              type sqluint32 value(0);
 dcl SQLM_UDB_ALL                type sqluint32 value(1);
 dcl SQLM_DCS_DBASE              type sqluint32 value(2);
 dcl SQLM_DCS_ALL                type sqluint32 value(3);
 dcl SQLM_APM                    type sqluint32 value(4);

 /*********************************************************************/
 /* Monitor switches                                                  */
 /*********************************************************************/

 dcl SQLM_UOW_SW                 fixed bin(31) value(0);
                                 /* Unit of Work information          */
 dcl SQLM_STATEMENT_SW           fixed bin(31) value(1);
                                 /* Statement information             */
 dcl SQLM_TABLE_SW               fixed bin(31) value(2);
                                 /* Table information                 */
 dcl SQLM_BUFFER_POOL_SW         fixed bin(31) value(3);
                                 /* Buffer Pool information           */
 dcl SQLM_LOCK_SW                fixed bin(31) value(4);
                                 /* Lock information                  */
 dcl SQLM_SORT_SW                fixed bin(31) value(5);
                                 /* Sort information                  */

 dcl SQLM_NUM_GROUPS             fixed bin(31) value(6);
                                 /* number of monitor switches        */

 /*********************************************************************/
 /* Statement Types (stmt_type)                                       */
 /*********************************************************************/
 dcl SQLM_STATIC                 fixed bin(31) value(1);
                                 /* Static statement                  */
 dcl SQLM_DYNAMIC                fixed bin(31) value(2);
                                 /* Dynamic statement                 */
 dcl SQLM_NON_STMT               fixed bin(31) value(3);
                                 /* Operation other than an SQL stmt  */
 dcl SQLM_STMT_TYPE_UNKNOWN      fixed bin(31) value(4);
                                 /* Unknown statement type            */

 /*********************************************************************/
 /* Statement Operation Types (stmt_operation)                        */
 /*********************************************************************/
 /* SQL operations */
 dcl SQLM_PREPARE                fixed bin(31) value(1);
                                 /* SQL Prepare                       */
 dcl SQLM_EXECUTE                fixed bin(31) value(2);
                                 /* SQL Execute                       */
 dcl SQLM_EXECUTE_IMMEDIATE      fixed bin(31) value(3);
                                 /* SQL Execute Immediate             */
 dcl SQLM_OPEN                   fixed bin(31) value(4);
                                 /* SQL Open                          */
 dcl SQLM_FETCH                  fixed bin(31) value(5);
                                 /* SQL Fetch                         */
 dcl SQLM_CLOSE                  fixed bin(31) value(6);
                                 /* SQL Close                         */
 dcl SQLM_DESCRIBE               fixed bin(31) value(7);
                                 /* SQL Describe                      */
 dcl SQLM_STATIC_COMMIT          fixed bin(31) value(8);
                                 /* SQL Static Commit                 */
 dcl SQLM_STATIC_ROLLBACK        fixed bin(31) value(9);
                                 /* SQL Static Rollback               */
 dcl SQLM_FREE_LOCATOR           fixed bin(31) value(10);
                                 /* SQL Free Locator                  */
 dcl SQLM_PREP_COMMIT            fixed bin(31) value(11);
                                 /* Prepare to commit (2-phase commit)*/
 dcl SQLM_CALL                   fixed bin(31) value(12);
                                 /* Call a stored procedure           */
 dcl SQLM_SELECT                 fixed bin(31) value(15);
                                 /* SELECT statement                  */
 dcl SQLM_PREP_OPEN              fixed bin(31) value(16);
                                 /* Prep. and open (DB2 Connect only) */
 dcl SQLM_PREP_EXEC              fixed bin(31) value(17);
                                 /* Prep. and execute (DB2 Connect)   */
 dcl SQLM_COMPILE                fixed bin(31) value(18);
                                 /* Compile (DB2 Connect only)        */

 /* non-SQL operations */
 dcl SQLM_RUNSTATS               fixed bin(31) value(20);
                                 /* Runstats                          */
 dcl SQLM_REORG                  fixed bin(31) value(21);
                                 /* Reorg                             */
 dcl SQLM_REBIND                 fixed bin(31) value(22);
                                 /* Rebind package                    */
 dcl SQLM_REDIST                 fixed bin(31) value(23);
                                 /* Redistribute                      */
 dcl SQLM_GETTA                  fixed bin(31) value(24);
                                 /* Get Table Authorization           */
 dcl SQLM_GETAA                  fixed bin(31) value(25);
                                 /* Get Administrative Authorization  */

 /*********************************************************************/
 /* Table Types (table_type)                                          */
 /*********************************************************************/
 dcl SQLM_USER_TABLE             fixed bin(31) value(1);
                                 /* User table                        */
 dcl SQLM_DROPPED_TABLE          fixed bin(31) value(2);
                                 /* Dropped user table                */
 dcl SQLM_TEMP_TABLE             fixed bin(31) value(3);
                                 /* Temporary table                   */
 dcl SQLM_CATALOG_TABLE          fixed bin(31) value(4);
                                 /* System Catalog table              */
 dcl SQLM_REORG_TABLE            fixed bin(31) value(5);
                                 /* Reorg table                       */

 /*********************************************************************/
 /* lock modes (lock_mode)                                            */
 /*********************************************************************/

 dcl SQLM_LNON                fixed bin(31) value(0);
                              /*  No Lock                             */
 dcl SQLM_LOIS                fixed bin(31) value(1);
                              /*  Intention Share Lock                */
 dcl SQLM_LOIX                fixed bin(31) value(2);
                              /*  Intention Exclusive Lock            */
 dcl SQLM_LOOS                fixed bin(31) value(3);
                              /*  Share Lock                          */
 dcl SQLM_LSIX                fixed bin(31) value(4);
                              /*  Share with Intention Exclusive Lock */
 dcl SQLM_LOOX                fixed bin(31) value(5);
                              /*  Exclusive Lock                      */
 dcl SQLM_LOIN                fixed bin(31) value(6);
                              /*  Intent None (For Dirty Read)        */
 dcl SQLM_LOOZ                fixed bin(31) value(7);
                              /*  Super Exclusive Lock                */
 dcl SQLM_LOOU                fixed bin(31) value(8);
                              /*  Update Lock                         */
 dcl SQLM_LONS                fixed bin(31) value(9);
                              /*  Next-key Share Lock                 */
 dcl SQLM_LONX                fixed bin(31) value(10);
                              /*  Next-key Exclusive Lock             */
 dcl SQLM_LOOW                fixed bin(31) value(11);
                              /*  Weak Exclusive Lock                 */
 dcl SQLM_LONW                fixed bin(31) value(12);
                              /*  Next-key Weak Exclusive Lock        */

 /*********************************************************************/
 /* subsection status (ss_status)                                     */
 /*********************************************************************/

 dcl SQLM_SSEXEC           fixed bin(31) value(1);
                           /* Subsection executing                    */
 dcl SQLM_SSTQ_WAIT_TO_RCV fixed bin(31) value(2);
                           /* Waiting to receive data on a tablequeue */
 dcl SQLM_SSTQ_WAIT_TO_SEND fixed bin(31) value(3);
                           /* Waiting to send data on a tablequeue    */
 dcl SQLM_SSCOMPLETED      fixed bin(31) value(4);
                           /* Subsection execution is completed       */

 /*********************************************************************/
 /* application status (appl_status)                                  */
 /*********************************************************************/

 dcl SQLM_CONNECTPEND                  fixed bin(31) value(1);
                                       /* connect pending             */
 dcl SQLM_CONNECTED                    fixed bin(31) value(2);
                                       /* connect completed           */
 dcl SQLM_UOWEXEC                      fixed bin(31) value(3);
                                       /* UOW executing               */
 dcl SQLM_UOWWAIT                      fixed bin(31) value(4);
                                       /* UOW waiting                 */
 dcl SQLM_LOCKWAIT                     fixed bin(31) value(5);
                                       /* lock wait                   */
 dcl SQLM_COMMIT_ACT                   fixed bin(31) value(6);
                                       /* commit active               */
 dcl SQLM_ROLLBACK_ACT                 fixed bin(31) value(7);
                                       /* rollback active             */
 dcl SQLM_RECOMP                       fixed bin(31) value(8);
                                       /* recompiling a plan          */
 dcl SQLM_COMP                         fixed bin(31) value(9);
                                       /* compiling a SQL statement   */
 dcl SQLM_INTR                         fixed bin(31) value(10);
                                       /* request interrupted         */
 dcl SQLM_DISCONNECTPEND               fixed bin(31) value(11);
                                       /* disconnect pending          */
 dcl SQLM_TPREP                        fixed bin(31) value(12);
                                       /* Prepared transaction        */
 dcl SQLM_THCOMT                       fixed bin(31) value(13);
                                       /* heuristically committed     */
 dcl SQLM_THABRT                       fixed bin(31) value(14);
                                       /* heuristically rolled back   */
 dcl SQLM_TEND                         fixed bin(31) value(15);
                                       /* Transaction ended           */
 dcl SQLM_CREATE_DB                    fixed bin(31) value(16);
                                       /* Creating Database           */
 dcl SQLM_RESTART                      fixed bin(31) value(17);
                                       /* Restarting a Database       */
 dcl SQLM_RESTORE                      fixed bin(31) value(18);
                                       /* Restoring a Database        */
 dcl SQLM_BACKUP                       fixed bin(31) value(19);
                                       /* Performing a Backup         */
 dcl SQLM_LOAD                         fixed bin(31) value(20);
                                       /* Performing a fast load      */
 dcl SQLM_UNLOAD                       fixed bin(31) value(21);
                                       /* Performing a fast unload    */
 dcl SQLM_IOERROR_WAIT                 fixed bin(31) value(22);
                                       /* Wait to disable tablespace  */
 dcl SQLM_QUIESCE_TABLESPACE           fixed bin(31) value(23);
                                       /* Quiescing a tablespace      */
 dcl SQLM_WAITFOR_REMOTE               fixed bin(31) value(24);
                                       /* Waiting for remote node     */
 dcl SQLM_REMOTE_RQST                  fixed bin(31) value(25);
                               /* Pending results from remote request */

 /*********************************************************************/
 /* DCS application status (dcs_appl_status)                          */
 /*********************************************************************/

 dcl SQLM_DCS_CONNECTPEND_OUTBOUND   fixed bin(31) value(101);
                                     /* connect to host db pending    */
 dcl SQLM_DCS_UOWWAIT_OUTBOUND       fixed bin(31) value(102);
                                     /* gateway waiting for reply     */
                                     /*   from host database          */
 dcl SQLM_DCS_UOWWAIT_INBOUND        fixed bin(31) value(103);
                                     /* conn. to host db established  */
                                     /* or gateway waiting for request*/

 /*********************************************************************/
 /* Concentrator agent statuses                                       */
 /*********************************************************************/
 dcl SQLM_AGENT_ASSOCIATED           fixed bin(31) value(1);
                                     /* agent associated with appl    */
 dcl SQLM_AGENT_NOT_ASSOCIATED       fixed bin(31) value(2);
                                     /* agent not assoc with appl     */

 /*********************************************************************/
 /* database status (db_status)                                       */
 /*********************************************************************/
 dcl SQLM_DB_ACTIVE                    fixed bin(31) value(0);
                                       /* Database is active          */
 dcl SQLM_DB_QUIESCE_PEND              fixed bin(31) value(1);
                                       /* Quiesce is pending for DB   */
 dcl SQLM_DB_QUIESCED                  fixed bin(31) value(2);
                                       /* Database has been quiesced  */
 dcl SQLM_DB_ROLLFWD                   fixed bin(31) value(3);
                                       /* DB in Database rollforward  */

 /*********************************************************************/
 /* rollforward types (rf_type)                                       */
 /*********************************************************************/
 dcl SQLM_ROLLFWD_TYP_DB       fixed bin(31) value(0);
                               /* Database rollforward                */
 dcl SQLM_ROLLFWD_TYP_TSPACE   fixed bin(31) value(1);
                               /* DB tablespace (on-line) rollforward */
 dcl SQLM_NO_ROLLFWD           fixed bin(31) value(2);
                               /* No rollforward in progress          */

 /*********************************************************************/
 /* Rollforward status (rf_status)                                    */
 /*********************************************************************/
 dcl SQLM_ROLLFWD_STATUS_REDO   fixed bin(31) value(0);
                                /* REDO phase in progress             */
 dcl SQLM_ROLLFWD_STATUS_UNDO   fixed bin(31) value(1);
                                /* UNDO phase in progress             */
 dcl SQLM_ROLLFWD_STATUS_SUCCESS fixed bin(31) value(2);
                                /* Successfuly completed on this node */
 dcl SQLM_ROLLFWD_STATUS_ERROR  fixed bin(31) value(3);
                                /* Error occurred on this node        */
 dcl SQLM_ROLLFWD_STATUS_USR_INTR fixed bin(31) value(4);
                                /* User intervention required         */


 /*********************************************************************/
 /* database manager status  (db2_status)                             */
 /*********************************************************************/

 dcl SQLM_DB2_ACTIVE                   fixed bin(31) value(0);
                                       /* DB2 is active               */
 dcl SQLM_DB2_QUIESCE_PEND             fixed bin(31) value(1);
                                       /* Quiesce is pending for DB2  */
 dcl SQLM_DB2_QUIESCED                 fixed bin(31) value(2);
                                       /* DB2 has been quiesced       */

 /*********************************************************************/
 /* UOW completion status (uow_comp_status)                           */
 /*********************************************************************/

 dcl SQLM_UOWCOMMIT          fixed bin(31) value(1);
                             /* UOW issued a commit                   */
 dcl SQLM_UOWROLLBACK        fixed bin(31) value(2);
                             /* UOW issued a rollback                 */
 dcl SQLM_UOWDEADLOCK        fixed bin(31) value(3);
                             /* UOW was rolled back due to a deadlock */
 dcl SQLM_UOWABEND           fixed bin(31) value(4);
                             /* UOW was rolled back due to an abend   */
 dcl SQLM_APPL_END           fixed bin(31) value(5);
                             /* application normal termination        */
 dcl SQLM_UOWLOCKTIMEOUT     fixed bin(31) value(6);
                             /* UOW was rolled back from lock timeout */
 dcl SQLM_UOWUNKNOWN         fixed bin(31) value(7);
                             /* Returned for flushed events           */

 /*********************************************************************/
 /* lock object type (lock_object_type)                               */
 /*********************************************************************/

 dcl SQLM_TABLE_LOCK             fixed bin(31) value(1);
                                 /* table lock type                   */
 dcl SQLM_ROW_LOCK               fixed bin(31) value(2);
                                 /* table row lock type               */
 dcl SQLM_INTERNAL_LOCK          fixed bin(31) value(3);
                                 /* Internal lock type                */
 dcl SQLM_TABLESPACE_LOCK        fixed bin(31) value(4);
                                 /* Tablespace lock type              */
 dcl SQLM_EOT_LOCK               fixed bin(31) value(5);
                                 /* end of table lock                 */
 dcl SQLM_KEYVALUE_LOCK          fixed bin(31) value(6);
                                 /* key value lock                    */
 dcl SQLM_SYSBOOT_LOCK           fixed bin(31) value(7);
                                 /* Internal lock on the sysboot table*/
 dcl SQLM_INTERNALP_LOCK         fixed bin(31) value(8);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALV_LOCK         fixed bin(31) value(9);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALS_LOCK         fixed bin(31) value(10);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALJ_LOCK         fixed bin(31) value(11);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALL_LOCK         fixed bin(31) value(12);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALC_LOCK         fixed bin(31) value(13);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALB_LOCK         fixed bin(31) value(14);
                                 /* Internal lock   (for internal use)*/
 dcl SQLM_INTERNALO_LOCK         fixed bin(31) value(15);
                                 /* Internal lock   (for internal use)*/

 /*********************************************************************/
 /* lock status (lock_status)                                         */
 /*********************************************************************/

 dcl SQLM_LRBGRNT                       fixed bin(31) value(1);
                                        /*  Granted State             */
 dcl SQLM_LRBCONV                       fixed bin(31) value(2);
                                        /*  Converting state          */

 /*********************************************************************/
 /* client communications protocols (client_protocol)                 */
 /*********************************************************************/
 dcl SQLM_PROT_APPC    char value(SQL_PROTOCOL_APPC);  /* appc        */
 dcl SQLM_PROT_NETBIOS char value(SQL_PROTOCOL_NETB);  /* netbios     */
 dcl SQLM_PROT_APPN    char value(SQL_PROTOCOL_APPN);  /* appn        */
 dcl SQLM_PROT_TCPIP   char value(SQL_PROTOCOL_TCPIP); /* tcp/ip      */
 dcl SQLM_PROT_CPIC    char value(SQL_PROTOCOL_CPIC);/*APPC using CPIC*/
 dcl SQLM_PROT_IPXSPX  char value(SQL_PROTOCOL_IPXSPX);/* ipx/spx     */
 dcl SQLM_PROT_LOCAL   char value(SQL_PROTOCOL_LOCAL); /* local client*/
 dcl SQLM_PROT_NPIPE   char value(SQL_PROTOCOL_NPIPE); /* Named pipe  */


 /*********************************************************************/
 /* Operating Systems (client_platform and server_platform)           */
 /*********************************************************************/
 dcl SQLM_PLATFORM_UNKNOWN              fixed bin(31) value(0);
                                        /* Unknown platform           */
 dcl SQLM_PLATFORM_OS2                  fixed bin(31) value(1);
                                        /* OS/2                       */
 dcl SQLM_PLATFORM_DOS                  fixed bin(31) value(2);
                                        /* DOS                        */
 dcl SQLM_PLATFORM_WINDOWS              fixed bin(31) value(3);
                                        /* Windows                    */
 dcl SQLM_PLATFORM_AIX                  fixed bin(31) value(4);
                                        /* AIX                        */
 dcl SQLM_PLATFORM_NT                   fixed bin(31) value(5);
                                        /* NT                         */
 dcl SQLM_PLATFORM_HP                   fixed bin(31) value(6);
                                        /* HP                         */
 dcl SQLM_PLATFORM_SUN                  fixed bin(31) value(7);
                                        /* Sun                        */
 dcl SQLM_PLATFORM_MVS_DRDA             fixed bin(31) value(8);
                                        /* MVS (client via DRDA)      */
 dcl SQLM_PLATFORM_AS400_DRDA           fixed bin(31) value(9);
                                        /* AS400 (client via DRDA)    */
 dcl SQLM_PLATFORM_VM_DRDA              fixed bin(31) value(10);
                                        /* VM (client via DRDA)       */
 dcl SQLM_PLATFORM_VSE_DRDA             fixed bin(31) value(11);
                                        /* VSE (client via DRDA)      */
 dcl SQLM_PLATFORM_UNKNOWN_DRDA         fixed bin(31) value(12);
                                        /* Unknown DRDA Client        */
 dcl SQLM_PLATFORM_SNI                  fixed bin(31) value(13);
                                        /* Siemens Nixdorf            */
 dcl SQLM_PLATFORM_MAC                  fixed bin(31) value(14);
                                        /* Macintosh Client           */
 dcl SQLM_PLATFORM_WINDOWS95            fixed bin(31) value(15);
                                        /* Windows 95                 */
 dcl SQLM_PLATFORM_SCO                  fixed bin(31) value(16);
                                        /* SCO                        */
 dcl SQLM_PLATFORM_SGI                  fixed bin(31) value(17);
                                        /* Silicon Graphic            */
 dcl SQLM_PLATFORM_LINUX                fixed bin(31) value(18);
                                        /* Linux                      */
 dcl SQLM_PLATFORM_DYNIX                fixed bin(31) value(19);
                                        /* DYNIX/ptx                  */
 dcl SQLM_PLATFORM_AIX64                fixed bin(31) value(20);
                                        /* AIX 64 bit                 */
 dcl SQLM_PLATFORM_SUN64                fixed bin(31) value(21);
                                        /* Sun 64 bit                 */
 dcl SQLM_PLATFORM_HP64                 fixed bin(31) value(22);
                                        /* HP 64 bit                  */
 dcl SQLM_PLATFORM_NT64                 fixed bin(31) value(23);
                                        /* NT 64 bit                  */
 dcl SQLM_PLATFORM_LINUX390             fixed bin(31) value(24);
                                        /* Linux for S/390            */
 dcl SQLM_PLATFORM_LINUXPPC             fixed bin(31) value(27);
                                        /* Linux for PPC              */

 /*********************************************************************/
 /* Operating System Application Priority Type (appl_priority_type)   */
 /*********************************************************************/
 dcl SQLM_FIXED_PRIORITY         fixed bin(31) value(1);
                                 /* Remains unchanged over time       */
 dcl SQLM_DYNAMIC_PRIORITY       fixed bin(31) value(2);
                                 /* Recalculated by OS based on usage */

 /*********************************************************************/
 /* Event Monitor Record Type Identifiers                             */
 /*   (sqlm_event_rec_header.type)                                    */
 /*                                                                   */
 /* Used to read the records in a trace produced by an Event Monitor  */
 /*********************************************************************/
 dcl SQLM_EVENT_DB               fixed bin(31) value(1);
                                 /* Database Event                    */
 dcl SQLM_EVENT_CONN             fixed bin(31) value(2);
                                 /* Connection Event                  */
 dcl SQLM_EVENT_TABLE            fixed bin(31) value(3);
                                 /* Table Event                       */
 dcl SQLM_EVENT_STMT             fixed bin(31) value(4);
                                 /* Statement Event                   */
 dcl SQLM_EVENT_STMTTEXT         fixed bin(31) value(5);
                                 /* Dynamic Statement Text (OBSOLETE) */
 dcl SQLM_EVENT_XACT             fixed bin(31) value(6);
                                 /* Transaction Event                 */
 dcl SQLM_EVENT_DEADLOCK         fixed bin(31) value(7);
                                 /* Deadlock Event                    */
 dcl SQLM_EVENT_DLCONN           fixed bin(31) value(8);
                                 /* Deadlock Connection Event         */
 dcl SQLM_EVENT_TABLESPACE       fixed bin(31) value(9);
                                 /* Tablespace Event                  */
 dcl SQLM_EVENT_DBHEADER         fixed bin(31) value(10);
                                 /* Database Header Event             */
 dcl SQLM_EVENT_START            fixed bin(31) value(11);
                                 /* Event monitor start Event         */
 dcl SQLM_EVENT_CONNHEADER       fixed bin(31) value(12);
                                 /* Connection Header Event           */
 dcl SQLM_EVENT_OVERFLOW         fixed bin(31) value(13);
                                 /* Overflow Event                    */
 dcl SQLM_EVENT_BUFFERPOOL       fixed bin(31) value(14);
                                 /* Bufferpool Event                  */
 dcl SQLM_EVENT_SUBSECTION       fixed bin(31) value(15);
                                 /* Subsection Event (MPP systems)    */
 dcl SQLM_EVENT_LOG_HEADER       fixed bin(31) value(16);
                                 /* Log header event                  */
 dcl SQLM_EVENT_MAX              fixed bin(31) value(16);
                                 /* Must be set to the largest value  */
                                 /* in the list                       */

 /*********************************************************************/
 /* Event Monitor Byte Order Identifiers (byte_order)                 */
 /*********************************************************************/
 dcl SQLM_LITTLE_ENDIAN          fixed bin(31) value(0);
                                 /* Little endian server              */
 dcl SQLM_BIG_ENDIAN             fixed bin(31) value(-1);
                                 /* Big endian server                 */

 /*********************************************************************/
 /* Database Monitor Error Constants (sqlcode)                        */
 /*********************************************************************/
 dcl SQLM_RC_INV_PTR          fixed bin(31) value(-1601);
                              /* Parameter is a NULL pointer          */
 dcl SQLM_RC_INV_OBJ_TYPE     fixed bin(31) value(-1602);
                              /* invalid obj_type in sqlma struct     */
 dcl SQLM_RC_NOT_SPECIFIED    fixed bin(31) value(-1603);
                              /* dbname/appl_id not specified in sqlma*/
 dcl SQLM_RC_NOT_NULL_TERM    fixed bin(31) value(-1604);
                              /* dbname/appl_id not NULL terminated   */
 dcl SQLM_RC_DBNOACT          fixed bin(31) value(1605);
                              /* database is not active               */
 dcl SQLM_RC_BUFFER_FULL      fixed bin(31) value(1606);
                              /* DBMON buffer area is full            */
 dcl SQLM_RC_NOMEM            fixed bin(31) value(-1607);
                              /* not enough working memory for DBMON  */
 dcl SQLM_RC_DUPLICATE_DB     fixed bin(31) value(1608);
                              /* duplicate database aliases           */
 dcl SQLM_RC_REMOTE_DB        fixed bin(31) value(-1609);
                              /* cannot monitor remote databases      */
 dcl SQLM_RC_INV_VALUE        fixed bin(31) value(-1610);
                              /* invalid value for input parameter    */
 dcl SQLM_RC_NO_DATA          fixed bin(31) value(1611);
                              /* No data returned by Database Monitor */
 dcl SQLM_RC_TOO_MANY_OBJECTS fixed bin(31) value(-1623);
                              /* Too many objects for this request.   */
 dcl SQLM_RC_MULTIPLE_NODES   fixed bin(31) value(-1624);
                              /* Databases in a sqlmonsz or sqlmonss  */
                              /* call reside at different nodes.      */

 /*********************************************************************/
 /* FCM Connection Status (connection_status)                         */
 /*********************************************************************/
 dcl SQLM_FCM_CONNECT_INACTIVE         fixed bin(31) value(0);
                                       /* No current connection       */
 dcl SQLM_FCM_CONNECT_ACTIVE           fixed bin(31) value(1);
                                       /* Connection is active        */
 dcl SQLM_FCM_CONNECT_CONGESTED        fixed bin(31) value(2);
                                       /* Connection is congested     */

 /*********************************************************************/
 /* Database location relative to snapshot application (db_location)  */
 /*********************************************************************/
 dcl SQLM_LOCAL                        fixed bin(31) value(1);
                                       /* Same node as snapshot       */
 dcl SQLM_REMOTE                       fixed bin(31) value(2);
                                       /* DB is on a different node   */

 /*********************************************************************/
 /* Node location definitions                                         */
 /*********************************************************************/
 dcl SQLM_CURRENT_NODE                 fixed bin(31) value(-1 );
 dcl SQLM_ALL_NODES                    fixed bin(31) value(-2 );

 /*********************************************************************/
 /*********************************************************************/
 /* Database System Monitor data structures                           */
 /*********************************************************************/
 /*********************************************************************/

 /*********************************************************************/
 /* Timestamp                                                         */
 /*********************************************************************/
 define structure
   1 sqlm_timestamp,
     2 seconds  type sqluint32,/* GMT time in seconds since Jan.1,1970*/
     2 microsec type sqluint32;/* microseconds, range 0 to 999999     */

 /*********************************************************************/
 /* Elpased time (for CPU times)                                      */
 /*********************************************************************/
 define structure
   1 sqlm_time,
     2 seconds  type sqluint32,/* elapsed seconds */
     2 microsec type sqluint32;
                /* elapsed microseconds, range 0 to 999999 */

 /*********************************************************************/
 /* Snapshot Monitoring defines (db2GetSnapshot, etc) for             */
 /* self-describing datastream                                        */
 /* Used by all versions of snapshot v6 and later.                    */
 /*********************************************************************/
 define structure
   1 sqlm_header_info,
     2 size    type sqluint32,
     2 type    type sqluint16,
     2 element type sqluint16;

 define structure
   1 sqlm_header_data,
     2 header  type sqlm_header_info,
     2 data(1) char(1);

 /*********************************************************************/
 /* Defines for snapshot output stream format                         */
 /*********************************************************************/
 dcl SQLM_STREAM_STATIC_FORMAT  fixed bin (31) value(0);
 dcl SQLM_STREAM_DYNAMIC_FORMAT fixed bin (31) value(1);

 /*********************************************************************/
 /* This structure can be used for parsing through the self           */
 /* describing snapshot data stream. All data in the snapshot and     */
 /* event monitor hiearchy have this header.                          */
 /*                                                                   */
 /*         size:         The size (in bytes) of the data stored in   */
 /*                       the data element.                           */
 /*                                                                   */
 /*         type:         The type of element stored in the data.     */
 /*                       See the defines of the form SQLM_TYP_...    */
 /*                       for values.                                 */
 /*                       Note that the type HEADER refers to         */
 /*                       "logical" types meaning they do not         */
 /*                       represent specific data elements, but       */
 /*                       rather logical groupings of elements.       */
 /*                                                                   */
 /*      element:         The element that data holds.                */
 /*                       See the defines of the form SQLM_ELM_...    */
 /*                       for values                                  */
 /*                                                                   */
 /*         data:         The data itself.                            */
 /*                                                                   */
 /*********************************************************************/
 /*                                                                   */
 /* Snapshot data is returned in a heirarchtical fashion.             */
 /* At the bottom of the hiearchy, are the individual data elements.  */
 /* Higher up in the hiearchy, are the logical groupings of data      */
 /* elements. What follows is a description of the logical data       */
 /* hiearchy. Shown by element values.                                */
 /*                                                                   */
 /* SQLM_ELM_COLLECTED - Top level logical data member, contains      */
 /*                      information relevant to the entire snapshot, */
 /*                      and indicates how many second tier snapshot  */
 /*                      logical data elements will follow.           */
 /* SQLM_ELM_DB2             - DB2 instance information               */
 /* SQLM_ELM_FCM             - FCM information                        */
 /* SQLM_ELM_FCM_NODE        - FCM node information                   */
 /* SQLM_ELM_APPL_INFO       - application identifiern                */
 /* SQLM_ELM_APPL            - application information                */
 /* SQLM_ELM_DCS_APPL_INFO   - dcs application identifier             */
 /* SQLM_ELM_DCS_APPL        - dcs application information            */
 /* SQLM_ELM_DCS_STMT        - dcs statement information              */
 /* SQLM_ELM_AGENT           - agent information                      */
 /* SQLM_ELM_LOCK_WAIT       - lock waiting information               */
 /* SQLM_ELM_DCS_DBASE       - dcs database information               */
 /* SQLM_ELM_DBASE           - database information                   */
 /* SQLM_ELM_ROLLFORWARD     - database rollforward information       */
 /* SQLM_ELM_TABLE_LIST      - database wide table information        */
 /* SQLM_ELM_TABLE           - table information                      */
 /* SQLM_ELM_LOCK            - lock information                       */
 /* SQLM_ELM_TABLESPACE_LIST - database wide tablespace info          */
 /* SQLM_ELM_TABLESPACE      - tablespace information                 */
 /* SQLM_ELM_BUFFERPOOL      - bufferpool information                 */
 /* SQLM_ELM_DYNSQL          - dynamic sql statement information      */
 /* SQLM_ELM_DYNSQL_LIST     - dynamic sql statement list             */
 /* SQLM_ELM_SWITCHES        - a list of the switch state on the      */
 /*                            server                                 */
 /* SQLM_ELM_APPL_LOCK_LIST  - a list of application locks            */
 /* SQLM_ELM_DB_LOCK_LIST    - a list of database locks               */
 /* SQLM_ELM_STMT            - statement information                  */
 /* SQLM_ELM_SUBSECTION      - subsection information                 */
 /*                                                                   */
 /* SQLM_ELM_COLLECTED --- DB2 - FCM - FCM_NODE                       */
 /*                            +- SWITCH_LIST +- UOW_SW               */
 /*                                           +- STATEMENT_SW         */
 /*                                           +- LOCK_SW              */
 /*                                           +- BUFFPOOL_SW          */
 /*                                           +- TABLE_SW             */
 /*                                           +- SORT_SW              */
 /*                     +- APPL_INFO                                  */
 /*                     +- DCS_APPL_INFO                              */
 /*                     +- DCS_APPL -- STMT                           */
 /*                                 +- DCS_APPL_INFO                  */
 /*                     +- APPL -- AGENT                              */
 /*                             +- APPLINFO                           */
 /*                             +- LOCK_WAIT                          */
 /*                             +- STMT -  SUBSECTION - AGENT   (MPP) */
 /*                                     +- AGENT                (SMP) */
 /*                     +- DCS_DBASE                                  */
 /*                     +- DBASE - ROLLFORWARD - TABLESPACE           */
 /*                     +- TABLE_LIST - TABLE                         */
 /*                     +- APPL_LOCK_LIST +-- LOCK                    */
 /*                                       +- LOCK_WAIT - LOCK         */
 /*                     +- DB_LOCK_LIST +- LOCK                       */
 /*                                     +- LOCK_WAIT - LOCK           */
 /*                                     +- APPL_LOCK_LIST             */
 /*                     +- TABLESPACE_LIST - TABLESPACE               */
 /*                     +- BUFFERPOOL                                 */
 /*                     +- DYNSQL_LIST - DYNSQL                       */
 /*                     +- SWITCH_LIST +- UOW_SW                      */
 /*                                    +- STATEMENT_SW                */
 /*                                    +- LOCK_SW                     */
 /*                                    +- BUFFPOOL_SW                 */
 /*                                    +- TABLE_SW                    */
 /*                                    +- SORT_SW                     */
 /*                     +- DBASE_REMOTE                               */
 /*                     +- APPL_REMOTE                                */
 /*                                                                   */
 /*********************************************************************/
 /*                                                                   */
 /* Event monitor data is returned as a series of records of the      */
 /* following types:                                                  */
 /* SQLM_ELM_EVENT_DB         - database event                        */
 /* SQLM_ELM_EVENT_CONN       - connection event                      */
 /* SQLM_ELM_EVENT_TABLE      - table event                           */
 /* SQLM_ELM_EVENT_STMT       - statement event                       */
 /* SQLM_ELM_EVENT_XACT       - transaction event                     */
 /* SQLM_ELM_EVENT_DEADLOCK   - deadlock event                        */
 /* SQLM_ELM_EVENT_DLCONN     - deadlocked connection event           */
 /* SQLM_ELM_EVENT_TABLESPACE - tablespace event                      */
 /* SQLM_ELM_EVENT_DBHEADER   - database header event                 */
 /* SQLM_ELM_EVENT_START      - event monitor start                   */
 /* SQLM_ELM_EVENT_CONNHEADER - connection header event               */
 /* SQLM_ELM_EVENT_OVERFLOW   - overflow event                        */
 /* SQLM_ELM_EVENT_BUFFERPOOL - bufferpool event                      */
 /* SQLM_ELM_EVENT_SUBSECTION - subsection event                      */
 /* SQLM_ELM_EVENT_LOG_HEADER - log start event                       */
 /*                                                                   */
 /*********************************************************************/

 /*********************************************************************/
 /* Monitor data types (reside in the "type" field of the             */
 /* sqlm_header_data                                                  */
 /*********************************************************************/

 /**************** Logical data elements ******************************/

 dcl SQLM_TYPE_HEADER     fixed bin(31) value(1);
                          /* The header monitor types, which          */
                          /* indicate what type of record is being    */
                          /* looked at when encountering an element   */
                          /* of this type, in indicates an element    */
                          /* composed of multible base data elements  */

 /**************** Base data elements**********************************/
 dcl SQLM_TYPE_STRING     fixed bin(31) value(50);
                          /* variable length string                   */
 dcl SQLM_TYPE_U8BIT      fixed bin(31) value(51);
                          /* unsigned 8 bit value                     */
 dcl SQLM_TYPE_8BIT       fixed bin(31) value(52);
                          /* signed 8 bit value                       */
 dcl SQLM_TYPE_16BIT      fixed bin(31) value(53);
                          /* signed 16 bit numeric value              */
 dcl SQLM_TYPE_U16BIT     fixed bin(31) value(54);
                          /* unsigned 16 bit numeric value            */
 dcl SQLM_TYPE_32BIT      fixed bin(31) value(55);
                          /* signed 32 bit numeric value              */
 dcl SQLM_TYPE_U32BIT     fixed bin(31) value(56);
                          /* unsigned 32 bit numeric value            */
 dcl SQLM_TYPE_U64BIT     fixed bin(31) value(57);
                          /* unsigned 64 bit value numeric value      */
 dcl SQLM_TYPE_64BIT      fixed bin(31) value(58);
                          /* signed 64 bit value                      */

 /*********************************************************************/
 /* Monitor data elements (reside in the "element" field of the       */
 /* sqlm_header_data                                                  */
 /*********************************************************************/
 /* The following group of defines relate to logical groupings of     */
 /* snapshot information. They do not represent data elements,        */
 /* but rather groups of data elements                                */
 /*********************************************************************/
 dcl SQLM_ELM_DB2         fixed bin(31) value(1);
                          /* DB2 instance information                 */
 dcl SQLM_ELM_FCM         fixed bin(31) value(2);
                          /* FCM information                          */
 dcl SQLM_ELM_FCM_NODE    fixed bin(31) value(3);
                          /* FCM node information                     */
 dcl SQLM_ELM_APPL_INFO   fixed bin(31) value(4);
                          /* application identifiern                  */
 dcl SQLM_ELM_APPL        fixed bin(31) value(5);
                          /* application information                  */
 dcl SQLM_ELM_DCS_APPL_INFO fixed bin(31) value(6);
                          /* dcs application identifier               */
 dcl SQLM_ELM_DCS_APPL    fixed bin(31) value(7);
                          /* dcs application information              */
 dcl SQLM_ELM_DCS_STMT    fixed bin(31) value(8);
                          /* dcs statement information                */
 dcl SQLM_ELM_SUBSECTION  fixed bin(31) value(9);
                          /* subsection related information           */
 dcl SQLM_ELM_AGENT       fixed bin(31) value(10);
                          /* agent information                        */
 dcl SQLM_ELM_LOCK_WAIT   fixed bin(31) value(11);
                          /* lock waiting information                 */
 dcl SQLM_ELM_DCS_DBASE   fixed bin(31) value(12);
                          /* dcs database information                 */
 dcl SQLM_ELM_DBASE       fixed bin(31) value(13);
                          /* database information                     */
 dcl SQLM_ELM_ROLLFORWARD fixed bin(31) value(14);
                          /* database rollforward information         */
 dcl SQLM_ELM_TABLE       fixed bin(31) value(15);
                          /* table information                        */
 dcl SQLM_ELM_LOCK        fixed bin(31) value(16);
                          /* lock information                         */
 dcl SQLM_ELM_TABLESPACE  fixed bin(31) value(17);
                          /* tablespace information                   */
 dcl SQLM_ELM_BUFFERPOOL  fixed bin(31) value(18);
                          /* bufferpool information                   */
 dcl SQLM_ELM_DYNSQL      fixed bin(31) value(19);
                          /* dynamic sql statement information        */
 dcl SQLM_ELM_COLLECTED   fixed bin(31) value(20);
                          /* First element in any data stream         */
 dcl SQLM_ELM_SWITCH_LIST fixed bin(31) value(21);
                          /* List of switches                         */
 dcl SQLM_ELM_UOW_SW      fixed bin(31) value(22);
                          /* unit of work switch                      */
 dcl SQLM_ELM_STATEMENT_SW fixed bin(31) value(23);
                          /* statement switch                         */
 dcl SQLM_ELM_TABLE_SW    fixed bin(31) value(24);
                          /* table switch                             */
 dcl SQLM_ELM_BUFFPOOL_SW fixed bin(31) value(25);
                          /* bufferpool switch                        */
 dcl SQLM_ELM_LOCK_SW     fixed bin(31) value(26);
                          /* lock switch                              */
 dcl SQLM_ELM_SORT_SW     fixed bin(31) value(27);
                          /* sort switch                              */
 dcl SQLM_ELM_TABLE_LIST  fixed bin(31) value(28);
                          /* database wide table information          */
 dcl SQLM_ELM_TABLESPACE_LIST fixed bin(31) value(29);
                          /* database wide tablespace information     */
 dcl SQLM_ELM_DYNSQL_LIST fixed bin(31) value(30);
                          /* List of dynamic sql statements           */
 dcl SQLM_ELM_APPL_LOCK_LIST fixed bin(31) value(31);
                          /* List of locks for an application         */
 dcl SQLM_ELM_DB_LOCK_LIST fixed bin(31) value(32);
                          /* List of locks for a db                   */
 dcl SQLM_ELM_STMT        fixed bin(31) value(33);
                          /* Statement related information            */
 dcl SQLM_ELM_DBASE_REMOTE fixed bin(31) value(34);
                          /* remote data source information by DB     */
 dcl SQLM_ELM_APPL_REMOTE fixed bin(31) value(35);
                          /* remote data source information by Appl   */
 dcl SQLM_ELM_APPL_ID_INFO fixed bin(31) value(36);
                          /* application ID information               */
 dcl SQLM_ELM_STMT_TRANSMISSIONS fixed bin(31) value(37);
                          /* transmission level info for a stmt  */
 dcl SQLM_MAX_LOGICAL_ELEMENT fixed bin(31) value(37);
                          /* This value should equal the largest of   */
                          /* the logical grouping elements            */

 /*********************************************************************/
 /* The following group of defines relate to logical groupings of     */
 /* event monitor information. They do not represent data elements,   */
 /* but rather groups of data elements                                */
 /*********************************************************************/
 dcl SQLM_ELM_EVENT_DB        fixed bin(31) value(100);
                              /* database event                       */
 dcl SQLM_ELM_EVENT_CONN      fixed bin(31) value(101);
                              /* connection event                     */
 dcl SQLM_ELM_EVENT_TABLE     fixed bin(31) value(102);
                              /* table event                          */
 dcl SQLM_ELM_EVENT_STMT      fixed bin(31) value(103);
                              /* statement event                      */
 dcl SQLM_ELM_EVENT_XACT      fixed bin(31) value(104);
                              /* transaction event                    */
 dcl SQLM_ELM_EVENT_DEADLOCK  fixed bin(31) value(105);
                              /* deadlock event                       */
 dcl SQLM_ELM_EVENT_DLCONN    fixed bin(31) value(106);
                              /* deadlocked connection event          */
 dcl SQLM_ELM_EVENT_TABLESPACE fixed bin(31) value(107);
                              /* tablespace event                     */
 dcl SQLM_ELM_EVENT_DBHEADER  fixed bin(31) value(108);
                              /* database header event                */
 dcl SQLM_ELM_EVENT_START     fixed bin(31) value(109);
                              /* event monitor start                  */
 dcl SQLM_ELM_EVENT_CONNHEADER fixed bin(31) value(110);
                              /* connection header event              */
 dcl SQLM_ELM_EVENT_OVERFLOW  fixed bin(31) value(111);
                              /* overflow event                       */
 dcl SQLM_ELM_EVENT_BUFFERPOOL fixed bin(31) value(112);
                              /* bufferpool event                     */
 dcl SQLM_ELM_EVENT_SUBSECTION fixed bin(31) value(113);
                              /* subsection event                     */
 dcl SQLM_ELM_EVENT_LOG_HEADER fixed bin(31) value(114);
                              /* log header event                     */

 /*********************************************************************/
 /* Timestamps are returned as logic data elements with seconds and   */
 /* microseconds returned in seperate base elements                   */
 /*********************************************************************/
 dcl SQLM_ELM_TIME_STAMP      fixed bin(31) value(200);
                              /* Timestamp                            */
 dcl SQLM_ELM_STATUS_CHANGE_TIME fixed bin(31) value(201);
                              /* last appl status change time         */
 dcl SQLM_ELM_GW_CON_TIME     fixed bin(31) value(202);
                              /* Connect start date/time              */
 dcl SQLM_ELM_PREV_UOW_STOP_TIME fixed bin(31) value(203);
                              /* prev commit or rollback time         */
 dcl SQLM_ELM_UOW_START_TIME  fixed bin(31) value(204);
                              /* time transaction execution started   */
 dcl SQLM_ELM_UOW_STOP_TIME   fixed bin(31) value(205);
                              /* unit-of-work stop time               */
 dcl SQLM_ELM_STMT_START      fixed bin(31) value(206);
                              /* when received from client at the     */
                              /* gateway                              */
 dcl SQLM_ELM_STMT_STOP       fixed bin(31) value(207);
                              /* when sent to client from the gateway */
 dcl SQLM_ELM_LAST_RESET      fixed bin(31) value(208);
                              /* Last snapshot reset date and time    */
 dcl SQLM_ELM_DB2START_TIME   fixed bin(31) value(209);
                              /* DB2START timestamp                   */
 dcl SQLM_ELM_DB_CONN_TIME    fixed bin(31) value(210);
                              /* Time of 1st database connection      */
 dcl SQLM_ELM_LAST_BACKUP     fixed bin(31) value(211);
                              /* Date/Time of Last Backup             */
 dcl SQLM_ELM_LOCK_WAIT_START_TIME fixed bin(31) value(212);
                              /* Time when lock wait entered          */
 dcl SQLM_ELM_APPL_CON_TIME   fixed bin(31) value(213);
                              /* Connect start date/time              */
 dcl SQLM_ELM_CONN_COMPLETE_TIME fixed bin(31) value(214);
                              /* Connect complete date/time           */
 dcl SQLM_ELM_DISCONN_TIME    fixed bin(31) value(215);
                              /* Time of last database disconnect     */
 dcl SQLM_ELM_EVENT_TIME      fixed bin(31) value(216);
                              /* Table Event Date and Time            */
 dcl SQLM_ELM_START_TIME      fixed bin(31) value(217);
                              /* Time event started                   */
 dcl SQLM_ELM_STOP_TIME       fixed bin(31) value(218);
                              /* SQL statement operation stop time    */
 dcl SQLM_ELM_RF_TIMESTAMP    fixed bin(31) value(219);
                              /* Time of Log record currently         */
                              /* processed                            */
 dcl SQLM_ELM_CONN_TIME       fixed bin(31) value(220);
                              /* Time of 1st database connection      */
 dcl SQLM_ELM_FIRST_OVERFLOW_TIME fixed bin(31) value(221);
                              /* The time of the first overflow       */
 dcl SQLM_ELM_LAST_OVERFLOW_TIME fixed bin(31) value(222);
                              /* The time of the last overflow        */
 dcl SQLM_ELM_GW_EXEC_TIME    fixed bin(31) value(223);
                              /* Time spent on gateway processing     */
 dcl SQLM_ELM_AGENT_USR_CPU_TIME fixed bin(31) value(224);
                              /* total user CPU time of application   */
 dcl SQLM_ELM_AGENT_SYS_CPU_TIME fixed bin(31) value(225);
                              /* total application system cpu time    */
 dcl SQLM_ELM_SS_USR_CPU_TIME fixed bin(31) value(226);
                              /* total user CPU time (sec.microsec)   */
 dcl SQLM_ELM_SS_SYS_CPU_TIME fixed bin(31) value(227);
                              /* total system CPU time                */
                              /* (sec.microsec)                       */
 dcl SQLM_ELM_USER_CPU_TIME   fixed bin(31) value(228);
                              /* Total user CPU time of appl agents   */
 dcl SQLM_ELM_TOTAL_EXEC_TIME fixed bin(31) value(229);
                              /* Total execution time                 */
 dcl SQLM_ELM_SWITCH_SET_TIME fixed bin(31) value(230);
                              /* Time the switch was set              */
 dcl SQLM_ELM_ELAPSED_EXEC_TIME  fixed bin(31) value(231);
                                 /* Elapsed execution time            */
 dcl SQLM_ELM_SELECT_TIME        fixed bin(31) value(232);
                                 /* Aggregate response time to queries*/
 dcl SQLM_ELM_INSERT_TIME        fixed bin(31) value(233);
                                 /* Aggregate response time to inserts*/
 dcl SQLM_ELM_UPDATE_TIME        fixed bin(31) value(234);
                                 /* Aggregate response time to updates*/
 dcl SQLM_ELM_DELETE_TIME        fixed bin(31) value(235);
                                 /* Aggregate response time to deletes*/
 dcl SQLM_ELM_CREATE_NICKNAME_TIME fixed bin(31) value(236);
                                 /* Aggregate response time to create */
                                 /* nicknames                         */
 dcl SQLM_ELM_PASSTHRU_TIME      fixed bin(31) value(237);
                                 /*Aggregate response time to passthru*/
 dcl SQLM_ELM_STORED_PROC_TIME   fixed bin(31) value(238);
                                 /* Aggregate response time to stored */
                                 /* procedures                        */
 dcl SQLM_ELM_REMOTE_LOCK_TIME   fixed bin(31) value(239);
                                 /* Aggregate responce time to lock   */
                                 /* remote table                      */
 dcl SQLM_ELM_NETWORK_TIME_TOP   fixed bin(31) value(240);
                                 /* High water mark for network time  */
 dcl SQLM_ELM_NETWORK_TIME_BOTTOM fixed bin(31) value(241);
                                 /* Low water mark for network time   */
 dcl SQLM_MAX_TIME_STAMP         fixed bin(31) value(241);
                                 /* Maximum timestamp value           */

 /*********************************************************************/
 /* Actual database monitor elements                                  */
 /*********************************************************************/
 dcl SQLM_ELM_SECONDS         fixed bin(31) value(300);
                              /* GMT time in seconds since Jan.1,1970 */
 dcl SQLM_ELM_MICROSEC        fixed bin(31) value(301);
                              /* microseconds, range 0 to 999999      */
 dcl SQLM_ELM_AGENT_ID        fixed bin(31) value(302);
                              /* used for requests based on           */
                              /* appl-handle                          */
 dcl SQLM_ELM_SERVER_DB2_TYPE fixed bin(31) value(303);
                              /* Server DB2 Type (defined in          */
                              /* sqlutil.cpy)                         */
 dcl SQLM_ELM_SERVER_PRDID    fixed bin(31) value(304);
                              /* product/version on server            */
 dcl SQLM_ELM_SERVER_NNAME    fixed bin(31) value(305);
                              /* Config NNAME of server               */
 dcl SQLM_ELM_SERVER_INSTANCE_NAME fixed bin(31) value(306);
                              /* instance name of DB2                 */
 dcl SQLM_ELM_NODE_NUMBER     fixed bin(31) value(307);
                              /* Node sending data                    */
 dcl SQLM_ELM_TIME_ZONE_DISP  fixed bin(31) value(308);
                              /* Diff. in secs between GMT and local  */
                              /* time                                 */
 dcl SQLM_ELM_SERVER_VERSION  fixed bin(31) value(309);
                              /* Version of server returning data     */
 dcl SQLM_ELM_APPL_STATUS     fixed bin(31) value(310);
                              /* Application Status                   */
 dcl SQLM_ELM_CODEPAGE_ID     fixed bin(31) value(311);
                              /* codepage/CCSID identifier            */
 dcl SQLM_ELM_STMT_TEXT       fixed bin(31) value(312);
                              /* Statement text                       */
 dcl SQLM_ELM_APPL_NAME       fixed bin(31) value(313);
                              /* Application Program Name             */
 dcl SQLM_ELM_APPL_ID         fixed bin(31) value(314);
                              /* Application Id                       */
 dcl SQLM_ELM_SEQUENCE_NO     fixed bin(31) value(315);
                              /* application id sequence number       */
 dcl SQLM_ELM_AUTH_ID         fixed bin(31) value(316);
                              /* Authorization Id                     */
 dcl SQLM_ELM_CLIENT_NNAME    fixed bin(31) value(317);
                              /* Config NNAME of client               */
 dcl SQLM_ELM_CLIENT_PRDID    fixed bin(31) value(318);
                              /* product/version on client            */
 dcl SQLM_ELM_INPUT_DB_ALIAS  fixed bin(31) value(319);
                              /* Input Database Alias                 */
 dcl SQLM_ELM_CLIENT_DB_ALIAS fixed bin(31) value(320);
                              /* Client Database Alias                */
 dcl SQLM_ELM_DB_NAME         fixed bin(31) value(321);
                              /* Database name                        */
 dcl SQLM_ELM_DB_PATH         fixed bin(31) value(322);
                              /* Database Path                        */
 dcl SQLM_ELM_NUM_ASSOC_AGENTS fixed bin(31) value(323);
                              /* Number of agents associated with     */
                              /* this application                     */
 dcl SQLM_ELM_COORD_NODE_NUM  fixed bin(31) value(324);
                              /* Coordinating node number             */
 dcl SQLM_ELM_AUTHORITY_LVL   fixed bin(31) value(325);
                              /* User authorizations                  */
 dcl SQLM_ELM_EXECUTION_ID    fixed bin(31) value(326);
                              /* login ID                             */
 dcl SQLM_ELM_CORR_TOKEN      fixed bin(31) value(327);
                              /* DRDA AS Correlation Token            */
 dcl SQLM_ELM_CLIENT_PID      fixed bin(31) value(328);
                              /* Process/thread ID of client appl.    */
 dcl SQLM_ELM_CLIENT_PLATFORM fixed bin(31) value(329);
                              /* Platform of client application       */
 dcl SQLM_ELM_CLIENT_PROTOCOL fixed bin(31) value(330);
                              /* Communications protocol of client    */
 dcl SQLM_ELM_COUNTRY_CODE    fixed bin(31) value(331);
                              /* Country code of client application   */
 dcl SQLM_ELM_COORD_AGENT_PID fixed bin(31) value(332);
                              /* Coordinator agent process/thread id  */
 dcl SQLM_ELM_GW_DB_ALIAS     fixed bin(31) value(333);
                              /* gateway  Database Alias              */
 dcl SQLM_ELM_OUTBOUND_COMM_ADDRESS fixed bin(31) value(334);
                              /* Outb. comm. address                  */
 dcl SQLM_ELM_INBOUND_COMM_ADDRESS fixed bin(31) value(335);
                              /* Inbound comm. address                */
 dcl SQLM_ELM_OUTBOUND_COMM_PROTOCOL fixed bin(31) value(336);
                              /* Outbound comm. protocol              */
 dcl SQLM_ELM_DCS_DB_NAME     fixed bin(31) value(337);
                              /* DCS Database name                    */
 dcl SQLM_ELM_HOST_DB_NAME    fixed bin(31) value(338);
                              /* Host Database name                   */
 dcl SQLM_ELM_HOST_PRDID      fixed bin(31) value(339);
                              /* Host Product id                      */
 dcl SQLM_ELM_OUTBOUND_APPL_ID fixed bin(31) value(340);
                              /* Outbound LUWID                       */
 dcl SQLM_ELM_OUTBOUND_SEQUENCE_NO fixed bin(31) value(341);
                              /* Outbound sequence #                  */
 dcl SQLM_ELM_DCS_APPL_STATUS fixed bin(31) value(342);
                              /* Status of DCS application            */
 dcl SQLM_ELM_HOST_CCSID      fixed bin(31) value(343);
                              /* Host database Coded Char Set ID      */
 dcl SQLM_ELM_OUTPUT_STATE    fixed bin(31) value(344);
                              /* Switch output state                  */
 dcl SQLM_ELM_COUNT           fixed bin(31) value(345);
                              /* The number of overflows              */
 dcl SQLM_ELM_ROWS_SELECTED   fixed bin(31) value(346);
                              /* # of rows selected                   */
 dcl SQLM_ELM_SQL_STMTS       fixed bin(31) value(347);
                              /* # of sql stmts attempted             */
 dcl SQLM_ELM_FAILED_SQL_STMTS fixed bin(31) value(348);
                              /* # of Failed SQL stmts                */
 dcl SQLM_ELM_COMMIT_SQL_STMTS fixed bin(31) value(349);
                              /* # of Commit SQL stmts                */
 dcl SQLM_ELM_ROLLBACK_SQL_STMTS fixed bin(31) value(350);
                              /* # of Rollback SQL stmts              */
 dcl SQLM_ELM_INBOUND_BYTES_RECEIVED fixed bin(31) value(351);
                              /* inbound # of bytes received          */
 dcl SQLM_ELM_OUTBOUND_BYTES_SENT fixed bin(31) value(352);
                              /* outbound # of bytes sent             */
 dcl SQLM_ELM_OUTBOUND_BYTES_RECEIVED fixed bin(31) value(353);
                              /* outbound # of bytes received         */
 dcl SQLM_ELM_INBOUND_BYTES_SENT fixed bin(31) value(354);
                              /* inbound # of bytes sent              */
 dcl SQLM_ELM_STMT_OPERATION  fixed bin(31) value(355);
                              /* most recent SQL stmt operation       */
 dcl SQLM_ELM_SECTION_NUMBER  fixed bin(31) value(356);
                              /* most recent SQL stmt section number  */
 dcl SQLM_ELM_LOCK_NODE       fixed bin(31) value(357);
                              /* Node on which app waited for lock    */
 dcl SQLM_ELM_CREATOR         fixed bin(31) value(358);
                              /* package creator                      */
 dcl SQLM_ELM_PACKAGE_NAME    fixed bin(31) value(359);
                              /* package name                         */
 dcl SQLM_ELM_APPL_IDLE_TIME  fixed bin(31) value(360);
                              /* time (seconds) since the application */
                              /* last completed a statement           */
 dcl SQLM_ELM_OPEN_CURSORS    fixed bin(31) value(361);
                              /* currently open cursors               */
 dcl SQLM_ELM_UOW_COMP_STATUS fixed bin(31) value(362);
                              /* previous uow completion status       */
 dcl SQLM_ELM_SEQUENCE_NO_HOLDING_LK fixed bin(31) value(363);
                              /* seq no. holding lock                 */
 dcl SQLM_ELM_ROLLED_BACK_AGENT_ID fixed bin(31) value(364);
                              /* Application handle                   */
 dcl SQLM_ELM_ROLLED_BACK_APPL_ID fixed bin(31) value(365);
                              /* victim's appl id                     */
 dcl SQLM_ELM_ROLLED_BACK_SEQUENCE_NO fixed bin(31) value(366);
                              /* victim's seq no.                     */
 dcl SQLM_ELM_XID             fixed bin(31) value(367);
                              /* XID                                  */
 dcl SQLM_ELM_TPMON_CLIENT_USERID fixed bin(31) value(368);
                              /* TP Monitor client user ID            */
 dcl SQLM_ELM_TPMON_CLIENT_WKSTN fixed bin(31) value(369);
                              /* TP Monitor client workstation        */
 dcl SQLM_ELM_TPMON_CLIENT_APP fixed bin(31) value(370);
                              /* TP Monitor client app. name          */
 dcl SQLM_ELM_TPMON_ACC_STR   fixed bin(31) value(371);
                              /* Client accounting string             */
 dcl SQLM_ELM_QUERY_COST_ESTIMATE fixed bin(31) value(372);
                              /* SQL compiler estim. in TIMERONS      */
 dcl SQLM_ELM_QUERY_CARD_ESTIMATE fixed bin(31) value(373);
                              /* SQL compiler estim. number of rows   */
 dcl SQLM_ELM_FETCH_COUNT     fixed bin(31) value(374);
                              /* total number of rows fetched         */
 dcl SQLM_ELM_GW_TOTAL_CONS   fixed bin(31) value(375);
                              /* connects since db activations        */
 dcl SQLM_ELM_GW_CUR_CONS     fixed bin(31) value(376);
                              /* appls currently connected            */
 dcl SQLM_ELM_GW_CONS_WAIT_HOST fixed bin(31) value(377);
                              /* appls waiting for host's reply       */
 dcl SQLM_ELM_GW_CONS_WAIT_CLIENT fixed bin(31) value(378);
                              /* appls waiting for client to send     */
 dcl SQLM_ELM_GW_CONNECTIONS_TOP fixed bin(31) value(379);
                              /* high water mark for concurrent       */
                              /* connections                          */
 dcl SQLM_ELM_SORT_HEAP_ALLOCATED fixed bin(31) value(380);
                              /* Sort heap currently allocated        */
 dcl SQLM_ELM_POST_THRESHOLD_SORTS fixed bin(31) value(381);
                              /* # sorts started after heap           */
                              /* threshold exceeded                   */
 dcl SQLM_ELM_PIPED_SORTS_REQUESTED fixed bin(31) value(382);
                              /* # of piped sorts requested by        */
                              /* by RDS to SLS                        */
 dcl SQLM_ELM_PIPED_SORTS_ACCEPTED fixed bin(31) value(383);
                              /* # of piped sorts accepted by SLS     */
 dcl SQLM_ELM_DL_CONNS        fixed bin(31) value(384);
                              /* number of conns deadlocked           */
 dcl SQLM_ELM_REM_CONS_IN     fixed bin(31) value(385);
                              /* Remote connects to target DB2        */
 dcl SQLM_ELM_REM_CONS_IN_EXEC fixed bin(31) value(386);
                              /* Remote connects to target exec DB2   */
 dcl SQLM_ELM_LOCAL_CONS      fixed bin(31) value(387);
                              /* Current Local Connections            */
 dcl SQLM_ELM_LOCAL_CONS_IN_EXEC fixed bin(31) value(388);
                              /* Local connects curr exec in DB2      */
 dcl SQLM_ELM_CON_LOCAL_DBASES fixed bin(31) value(389);
                              /* Local databases w/current connects   */
 dcl SQLM_ELM_AGENTS_REGISTERED fixed bin(31) value(390);
                              /* Number of agents registered in DB2   */
 dcl SQLM_ELM_AGENTS_WAITING_ON_TOKEN fixed bin(31) value(391);
                              /* # of agents waiting on a token       */
 dcl SQLM_ELM_DB2_STATUS      fixed bin(31) value(392);
                              /* status of the DB2 instance           */
 dcl SQLM_ELM_AGENTS_REGISTERED_TOP fixed bin(31) value(393);
                              /* agents_registered high water mark    */
 dcl SQLM_ELM_AGENTS_WAITING_TOP fixed bin(31) value(394);
                              /* agents_waiting high water mark       */
 dcl SQLM_ELM_COMM_PRIVATE_MEM fixed bin(31) value(395);
                              /* Committed Private Memory             */
 dcl SQLM_ELM_IDLE_AGENTS     fixed bin(31) value(396);
                              /* number of unassigned agents in       */
                              /* pool                                 */
 dcl SQLM_ELM_AGENTS_FROM_POOL fixed bin(31) value(397);
                              /* # agents assigned from pool          */
 dcl SQLM_ELM_AGENTS_CREATED_EMPTY_POOL fixed bin(31) value(398);
                              /* # agents created because the         */
                              /* pool was empty                       */
 dcl SQLM_ELM_AGENTS_TOP      fixed bin(31) value(399);
                              /* agents high water mark               */
 dcl SQLM_ELM_COORD_AGENTS_TOP fixed bin(31) value(400);
                              /*coordinating agents high water mark   */
 dcl SQLM_ELM_MAX_AGENT_OVERFLOWS fixed bin(31) value(401);
                              /* # of attempts to exceed the          */
                              /* MAXAGENTS configuration parameter.   */
 dcl SQLM_ELM_AGENTS_STOLEN   fixed bin(31) value(402);
                              /* # agents stolen                      */
 dcl SQLM_ELM_PRODUCT_NAME    fixed bin(31) value(403);
                              /* Product Name                         */
 dcl SQLM_ELM_COMPONENT_ID    fixed bin(31) value(404);
                              /* Product Identificiation              */
 dcl SQLM_ELM_SERVICE_LEVEL   fixed bin(31) value(405);
                              /* Service Level                        */
 dcl SQLM_ELM_POST_THRESHOLD_HASH_JOINS fixed bin(31) value(406);
                              /* # hash joins started after           */
                              /* heap threshold exceeded              */
 dcl SQLM_ELM_BUFF_FREE       fixed bin(31) value(407);
                              /* # of FCM buffers free                */
 dcl SQLM_ELM_BUFF_FREE_BOTTOM fixed bin(31) value(408);
                              /* low water mark of buffers free       */
 dcl SQLM_ELM_MA_FREE         fixed bin(31) value(409);
                              /* # of FCM message anchors free        */
 dcl SQLM_ELM_MA_FREE_BOTTOM  fixed bin(31) value(410);
                              /* low water mark of anchors free       */
 dcl SQLM_ELM_CE_FREE         fixed bin(31) value(411);
                              /* # of FCM connection entries free     */
 dcl SQLM_ELM_CE_FREE_BOTTOM  fixed bin(31) value(412);
                              /* low water mark of free CEs           */
 dcl SQLM_ELM_RB_FREE         fixed bin(31) value(413);
                              /* # of FCM request blocks free         */
 dcl SQLM_ELM_RB_FREE_BOTTOM  fixed bin(31) value(414);
                              /* low water mark of free RBs           */
 dcl SQLM_ELM_NUMBER_NODES    fixed bin(31) value(415);
                              /* # of FCM node structures which       */
                              /* follow.                              */
 dcl SQLM_ELM_CONNECTION_STATUS fixed bin(31) value(416);
                              /* FCM Connnection status to node       */
 dcl SQLM_ELM_TOTAL_BUFFERS_SENT fixed bin(31) value(417);
                              /* Total # of buffers sent              */
 dcl SQLM_ELM_TOTAL_BUFFERS_RCVD fixed bin(31) value(418);
                              /* Total # of buffers received          */
 dcl SQLM_ELM_LOCKS_HELD      fixed bin(31) value(419);
                              /* Locks currently held                 */
 dcl SQLM_ELM_LOCK_WAITS      fixed bin(31) value(420);
                              /* Lock waits since 1st connect         */
 dcl SQLM_ELM_LOCK_WAIT_TIME  fixed bin(31) value(421);
                              /* time spent waiting on locks          */
 dcl SQLM_ELM_LOCK_LIST_IN_USE fixed bin(31) value(422);
                              /* lock list memory in use              */
 dcl SQLM_ELM_DEADLOCKS       fixed bin(31) value(423);
                              /* number of deadlocks                  */
 dcl SQLM_ELM_LOCK_ESCALS     fixed bin(31) value(424);
                              /* number of lock escalations           */
 dcl SQLM_ELM_X_LOCK_ESCALS   fixed bin(31) value(425);
                              /* number of x-lock excalations         */
 dcl SQLM_ELM_LOCKS_WAITING   fixed bin(31) value(426);
                              /* agents currently waiting on locks    */
 dcl SQLM_ELM_TOTAL_SORTS     fixed bin(31) value(427);
                              /* total number of sorts                */
 dcl SQLM_ELM_TOTAL_SORT_TIME fixed bin(31) value(428);
                              /* elapsed time spent in sorts          */
 dcl SQLM_ELM_SORT_OVERFLOWS  fixed bin(31) value(429);
                              /* number of sort overflows             */
 dcl SQLM_ELM_ACTIVE_SORTS    fixed bin(31) value(430);
                              /* sorts currently active               */
 dcl SQLM_ELM_POOL_DATA_L_READS fixed bin(31) value(431);
                              /* pool data logical reads              */
 dcl SQLM_ELM_POOL_DATA_P_READS fixed bin(31) value(432);
                              /* pool data reads                      */
 dcl SQLM_ELM_POOL_DATA_WRITES fixed bin(31) value(433);
                              /* pool data writes                     */
 dcl SQLM_ELM_POOL_INDEX_L_READS fixed bin(31) value(434);
                              /* pool index logical reads             */
 dcl SQLM_ELM_POOL_INDEX_P_READS fixed bin(31) value(435);
                              /* pool index reads                     */
 dcl SQLM_ELM_POOL_INDEX_WRITES fixed bin(31) value(436);
                              /* pool index writes                    */
 dcl SQLM_ELM_POOL_READ_TIME  fixed bin(31) value(437);
                              /* Buff pool read time                  */
 dcl SQLM_ELM_POOL_WRITE_TIME fixed bin(31) value(438);
                              /* Buff pool write time                 */
 dcl SQLM_ELM_FILES_CLOSED    fixed bin(31) value(439);
                              /* files closed                         */
 dcl SQLM_ELM_DYNAMIC_SQL_STMTS fixed bin(31) value(440);
                              /* # of Dynamic SQL stmts               */
 dcl SQLM_ELM_STATIC_SQL_STMTS fixed bin(31) value(441);
                              /* # of Static SQL stmts                */
 dcl SQLM_ELM_SELECT_SQL_STMTS fixed bin(31) value(442);
                              /* # of SQL select stmts                */
 dcl SQLM_ELM_DDL_SQL_STMTS   fixed bin(31) value(443);
                              /* # of data definition lang. stmts     */
 dcl SQLM_ELM_UID_SQL_STMTS   fixed bin(31) value(444);
                              /* # of update/insert/delete stmts      */
 dcl SQLM_ELM_INT_AUTO_REBINDS fixed bin(31) value(445);
                              /* # of Auto Rebinds                    */
 dcl SQLM_ELM_INT_ROWS_DELETED fixed bin(31) value(446);
                              /* # of Casc. Deletes                   */
 dcl SQLM_ELM_INT_ROWS_UPDATED fixed bin(31) value(447);
                              /* # of Set Null Deletes                */
 dcl SQLM_ELM_INT_COMMITS     fixed bin(31) value(448);
                              /* # of int. Commits                    */
 dcl SQLM_ELM_INT_ROLLBACKS   fixed bin(31) value(449);
                              /* # of int. Rollbacks                  */
 dcl SQLM_ELM_INT_DEADLOCK_ROLLBACKS fixed bin(31) value(450);
                              /* # of Rollbacks due to deadlock       */
 dcl SQLM_ELM_ROWS_DELETED    fixed bin(31) value(451);
                              /* # of Rows Deleted                    */
 dcl SQLM_ELM_ROWS_INSERTED   fixed bin(31) value(452);
                              /* # of Rows Inserted                   */
 dcl SQLM_ELM_ROWS_UPDATED    fixed bin(31) value(453);
                              /* # of Rows Updated                    */
 dcl SQLM_ELM_BINDS_PRECOMPILES fixed bin(31) value(454);
                              /* # of Binds/Precomps                  */
 dcl SQLM_ELM_LOCKS_HELD_TOP  fixed bin(31) value(455);
                              /* max locks held in transaction        */
 dcl SQLM_ELM_NUM_NODES_IN_DB2_INSTANCE fixed bin(31) value(456);
                              /* 1 if SERIAL                          */
 dcl SQLM_ELM_TOTAL_CONS      fixed bin(31) value(457);
                              /* total number of connects             */
 dcl SQLM_ELM_APPLS_CUR_CONS  fixed bin(31) value(458);
                              /* Appls currently connected            */
 dcl SQLM_ELM_APPLS_IN_DB2     fixed bin(31) value(459);
                              /* Appls executing in the DB2           */
 dcl SQLM_ELM_SEC_LOG_USED_TOP fixed bin(31) value(460);
                              /* Maximum secondary log space used     */
 dcl SQLM_ELM_TOT_LOG_USED_TOP fixed bin(31) value(461);
                              /* Maximum total log space used         */
 dcl SQLM_ELM_SEC_LOGS_ALLOCATED fixed bin(31) value(462);
                              /* Number of secondary logs allocated   */
 dcl SQLM_ELM_POOL_ASYNC_INDEX_READS fixed bin(31) value(463);
                              /* asynchronous pool index reads        */
 dcl SQLM_ELM_POOL_DATA_TO_ESTORE fixed bin(31) value(464);
                              /* #pages copied from BP to estore      */
 dcl SQLM_ELM_POOL_INDEX_TO_ESTORE fixed bin(31) value(465);
                              /* #pages copied from BP to estore      */
 dcl SQLM_ELM_POOL_INDEX_FROM_ESTORE fixed bin(31) value(466);
                              /* #pages copied from estore to BP      */
 dcl SQLM_ELM_POOL_DATA_FROM_ESTORE fixed bin(31) value(467);
                              /* #pages copied from estore to BP      */
 dcl SQLM_ELM_DB_STATUS       fixed bin(31) value(468);
                              /* status of the Database               */
 dcl SQLM_ELM_LOCK_TIMEOUTS   fixed bin(31) value(469);
                              /* # of lock timeouts                   */
 dcl SQLM_ELM_CONNECTIONS_TOP fixed bin(31) value(470);
                              /* high water mark for current          */
                              /* connections                          */
 dcl SQLM_ELM_DB_HEAP_TOP     fixed bin(31) value(471);
                              /* high water mark for database heap    */
 dcl SQLM_ELM_POOL_ASYNC_DATA_READS fixed bin(31) value(472);
                              /* asynchronous pool data reads         */
 dcl SQLM_ELM_POOL_ASYNC_DATA_WRITES fixed bin(31) value(473);
                              /* asynchronous pool data writes        */
 dcl SQLM_ELM_POOL_ASYNC_INDEX_WRITES fixed bin(31) value(474);
                              /* asynchronous pool indx writes        */
 dcl SQLM_ELM_POOL_ASYNC_READ_TIME fixed bin(31) value(475);
                              /* total async read time                */
 dcl SQLM_ELM_POOL_ASYNC_WRITE_TIME fixed bin(31) value(476);
                              /* total async write time               */
 dcl SQLM_ELM_POOL_ASYNC_DATA_READ_REQS fixed bin(31) value(477);
                              /* # async read requests                */
 dcl SQLM_ELM_POOL_LSN_GAP_CLNS fixed bin(31) value(478);
                              /* LSN Gap cleaner triggers             */
 dcl SQLM_ELM_POOL_DRTY_PG_STEAL_CLNS fixed bin(31) value(479);
                              /* dirty page steal cleaner triggers    */
 dcl SQLM_ELM_POOL_DRTY_PG_THRSH_CLNS fixed bin(31) value(480);
                              /* dirty list threshold cln trig        */
 dcl SQLM_ELM_DIRECT_READS    fixed bin(31) value(481);
                              /* direct reads                         */
 dcl SQLM_ELM_DIRECT_WRITES   fixed bin(31) value(482);
                              /* direct writes                        */
 dcl SQLM_ELM_DIRECT_READ_REQS fixed bin(31) value(483);
                              /* direct read requests                 */
 dcl SQLM_ELM_DIRECT_WRITE_REQS fixed bin(31) value(484);
                              /* direct write requests                */
 dcl SQLM_ELM_DIRECT_READ_TIME fixed bin(31) value(485);
                              /* direct read time                     */
 dcl SQLM_ELM_DIRECT_WRITE_TIME fixed bin(31) value(486);
                              /* direct write time                    */
 dcl SQLM_ELM_INT_ROWS_INSERTED fixed bin(31) value(487);
                              /* # rows insrted for Trigger           */
 dcl SQLM_ELM_LOG_READS       fixed bin(31) value(488);
                              /* # of log pages read                  */
 dcl SQLM_ELM_LOG_WRITES      fixed bin(31) value(489);
                              /* # of log pages read                  */
 dcl SQLM_ELM_PKG_CACHE_LOOKUPS fixed bin(31) value(490);
                              /* # of section lookups                 */
 dcl SQLM_ELM_PKG_CACHE_INSERTS fixed bin(31) value(491);
                              /* # of sections inserted into cache    */
 dcl SQLM_ELM_CAT_CACHE_LOOKUPS fixed bin(31) value(492);
                              /* # of table descriptor lookups        */
 dcl SQLM_ELM_CAT_CACHE_INSERTS fixed bin(31) value(493);
                              /* # of table descriptors inserted      */
 dcl SQLM_ELM_CAT_CACHE_OVERFLOWS fixed bin(31) value(494);
                              /* # of catalog cache overflows         */
 dcl SQLM_ELM_CAT_CACHE_HEAP_FULL fixed bin(31) value(495);
                              /* # of overflows due to db heap full   */
 dcl SQLM_ELM_CATALOG_NODE    fixed bin(31) value(496);
                              /* Catalog node number                  */
 dcl SQLM_ELM_TOTAL_SEC_CONS  fixed bin(31) value(497);
                              /* Secondary connects                   */
                              /* database connection.                 */
                              /* with appls connected to this db.     */
 dcl SQLM_ELM_DB_LOCATION     fixed bin(31) value(498);
                              /* local or remote to snapshot appl.    */
 dcl SQLM_ELM_SERVER_PLATFORM fixed bin(31) value(499);
                              /* OS on which dbm runs                 */
 dcl SQLM_ELM_CATALOG_NODE_NAME fixed bin(31) value(500);
                              /* Catalog network node name            */
 dcl SQLM_ELM_PREFETCH_WAIT_TIME fixed bin(31) value(501);
                              /* Time waited for prefetch (ms)        */
 dcl SQLM_ELM_APPL_SECTION_LOOKUPS fixed bin(31) value(502);
                              /* # of section lookups                 */
 dcl SQLM_ELM_APPL_SECTION_INSERTS fixed bin(31) value(503);
                              /* # of sections inserted               */
 dcl SQLM_ELM_TOTAL_HASH_JOINS fixed bin(31) value(504);
                              /* number of hash joins                 */
 dcl SQLM_ELM_TOTAL_HASH_LOOPS fixed bin(31) value(505);
                              /* number of hash loops                 */
 dcl SQLM_ELM_HASH_JOIN_OVERFLOWS fixed bin(31) value(506);
                              /* number of hash join overflows        */
 dcl SQLM_ELM_HASH_JOIN_SMALL_OVERFLOWS fixed bin(31) value(507);
                              /* small hash join overflows            */
 dcl SQLM_ELM_UOW_LOCK_WAIT_TIME fixed bin(31) value(508);
                              /* time UOW waited on locks (ms)        */
 dcl SQLM_ELM_STMT_TYPE       fixed bin(31) value(509);
                              /* Statement type indicator             */
 dcl SQLM_ELM_CURSOR_NAME     fixed bin(31) value(510);
                              /* Name of cursor                       */
 dcl SQLM_ELM_UOW_LOG_SPACE_USED fixed bin(31) value(511);
                              /* Log space used in most recent UOW    */
 dcl SQLM_ELM_OPEN_REM_CURS   fixed bin(31) value(512);
                              /* Currently open remote cursors        */
 dcl SQLM_ELM_OPEN_REM_CURS_BLK fixed bin(31) value(513);
                              /* Currently open rem cursors w/blk     */
 dcl SQLM_ELM_REJ_CURS_BLK    fixed bin(31) value(514);
                              /* Rej block remote cursor requests     */
 dcl SQLM_ELM_ACC_CURS_BLK    fixed bin(31) value(515);
                              /* Acc block remote cursor requests     */
 dcl SQLM_ELM_VERSION         fixed bin(31) value(516);
                              /* Event Monitor Version                */
 dcl SQLM_ELM_EVENT_MONITOR_NAME fixed bin(31) value(517);
                              /* Name of the Event Mon                */
 dcl SQLM_ELM_SQL_REQS_SINCE_COMMIT fixed bin(31) value(518);
                              /* # SQL requests since last commit     */
 dcl SQLM_ELM_NUM_SEC_APPL_STRUCTS fixed bin(31) value(519);
                              /* Secondary application information    */
 dcl SQLM_ELM_BYTE_ORDER      fixed bin(31) value(520);
                              /* Big Endian or Little Endian          */
 dcl SQLM_ELM_PREP_TIME_WORST fixed bin(31) value(521);
                              /* Worst prep time of statement         */
 dcl SQLM_ELM_ROWS_READ       fixed bin(31) value(522);
                              /* # rows read                          */
 dcl SQLM_ELM_ROWS_WRITTEN    fixed bin(31) value(523);
                              /* # rows written                       */
 dcl SQLM_ELM_OPEN_LOC_CURS   fixed bin(31) value(524);
                              /* Currently open local cursors         */
 dcl SQLM_ELM_OPEN_LOC_CURS_BLK fixed bin(31) value(525);
                              /* Currently open local cursors w/blk   */
 dcl SQLM_ELM_COORD_NODE      fixed bin(31) value(526);
                              /* Coordinating node number.            */
 dcl SQLM_ELM_NUM_AGENTS      fixed bin(31) value(527);
                              /* # of agents currently active         */
 dcl SQLM_ELM_ASSOCIATED_AGENTS_TOP fixed bin(31) value(528);
                              /* # of agents associated with this*/
                              /* application  high water mark.        */
 dcl SQLM_ELM_APPL_PRIORITY   fixed bin(31) value(529);
                              /* priority at which appl agents work   */
 dcl SQLM_ELM_APPL_PRIORITY_TYPE fixed bin(31) value(530);
                              /* Dynamic or Static                    */
 dcl SQLM_ELM_DEGREE_PARALLELISM fixed bin(31) value(531);
                              /* SMP Intraquery Parallelism req       */
 dcl SQLM_ELM_STMT_SORTS      fixed bin(31) value(532);
                              /* number of sorts for this statement   */
 dcl SQLM_ELM_STMT_USR_CPU_TIME fixed bin(31) value(533);
                              /* total user CPU time of SQL stmt      */
 dcl SQLM_ELM_STMT_SYS_CPU_TIME fixed bin(31) value(534);
                              /* total system CPU time for SQL stmt   */
 dcl SQLM_ELM_SS_NUMBER       fixed bin(31) value(535);
                              /* Subsection number                    */
 dcl SQLM_ELM_SS_STATUS       fixed bin(31) value(536);
                              /* Subsection status                    */
 dcl SQLM_ELM_SS_NODE_NUMBER  fixed bin(31) value(537);
                              /* Node where the subsec is executing   */
 dcl SQLM_ELM_SS_EXEC_TIME    fixed bin(31) value(538);
                              /* Execution elapsed time in seconds    */
 dcl SQLM_ELM_PREP_TIME_BEST  fixed bin(31) value(539);
                              /* Best prep time of statement          */
 dcl SQLM_ELM_NUM_COMPILATIONS fixed bin(31) value(540);
                              /* Number of compilation environments   */
 dcl SQLM_ELM_TQ_NODE_WAITED_FOR fixed bin(31) value(541);
                              /* If blocked when sending or           */
                              /* receiving on a tablequeue, node      */
                              /* for which we wait                    */
 dcl SQLM_ELM_TQ_WAIT_FOR_ANY fixed bin(31) value(542);
                              /* TRUE if waiting for any node         */
 dcl SQLM_ELM_TQ_ID_WAITING_ON fixed bin(31) value(543);
                              /* tablequeue waiting to send/receive   */
 dcl SQLM_ELM_TQ_TOT_SEND_SPILLS fixed bin(31) value(544);
                              /* Total # of buffers overflowed to a   */
                              /* temp table when sending on a tq      */
 dcl SQLM_ELM_TQ_CUR_SEND_SPILLS fixed bin(31) value(545);
                              /* Current # of tq send buffers         */
                              /* overflowed                           */
 dcl SQLM_ELM_TQ_MAX_SEND_SPILLS fixed bin(31) value(546);
                              /* Maximum # of tq send buffers         */
                              /* overflowed                           */
 dcl SQLM_ELM_TQ_ROWS_READ    fixed bin(31) value(547);
                              /* Total # rows received on             */
                              /* tablequeues                          */
 dcl SQLM_ELM_TQ_ROWS_WRITTEN fixed bin(31) value(548);
                              /* Total # rows sent on tablequeues     */
 dcl SQLM_ELM_AGENT_PID       fixed bin(31) value(549);
                              /* db2agent process/thread id           */
 dcl SQLM_ELM_LOCK_ESCALATION fixed bin(31) value(550);
                              /*Was this lock part of an escalation   */
 dcl SQLM_ELM_SUBSECTION_NUMBER fixed bin(31) value(551);
                              /* Subsection waiting for lock          */
 dcl SQLM_ELM_LOCK_MODE       fixed bin(31) value(552);
                              /* Mode of Lock waited on               */
 dcl SQLM_ELM_LOCK_OBJECT_TYPE fixed bin(31) value(553);
                              /* lock object type: row, table,        */
 dcl SQLM_ELM_NUM_EXECUTIONS  fixed bin(31) value(554);
                              /* Number of executions                 */
 dcl SQLM_ELM_TABLE_NAME      fixed bin(31) value(555);
                              /* Table name                           */
 dcl SQLM_ELM_TABLE_SCHEMA    fixed bin(31) value(556);
                              /* Schema name                          */
 dcl SQLM_ELM_TABLESPACE_NAME fixed bin(31) value(557);
                              /* Tablespace name                      */
 dcl SQLM_ELM_AGENT_ID_HOLDING_LK fixed bin(31) value(558);
                              /* Application holding the lock         */
 dcl SQLM_ELM_APPL_ID_HOLDING_LK fixed bin(31) value(559);
                              /* Appl. holding the lock               */
 dcl SQLM_ELM_NUM_TABLES      fixed bin(31) value(560);
                              /* # of sqlm_table struct returned      */
 dcl SQLM_ELM_TABLE_FILE_ID   fixed bin(31) value(561);
                              /* the file ID for the table            */
 dcl SQLM_ELM_TABLE_TYPE      fixed bin(31) value(562);
                              /* table type                           */
 dcl SQLM_ELM_OVERFLOW_ACCESSES fixed bin(31) value(563);
                              /* no. of accesses to overflow rec      */
 dcl SQLM_ELM_PAGE_REORGS     fixed bin(31) value(564);
                              /* no. of page reorgs for table         */
 dcl SQLM_ELM_SQLCABC         fixed bin(31) value(565);
                              /* size of the sqlca                    */
 dcl SQLM_ELM_LOCK_STATUS     fixed bin(31) value(566);
                              /* Lock status                          */
 dcl SQLM_ELM_LOCK_OBJECT_NAME fixed bin(31) value(567);
                              /* Lock Object Name -                   */
                              /* RID or FID of lock obj               */
 dcl SQLM_ELM_RF_TYPE         fixed bin(31) value(568);
                              /* database or tablespace rollforward   */
 dcl SQLM_ELM_RF_LOG_NUM      fixed bin(31) value(569);
                              /* Current log being processed          */
 dcl SQLM_ELM_RF_STATUS       fixed bin(31) value(570);
                              /* Log phase in progress                */
 dcl SQLM_ELM_TS_NAME         fixed bin(31) value(571);
                              /* Tablespace being rolled forward      */
 dcl SQLM_ELM_BP_NAME         fixed bin(31) value(572);
                              /* Bufferpool name                      */
 dcl SQLM_ELM_STMT_NODE_NUMBER fixed bin(31) value(573);
                              /* Statement node number                */
 dcl SQLM_ELM_PARTIAL_RECORD  fixed bin(31) value(574);
                              /* partial record for flush evmon       */
 dcl SQLM_ELM_SYSTEM_CPU_TIME fixed bin(31) value(575);
                              /* Amount of system cpu time used       */
 dcl SQLM_ELM_SQLCA           fixed bin(31) value(576);
                              /* An sqlca                             */
 dcl SQLM_ELM_SQLCODE         fixed bin(31) value(577);
                              /* sqlcode of the sqlca                 */
 dcl SQLM_ELM_SQLERRML        fixed bin(31) value(578);
                              /* length of ca message tokens          */
 dcl SQLM_ELM_SQLERRMC        fixed bin(31) value(579);
                              /* message tokens                       */
 dcl SQLM_ELM_SQLERRP         fixed bin(31) value(580);
                              /* diagnostic information               */
 dcl SQLM_ELM_SQLERRD         fixed bin(31) value(581);
                              /* diagnostic information               */
 dcl SQLM_ELM_SQLWARN         fixed bin(31) value(582);
                              /* warning flags                        */
 dcl SQLM_ELM_SQLSTATE        fixed bin(31) value(583);
                              /* state corresponding to SQLCODE       */
 dcl SQLM_ELM_UOW_STATUS      fixed bin(31) value(584);
                              /* uow status                           */
 dcl SQLM_ELM_TOTAL_SYS_CPU_TIME fixed bin(31) value(585);
                              /* elapsed system cpu time              */
 dcl SQLM_ELM_TOTAL_USR_CPU_TIME fixed bin(31) value(586);
                              /* elapsed user   cpu time              */
 dcl SQLM_ELM_LOCK_MODE_REQUESTED fixed bin(31) value(587);
                              /* the lock mode requested              */
 dcl SQLM_ELM_INACTIVE_GW_AGENTS fixed bin(31) value(588);
                              /* number of primed gw agents           */
 dcl SQLM_ELM_NUM_GW_CONN_SWITCHES fixed bin(31) value(589);
                              /* number of times an primed agent      */
                              /* was stolen.                          */
 dcl SQLM_ELM_GW_COMM_ERRORS  fixed bin(31) value(590);
                              /* number of comm erros on the gw       */
 dcl SQLM_ELM_GW_COMM_ERROR_TIME fixed bin(31) value(591);
                              /* time of the most recent comm err     */
 dcl SQLM_ELM_GW_CON_START_TIME fixed bin(31) value(592);
                              /* time the most recent conn started    */
 dcl SQLM_ELM_CON_RESPONSE_TIME fixed bin(31) value(593);
                              /* most recent connection response tm   */
 dcl SQLM_ELM_CON_ELAPSED_TIME fixed bin(31) value(594);
                              /* elapsed connected time of most       */
                              /* recent disconnect                    */
 dcl SQLM_ELM_HOST_RESPONSE_TIME fixed bin(31) value(595);
                              /* elapsed response time from host      */
 dcl SQLM_ELM_PKG_CACHE_NUM_OVERFLOWS fixed bin(31) value(596);
                              /* number of pkg cache overflows        */
 dcl SQLM_ELM_PKG_CACHE_SIZE_TOP fixed bin(31) value(597);
                              /* high water mark for pkg cache size   */
 dcl SQLM_ELM_APPL_ID_OLDEST_XACT fixed bin(31) value(598);
                              /* transaction holding oldest xact      */
 dcl SQLM_ELM_TOTAL_LOG_USED  fixed bin(31) value(599);
                              /* log space used by database           */
 dcl SQLM_ELM_TOTAL_LOG_AVAILABLE fixed bin(31) value(600);
                              /* log space available in database      */
 dcl SQLM_ELM_STMT_ELAPSED_TIME fixed bin(31) value(601);
                              /* previous statement elapsed time      */
 dcl SQLM_ELM_UOW_ELAPSED_TIME fixed bin(31) value(602);
                              /* previous uow elpased time            */
 dcl SQLM_ELM_SQLCAID         fixed bin(31) value(603);
                              /* sqlca eyecatcher                     */
 dcl SQLM_ELM_SMALLEST_LOG_AVAIL_NODE fixed bin(31) value(604);
                                 /* node with worst log  ratio        */
 dcl SQLM_ELM_DISCONNECTS        fixed bin(31) value(605);
                                 /* number of disconnects             */
 dcl SQLM_ELM_CREATE_NICKNAME    fixed bin(31) value(606);
                                 /* number of create nickname stmts   */
 dcl SQLM_ELM_PASSTHRUS          fixed bin(31) value(607);
                                 /* number of stmts passed through    */
 dcl SQLM_ELM_STORED_PROCS       fixed bin(31) value(608);
                                 /* number of stored procedures       */
 dcl SQLM_ELM_SP_ROWS_SELECTED   fixed bin(31) value(609);
                                 /* number of rows returned from      */
                                 /* stored procedures                 */
 dcl SQLM_ELM_DATASOURCE_NAME    fixed bin(31) value(610);
                                 /* Remote datasource name            */
 dcl SQLM_ELM_REMOTE_LOCKS       fixed bin(31) value(611);
                                 /* number of remote table lock stmts */
 dcl SQLM_ELM_BLOCKING_CURSOR    fixed bin(31) value(612);
                                 /* Blocking cursor                   */
 dcl SQLM_ELM_OUTBOUND_BLOCKING_CURSOR fixed bin(31) value(613);
                                 /* outbound blocking cursor     */
 dcl SQLM_ELM_INSERT_SQL_STMTS   fixed bin(31) value(614);
                                 /* Insert sql statements             */
 dcl SQLM_ELM_UPDATE_SQL_STMTS   fixed bin(31) value(615);
                                 /* Update sql statements             */
 dcl SQLM_ELM_DELETE_SQL_STMTS   fixed bin(31) value(616);
                                 /* Delete sql statements             */
 dcl SQLM_ELM_UNREAD_PREFETCH_PAGES fixed bin(31) value(617);
                                 /* unread prefetch pages           */
 dcl SQLM_ELM_AGENT_STATUS       fixed bin(31) value(618);
                                 /* work agent association status     */
 dcl SQLM_ELM_NUM_TRANSMISSIONS  fixed bin(31) value(619);
                                 /* Number of Transmissions           */
 dcl SQLM_ELM_OUTBOUND_BYTES_SENT_TOP fixed bin(31) value(620);
                                 /* High water mark for number    */
                                 /*   of bytes sent               */
 dcl SQLM_ELM_OUTBOUND_BYTES_RECEIVED_TOP fixed bin(31) value(621);
                                 /* High water mark for       */
                                 /*  number of bytes received */
 dcl SQLM_ELM_OUTBOUND_BYTES_SENT_BOTTOM  fixed bin(31) value(622);
                                 /* Low water mark for number */
                                 /*  of bytes sent            */
 dcl SQLM_ELM_OUTBOUND_BYTES_RECEIVED_BOTTOM fixed bin(31) value(623);
                                 /* High water mark for    */
                                 /*  num of bytes received */
 /* The following elements represent counts of the number of          */
 /* transmissions whose size in bytes is less than or equal to the    */
 /*  number in the name.                                              */
 dcl SQLM_ELM_MAX_DATA_SENT_128       fixed bin(31) value(624);
                                      /* Cnt:Sent size <= 128 bytes   */
 dcl SQLM_ELM_MAX_DATA_SENT_256       fixed bin(31) value(625);
                                      /* Cnt:Sent size <= 256 bytes   */
 dcl SQLM_ELM_MAX_DATA_SENT_512       fixed bin(31) value(626);
                                      /* Cnt:Sent size <= 512 bytes   */
 dcl SQLM_ELM_MAX_DATA_SENT_1024      fixed bin(31) value(627);
                                      /* Cnt:Sent size <= 1024 bytes  */
 dcl SQLM_ELM_MAX_DATA_SENT_2048      fixed bin(31) value(628);
                                      /* Cnt:Sent size <= 2048 bytes  */
 dcl SQLM_ELM_MAX_DATA_SENT_4096      fixed bin(31) value(629);
                                      /* Cnt:Sent size <= 4096 bytes  */
 dcl SQLM_ELM_MAX_DATA_SENT_8192      fixed bin(31) value(630);
                                      /* Cnt:Sent size <= 8192 bytes  */
 dcl SQLM_ELM_MAX_DATA_SENT_16384     fixed bin(31) value(631);
                                      /* Cnt:Sent size <= 16384 bytes */
 dcl SQLM_ELM_MAX_DATA_SENT_31999     fixed bin(31) value(632);
                                      /* Cnt:Sent size <= 31999 bytes */
 dcl SQLM_ELM_MAX_DATA_SENT_64000     fixed bin(31) value(633);
                                      /* Cnt:Sent size <= 64000 bytes */
 dcl SQLM_ELM_MAX_DATA_SENT_GT64000   fixed bin(31) value(634);
                                      /* Cnt:Sent size > 64000 bytes  */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_128   fixed bin(31) value(635);
                                      /* Cnt:Rcv size <= 128 bytes    */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_256   fixed bin(31) value(636);
                                      /* Cnt:Rcv size <= 256 bytes    */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_512   fixed bin(31) value(637);
                                      /* Cnt:Rcv size <= 512 bytes    */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_1024  fixed bin(31) value(638);
                                      /* Cnt:Rcv size <= 1024 bytes   */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_2048  fixed bin(31) value(639);
                                      /* Cnt:Rcv size <= 2048 bytes   */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_4096  fixed bin(31) value(640);
                                      /* Cnt:Rcv size <= 4096 bytes   */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_8192  fixed bin(31) value(641);
                                      /* Cnt:Rcv size <= 8192 bytes   */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_16384 fixed bin(31) value(642);
                                      /* Cnt:Rcv size <= 16384 bytes  */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_31999 fixed bin(31) value(643);
                                      /* Cnt:Rcv size <= 31999 bytes  */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_64000 fixed bin(31) value(644);
                                      /* Cnt:Rcv size <= 64000 bytes  */
 dcl SQLM_ELM_MAX_DATA_RECEIVED_GT64000 fixed bin(31) value(645);
                                      /* Cnt:Rcv size > 64000 bytes  */
 /* The following elements represent counts of the number of         */
 /* transmissions whose network transmission time is less than the   */
 /* time (in milliseconds) in the name.                              */
 dcl SQLM_ELM_MAX_TIME_2_MS      fixed bin(31) value(646);
                                 /* Cnt:network time <= 2 millisec.   */
 dcl SQLM_ELM_MAX_TIME_4_MS      fixed bin(31) value(647);
                                 /* Cnt:network time <= 4 millisec.   */
 dcl SQLM_ELM_MAX_TIME_8_MS      fixed bin(31) value(648);
                                 /* Cnt:network time <= 8 millisec.   */
 dcl SQLM_ELM_MAX_TIME_16_MS     fixed bin(31) value(649);
                                 /* Cnt:network time <= 16 millisec.  */
 dcl SQLM_ELM_MAX_TIME_32_MS     fixed bin(31) value(650);
                                 /* Cnt:network time <= 32 millisec.  */
 dcl SQLM_ELM_MAX_TIME_GT32_MS   fixed bin(31) value(651);
                                 /* Cnt:network time > 32 millisec.   */

 /*********************************************************************/
 /* NOTE: 60000 - 65535 reserved for IBM use                          */
 /*********************************************************************/


 /*********************************************************************/
 /* Snapshot Monitoring API (sqlmonss, sqlmon, sqlmrset) data         */
 /* structures                                                        */
 /* Used by version 5.2 snapshot and under exclusively                */
 /*********************************************************************/

 /*********************************************************************/
 /*  Snapshot Object Structure - Specifies a snapshot request         */
 /*  (sqlmonss input)                                                 */
 /*                                                                   */
 /*  Specifies what information to collect (e.g., list of locks) for  */
 /*  a given object, such as a database or an application.            */
 /*                                                                   */
 /*  Note: 'agent_id', and 'object' are required, only if applicable  */
 /*        for the request type, and are mutually exclusive.          */
 /*        For example: a database name is required when the type is  */
 /*        SQLMA_DBASE_LOCKS (get snapshot for locks on database),    */
 /*        whereas an agent_id is required when the type is           */
 /*        SQLMA_APPL_LOCKS_AGENT_ID.                                 */
 /*        Note that AGENT ID is the *APPLICATION HANDLE* of an       */
 /*        application, which can be retrieved with an                */
 /*        SQLMA_APPLINFO_ALL (list applications) request.            */
 /*        It does not correspond to any Operating System process id. */
 /*        (It is named 'agent' for source compatibility with older   */
 /*        releases of DB2.                                           */
 /*                                                                   */
 /*        Both agent_id and object are ignored for requests such     */
 /*        as SQLMA_APPLINFO_ALL (list applications).                 */
 /*********************************************************************/
 define structure
   1 sqlm_obj_struct, /* specifies a snapshot request                 */
     2 agent_id type sqluint32,
                      /* used for requests based on appl-handle       */
     2 obj_type type sqluint32,
                      /* Snapshot Request Type (SQLMA_XXXX)           */
     2 object   char (SQLM_OBJECT_SZ);
                      /* used for requests based on object            */
                      /* name, such as 'get snapshot for database'    */

 /*********************************************************************/
 /*  SQL Monitor Area  - A list of snapshot requests                  */
 /*                    - (sqlmonss input)                             */
 /*********************************************************************/
 define structure
   1 sqlma,
     2 obj_num type sqluint32,         /* number of snapshot requests */
     2 obj_var (1) type sqlm_obj_struct;
                      /* A req: which object and what info to collect */

 /*********************************************************************/
 /* macro for estimating SQLMA size (use to allocate an sqlma)        */
 /* where 'n' is the number of requests for the snapshot              */
 /*********************************************************************/

 %SQLMASIZE: proc (n) returns (char);
   dcl n char;
   return ('(size (: sqlma :) + ' ||
           '(' || n || ' - 1) * size (: sqlm_obj_struct :))');
 %end SQLMASIZE;

 /*********************************************************************/
 /* Monitor Switch status                                             */
 /*********************************************************************/
 define structure
   1 sqlm_recording_group,
     2 input_state  type sqluint32,
                         /* input state to set group (sqlmon()) */
     2 output_state type sqluint32,     /* returned current state */
     2 start_time   type sqlm_timestamp;/* monitor switch set time */

 /*********************************************************************/
 /* sqlmonss output                                                   */
 /*********************************************************************/
 define structure
   1 sqlm_collected,
     2 size            type sqluint32, /* size of sqlm_collected */
     2 db2             type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 databases       type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 table_databases type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 lock_databases  type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 applications    type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 applinfos       type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 dcs_applinfos   type sqluint32,
                       /* OBSOLETE - use num_top_level_structs */
     2 server_db2_type type sqluint32,
                       /* Server DB2 Type (defined in sqlutil.cpy) */
     2 time_stamp      type sqlm_timestamp, /* Snapshot time */
     2 group_states    (SQLM_NUM_GROUPS) type sqlm_recording_group,
                       /* current sw settings */
     2 server_prdid    char(SQLM_IDENT_SZ),
                       /* product/version on server */
     2 server_nname    char(SQLM_IDENT_SZ),
                       /* Config NNAME of server */
     2 server_instance_name char(SQLM_IDENT_SZ),
                       /* instance name of DB2 */
     2 reserved        char(22),       /* reserved for future use */
     2 node_number     type sqluint16, /* Node sending data */
     2 time_zone_disp  type sqlint32,
                       /* Diff. in secs between GMT and local time */
     2 num_top_level_structs type sqluint32,
                       /* # of high level structsreturned */
     2 tablespace_databases  type sqluint32,
                       /* OBSOLETE: use num_top_level_structs */
     2 server_version  type sqluint32;
                       /* Version of server returning data */

 /*********************************************************************/
 /*********************************************************************/
 /* The following are returned in the sqlmonss (user supplied)        */
 /* output buffer:                                                    */
 /*********************************************************************/
 /*********************************************************************/

 /*********************************************************************/
 /* Application Identification Information                            */
 /*********************************************************************/
 define structure
   1 sqlm_appl_id_info,
     2 agent_id    type sqluint32,   /* Application handle            */
     2 appl_status type sqluint32,   /* Application Status            */
     2 codepage_id type sqluint32,   /* codepage/CCSID at node        */
                                     /* where app started             */
     2 status_change_time type sqlm_timestamp,
                                     /* last appl status change time  */
     2 appl_name      char(SQLM_IDENT_SZ),
                                     /* Application Program Name      */
     2 appl_id        char(SQLM_APPLID_SZ),
                                     /* Application Id                */
     2 sequence_no    char(SQLM_SEQ_SZ),
                                     /* application id sequence number*/
     2 auth_id        char(SQLM_IDENT_SZ),
                                     /* Authorization Id              */
     2 client_nname   char(SQLM_IDENT_SZ),
                                     /* Config NNAME of client        */
     2 client_prdid   char(SQLM_IDENT_SZ),
                                     /* product/version on client     */
     2 input_db_alias char(SQLM_IDENT_SZ),
                                     /* Input Database Alias          */
     2 client_db_alias char(SQLM_IDENT_SZ),
                                     /* Client Database Alias         */
     2 db_name        char(SQLM_IDENT_SZ), /* Database name    */
     2 db_path        char(SQLM_DBPATH_SZ);/* Database Path    */

 /*********************************************************************/
 /* Application Id Information                                        */
 /*********************************************************************/
 define structure
   1 sqlm_applinfo,
     2 size      type sqluint32,/* size of sqlm_applinfo */
     2 info_type char(1),/* Always set to SQLM_APPLINFO_SS*/
     2 pad       char(3),/* padding for 4-byte alignment */
     2 id_info   type sqlm_appl_id_info,/* Identification information */
     2 reserved  char(20),/* reserved for future use */
     2 num_assoc_agents type sqluint32,/* Number of agents associated */
                                       /* with this application */
     2 coord_node_num   type sqluint32,/* Coordinating node number */
     2 authority_lvl    type sqluint32,/* User authorizations */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Client Identification Information         */
     /*****************************************************************/
     2 execution_id    char(SQLM_IDENT_SZ),  /* login ID */
     2 corr_token      char(SQLM_APPLID_SZ),
                       /* DRDA AS Correlation Token                   */
     2 client_pid      type sqluint32,
                       /* Process/thread ID of client appl.           */
     2 client_platform type sqluint16,
                       /* Platform of client application              */
     2 client_protocol type sqluint16,
                       /* Communications protocol of client           */
     2 country_code    type sqluint16,
                            /* Country code of client application     */
     2 pad2            char(2),
     2 coord_agent_pid type sqlint32;
                            /* Coordinator agent process/thread id    */


 /*********************************************************************/
 /* LIST DCS APPLICATIONS  output                                     */
 /*********************************************************************/
 /* DCS Application Identification Information                        */
 /* In V5.1 and beyond, it is always followed by sqlm_dcs_applid_info.*/
 /*                                                                   */
 /*     high-level struct      secondary-level structures             */
 /*  +--------------------------+----------------------+              */
 /*  |sqlm_dcs_applinfo         |sqlm_dcs_applid_info  |              */
 /*  |num_sec_dcs_app_structs:1 |                      |              */
 /*  +--------------------------+----------------------+              */
 /*                                                                   */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_applinfo,
     2 size      type sqluint32,/* size of sqlm_dcs_applinfo */
     2 info_type char(1),/* set to SQLM_DCS_APPLINFO_SS */
     2 pad       char(3),/* padding for 4-byte alignment */
     /* The following fields have been moved to the                   */
     /* sqlm_dcs_applid_info secondary structure.                     */
     /* They are only returned for down-level (V5.0.0 and lower)      */
     /* list application requests.                                    */
     2 agent_id                type sqluint32,            /* OBSOLETE,*/
                                     /* MOVED to sqlm_dcs_applid_info */
     2 codepage_id             type sqluint32,            /* OBSOLETE */
     2 appl_name               char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 appl_id                 char(SQLM_APPLID_SZ),      /* OBSOLETE */
     2 sequence_no             char(SQLM_SEQ_SZ),         /* OBSOLETE */
     2 auth_id                 char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 client_nname            char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 client_prdid            char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 client_db_alias         char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 db_name                 char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 host_prdid              char(SQLM_IDENT_SZ),       /* OBSOLETE */
     2 outbound_appl_id        char(SQLM_APPLID_SZ),      /* OBSOLETE */
     2 outbound_sequence_no    char(SQLM_SEQ_SZ),         /* OBSOLETE */
     2 dcs_appl_status         type sqluint32,            /* OBSOLETE */
     2 status_change_time      type sqlm_timestamp,       /* OBSOLETE */
     2 client_platform         type sqluint16,            /* OBSOLETE */
     2 client_protocol         type sqluint16,            /* OBSOLETE */
     2 host_ccsid              type sqluint16,            /* OBSOLETE */
     2 num_sec_dcs_app_structs type sqluint32,
                               /* number of structs following */
     2 reserved char(10);      /* reserved for future use */

 /*********************************************************************/
 /* Identification information returned for a DCS application         */
 /* in V5.1 and beyond.                                               */
 /* (Duplicated for backward compatibility in sqlm_dcs_applinfo.)     */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_applid_info,
     2 size      type sqluint32,/* size of sqlm_dcs_applid_info */
     2 info_type char(1),       /* set to SQLM_DCS_APPLID_SS */
     2 pad       char(3),       /* padding for 4-byte alignment */
     /*****************************************************************/
     /* Client Identification Information                             */
     /*****************************************************************/
     2 agent_id              type sqluint32,/* Application handle */
     2 codepage_id           type sqluint32,/* codepage/CCSID at node */
                                            /* where app started */
     2 client_pid            type sqluint32,
                             /* Process/thread ID of client appl. */
     2 appl_name             char(SQLM_IDENT_SZ),
                             /* Application Program Name */
     2 appl_id               char(SQLM_APPLID_SZ),
                             /* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* application id sequence number*/
     2 auth_id               char(SQLM_IDENT_SZ),
                             /* Authorization Id */
     2 client_nname          char(SQLM_IDENT_SZ),
                             /* Config NNAME of client */
     2 client_prdid          char(SQLM_IDENT_SZ),
                             /* product/version on client */
     2 gw_db_alias           char(SQLM_IDENT_SZ),
                             /* gateway Database Alias */
     2 execution_id          char(SQLM_IDENT_SZ),
                             /* Client Login ID */
     2 outbound_comm_address char(SQLM_COMM_ADDR_SZ),
                             /* Outb. comm. address */
     2 inbound_comm_address  char(SQLM_COMM_ADDR_SZ),
                             /* Inbound comm. address */
     2 outbound_comm_protocol type sqluint16,
                             /* Outbound comm. protocol */
     2 client_platform       type sqluint16,/* Client platform */
     2 client_protocol       type sqluint16,/* Client protocol */
     2 pad2                  char(2),
     /*****************************************************************/
     /* Gateway and Host Identification Information                   */
     /*****************************************************************/
     2 dcs_db_name           char(SQLM_IDENT_SZ),
                             /* DCS Database name */
     2 host_db_name          char(SQLM_IDENT_SZ),
                             /* Host Database name */
     2 host_prdid            char(SQLM_IDENT_SZ),
                             /* Host Product id */
     2 outbound_appl_id      char(SQLM_APPLID_SZ),
                             /* Outbound LUWID */
     2 outbound_sequence_no  char(SQLM_SEQ_SZ),
                             /* Outbound sequence # */
     2 dcs_appl_status       type sqluint32,
                             /* Status of DCS application */
     2 status_change_time    type sqlm_timestamp,
                             /* Time status last changed */
     2 host_ccsid            type sqluint16,
                             /* Host database Coded Char Set ID */
     2 pad3                  char(2);

 /*********************************************************************/
 /* Counters for SNAPSHOT DCS APPLICATION                             */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_appl_stats,
     2 gw_con_time           type sqlm_timestamp,
                             /* Connect start date/time */
     /*****************************************************************/
     /* Application level cumulative counters                         */
     /*****************************************************************/
     2 gw_exec_time          type sqlm_time,
                             /* Time spent on gateway processing*/
     2 rows_selected         type sqluint32,
                             /* # of rows selected */
     /*****************************************************************/
     /* SQL statement counters                                        */
     /*****************************************************************/
     2 sql_stmts             type sqluint32,
                             /* # of sql stmts attempted since conn */
     2 failed_sql_stmts      type sqluint32,
                             /* # of Failed SQL stmts since conn */
     2 commit_sql_stmts      type sqluint32,
                             /* # of Commit SQL stmts since conn */
     2 rollback_sql_stmts    type sqluint32,
                             /* # of Rollback SQL stmts since conn*/
     /*****************************************************************/
     /* DB2 Connect elements                                          */
     /*****************************************************************/
     2 inbound_bytes_received  type sqluint32,
                             /* inbound # of bytes received */
     2 outbound_bytes_sent     type sqluint32,
                             /* outbound # of bytes sent */
     2 outbound_bytes_received type sqluint32,
                             /* outbound # of bytes received */
     2 inbound_bytes_sent      type sqluint32;
                             /* inbound # of bytes sent */

 /*********************************************************************/
 /* The following structure uses the previous one and also contains   */
 /* the size and info_type fields. It is used as a secondary          */
 /* structure that occurs after sqlm_dcs_appl structure in            */
 /* GET SNAPSHOT FOR DCS APPLICATION output.                          */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_appl_snap_stats,
     2 size       type sqluint32, /* size of sqlm_dcs_appl_snap_stats */
     2 info_type  char(1),        /* set to SQLM_DCS_APPL_STATS_SS    */
     2 pad        char(3),        /* padding for 4-byte alignment     */
     2 appl_stats type sqlm_dcs_appl_stats;


 /*********************************************************************/
 /* GET SNAPSHOT FOR DCS APPLICATIONS                                 */
 /*                                                                   */
 /*  Secondary-level structures are returned, if applicable.          */
 /*  They provide extra information about the connection.             */
 /*                                                                   */
 /*  The secondary-level structures sqlm_dcs_applid_info and          */
 /*  sqlm_appl_snap_stats are always returned (in that order).        */
 /*  They immediately follow the high-level structure sqlm_dcs_appl   */
 /*  in the sqlmonss buffer.                                          */
 /*                                                                   */
 /*    high-level struct     secondary-level structures               */
 /* |-----------+----------|--------------------+--------------------+*/
 /* +----------------------+--------------------+--------------------+*/
 /* |sqlm_dcs_appl         |sqlm_dcs_applid_info|sqlm_appl_snap_stats|*/
 /* |num_sec_dcs_structs:5 |                    |                    |*/
 /* +----------------------+----------------------------------------- */
 /*                                                                   */
 /*     secondary-level structures (continued)                        */
 /* ... +-------------+----------------+-------------|                */
 /*     +-------------+----------------+-------------+                */
 /* ... |sqlm_appl_xid|sqlm_tpmon_info |sqlm_dcs_stmt|                */
 /*     |             |                |             |                */
 /* ... -------------------------------+-------------+                */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_appl,
     2 size  type sqluint32, /* size of sqlm_dcs_appl */
     2 info_type    char(1), /* always set to SQLM_DCS_APPL_SS */
     2 pad          char(3), /* padding for 4-byte alignment */
     2 num_sec_dcs_structs   type sqluint32,
                             /* number of structures that follow this */
                             /* one in the snapshot output buffer to  */
                             /* provide info for this DCS application */
     2 stmt_operation        type sqluint32,
                             /* most recent SQL stmt operation */
     2 section_number        type sqluint32,
                             /* most recent SQL stmt section number*/
     2 stmt_start            type sqlm_timestamp,
                          /* when received from client at the gateway */
     2 stmt_stop             type sqlm_timestamp,
                             /* when sent to client from the gateway */
     2 creator               char(SQLM_IDENT_SZ),
     2 package_name          char(SQLM_IDENT_SZ),
     2 appl_idle_time        type sqluint32,
                          /* time (seconds) since last stmt completed */
     2 open_cursors          type sqluint32,
                             /* currently open cursors */
     /*****************************************************************/
     /* Unit-Of-Work Information                                      */
     /*****************************************************************/
     2 uow_comp_status       type sqluint32,
                             /* previous uow completion status */
     2 prev_uow_stop_time    type sqlm_timestamp,
                             /* prev commit or rollback time */
     2 uow_start_time        type sqlm_timestamp,
                             /* time trans exec started */
     2 uow_stop_time         type sqlm_timestamp,
                             /* unit-of-work stop time */
     2 inbound_bytes_received  type sqluint32,            /* OBSOLETE */
     2 outbound_bytes_sent     type sqluint32,            /* OBSOLETE */
     2 outbound_bytes_received type sqluint32,            /* OBSOLETE */
     2 inbound_bytes_sent      type sqluint32,            /* OBSOLETE */
     /*****************************************************************/
     /* Last snapshot reset                                           */
     /*****************************************************************/
     2 last_reset            type sqlm_timestamp;
                             /* Last snapshot reset date and time */

 /*********************************************************************/
 /* XID Information - returned on application and DCS application     */
 /*                   snapshot                                        */
 /*********************************************************************/
 /* 2-phase commit transaction id - generated by our own TM database  */
 /* or external TM                                                    */

 define structure
   1 sqlm_appl_xid,
     2 size   type sqluint32, /* Use instead of sizeof(sqlm_appl_xid) */
     2 info_type char(1),        /* Always set to SQLM_APPL_XID_SS */
     2 pad       char(3),        /* padding for 4-byte alignment */
     2 xid_size  type sqluint32, /* XID size */
     2 xid       char(1);        /* XID */

 /*********************************************************************/
 /* 3-tier client information - returned on application and DCS       */
 /*                             application snapshot if sqleseti call */
 /*                             is done in app.                       */
 /*                                                                   */
 /* layout:                                                           */
 /* sqlm_tpmon_info may be followed by the text, if any, provided as  */
 /* accounting information to the Set Client api                      */
 /*                                                                   */
 /*  +------------------------+--------------------------+            */
 /*  |sqlm_tpmon_info         |"ACCOUNTING INFO PDADFBW "|            */
 /*  |  size: 300             |                          |            */
 /*  |  acc_str_length: 200   |                          |            */
 /*  |  acc_str_offset: 100   |                          |            */
 /*  +------------------------+--------------------------+            */
 /*                                                                   */
 /*********************************************************************/
 define structure
   1 sqlm_tpmon_info,
     2 size  type sqluint32, /* Use instead of sizeof(sqlm_tpmon_info) */
     2 info_type    char(1), /* Always set to SQLM_TPMON_INFO_SS */
     2 pad          char(3), /* padding for 4-byte alignment */
     2 tpmon_client_userid   char(SQLM_IDENT_SZ),
                             /* TP Monitor client user ID */
     2 tpmon_client_wkstn    char(SQLM_IDENT_SZ),
                             /* TP Monitor client workstation */
     2 tpmon_client_app      char(SQLM_IDENT_SZ),
                             /* TP Monitor client app. name */
     2 acc_str_length        type sqluint16,
                             /* Client accounting string size in bytes*/
     2 acc_str_offset        type sqluint16;
                             /* Offset from start of sqlm_tpmon_info */

 /*********************************************************************/
 /*                                                                   */
 /* Statement that is running on a host                               */
 /*                                                                   */
 /* (info returned for DCS applications, only if the statement        */
 /*  switch is ON)                                                    */
 /*                                                                   */
 /* layout:                                                           */
 /* sqlm_dcs_stmt may be followed by statement text.                  */
 /*                                                                   */
 /*  +------------------------+--------------------------+            */
 /*  |sqlm_dcs_stmt           |"SELECT * FROM TABLE1    "|            */
 /*  |  size: 132             |                          |            */
 /*  |  stmt_length: 24       |                          |            */
 /*  |  stmt_text_offset: 108 |                          |            */
 /*  +------------------------+--------------------------+            */
 /*                                                                   */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_stmt,
     2 size  type sqluint32, /* use instead of sizeof(sqlm_dcs_stmt) */
                             /* *INCLUDES* variable length SQL text  */
     2 info_type    char(1), /* always set to SQLM_DCS_STMT_SS */
     2 pad          char(3), /* padding for 4-byte alignment */
     2 creator               char(SQLM_IDENT_SZ),
                             /* auth id for precompile */
     2 package_name          char(SQLM_IDENT_SZ),
                             /* package name */
     2 section_number        type sqluint32,/* section number */
     2 query_cost_estimate   type sqluint32,
                             /* SQL compiler estim. in TIMERONS */
     2 query_card_estimate   type sqluint32,
                             /* SQL compiler estim. number of rows */
     2 stmt_start            type sqlm_timestamp,
                             /* SQL statement operation start time */
     2 stmt_stop             type sqlm_timestamp,
                             /* SQL statement operation stop time */
     2 stmt_operation        type sqluint32,
                             /* most recent operation executed */
     2 fetch_count           type sqluint32,
                             /* total number of rows fetched */
     /* Gateway statistics */
     2 gw_exec_time          type sqlm_time,
                             /* Time spent executing in the gateway */
     2 inbound_bytes_received  type sqluint32,/* client -> gateway */
     2 outbound_bytes_sent     type sqluint32,/* gateway -> host */
     2 outbound_bytes_received type sqluint32,/* host -> gateway */
     2 inbound_bytes_sent      type sqluint32,/* gateway -> client */
     2 stmt_length           type sqluint16,
                             /* length of SQL stmt text, which is */
                             /* blank-padded to a 4-byte boundary */
     2 stmt_text_offset      type sqluint16;
                             /* text offset from start of sqlm_stmt */

 /*********************************************************************/
 /*                                                                   */
 /* DCS database statistics                                           */
 /*                                                                   */
 /*********************************************************************/
 define structure
   1 sqlm_dcs_dbase,
     2 size  type sqluint32, /* size of sqlm_dcs_dbase */
     2 info_type    char(1), /* always set to SQLM_DCS_DBASE_SS */
     2 pad          char(3), /* padding for 4-byte alignment */
     2 dcs_db_name           char(SQLM_IDENT_SZ),
                             /* dcs database name */
     2 host_db_name          char(SQLM_IDENT_SZ),
                             /* host database name */
     2 gw_con_time           type sqlm_timestamp,
                             /* first connect date/time */
     2 last_reset            type sqlm_timestamp,
                             /* last monitor reset */
     /*****************************************************************/
     /* SQL statement counts                                          */
     /*****************************************************************/
     2 sql_stmts             type sqluint32,
                             /* # of sql stmts since connection */
     2 failed_sql_stmts      type sqluint32,
                             /* # of failed SQL stmts since conn */
     2 commit_sql_stmts      type sqluint32,
                             /* # of commit SQL stmts since conn */
     2 rollback_sql_stmts    type sqluint32,
                             /* # of rollback SQL stmts since conn*/
     2 rows_selected         type sqluint32,
                             /* # of rows selected */
     /*****************************************************************/
     /* Gateway statistics                                            */
     /*****************************************************************/
     2 gw_total_cons         type sqluint32,
                             /* connects since db activations */
     2 gw_cur_cons           type sqluint32,
                             /* appls currently connected */
     2 gw_cons_wait_host     type sqluint32,
                             /* appls waiting for host's reply */
     2 gw_cons_wait_client   type sqluint32,
                             /* appls waiting for client to send */
     2 gw_connections_top    type sqluint32;
                             /* high water mark for concurrent conn's */

 /*********************************************************************/
 /* Remote Data Source Related Snapshot Information by DB             */
 /*********************************************************************/

 define structure
   1 sqlm_dbase_remote,
    2 size                   type sqluint32,
                             /* size of sqlm_dbase_remote */
    2 info_type              char(1),
                             /* collected information type */
    2 datasource_name        char(SQLM_SERVERNAME_SZ),
                             /* Remote data source name @d138658rps */
    2 db_name                char(SQLM_IDENT_SZ),
                             /* Database name */
    2 total_cons             type sqluint32,/* # of connects */
    2 disconnects            type sqluint32,/* # of disconnects */
    2 commit_sql_stmts       type sqluint32,/* # of commits */
    2 rollback_sql_stmts     type sqluint32,/* # of rollbacks */
    2 select_sql_stmts       type sqluint32,/* # of queries */
    2 insert_sql_stmts       type sqluint32,/* # of inserts */
    2 update_sql_stmts       type sqluint32,/* # of updates */
    2 delete_sql_stmts       type sqluint32,/* # of deletes */
    2 create_nickname        type sqluint32,
                             /* # of create nickname statements */
    2 passthrus              type sqluint32,
                             /* # of statements passed through */
    2 stored_procs           type sqluint32,
                             /* # of stored procedures */
    2 rows_selected          type sqluint32,/* # of rows returned */
    2 rows_updated           type sqluint32,/* # of rows updated */
    2 rows_deleted           type sqluint32,/* # of rows deleted */
    2 rows_inserted          type sqluint32,/* # of rows inserted */
    2 sp_rows_selected       type sqluint32,
                             /* # of rows returned from stored proc */
    2 failed_sql_stmts       type sqluint32,
                             /* # of statements that failed */
    2 select_time            type sqlm_time,
                             /* Aggregate response time to queries */
    2 insert_time            type sqlm_time,
                             /* Aggregate response time to inserts */
    2 update_time            type sqlm_time,
                             /* Aggregate response time to updates */
    2 delete_time            type sqlm_time,
                             /* Aggregate response time to deletes */
    2 create_nickname_time   type sqlm_time,
                             /* Aggregate response time to create nick*/
    2 passthru_time          type sqlm_time,
                             /* Aggregate response time to passthru */
    2 stored_proc_time       type sqlm_time;
                             /* Aggregate response time to passthru */

 /*********************************************************************/
 /* Remote Data Source Related Snapshot Information by Application    */
 /*********************************************************************/

 define structure
   1 sqlm_appl_remote,
    2 size                   type sqluint32,
                             /* size of sqlm_appl_remote */
    2 info_type              char(1),
                             /* collected information type */
    2 id_info                type sqlm_appl_id_info,
                             /* appl identification information */
    2 datasource_name        char(SQLM_SERVERNAME_SZ),
                             /* Remote data source name @d138658rps */
    2 db_name                char(SQLM_IDENT_SZ),/* Database name */
    2 commit_sql_stmts       type sqluint32,/* # of commits */
    2 rollback_sql_stmts     type sqluint32,/* # of rollbacks */
    2 select_sql_stmts       type sqluint32,/* # of queries */
    2 insert_sql_stmts       type sqluint32,/* # of inserts */
    2 update_sql_stmts       type sqluint32,/* # of updates */
    2 delete_sql_stmts       type sqluint32,/* # of deletes */
    2 create_nickname        type sqluint32,
                             /* # of create nickname statements */
    2 passthrus              type sqluint32,
                             /* # of statements passed through */
    2 stored_procs           type sqluint32,/* # of stored procedures */
    2 rows_selected          type sqluint32,/* # of rows returned */
    2 rows_updated           type sqluint32,/* # of rows updated */
    2 rows_deleted           type sqluint32,/* # of rows deleted */
    2 rows_inserted          type sqluint32,/* # of rows inserted */
    2 sp_rows_selected       type sqluint32,
                             /* # of rows returned from stored proc */
    2 failed_sql_stmts       type sqluint32,
                             /* # of statements that failed */
    2 select_time            type sqlm_time,
                             /* Aggregate response time to queries */
    2 insert_time            type sqlm_time,
                             /* Aggregate response time to inserts */
    2 update_time            type sqlm_time,
                             /* Aggregate response time to updates */
    2 delete_time            type sqlm_time,
                             /* Aggregate response time to deletes */
    2 create_nickname_time   type sqlm_time,
                             /* Aggregate response time to create nick*/
    2 passthru_time          type sqlm_time,
                             /* Aggregate response time to passthru */
    2 stored_proc_time       type sqlm_time;
                             /* Aggregate response time to passthru */


 /*********************************************************************/
 /* Database manager Snapshot                                         */
 /*********************************************************************/
 /* DB2 snapshot layout.  If running in a parallel environment,       */
 /* 'secondary' level structures may also be returned.  For example:  */
 /*                                                                   */
 /*      high-level struct      secondary-level                       */
 /*  |------------+-----------|--------+--------|                     */
 /*  +------------------------+-----------------+ ...                 */
 /*  |sqlm_db2                |sqlm_fcm         |                     */
 /*  |  num_sec_dbm_structs: 1|  number_nodes: 2|                     */
 /*  +------------------------+-----------------+ ...                 */
 /*                                                                   */
 /*  ... +-------------+-------------+                                */
 /*      |sqlm_fcm_node|sqlm_fcm_node|                                */
 /*      |             |             |                                */
 /*  ... +-------------+-------------+                                */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_db2,
     2 size  type sqluint32, /* size of sqlm_db2 */
     2 info_type    char(1), /* Always set to SQLM_DB2_SS */
     2 pad1         char(3), /* padding for 4-byte alignment */
     /*****************************************************************/
     /* Sorting Information                                           */
     /*****************************************************************/
     2 sort_heap_allocated   type sqluint32,
                             /* Sort heap currently allocated */
     2 post_threshold_sorts  type sqluint32,
                             /* # sorts started after heap */
                             /* threshold exceeded */
     2 piped_sorts_requested type sqluint32,
                             /* # of piped sorts requested */
                             /* by RDS to SLS */
     2 piped_sorts_accepted  type sqluint32,
                             /* # of piped sorts accepted by SLS */
     /*****************************************************************/
     /* Timestamps                                                    */
     /*****************************************************************/
     2 db2start_time         type sqlm_timestamp,
                             /* DB2START timestamp */
     2 last_reset            type sqlm_timestamp,
                             /* Date/Time of Last Reset */
     /*****************************************************************/
     /* Connection Information                                        */
     /*****************************************************************/
     2 rem_cons_in           type sqluint32,
                             /* Remote connects to target DB2 */
     2 rem_cons_in_exec      type sqluint32,
                             /* Remote connects to target exec DB2 */
     2 local_cons            type sqluint32,
                             /* Current Local Connections */
     2 local_cons_in_exec    type sqluint32,
                             /* Local connects curr exec in DB2 */
     2 con_local_dbases      type sqluint32,
                             /* Local databases w/current connects */
     2 agents_registered     type sqluint32,
                             /* Number of agents registered in DB2 */
     2 agents_waiting_on_token type sqluint32,
                             /* # of agents waiting on a token */
     /*****************************************************************/
     /* Server Switch settings - indicate if the DBMS is collecting   */
     /* monitor data                                                  */
     /*****************************************************************/
     2 dbmon_sw_settings     char(SQLM_NUM_GROUPS),
                             /* SQLM_OFF, SQLM_ON */
     2 pad2                  char(2),/* padding for 4-byte alignment */
     2 dbmon_sw_set_time     (SQLM_NUM_GROUPS) type sqluint32,
                             /* GMT time (in seconds) when */
                             /* switch was set - 0 if switch is OFF */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 DB2 Instance Status                       */
     /*****************************************************************/
     2 db2_status            type sqluint32,
                             /* status of the DB2 instance */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 High Water Marks                          */
     /*****************************************************************/
     2 agents_registered_top type sqluint32,
                             /* agents_registered high water mark */
     2 agents_waiting_top    type sqluint32,
                             /* agents_waiting high water mark */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 DB2 Instance Memory Usage Information     */
     /*****************************************************************/
     2 comm_private_mem      type sqluint32,
                             /* Committed Private Memory */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Agent Information                         */
     /*****************************************************************/
     2 idle_agents           type sqluint32,
                             /* number of unassigned agents in pool*/
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Agent Information                         */
     /*****************************************************************/
     2 agents_from_pool      type sqluint32,
                             /* # agents assigned from pool */
     2 agents_created_empty_pool type sqluint32,
                             /* # agents created because the */
                             /* pool was empty */
     2 coord_agents_top      type sqluint32,
                             /* coordinating agents high water mark*/
     2 max_agent_overflows   type sqluint32,
                             /* # of attempts to exceed the */
                             /* MAXAGENTS configuration parameter. */
     2 agents_stolen         type sqluint32,
                             /* # agents stolen */
     2 num_sec_dbm_structs   type sqluint32,
                             /* Secondary database manager info */
     2 product_name          char(SQLM_LG_IDENT_SZ),
                             /* Product Name */
     2 component_id          char(SQLM_IDENT_SZ),
                             /* Product Identificiation */
     2 service_level         char(SQLM_SH_IDENT_SZ),
                             /* Service Level */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5_2 DB2 CONNECT (DDCS) information          */
     /*****************************************************************/
     2 gw_total_cons         type sqluint32,
                             /* Total number of gateway connections */
     2 gw_cur_cons           type sqluint32,
                             /* Current number of gateway connections */
     2 gw_cons_wait_host     type sqluint32,
                             /* # gateway conns waiting for host reply*/
     2 gw_cons_wait_client   type sqluint32,
                             /* Gateway conns waiting for client reply*/
     2 post_threshold_hash_joins type sqluint32;
                             /* # hash joins started after heap*/
                             /* threshold exceeded */

 /*********************************************************************/
 /* Fast Communication Manager (FCM) related Snapshot Information     */
 /*********************************************************************/
 define structure
   1 sqlm_fcm,
     2 size  type sqluint32, /* size of sqlm_fcm */
     2 info_type    char(1), /* Always set to SQLM_FCM_SS */
     2 pad          char(3), /* padding for 4-byte alignment */
     /*****************************************************************/
     /* FCM Buffer Information                                        */
     /*****************************************************************/
     2 buff_free             type sqluint32,
                             /* # of FCM buffers free */
     2 buff_free_bottom      type sqluint32,
                             /* low water mark of buffers free */
     /*****************************************************************/
     /* FCM Message Anchor Information                                */
     /*****************************************************************/
     2 MA_free               type sqluint32,
                             /* # of FCM message anchors free */
     2 MA_free_bottom        type sqluint32,
                             /* low water mark of anchors free */
     /*****************************************************************/
     /* FCM Connection Entry Information                              */
     /*****************************************************************/
     2 CE_free               type sqluint32,
                             /* # of FCM connection entries free */
     2 CE_free_bottom        type sqluint32,
                             /* low water mark of free CEs */
     /*****************************************************************/
     /* FCM Request Blocks Information                                */
     /*****************************************************************/
     2 RB_free               type sqluint32,
                             /* # of FCM request blocks free */
     2 RB_free_bottom        type sqluint32,
                             /* low water mark of free RBs */
     /*****************************************************************/
     /* FCM Node Status Information                                   */
     /*****************************************************************/
     2 number_nodes          type sqluint32;
                             /* # of FCM node structures which follow.*/

 /*********************************************************************/
 /* FCM Node Snapshot Information                                     */
 /*********************************************************************/
 define structure
   1 sqlm_fcm_node,
     2 size  type sqluint32, /* size of sqlm_fcm_node */
     2 info_type    char(1), /* Always set to SQLM_NODE_SS */
     2 pad1         char(1), /* padding for half-word aligment */
     2 node_number           type sqluint16,
                             /* Remote node number */
     2 connection_status     type sqluint32,
                             /* FCM Connnection status to node */
     /*****************************************************************/
     /* FCM Buffer Counts                                             */
     /*****************************************************************/
     2 total_buffers_sent    type sqluint32,
                             /* Total # of buffers sent */
     2 total_buffers_rcvd    type sqluint32;
                             /* Total # of buffers received */

 /*********************************************************************/
 /* Database Snapshot                                                 */
 /*********************************************************************/
 /* Database snapshot layout. If a rollforward is in progress, a      */
 /* 'secondary' level structure is also returned, for example:        */
 /*                                                                   */
 /*          high-level struct        secondary-level                 */
 /*      |------------+-------------|---------+---------|             */
 /*      +--------------------------+-------------------+ ...         */
 /*      |sqlm_dbase                |sqlm_rollfwd_info  |             */
 /*      |  num_sec_dbase_structs: 1|  rf_num_tspaces: 1|             */
 /*      +--------------------------+-------------------+ ...         */
 /*                                                                   */
 /*      ... +--------------------+                                   */
 /*          |sqlm_rollfwd_ts_info|                                   */
 /*          |                    |                                   */
 /*      ... +--------------------+                                   */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_dbase,
     2 size  type sqluint32, /* size of sqlm_dbase */
     2 info_type    char(1), /* Always set to SQLM_DBASE_SS */
     2 pad1         char(3), /* padding for 4-byte alignment */
     2 input_db_alias        char(SQLM_IDENT_SZ),
                             /* Input Database Alias */
     2 db_name               char(SQLM_IDENT_SZ),
                             /* Database name */
     2 db_path               char(SQLM_DBPATH_SZ),
                             /* Database Path */
     /*****************************************************************/
     /* Locking Information                                           */
     /*****************************************************************/
     2 locks_held            type sqluint32,
                             /* Locks currently held */
     2 lock_waits            type sqluint32,
                             /* Lock waits since 1st connect */
     2 lock_wait_time        type sqluint32,
                             /* Total time dbase waited on locks */
     2 lock_list_in_use      type sqluint32,
                             /* total lock list memory in use */
     2 deadlocks             type sqluint32,
                             /* Deadlocks since 1st db connect */
     2 lock_escals           type sqluint32,
                             /* lock escals since 1st db connect */
     2 x_lock_escals         type sqluint32,
                             /* X lock escals since 1st db connect*/
     2 locks_waiting         type sqluint32,
                             /* Agents currently waiting on locks */
     /*****************************************************************/
     /* Sorting Information                                           */
     /*****************************************************************/
     2 sort_heap_allocated   type sqluint32,
                             /* Total sort heap allocated */
     2 total_sorts           type sqluint32,
                             /* number of sorts since 1st connect */
     2 total_sort_time       type sqluint32,
                             /* elapsed time spent in sorts  */
     2 sort_overflows        type sqluint32,
                             /* number of sort overflows */
     2 active_sorts          type sqluint32,
                             /* sorts currently active */
     /*****************************************************************/
     /* Buffer Pool Information                                       */
     /*****************************************************************/
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads since conn*/
     2 pool_data_p_reads     type sqluint32,
                             /* pool data reads since 1st connect */
     2 pool_data_writes      type sqluint32,
                             /* pool data writes since 1st connect*/
     2 pool_index_l_reads    type sqluint32,
                             /* pool indx logical reads since conn*/
     2 pool_index_p_reads    type sqluint32,
                             /* pool indx reads since 1st connect */
     2 pool_index_writes     type sqluint32,
                             /* pool indx writes since 1st connect*/
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time since 1st conn*/
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time since 1st con*/
     2 files_closed          type sqluint32,
                             /* files closed since first db conn */
     /*****************************************************************/
     /* SQL statement counts                                          */
     /*****************************************************************/
     2 commit_sql_stmts      type sqluint32,
                             /* # of Commit SQL stmts since conn */
     2 rollback_sql_stmts    type sqluint32,
                             /* # of Rollback SQL stmts since conn*/
     2 dynamic_sql_stmts     type sqluint32,
                             /* # of Dynamic SQL stmts since conn */
     2 static_sql_stmts      type sqluint32,
                             /* # of Static SQL stmts since conn */
     2 failed_sql_stmts      type sqluint32,
                             /* # of Failed SQL stmts since conn */
     2 select_sql_stmts      type sqluint32,
                             /* # of SQL select stmts since conn */
     2 ddl_sql_stmts         type sqluint32,
                             /* # of data definition lang. stmts */
     2 uid_sql_stmts         type sqluint32,
                             /* # of update/insert/delete stmts */
     /*****************************************************************/
     /* Internal counts                                               */
     /*****************************************************************/
     2 int_auto_rebinds      type sqluint32,
                             /* # of Auto Rebinds since 1st conn */
     2 int_rows_deleted      type sqluint32,
                             /* # of Casc. Deletes since 1st conn */
     2 int_rows_updated      type sqluint32,
                             /* # of Set Null Deletes since conn */
     2 int_commits           type sqluint32,
                             /* # of int. Commits since 1st conn */
     2 int_rollbacks         type sqluint32,
                             /* # of int. Rollbacks since 1st conn*/
     2 int_deadlock_rollbacks type sqluint32,
                             /* # of Rollbacks due to deadlock */
                             /* since 1st connect */
     /*****************************************************************/
     /* Row counts                                                    */
     /*****************************************************************/
     2 rows_deleted          type sqluint32,
                             /* # of Rows Deleted since connect */
     2 rows_inserted         type sqluint32,
                             /* # of Rows Inserted since connect */
     2 rows_updated          type sqluint32,
                             /* # of Rows Updated since connect */
     2 rows_selected         type sqluint32,
                             /* # of Rows Selected since connect */
     /*****************************************************************/
     /* Binds/Precompiles                                             */
     /*****************************************************************/
     2 binds_precompiles     type sqluint32,
                             /* # of Binds/Precomps since 1st conn*/
     /*****************************************************************/
     /* Timestamps                                                    */
     /*****************************************************************/
     2 db_conn_time          type sqlm_timestamp,
                             /* Time of 1st database connection */
     2 last_reset            type sqlm_timestamp,
                             /* Date/Time of Last Reset */
     2 last_backup           type sqlm_timestamp,
                             /* Date/Time of Last Backup */
     /*****************************************************************/
     /* Application connection counters                               */
     /*****************************************************************/
     2 total_cons            type sqluint32,
                             /* Connects since 1st db connect */
     2 appls_cur_cons        type sqluint32,
                             /* Appls currently connected */
     2 appls_in_db2          type sqluint32,
                             /* Appls executing in the DB2 */
     /*****************************************************************/
     /* Logging Information                                           */
     /*****************************************************************/
     2 sec_log_used_top      type sqluint32,
                             /* Maximum secondary log space used */
     2 tot_log_used_top      type sqluint32,
                             /* Maximum total log space used */
     2 sec_logs_allocated    type sqluint32,
                             /* Number of secondary logs allocated*/
     2 reserved              char(8), /* reserved for future use */
     2 num_sec_dbase_structs type sqluint32,
                             /* Secondary Database information */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 pool_async_index_reads type sqluint32,
                             /* asynchronous pool index reads */
     2 pool_data_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore  type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Database Status                           */
     /*****************************************************************/
     2 db_status             type sqluint32,
                             /* status of the Database */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 lock information                          */
     /*****************************************************************/
     2 lock_timeouts         type sqluint32,
                             /* # of lock timeouts since 1st conn */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 High Water Marks                          */
     /*****************************************************************/
     2 connections_top       type sqluint32,
                           /* high water mark for current connections */
     2 db_heap_top           type sqluint32,
                           /* high water mark for database heap(bytes)*/
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 pool_async_data_reads type sqluint32,
                             /* asynchronous pool data reads */
     2 pool_async_data_writes type sqluint32,
                             /* asynchronous pool data writes */
     2 pool_async_index_writes type sqluint32,
                             /* asynchronous pool index writes */
     2 pool_async_read_time  type sqluint32,
                             /* total async read time */
     2 pool_async_write_time type sqluint32,
                             /* total async write time */
     2 pool_async_data_read_reqs type sqluint32,
                             /* # async read requests */
     2 pool_lsn_gap_clns     type sqluint32,
                             /* LSN Gap cleaner triggers */
     2 pool_drty_pg_steal_clns type sqluint32,
                             /* dirty page steal cleaner trig. */
     2 pool_drty_pg_thrsh_clns type sqluint32,
                             /* dirty list thresholdcln trig. */
     2 direct_reads          type sqluint32,
                             /* direct reads since 1st connect */
     2 direct_writes         type sqluint32,
                             /* direct writes since 1st conn */
     2 direct_read_reqs      type sqluint32,
                             /* direct read requests */
     2 direct_write_reqs     type sqluint32,
                             /* direct write requests */
     2 direct_read_time      type sqluint32,
                             /* direct read time since 1st conn */
     2 direct_write_time     type sqluint32,
                             /* direct write time since 1st conn*/
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Internal counts                           */
     /*****************************************************************/
     2 int_rows_inserted     type sqluint32,
                             /* # rows insrted for Trigger */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Logging Information                       */
     /*****************************************************************/
     2 log_reads             type sqluint32,
                             /* # of log pages read since 1st conn */
     2 log_writes            type sqluint32,
                             /* # of log pages read since 1st conn */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Package Cache Information                 */
     /*****************************************************************/
     2 pkg_cache_lookups     type sqluint32,
                             /* # of section lookups */
     2 pkg_cache_inserts     type sqluint32,
                             /* # of sections inserted into cache */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Catalog Cache Information                 */
     /*****************************************************************/
     2 cat_cache_lookups     type sqluint32,
                             /* # of table descriptor lookups */
     2 cat_cache_inserts     type sqluint32,
                             /* # of table descriptors inserted */
     2 cat_cache_overflows   type sqluint32,
                             /* # of catalog cache overflows */
     2 cat_cache_heap_full   type sqluint32,
                             /* # of overflows due to db heap full */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5                                           */
     /*****************************************************************/
     2 catalog_node          type sqluint32,/* Catalog node number */
     2 total_sec_cons        type sqluint32,
                             /* Secondary connects since 1st */
                             /* database connection. */
     2 num_assoc_agents      type sqluint32,
                             /* Current number of agents associated*/
                             /* with appls connected to this db. */
     2 agents_top            type sqluint32,
                             /* max # of agents associated at once */
                             /* with appls connected to this db. */
     2 coord_agents_top      type sqluint32,
                             /* max # of coordinating agents */
                             /* connected to this db. at one time. */
     2 db_location           type sqluint16,
                             /* local or remote to snapshot appl. */
     2 server_platform       type sqluint16,/* OS on which dbm runs */
     2 catalog_node_name     char(SQLM_LG_IDENT_SZ),
                             /* Catalog network node name */
     2 prefetch_wait_time    type sqluint32,
                             /* Time waited for prefetch (ms) */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Application Section Retrieval Information */
     /*****************************************************************/
     2 appl_section_lookups  type sqluint32, /* # of section lookups  */
     2 appl_section_inserts  type sqluint32, /* # of sections inserted*/
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5_2 Hash join information                   */
     /*****************************************************************/
     2 total_hash_joins      type sqluint32, /* number of hash joins  */
     2 total_hash_loops      type sqluint32, /* number of hash loops  */
     2 hash_join_overflows   type sqluint32,
                             /* number of hash join overflows */
     2 hash_join_small_overflows type sqluint32;
                             /* small hash join overflows */


 /*********************************************************************/
 /* Application snapshot                                              */
 /*********************************************************************/
 /* layout:                                                           */
 /* sqlm_appl may be followed by secondary structures that provide    */
 /* more information about the application.                           */
 /*                                                                   */
 /* The secondary structures are returned in the following order.     */
 /*   1) List of associated agents                                    */
 /*      sqlm_agent for each *associated* agent                       */
 /*      (either active or idle)                                      */
 /*   2) Lock Wait info                                               */
 /*      sqlm_lock_wait for each lock waited on (returned if lock     */
 /*      switch is set)                                               */
 /*   3) Statement level information   (returned if statement switch  */
 /*      is set)                                                      */
 /*      Statement information is returned using the following        */
 /*      structures, returned in order:                               */
 /*                                                                   */
 /*       +---------------------------------+----------------------+  */
 /*       |Non-Partitioned Databases        |Partitionned Databases|  */
 /*       +----------------+----------------+----------------------+  */
 /*       |Query degree = 1|Query degree > 1|Query degree = n      |  */
 /*       +----------------+----------------+----------------------+  */
 /*       |sqlm_stmt       |sqlm_stmt       |sqlm_stmt             |  */
 /*       |                |sqlm_agent      |sqlm_subsection       |  */
 /*       |                |                |sqlm_agent            |  */
 /*       +----------------+----------------+----------------------+  */
 /*                                                                   */
 /*      An sqlm_stmt is returned for each currently open cursor,     */
 /*      and for the most recent statement processed (either the      */
 /*      statement still running, if any, or last one terminated).    */
 /*      Each sqlm_stmt may be followed by subsection and/or agent    */
 /*      information for the statement.                               */
 /*                                                                   */
 /*      On partitioned systems, an sqlm_subsection is returned for   */
 /*      each subsection processed.                                   */
 /*                                                                   */
 /*      An sqlm_agent is returned for each agent *currently working* */
 /*      on either a statement or subsection.                         */
 /*                                                                   */
 /* For example, assuming a partitioned database:                     */
 /*                                                                   */
 /*    high-level struct            secondary-level structures        */
 /* |-----------+-----------|--------------------+---------------- ...*/
 /* +-----------------------+----------+----------+--------------+    */
 /* |sqlm_appl              |sqlm_agent|sqlm_agent|sqlm_lock_wait|    */
 /* |num_sec_appl_structs:10|          |          |              | ...*/
 /* |num_assoc_agents:    2 |          |          |              |    */
 /* +-----------------------+----------+----------+--------------+    */
 /*                                                                   */
 /*          secondary-level structures (continued)                   */
 /*   ---------------------+-------------------------------------- ...*/
 /*   +---------------+---------------+----------+---------------+    */
 /*   |sqlm_stmt      |sqlm_subsection|sqlm_agent|sqlm_subsection|    */
 /*   |num_ss: 2      |               |          |               | ...*/
 /*   |num_agents: 2  |num_agents: 1  |          |num_agents: 1  |    */
 /*   +---------------+---------------+----------+---------------+    */
 /*                                                                   */
 /*          secondary-level structures (continued)                   */
 /*  ... ----------------------------------------------|              */
 /*      +-------------+---------------+---------------+              */
 /*      |sqlm_agent   |sqlm_stmt      |sqlm_subsection|              */
 /*  ... |             |num_ss: 1      |               |              */
 /*      |             |num_agents: 0  |num_agents: 0  |              */
 /*      +-------------+---------------+---------------+              */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_appl,
     2 size  type sqluint32, /* size of sqlm_appl */
     2 info_type    char(1), /* Always set to SQLM_APPL_SS */
     2 pad1         char(3), /* padding for 4-byte alignment */
     /*****************************************************************/
     /* Identification Information                                    */
     /*****************************************************************/
     2 id_info               type sqlm_appl_id_info,
                             /* identification information */
     /*****************************************************************/
     /* Lock Information                                              */
     /*****************************************************************/
     2 locks_held            type sqluint32,
                             /* locks currently held by appl. */
     2 lock_waits            type sqluint32,
                             /* Lock waits since appl. connect */
     2 lock_wait_time        type sqluint32,
                             /* total time appl waited on locks */
     2 lock_escals           type sqluint32,
                             /* Lock Escalations since appl conn. */
     2 x_lock_escals         type sqluint32,
                             /* X lock escals since appl connect */
     2 deadlocks             type sqluint32,
                             /* Deadlocks since appl. connect */
     2 uow_lock_wait_time    type sqluint32,
                             /* time UOW waited on locks (ms) */
     2 agent_id_holding_lk   type sqluint32,
                             /* OBSOLETE : use sqlm_lock_wait */
     2 table_file_id         type sqluint32,
                             /* OBSOLETE : use sqlm_lock_wait */
     2 lock_mode             type sqluint32,
                             /* OBSOLETE : use sqlm_lock_wait */
     2 lock_object_type      type sqluint32,
                             /* OBSOLETE : use sqlm_lock_wait */
     2 lock_object_name      type sqluint32,
                             /* OBSOLETE : use sqlm_lock_wait */
     2 lock_wait_start_time  type sqlm_timestamp,
                             /* OBSOLETE : use sqlm_lock_wait */
     2 appl_id_holding_lk    char(SQLM_APPLID_SZ), /* OBSOLETE */
     2 sequence_no_holding_lk char(SQLM_SEQ_SZ),          /* OBSOLETE */
     /*****************************************************************/
     /* Sorting Information                                           */
     /*****************************************************************/
     2 total_sorts           type sqluint32,
                             /* Total Sorts since connect */
     2 total_sort_time       type sqluint32,
                             /* elapsed time spent in sorts  */
     2 sort_overflows        type sqluint32,
                             /* number of sort overflows */
     /*****************************************************************/
     /* Buffer Pool Information                                       */
     /*****************************************************************/
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads since conn*/
     2 pool_data_p_reads     type sqluint32,
                             /* pool data reads since 1st connect */
     2 pool_data_writes      type sqluint32,
                             /* pool data writes since 1st connect*/
     2 pool_index_l_reads    type sqluint32,
                             /* pool indx logical reads since conn*/
     2 pool_index_p_reads    type sqluint32,
                             /* pool indx reads since 1st connect */
     2 pool_index_writes     type sqluint32,
                             /* pool indx writes since 1st connect*/
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time since 1st conn*/
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time since 1st con*/
     /*****************************************************************/
     /* SQL statement counts                                          */
     /*****************************************************************/
     2 commit_sql_stmts      type sqluint32,
                             /* # of Commit SQL stmts since conn */
     2 rollback_sql_stmts    type sqluint32,
                             /* # of Rollback SQL stmts since conn*/
     2 dynamic_sql_stmts     type sqluint32,
                             /* # of Dynamic SQL stmts since conn */
     2 static_sql_stmts      type sqluint32,
                             /* # of Static SQL stmts since conn */
     2 failed_sql_stmts      type sqluint32,
                             /* # of Failed SQL stmts since conn */
     2 select_sql_stmts      type sqluint32,
                             /* # of SQL select stmts since conn */
     2 ddl_sql_stmts         type sqluint32,
                             /* # of data definition lang. stmts */
     2 uid_sql_stmts         type sqluint32,
                             /* # of update/insert/delete stmts */
     /*****************************************************************/
     /* Internal counts                                               */
     /*****************************************************************/
     2 int_auto_rebinds      type sqluint32,
                             /* # of Auto Rebinds since 1st conn */
     2 int_rows_deleted      type sqluint32,
                             /* # of Casc. Deletes since 1st conn */
     2 int_rows_updated      type sqluint32,
                             /* # of Set Null Deletes since conn */
     2 int_commits           type sqluint32,
                             /* # of int. Commits since 1st conn */
     2 int_rollbacks         type sqluint32,
                             /* # of int. Rollbacks since 1st conn*/
     2 int_deadlock_rollbacks type sqluint32,
                             /* # of Rollbacks due to deadlock */
                             /* since 1st connect */
     /*****************************************************************/
     /* Row counts                                                    */
     /*****************************************************************/
     2 rows_deleted          type sqluint32,
                             /* # of Rows Deleted since connect*/
     2 rows_inserted         type sqluint32,
                             /* # of Rows Inserted since connect */
     2 rows_updated          type sqluint32,
                             /* # of Rows Updated since connect */
     2 rows_selected         type sqluint32,
                             /* # of Rows Selected since connect */
     /*****************************************************************/
     /* Binds/Precompiles                                             */
     /*****************************************************************/
     2 binds_precompiles   type sqluint32,
                             /* # of Binds/Precomps since 1st conn*/
     /*****************************************************************/
     /* SQL Statement Information - current operation performed on    */
     /* coordinator                                                   */
     /*****************************************************************/
     2 stmt_type           type sqluint32,
     2 stmt_operation      type sqluint32,
     2 section_number      type sqluint32,
     2 stmt_length         type sqluint32,/* OBSOLETE (use sqlm_stmt) */
     2 stmt_sorts          type sqluint32,/* OBSOLETE (use sqlm_stmt) */
     2 stmt_start          type sqlm_timestamp,
     2 stmt_stop           type sqlm_timestamp,
                      /* Last statement stop time, 0 if still running */
     2 cursor_name         char(SQLM_IDENT_SZ),
     2 creator             char(SQLM_IDENT_SZ),
     2 package_name        char(SQLM_IDENT_SZ),
     /*****************************************************************/
     /* Unit-Of-Work Information                                      */
     /*****************************************************************/
     2 uow_log_space_used    type sqluint32,
                             /* Log space used in most recent UOW */
     2 uow_comp_status       type sqluint32,
                             /* previous uow completion status */
     2 prev_uow_stop_time    type sqlm_timestamp,
                             /* prev commit or rollback time */
     2 uow_start_time        type sqlm_timestamp,
                             /* time trans exec started */
     2 uow_stop_time         type sqlm_timestamp,
                             /* unit-of-work stop time */
     /*****************************************************************/
     /* Remote cursor Information                                     */
     /*****************************************************************/
     2 open_rem_curs         type sqluint32,
                             /* Currently open remote cursors */
     2 open_rem_curs_blk     type sqluint32,
                             /* Currently open remote cursors w/blk*/
     2 rej_curs_blk          type sqluint32,
                             /* Rej block remote cursor requests */
     2 acc_curs_blk          type sqluint32,
                             /* Acc block remote cursor requests */
     /*****************************************************************/
     /* Timestamps                                                    */
     /*****************************************************************/
     2 appl_con_time         type sqlm_timestamp,
                             /* Connect start date/time */
     2 conn_complete_time    type sqlm_timestamp,
                             /* Connect complete date/time */
     2 last_reset            type sqlm_timestamp,
                             /* Last reset date and time */
     2 curr_comm_heap_size   type sqluint32,              /* OBSOLETE */
     2 max_comm_heap_size    type sqluint32,              /* OBSOLETE */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Agent CPU times                           */
     /*****************************************************************/
     2 appl_idle_time        type sqluint32,
                             /* Application idle time (seconds) */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 pool_data_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore  type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 authority_lvl         type sqluint32,
                             /* User authorizations */
     2 sql_reqs_since_commit type sqluint32,
                             /* # SQL requests since last commit */
     2 num_sec_appl_structs  type sqluint32,
                             /* Secondary application information */
     2 table_name            char(SQLM_IDENT_SZ),
                             /* OBSOLETE (moved to sqlm_lock_wait) */
     2 table_schema          char(SQLM_IDENT_SZ),
                             /* OBSOLETE (moved to sqlm_lock_wait) */
     2 tablespace_name       char(SQLM_IDENT_SZ),
                             /* OBSOLETE (moved to sqlm_lock_wait) */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 lock information                          */
     /*****************************************************************/
     2 lock_timeouts         type sqluint32,
                             /* number of lock timeouts since conn */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Agent CPU times                           */
     /*****************************************************************/
     2 agent_usr_cpu_time    type sqlm_time,
                             /* total user CPU time of application */
     2 agent_sys_cpu_time    type sqlm_time,
                             /* total application system cpu time */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 SQL Statement CPU times                   */
     /*****************************************************************/
     2 stmt_usr_cpu_time     type sqlm_time,
                             /* OBSOLETE (moved to sqlm_stmt) */
     2 stmt_sys_cpu_time     type sqlm_time,
                             /* OBSOLETE (moved to sqlm_stmt) */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Internal counts                           */
     /*****************************************************************/
     2 int_rows_inserted     type sqluint32,
                             /* # rows insrted for Trigger */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Row Counts                                */
     /*****************************************************************/
     2 rows_read             type sqluint32,
                             /* # rows read since connection */
     2 rows_written          type sqluint32,
                             /* # rows written since connetion */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 I/O Information                           */
     /*****************************************************************/
     2 direct_reads          type sqluint32,
                             /* direct reads since connect */
     2 direct_writes         type sqluint32,
                             /* direct writes since connect */
     2 direct_read_reqs      type sqluint32,
                             /* direct read requests since conn */
     2 direct_write_reqs     type sqluint32,
                             /* direct write requests since conn*/
     2 direct_read_time      type sqluint32,
                             /* direct read time since connect */
     2 direct_write_time     type sqluint32,
                             /* direct write time since connect */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Local Cursor Information                  */
     /*****************************************************************/
     2 open_loc_curs         type sqluint32,
                             /* Currently open local cursors */
     2 open_loc_curs_blk     type sqluint32,
                             /* Currently open local cursors w/blk */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Client Identification Information         */
     /*****************************************************************/
     2 execution_id          char(SQLM_IDENT_SZ),
                             /* login ID */
     2 corr_token            char(SQLM_APPLID_SZ),
                             /* DRDA AS Correlation Token */
     2 client_pid            type sqluint32,
                             /* Process thread ID of client appl. */
     2 client_platform       type sqluint16,
                             /* Platform of client application */
     2 client_protocol       type sqluint16,
                             /* Communications protocol of client */
     2 country_code          type sqluint16,
                             /* Country code of client application */
     2 pad2                  char(2), /* Padding for 4-byte alignment */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Package Cache Information                 */
     /*****************************************************************/
     2 pkg_cache_lookups     type sqluint32,
                             /* # of section lookups */
     2 pkg_cache_inserts     type sqluint32,
                             /* # of sections inserted into cache */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Catalog Cache Information                 */
     /*****************************************************************/
     2 cat_cache_lookups     type sqluint32,
                             /* # of table descriptor lookups */
     2 cat_cache_inserts     type sqluint32,
                             /* # of table descriptors inserted */
     2 cat_cache_overflows   type sqluint32,
                             /* # of catalog cache overflows */
     2 cat_cache_heap_full   type sqluint32,
                             /* # of overflows due to db heap full */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5                                           */
     /*****************************************************************/
     2 coord_node            type sqluint32,
                             /* Coordinating node number. */
     2 num_assoc_agents      type sqluint32,
                             /* # of agents currently associated */
     2 num_agents            type sqluint32,
                             /* # of agents currently active */
     2 agents_stolen         type sqluint32,
                             /* total # of agents stolen from appl.*/
     2 associated_agents_top type sqluint32,
                             /* # of agents associated with this */
                             /* application high water mark. */
     2 appl_priority         type sqlint32,
                             /* priority at which appl agents work */
     2 appl_priority_type    type sqluint32,
                             /* Dynamic or Static */
     2 prefetch_wait_time    type sqluint32,
                             /* Time waited for prefetch (ms) */
     2 coord_agent_pid       type sqlint32,
                             /* Coordinator agent process/thread id*/
     2 appl_section_lookups  type sqluint32,
                             /* # of section lookups */
     2 appl_section_inserts  type sqluint32,
                             /* # of sections inserted */
     2 locks_waiting         type sqluint32,
                             /* # agents currently waiting on locks*/
     2 outbound_comm_address char(SQLM_COMM_ADDR_SZ),
                             /* Outb.comm. addr.*/
     2 inbound_comm_address  char(SQLM_COMM_ADDR_SZ),
                             /* Inb. comm. addr. */
     2 outbound_comm_protocol type sqluint16,
                             /* Outbound comm. protocol */
     2 pad3                  char(2),
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5_2 Hash join information                   */
     /*****************************************************************/
     2 total_hash_joins      type sqluint32,
                             /* number of hash joins */
     2 total_hash_loops      type sqluint32,
                             /* number of hash loops */
     2 hash_join_overflows   type sqluint32,
                             /* number of hash join overflows */
     2 hash_join_small_overflows type sqluint32;
                             /* small hash join overflows */

 /*********************************************************************/
 /* SQL Statement snapshot - returned on application snapshot         */
 /*                          (SQLMA_APPL)                             */
 /*********************************************************************/
 /* layout:                                                           */
 /* sqlm_stmt may be followed by dynamic statement text, and agent    */
 /* structures.                                                       */
 /* On Partitioned database systems, it may be followed by subsection */
 /* statistics. For example:                                          */
 /*                                                                   */
 /*  Non-Partitioned database (query degree=2):                       */
 /*  +-----------------+-----------------+----------+----------+      */
 /*  |sqlm_stmt        |"SELECT *        |sqlm_agent|sqlm_agent|      */
 /*  |  stmt_length: 24|   FROM TABLE1"  |          |          |      */
 /*  |  num_ss:       1|                 |          |          |      */
 /*  |  num_agents:   2|                 |          |          |      */
 /*  +-----------------+-----------------+----------+----------+      */
 /*                                                                   */
 /*  Partitioned database output (query degree=1):                    */
 /*  +-----------------+-----------------+---------------+----------+ */
 /*  |sqlm_stmt        |"SELECT *        |sqlm_subsection|sqlm_agent| */
 /*  |  stmt_length: 24|   FROM TABLE1"  |ss_number: 0   |          | */
 /*  |  num_ss:       1|                 |               |          | */
 /*  |  num_agents:   1|                 |num_agents: 1  |          | */
 /*  +-----------------+-----------------+---------------+----------+ */
 /*                                                                   */
 /* The statement text length is rounded up to a multiple of 4 bytes  */
 /* and is blank padded. It is *NOT* null terminated.                 */
 /* It is retrieved as follows:                                       */
 /*                                                                   */
 /*    char*       snapshot_buffer                                    */
 /*    sqlm_stmt*  stmt_snapshot = (sqlm_stmt*) snapshot_buffer       */
 /*    char *stmt_text = snapshot_buffer +                            */
 /*                      stmt_snapshot->stmt_text_offset              */
 /*                                                                   */
 /* note: num_sec_appl_structs in sqlm_appl includes the count of     */
 /*       sqlm_subsection and sqlm_agent structures.                  */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_stmt,
     2 size        type sqluint32,/* Use instead of sizeof(sqlm_stmt) */
      /* *INCLUDES* variable length SQL text */
     2 info_type   char(1),/* Always set to SQLM_STMT_SS */
     2 pad         char(1),/* padding for half-word alignment */
     2 stmt_node_number      type sqluint16,
                             /* Node where the statement is executing */
     2 stmt_type             type sqluint32,
                             /* type of stmt: Dynamic or static */
     2 stmt_operation        type sqluint32,/* Current Operation */
     2 section_number        type sqluint32,/* Section Number */
     2 query_cost_estimate   type sqluint32,
                             /* SQL compiler estim. in TIMERONS */
     2 query_card_estimate   type sqluint32,
                             /* SQL compiler estim. number of rows */
     2 degree_parallelism    type sqluint32,
                             /* SMP Intraquery Parallelism requested */
     2 stmt_sorts            type sqluint32,
                             /* number of sorts for this statement */
     2 total_sort_time       type sqluint32,
                             /* Total sort time for this statement */
     2 sort_overflows        type sqluint32,
                             /* # of sort overflows for this stmt */
     2 rows_read             type sqluint32,/* # of DMS rows read */
     2 rows_written          type sqluint32,/* # of DMS rows read */
     2 int_rows_deleted      type sqluint32,
                             /* # of internal deletes by the stmt */
     2 int_rows_updated      type sqluint32,
                             /* # of internal updates by the stmt */
     2 int_rows_inserted     type sqluint32,
                             /* # of internal inserts by the stmt */
     2 fetch_count           type sqluint32,/* Count of fetches */
     2 stmt_start            type sqlm_timestamp,
                             /* SQL statement operation start time */
     2 stmt_stop             type sqlm_timestamp,
                             /* SQL statement operation stop time */
     2 cursor_name           char(SQLM_IDENT_SZ),
                             /* sql stmt.cursor name */
     2 creator               char(SQLM_IDENT_SZ),
                             /* auth id for precompile */
     2 package_name          char(SQLM_IDENT_SZ),
                             /* Package Name */
     2 stmt_usr_cpu_time     type sqlm_time,
                             /* total user CPU time of SQL stmt */
     2 stmt_sys_cpu_time     type sqlm_time,
                             /* total system CPU time for SQL stmt */
     2 num_ss                type sqluint32,/* number of subsections */
     2 num_agents            type sqluint32,
                             /* # of agents currently working on stmt */
     2 agents_top            type sqluint32,
                             /* # of agents created for statement */
     2 stmt_length           type sqluint16,
                             /* length of dynamic SQL text, which is */
                             /* blank padded to a 4-byte boundary    */
     2 stmt_text_offset      type sqluint16;
                             /* Text offset from start of sqlm_stmt */

 /*********************************************************************/
 /* SQL Subsection -  returned on application snapshot (SQLMA_APPL)   */
 /*********************************************************************/
 define structure
   1 sqlm_subsection,
     2 size type sqluint32,/* Use instead of sizeof(sqlm_subsection)*/
     2 info_type   char(1),/* Always set to SQLM_SUBSECTION_SS */
     2 pad1        char(1),/* padding for memory alignment */
     2 ss_number             type sqluint16,/* Subsection number */
     2 ss_status             type sqluint16,/* Subsection status */
     2 ss_node_number        type sqluint16,
                             /* Node where the subsection is executing*/
     2 ss_exec_time          type sqluint32,
                             /* Execution elapsed time in seconds */
     2 ss_usr_cpu_time       type sqlm_time,
                             /* total user CPU time (sec.microsec) */
     2 ss_sys_cpu_time       type sqlm_time,
                             /* total system CPU time (sec.microsec) */
                             /* Tablequeue information */
     2 tq_node_waited_for    type sqluint16,
                            /* If blocked when sending or receiving   */
                            /* on a tablequeue, node for which we wait*/
     2 tq_wait_for_any       type sqluint16,
                             /* TRUE if waiting for any node to send */
     2 tq_id_waiting_on      type sqluint16,
                             /* tablequeue waiting to send/receive */
     2 pad2                  char(2),
                             /* padding for 4-byte memory alignment */
     2 tq_tot_send_spills    type sqluint32,
                             /* Total # of buffers overflowed to a */
                             /* temp table when sending data on a tq */
     2 tq_cur_send_spills    type sqluint32,
                            /* Current # of tq send buffers overflowed*/
     2 tq_max_send_spills    type sqluint32,
                            /* Maximum # of tq send buffers overflowed*/
     2 tq_rows_read          type sqluint32,
                             /* Total # rows received on tablequeues */
     2 tq_rows_written       type sqluint32,
                             /* Total # rows sent on tablequeues */
     2 rows_read             type sqluint32,
                             /* # of Data Manager (DMS) rows read */
     2 rows_written          type sqluint32,/* # of DMS rows written */
     2 num_agents            type sqluint32;
                             /* # of agents currently working on subs */

 /*********************************************************************/
 /* SQL Agent -  returned on application snapshot (SQLMA_APPL)        */
 /*********************************************************************/
 define structure
   1 sqlm_agent,
     2 size      type sqluint32,/* Use instead of sizeof(sqlm_agent) */
     2 info_type char(1),       /* Always set to SQLM_AGENT_SS */
     2 pad1      char(3),       /* padding for 4-byte alignment */
     2 agent_pid type sqlint32; /* db2agent process/thread id */

 /*********************************************************************/
 /* Lock Wait Snapshot Information                                    */
 /*********************************************************************/
 define structure
   1 sqlm_lock_wait,
     2 size      type sqluint32,/* Use over sizeof(sqlm_lock_wait) */
     2 info_type char(1),/* Always set to SQLM_LOCK_WAIT_SS */
     2 lock_escalation       char(1),
                             /* Was this lock part of an escalation */
     2 pad1                  char(2),/* padding for 4 byte alignment */
     2 subsection_number     type sqluint32,
                             /* Subsection waiting for lock */
     2 lock_mode             type sqluint32,/* Mode of Lock waited on */
     2 lock_object_type      type sqluint32,
                             /* lock object type: row, table, ... */
     2 lock_wait_start_time  type sqlm_timestamp,
                             /* Time when lock wait entered */
     2 table_name            char(SQLM_IDENT_SZ),
     2 table_schema          char(SQLM_IDENT_SZ),
     2 tablespace_name       char(SQLM_IDENT_SZ),
     2 agent_id_holding_lk   type sqluint32,
                             /* Application holding the lock */
     2 appl_id_holding_lk    char(SQLM_APPLID_SZ);
                             /* Appl. holding the lock */

 /*********************************************************************/
 /* Table Related Snapshot Information                                */
 /*********************************************************************/
 define structure
   1 sqlm_table_header,
     2 size           type sqluint32,/* size of sqlm_table_header */
     2 info_type      char(1),/* Always set to SQLM_TABLE_HEADER_SS*/
     2 pad1           char(3),/* padding for 4-byte alignment */
     2 num_tables     type sqluint32,
                             /* # of sqlm_table struct returned */
     2 db_conn_time   type sqlm_timestamp,
                             /* Time of 1st database connection */
     2 last_reset     type sqlm_timestamp,/* last reset date and time */
     2 input_db_alias char(SQLM_IDENT_SZ),/* Input Database Alias */
     2 db_name        char(SQLM_IDENT_SZ),/* Database name */
     2 db_path        char(SQLM_DBPATH_SZ);/* Database Path */

 define structure
   1 sqlm_table,
     2 size           type sqluint32,/* size of sqlm_table */
     2 info_type      char(1),/* Always set to SQLM_TABLE_SS */
     2 pad1           char(3),/* padding for 4 byte alignment */
     2 table_file_id         type sqluint32,
                             /* the file ID for the table */
     2 table_type            type sqluint32,/* table type */
     2 rows_written          type sqluint32,
                             /* number of changes to the table */
     2 rows_read             type sqluint32,
                             /* number of reads from the table */
     2 overflow_accesses     type sqluint32,
                             /* no. of accesses to overflow rec */
     2 page_reorgs           type sqluint32,
                             /* no. of page reorgs for table */
     2 reserved              char(28),/* reserved for future use */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Table Identification                      */
     /*****************************************************************/
     2 table_name            char(SQLM_IDENT_SZ),/* table name */
     2 table_schema          char(SQLM_IDENT_SZ);/* table schema */

 /*********************************************************************/
 /* lock related information                                          */
 /*********************************************************************/
 /* Database lock snapshot layout, example:                           */
 /*                                                                   */
 /*              high-level struct                                    */
 /*           |-----------+------------|                              */
 /* buffer--->+------------------------+--------------+               */
 /*           |sqlm_dbase_lock         |sqlm_appl_lock| ...           */
 /*           |  num_appls: 2          |          (1) |               */
 /*           +------------------------+--------------+               */
 /*                                                                   */
 /*                                    +--------------+               */
 /*                                ... |sqlm_appl_lock|               */
 /*                                    |              |               */
 /*                                    +--------------+               */
 /*                                                                   */
 /*             (1) see sqlm_appl_lock layout                         */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_dbase_lock,
     2 size           type sqluint32,/* size of sqlm_dbase_lock */
     2 info_type      char(1), /* Always set to SQLM_DBASE_LOCK_SS */
     2 pad            char(3), /* padding for 4-byte alignment */
     2 locks_held            type sqluint32,
                             /* number of locks currently held */
     2 appls_cur_cons        type sqluint32,
                             /* Appls currently connected */
     2 num_appls             type sqluint32,
                             /* # sqlm_appl_lock structs returned */
     2 locks_waiting         type sqluint32,
                             /* Agents currently waiting on locks */
     2 input_db_alias        char(SQLM_IDENT_SZ),
                             /* Input Database Alias */
     2 db_name               char(SQLM_IDENT_SZ),/* Database name */
     2 db_path               char(SQLM_DBPATH_SZ);/* Database Path */

 /*********************************************************************/
 /* Application lock snapshot                                         */
 /*********************************************************************/
 /* Application lock snapshot layout, example:                        */
 /*                                                                   */
 /*              high-level struct                                    */
 /*           |-----------+------------|                              */
 /* buffer--->+------------------------+--------------+---------+     */
 /*           |sqlm_appl_lock          |sqlm_lock_wait|sqlm_lock| ... */
 /*           |  num_locks: 2          |              |         |     */
 /*           |  num_lockwaits: 1      |              |         |     */
 /*           +------------------------+--------------+---------+     */
 /*                                                                   */
 /*                                                   +---------+     */
 /*                                               ... |sqlm_lock|     */
 /*                                                   |         |     */
 /*                                                   |         |     */
 /*                                                   +---------+     */
 /*                                                                   */
 /* Lock waits, if any, *always precede the locks*. That is, read the */
 /* buffer in the following manner:                                   */
 /*                                                                   */
 /*    sqlm_appl_lock *app_lock_info = (sqlm_appl_lock*) buffer       */
 /*    while (app_lock_info->num_lockwaits--)                         */
 /*    {                                                              */
 /*       sqlm_lock_wait *appl_lock = (sqlm_lock_wait*) buffer        */
 /*                . . .                                              */
 /*       buffer += appl_lock->size                                   */
 /*    }                                                              */
 /*    while (app_lock_info->num_locks--)                             */
 /*    {                                                              */
 /*       sqlm_lock *lock = (sqlm_lock*) buffer                       */
 /*                 . . .                                             */
 /*       buffer += lock->size                                        */
 /*    }                                                              */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_appl_lock,
     2 size           type sqluint32,/* size of sqlm_appl_lock */
     2 info_type      char(1), /* Always set to SQLM_APPL_LOCK_SS */
     2 pad            char(3), /* padding for 4-byte alignment */
     /*****************************************************************/
     /* Application Identification Information                        */
     /*****************************************************************/
     2 agent_id              type sqluint32,/* Application handle */
     2 appl_status           type sqluint32,/* Application Status */
     2 codepage_id           type sqluint32,/* codepage/CCSID at node */
                                            /* where app started      */
     2 locks_held            type sqluint32,
                             /* locks currently held by appl. */
     2 num_locks             type sqluint32,
                             /* # sqlm_lock structures returned */
     2 status_change_time    type sqlm_timestamp,
                             /* last appl status change time */
     2 appl_id               char(SQLM_APPLID_SZ),/* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* appl id sequence number */
     2 appl_name             char(SQLM_IDENT_SZ),/* Application Name */
     2 auth_id               char(SQLM_IDENT_SZ),/* Authorization Id */
     2 client_db_alias       char(SQLM_IDENT_SZ),
                             /* Client Database Alias */
     2 agent_id_holding_lk   type sqluint32,/* OBSOLETE */
     2 lock_object_name      type sqluint32,/* OBSOLETE */
     2 lock_object_type      type sqluint32,/* OBSOLETE */
     2 table_file_id         type sqluint32,/* OBSOLETE */
     2 appl_id_holding_lk    char(SQLM_APPLID_SZ),/* OBSOLETE */
     2 sequence_no_holding_lk char(SQLM_SEQ_SZ),/* OBSOLETE */
     2 reserved              char(24),/* OBSOLETE */
     2 lock_wait_time        type sqluint32,
                             /* total wait time in millisec */
     2 num_lockwaits         type sqluint32,
                             /* # sqlm_lock_wait following */
     2 table_name            char(SQLM_IDENT_SZ),/* OBSOLETE */
     2 table_schema          char(SQLM_IDENT_SZ),/* OBSOLETE */
     2 tablespace_name       char(SQLM_IDENT_SZ);/* OBSOLETE */

 define structure
   1 sqlm_lock,
     2 size                  type sqluint32,/* size of sqlm_lock */
     2 info_type             char(1),/* Always set to SQLM_LOCK_SS */
     2 lock_escalation       char(1),
                             /* Was this lock part of an escalation */
     2 pad                   char(2),/* padding for 4-byte alignment */
     2 table_file_id         type sqluint32,
                             /* FID of table involved in lock */
     2 lock_object_type      type sqluint32,
                             /* lock object type: row, table */
     2 lock_mode             type sqluint32,/* Lock mode */
     2 lock_status           type sqluint32,/* Lock status */
     2 lock_object_name      type sqluint32,/* Lock Object Name -     */
                                            /* RID or FID of lock obj */
     2 reserved              char(32),/* reserved for future use */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION2 Lock Information                          */
     /*****************************************************************/
     2 table_name            char(SQLM_IDENT_SZ),/* table name */
     2 table_schema          char(SQLM_IDENT_SZ),/* table schema */
     2 tablespace_name       char(SQLM_IDENT_SZ);
                             /* name of the tablespace */

 /*********************************************************************/
 /* Tablespace Related Snapshot Information                           */
 /*********************************************************************/
 define structure
   1 sqlm_tablespace_header,
     2 size         type sqluint32,/* size of sqlm_tablespace_header */
     2 info_type    char(1),/* Set to SQLM_TABLESPACE_HEADER_SS */
     2 pad          char(3),/* padding for 4-byte alignment */
     2 num_tablespaces       type sqluint32,
                             /* # sqlm_tablespace structs returned*/
     2 db_conn_time          type sqlm_timestamp,
                             /* Time of 1st database connection */
     2 last_reset            type sqlm_timestamp,
                             /* last reset date and time */
     2 input_db_alias        char(SQLM_IDENT_SZ),
                             /* Input Database Alias */
     2 db_name               char(SQLM_IDENT_SZ),/* Database name */
     2 db_path               char(SQLM_DBPATH_SZ);/* Database Path */


 define structure
   1 sqlm_tablespace,
     2 size            type sqluint32,/* size of sqlm_table */
     2 info_type       char(1),/* Always set to SQLM_TABLESPACE_SS */
     2 pad             char(3),/* padding for 4 byte alignment */
     2 tablespace_name       char(SQLM_IDENT_SZ),
                             /* name of the tablespace */
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads since conn*/
     2 pool_data_p_reads     type sqluint32,
                             /* pool data physical reads since con*/
     2 pool_async_data_reads type sqluint32,
                             /* asynchronous pool data reads */
     2 pool_data_writes      type sqluint32,
                             /* pool data writes since connect */
     2 pool_async_data_writes type sqluint32,
                             /* asynchronous pool data writes */
     2 pool_index_l_reads    type sqluint32,
                             /* pool index logical reads since con*/
     2 pool_index_p_reads    type sqluint32,
                             /* pool index physical reads since cn*/
     2 pool_index_writes     type sqluint32,
                             /* pool index writes since connect */
     2 pool_async_index_writes type sqluint32,
                             /* asynchronous pool index writes */
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time since 1st conn*/
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time since 1st con*/
     2 pool_async_read_time  type sqluint32,
                             /* asynchronous read time */
     2 pool_async_write_time type sqluint32,
                             /* asynchronous write time */
     2 pool_async_data_read_reqs type sqluint32,
                             /* # async read requests */
     2 direct_reads          type sqluint32,
                             /* direct reads since 1st connect */
     2 direct_writes         type sqluint32,
                             /* direct writes since 1st conn */
     2 direct_read_reqs      type sqluint32,
                             /* direct read requests */
     2 direct_write_reqs     type sqluint32,
                             /* direct write requests */
     2 direct_read_time      type sqluint32,
                             /* direct read time since 1st conn */
     2 direct_write_time     type sqluint32,
                             /* direct write time since 1st conn */
     2 files_closed          type sqluint32,
                             /* files closed for tablespace */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 pool_async_index_reads type sqluint32,
                             /* asynchronous pool index reads */
     2 pool_data_to_estore    type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore  type sqluint32;
                             /* #pages copied from estore to BP */

 define structure
   1 sqlm_rollfwd_info,
     2 size       type sqluint32,
                          /* Use instead of sizeof(sqlm_rollfwd_info) */
     2 info_type  char(1),/* Always set to SQLM_DBASE_ROLLFWD_SS */
     2 pad        char(1),/* For 2-byte alignment */
     2 node_number           type sqluint16,
                             /* Node for which this info is about */
     2 rf_type               type sqluint32,
                             /* database or tablespace rollforward */
     2 rf_log_num            type sqluint32,
                             /* Current log being processed */
     2 rf_status             type sqluint32,
                             /* Log phase in progress */
     2 rf_timestamp          type sqluint32,
                           /* Time of Log record currently processed, */
                           /* GMT time in seconds since Jan 1st, 1970 */
     2 rf_num_tspaces        type sqluint32;
                           /* number of sqlm_rollfwd_ts_info following*/

 define structure
   1 sqlm_rollfwd_ts_info,
     2 size                  type sqluint32,
                             /* Must use to skip this record in buffer*/
     2 info_type             char(1),
                       /* Always set to SQLM_DBASE_ROLLFWD_TS_NAME_SS */
     2 pad                   char(3),/* For 4-byte alignment */
     2 ts_name               char(SQLM_IDENT_SZ);
                             /* Tablespace being rolled forward */


 /*********************************************************************/
 /* Bufferpool Related Snapshot Information                           */
 /*********************************************************************/
 define structure
   1 sqlm_bp_info,
     /* Version 1 counters */
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads */
     2 pool_data_p_reads     type sqluint32,
                             /* pool data physical reads */
     2 pool_data_writes      type sqluint32,
                             /* pool data writes */
     2 pool_index_l_reads    type sqluint32,
                             /* pool index logical reads */
     2 pool_index_p_reads    type sqluint32,
                             /* pool index physical reads */
     2 pool_index_writes     type sqluint32,
                             /* pool index writes */
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time */
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time */
     2 files_closed          type sqluint32,
                             /* files closed for bufferpool */
     /* Version 2 counters */
     2 pool_async_data_reads type sqluint32,
                             /* asynchronous pool data reads */
     2 pool_async_data_writes type sqluint32,
                             /* asynchronous pool data writes */
     2 pool_async_index_writes type sqluint32,
                             /* asynchronous pool index writes */
     2 pool_async_read_time  type sqluint32,
                             /* asynchronous read time */
     2 pool_async_write_time type sqluint32,
                             /* asynchronous write time */
     2 pool_async_data_read_reqs type sqluint32,
                             /* # async read requests */
     2 direct_reads          type sqluint32,/* direct reads */
     2 direct_writes         type sqluint32,/* direct writes */
     2 direct_read_reqs      type sqluint32,
                             /* direct read requests */
     2 direct_write_reqs     type sqluint32,
                             /* direct write requests */
     2 direct_read_time      type sqluint32,
                             /* direct read time */
     2 direct_write_time     type sqluint32,
                             /* direct write time */
     /* Version 3 counters */
     2 pool_async_index_reads type sqluint32,
                             /* asynchronous pool index reads */
     2 pool_data_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore  type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore type sqluint32;
                             /* #pages copied from estore to BP */

 define structure
   1 sqlm_bufferpool,
     2 size  type sqluint32, /* Use instead of sizeof(sqlm_bufferpool)*/
     2 info_type    char(1), /* Always set to SQLM_BUFFERPOOL_SS */
     2 pad          char(3), /* For 4-byte memory alignment */
     2 bp_name        char(SQLM_IDENT_SZ),/* Bufferpool name */
     2 input_db_alias char(SQLM_IDENT_SZ),/* Database alias */
     2 db_name        char(SQLM_IDENT_SZ),/* Database name */
     2 db_path        char(SQLM_DBPATH_SZ),/* Database Path */
     2 bp_info        type sqlm_bp_info;
                      /* total stats from all tspaces for this bp */

 /*********************************************************************/
 /*********************************************************************/
 /* Event Monitoring event records                                    */
 /*********************************************************************/
 /*********************************************************************/

 /*********************************************************************/
 /* Log Stream Event Header for event monitors v6 and later           */
 /*********************************************************************/
 define structure
   1 sqlm_event_log_stream_header,
     2 byte_order type sqlint32,
     2 size       type sqluint32,
     2 version    type sqluint32;

 /*********************************************************************/
 /*  Event Monitor Log Header Record                                  */
 /*********************************************************************/
 define structure
   1 sqlm_event_log_header,
     2 byte_order            type sqlint32,
                             /* Big Endian or Little Endian */
     2 size                  type sqluint32,/* Size of this record */
     2 version               type sqluint32,/* Event Monitor Version */
     2 event_monitor_name    char(SQLM_IDENT_SZ),
                             /* Name of the Event Mon */
     2 codepage_id           type sqluint16,
                             /* Code page of Database */
     2 country_code          type sqluint16,
                             /* Country Code of Database */
     2 server_prdid          char(SQLM_IDENT_SZ),
                             /* Server Product Id */
     2 server_instance_name  char(SQLM_IDENT_SZ),
                             /*instance name of DB2 */
     2 num_nodes_in_db2_instance type sqluint32;/* 1 if SERIAL */

 /*********************************************************************/
 /* Event Monitor Record Header                                       */
 /*********************************************************************/
 define structure
   1 sqlm_event_rec_header,
     /* All event monitor event records have size and type as their   */
     /* first data elements. These fields can be viewed as a          */
     /* 'header' that has to be read first to determine how to read   */
     /* the rest of the data. The record size for a given event type  */
     /* may vary between releases of DB2.                             */
     2 size type sqluint32, /* size of Event (size of entire struct)  */
     2 type type sqluint32; /* type of Event */

 /*********************************************************************/
 /*  Event Monitor Database Event Record                              */
 /*********************************************************************/
 define structure
   1 sqlm_db_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     /*****************************************************************/
     /* Locking Information                                           */
     /*****************************************************************/
     2 lock_waits            type sqluint32,/* Lock waits */
     2 lock_wait_time        type sqluint32,
                             /* Total time dbase waited on locks */
     2 deadlocks             type sqluint32,/* Deadlocks */
     2 lock_escals           type sqluint32,/* lock escalations */
     2 x_lock_escals         type sqluint32,/* X lock escalations */
     2 lock_timeouts         type sqluint32,/* Lock timeouts */
     /*****************************************************************/
     /* Sorting Information                                           */
     /*****************************************************************/
     2 total_sorts           type sqluint32,/* number of sorts */
     2 total_sort_time       type sqluint32,
                             /* elapsed time spent in sorts */
     2 sort_overflows        type sqluint32,
                             /* number of sort overflows */
     /*****************************************************************/
     /* Buffer Pool and I/O Information                               */
     /*****************************************************************/
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads */
     2 pool_data_p_reads     type sqluint32,
                             /* pool data physical reads */
     2 pool_async_data_reads type sqluint32,
                             /* asynchronous pool data reads */
     2 pool_data_writes      type sqluint32,
                             /* pool data writes */
     2 pool_async_data_writes type sqluint32,
                             /* asynchronous pool data writes */
     2 pool_index_l_reads    type sqluint32,
                             /* pool index logical reads */
     2 pool_index_p_reads    type sqluint32,
                             /* pool index physicl reads */
     2 pool_index_writes     type sqluint32,
                             /* pool index page writes */
     2 pool_async_index_writes type sqluint32,
                             /* asynchronous pool index writes */
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time */
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time */
     2 pool_async_read_time  type sqluint32,
                             /* asynchronous read time */
     2 pool_async_write_time type sqluint32,
                             /* asynchronous write time */
     2 pool_async_data_read_reqs type sqluint32,
                             /* # async read requests */
     2 pool_lsn_gap_clns     type sqluint32,
                             /* LSN Gap cleaner triggers */
     2 pool_drty_pg_steal_clns type sqluint32,
                             /* dirty page steal cleaner trig.*/
     2 pool_drty_pg_thrsh_clns type sqluint32,
                             /* dirty list threshold cln trig.*/
     2 direct_reads          type sqluint32,/* direct reads */
     2 direct_writes         type sqluint32,/* direct writes */
     2 direct_read_reqs      type sqluint32,/* direct read requests */
     2 direct_write_reqs     type sqluint32,/* direct write requests */
     2 direct_read_time      type sqluint32,/* direct read time */
     2 direct_write_time     type sqluint32,/* direct write time */
     2 files_closed          type sqluint32,/* files closed */
     /*****************************************************************/
     /* SQL statement counts                                          */
     /*****************************************************************/
     2 commit_sql_stmts      type sqluint32,
                             /* # of Commit SQL statements */
     2 rollback_sql_stmts    type sqluint32,
                             /* # of Rollback SQL statements */
     2 dynamic_sql_stmts     type sqluint32,
                             /* # of Dynamic SQL statements */
     2 static_sql_stmts      type sqluint32,
                             /* # of Static SQL statements */
     2 failed_sql_stmts      type sqluint32,
                             /* # of Failed SQL statements */
     2 select_sql_stmts      type sqluint32,
                             /* # of SQL select statements */
     2 ddl_sql_stmts         type sqluint32,
                             /* # of data definition lang. stmts */
     2 uid_sql_stmts         type sqluint32,
                             /* # of update/insert/delete stmts */
     /*****************************************************************/
     /* Internal counts                                               */
     /*****************************************************************/
     2 int_auto_rebinds      type sqluint32,
                             /* # of interanl auto rebinds */
     2 int_rows_deleted      type sqluint32,
                             /* # of internal rows deleted */
     2 int_rows_updated      type sqluint32,
                             /* # of internal rows updated */
     2 int_rows_inserted     type sqluint32,
                             /* # of internal rows inserted */
     2 int_commits           type sqluint32,/* # of internal commits */
     2 int_rollbacks         type sqluint32,/* # of internal rollbacks*/
     /*****************************************************************/
     /* Row counts                                                    */
     /*****************************************************************/
     2 rows_deleted          type sqluint32,/* # of Rows Deleted */
     2 rows_inserted         type sqluint32,/* # of Rows Inserted */
     2 rows_updated          type sqluint32,/* # of Rows Updated */
     2 rows_selected         type sqluint32,/* # of Rows Selected */
     /*****************************************************************/
     /* Binds/Precompiles                                             */
     /*****************************************************************/
     2 binds_precompiles     type sqluint32,
                             /* # of Binds/Precomps/Rebinds */
     /*****************************************************************/
     /* Timestamps                                                    */
     /*****************************************************************/
     2 disconn_time          type sqlm_timestamp,
                             /* Time of last database disconnect */
     /*****************************************************************/
     /* Application connection counters                               */
     /*****************************************************************/
     2 total_cons            type sqluint32,/* Total Connects */
     2 connections_top       type sqluint32,
                             /* High water mark for connections */
     /*****************************************************************/
     /* Database memory pool high water marks                         */
     /*****************************************************************/
     2 db_heap_top           type sqluint32,
                             /* High water mark for dbheap */
     /*****************************************************************/
     /* Logging Information                                           */
     /*****************************************************************/
     2 sec_log_used_top      type sqluint32,
                             /* Maximum secondary log space used */
     2 tot_log_used_top      type sqluint32,
                             /* Maximum total log space used */
     2 log_reads             type sqluint32,/* # of log pages read */
     2 log_writes            type sqluint32,/* # of log pages written */
     /*****************************************************************/
     /* Package Cache Information                                     */
     /*****************************************************************/
     2 pkg_cache_lookups     type sqluint32,/* # of section lookups */
     2 pkg_cache_inserts     type sqluint32,
                             /* # of sections inserted into cache */
     /*****************************************************************/
     /* Catalog Cache Information                                     */
     /*****************************************************************/
     2 cat_cache_lookups     type sqluint32,
                             /* # of table descriptor lookups */
     2 cat_cache_inserts     type sqluint32,
                             /* # of table descriptors inserted */
     2 cat_cache_overflows   type sqluint32,
                             /* # of catalog cache overflows */
     2 cat_cache_heap_full   type sqluint32,
                             /* # of overflows due to db heap full */
     /*****************************************************************/
     /* Application Section Retrieval Information                     */
     /*****************************************************************/
     2 appl_section_lookups  type sqluint32,/* # of section lookups */
     2 appl_section_inserts  type sqluint32,/* # of sections inserted */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 pool_async_index_reads type sqluint32,
                             /* asynchronous pool index reads */
     2 pool_data_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore  type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 prefetch_wait_time    type sqluint32,
                             /* Time spent waiting for prefetch(ms)*/
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Server details                            */
     /*****************************************************************/
     2 catalog_node          type sqluint32,/* catalog node number */
     2 server_platform       type sqluint16,
                             /* OS on which the db manager runs */
     2 catalog_node_name     char(SQLM_LG_IDENT_SZ),
                             /* Catalog network node name */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5_2 Hash join information                   */
     /*****************************************************************/
     2 total_hash_joins      type sqluint32,/* number of hash joins */
     2 total_hash_loops      type sqluint32,/* number of hash loops */
     2 hash_join_overflows   type sqluint32,
                             /* number of hash join overflows */
     2 hash_join_small_overflows type sqluint32;
                             /* small hash join overflows */


 /*********************************************************************/
 /*  Event Monitor Connection Event Record                            */
 /*********************************************************************/
 define structure
   1 sqlm_conn_event,
     2 size        type sqluint32,/* event record size */
     2 event_type  type sqluint32,/* event type identifier */
     2 appl_id     char(SQLM_APPLID_SZ),/* Application Id */
     2 sequence_no char(SQLM_SEQ_SZ),/* application id sequence number*/
     /*****************************************************************/
     /* Locking Information                                           */
     /*****************************************************************/
     2 lock_waits            type sqluint32,
                             /* Lock waits since appl. connect */
     2 lock_wait_time        type sqluint32,
                             /* total time waited on locks in ms */
     2 lock_escals           type sqluint32,
                             /* Lock Escalations since appl conn. */
     2 x_lock_escals         type sqluint32,
                             /* X lock escals since appl connect */
     2 deadlocks             type sqluint32,
                             /* Deadlocks since appl. connect */
     2 lock_timeouts         type sqluint32,
                             /* Lock timeouts since 1st db connect*/
     /*****************************************************************/
     /* Sorting Information                                           */
     /*****************************************************************/
     2 total_sorts           type sqluint32,
                             /* Total Sorts since connect */
     2 total_sort_time       type sqluint32,
                             /* elapsed time spent in sorts */
     2 sort_overflows        type sqluint32,
                             /* number of sort overflows */
     /*****************************************************************/
     /* Buffer Pool and I/O Information                               */
     /*****************************************************************/
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads since conn*/
     2 pool_data_p_reads     type sqluint32,
                             /* pool data physical reads since con*/
     2 pool_data_writes      type sqluint32,
                             /* pool data writes since 1st connect*/
     2 pool_index_l_reads    type sqluint32,
                             /* pool indx logical reads since conn*/
     2 pool_index_p_reads    type sqluint32,
                             /* pool indx physical reads since con*/
     2 pool_index_writes     type sqluint32,
                             /* pool indx writes since 1st connect*/
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time since 1st conn*/
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time since 1st con*/
     2 direct_reads          type sqluint32,
                             /* direct reads since connect */
     2 direct_writes         type sqluint32,
                             /* direct writes since connect */
     2 direct_read_reqs      type sqluint32,
                             /* direct read requests since conn */
     2 direct_write_reqs     type sqluint32,
                             /* direct write requests since conn */
     2 direct_read_time      type sqluint32,
                             /* direct read time since connect */
     2 direct_write_time     type sqluint32,
                             /* direct write time since connect */
     /*****************************************************************/
     /* SQL statement counts                                          */
     /*****************************************************************/
     2 commit_sql_stmts      type sqluint32,
                             /* # of Commit SQL stmts since conn */
     2 rollback_sql_stmts    type sqluint32,
                             /* # of Rollback SQL stmts since conn*/
     2 dynamic_sql_stmts     type sqluint32,
                             /* # of Dynamic SQL stmts since conn */
     2 static_sql_stmts      type sqluint32,
                             /* # of Static SQL stmts since conn */
     2 failed_sql_stmts      type sqluint32,
                             /* # of Failed SQL stmts since conn */
     2 select_sql_stmts      type sqluint32,
                             /* # of SQL select stmts since conn */
     2 ddl_sql_stmts         type sqluint32,
                             /* # of data definition lang. stmts */
     2 uid_sql_stmts         type sqluint32,
                             /* # of update/insert/delete stmts */
     /*****************************************************************/
     /* Internal counts                                               */
     /*****************************************************************/
     2 int_auto_rebinds      type sqluint32,
                             /* # of Auto Rebinds since connect */
     2 int_rows_deleted      type sqluint32,
                             /* # of internal deletes since conn */
     2 int_rows_updated      type sqluint32,
                             /* # of internal updates since conn */
     2 int_rows_inserted     type sqluint32,
                             /* # of internal inserts since conn */
     2 int_commits           type sqluint32,
                             /* # of int. Commits since 1st conn */
     2 int_rollbacks         type sqluint32,
                             /* # of int. Rollbacks since 1st conn*/
     2 int_deadlock_rollbacks type sqluint32,
                             /* # of Rollbacks due to deadlock */
                             /* since 1st connect */
     /*****************************************************************/
     /* Row counts                                                    */
     /*****************************************************************/
     2 rows_deleted          type sqluint32,
                             /* # of Rows Deleted since connect */
     2 rows_inserted         type sqluint32,
                             /* # of Rows Inserted since connect */
     2 rows_updated          type sqluint32,
                             /* # of Rows Updated since connect */
     2 rows_selected         type sqluint32,
                             /* # of Rows Selected since connect */
     2 rows_read             type sqluint32,
                             /* # of Rows read since connect */
     2 rows_written          type sqluint32,
                             /* # of Rows written since connect */
     /*****************************************************************/
     /* Binds/Precompiles                                             */
     /*****************************************************************/
     2 binds_precompiles     type sqluint32,
                             /* # of Binds/Precomps/Rebinds */
     /*****************************************************************/
     /* Blocking Cursor Information                                   */
     /*****************************************************************/
     2 rej_curs_blk          type sqluint32,
                             /* Rejected block cursor requests */
     2 acc_curs_blk          type sqluint32,
                             /* Accepted block cursor requests */
     /*****************************************************************/
     /* Timestamps                                                    */
     /*****************************************************************/
     2 disconn_time          type sqlm_timestamp,
                             /* Disconnection date/time */
     /*****************************************************************/
     /* Agents activity                                               */
     /*****************************************************************/
     2 user_cpu_time         type sqlm_time,
                             /* Total user CPU time of appl agents */
     2 system_cpu_time       type sqlm_time,
                             /* Total system CPU time of appl agents */
     /*****************************************************************/
     /* Package Cache Information                                     */
     /*****************************************************************/
     2 pkg_cache_lookups     type sqluint32,/* # of section lookups */
     2 pkg_cache_inserts     type sqluint32,
                             /* # of sections inserted into cache */
     /*****************************************************************/
     /* Catalog Cache Information                                     */
     /*****************************************************************/
     2 cat_cache_overflows   type sqluint32,
                             /* # of catalog cache overflows */
     2 cat_cache_heap_full   type sqluint32,
                             /* # of overflows due to db heap full */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5                                           */
     /*****************************************************************/
     2 appl_section_lookups  type sqluint32,/* # of section lookups */
     2 appl_section_inserts  type sqluint32,/* # of sections inserted */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 prefetch_wait_time    type sqluint32,
                             /* Time waited for prefetch (ms) */
     2 pool_data_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore  type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5                                           */
     /*****************************************************************/
     2 authority_lvl         type sqluint32,/* user authorizations */
     2 coord_node            type sqluint32,
                             /* coordinating node number */
     2 appl_priority         type sqlint32,
                             /* priority at which appl agents work*/
     2 appl_priority_type    type sqluint32,/* dynamic or static */
     2 agent_id              type sqluint32,/* Application handle */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5_2 Hash join information                   */
     /*****************************************************************/
     2 total_hash_joins      type sqluint32,/* number of hash joins */
     2 total_hash_loops      type sqluint32,/* number of hash loops */
     2 hash_join_overflows   type sqluint32,
                             /* number of hash join overflows */
     2 hash_join_small_overflows type sqluint32,
                             /* small hash join overflows */
     2 cat_cache_inserts     type sqluint32,
                             /* # of catalog cache inserts */
     2 cat_cache_lookups     type sqluint32;
                             /* # of catalog cache overflows */


 /*********************************************************************/
 /*  Event Monitor Table Event Record                                 */
 /*********************************************************************/
 define structure
   1 sqlm_table_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     2 table_name            char(SQLM_IDENT_SZ),
                             /* the name of the table */
     2 table_schema          char(SQLM_IDENT_SZ),
                             /* the name of the table */
     2 table_type            type sqluint32,/* table type */
     2 rows_written          type sqluint32,
                             /* number of changes to the table */
     2 rows_read             type sqluint32,
                             /* number of reads from the table */
     2 overflow_accesses     type sqluint32,
                             /* no. of accesses to overflow rec */
     2 table_event_time      type sqlm_timestamp,
                             /* Table Event Date and Time */
     2 page_reorgs           type sqluint32;
                             /* no. of reorgs for the table */

 /*********************************************************************/
 /*  Event Monitor Statement record                                   */
 /*********************************************************************/
 /* NOTE: Text follows the record, its length is rounded up to a 4    */
 /*       bytes boundary, and the text is padded with blanks.         */
 /*       It is *NOT* null terminated.  For example:                  */
 /*          +-------------------------+----------------------+       */
 /*          |sqlm_stmt_event          |"SELECT * FROM T18   "|       */
 /*          |  size:             352  |                      |       */
 /*          |  stmt_length:       20  |                      |       */
 /*          |  stmt_text_offset: 332  |                      |       */
 /*          +-------------------------+----------------------+       */
 /*-------------------------------------------------------------------*/
 define structure
   1 sqlm_stmt_event,
     2 size                  type sqluint32,
                             /* event record size *INCLUDING* */
                             /* dynamic SQL statement text */
     2 event_type            type sqluint32,
                             /* Always set to SQLM_EVENT_STMT */
     2 appl_id               char(SQLM_APPLID_SZ),
                             /* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* Application Id sequence number*/
     2 stmt_type             type sqluint32,
                             /* type of stmt: Dynamic or static */
     2 operation             type sqluint32,
                             /* Statement Operation */
     2 fetch_count           type sqluint32,
                             /* Count of fetches */
     2 section_number        type sqluint32,
                             /* Section Number */
     2 start_time            type sqlm_timestamp,
                             /* SQL statement operation start time*/
     2 stop_time             type sqlm_timestamp,
                             /* SQL statement operation stop time */
     2 cursor_name           char(SQLM_IDENT_SZ),
                             /* sql stmt.cursor name */
     2 creator               char(SQLM_IDENT_SZ),
                             /* auth id for precompile */
     2 package_name          char(SQLM_IDENT_SZ),
                             /* Package Name */
     2 user_cpu_time         type sqlm_time,
                             /* Total user CPU time of statement */
     2 system_cpu_time       type sqlm_time,
                             /* Total system CPU time of statement */
     2 total_sorts           type sqluint32,
                             /* Total number of sorts for this stmt*/
     2 total_sort_time       type sqluint32,
                             /* Total sort time for this statement */
     2 sort_overflows        type sqluint32,
                             /* # of sort overflows for this stmt */
     2 rows_read             type sqluint32,
                             /* # of rows read by this statement */
     2 rows_written          type sqluint32,
                             /* # of rows upd/ins/del for this stmt*/
     2 int_rows_deleted      type sqluint32,
                             /* # of internal deletes by the stmt */
     2 int_rows_updated      type sqluint32,
                             /* # of internal updates by the stmt */
     2 int_rows_inserted     type sqluint32,
                             /* # of internal inserts by the stmt */
     2 sqlca                 type sqlca,/* sqlca from statement */
     2 agent_id              type sqluint32,/* Application handle */
     2 agents_top            type sqluint32,
                             /* # of agents created for statement */
     2 stmt_length           type sqluint16,
                             /* length of SQL text, 0 if none.      */
                             /* It is only returned for dynamic SQL */
     2 stmt_text_offset      type sqluint16;
                             /* offset from sqlm_stmt_event start */

 /* The following event is only logged by VERSION 2 servers           */
 /* Starting with UDB V5, the text became part of the sqlm_stmt_event */
 define structure
   1 sqlm_stmttext_event,    /* OBSOLETE */
     2 size                  type sqluint32,/* event record size */
                             /* INCLUDES statement text */
     2 event_type            type sqluint32,
                             /* Set to SQLM_EVENT_STMTTEXT */
     2 appl_id               char(SQLM_APPLID_SZ),/* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* application id sequence number*/
     2 creator               char(SQLM_IDENT_SZ),
                             /* auth id for precompile */
     2 package_name          char(SQLM_IDENT_SZ),/* Package Name */
     2 section_number        type sqluint32,/* Section Number */
     2 stmt_length           type sqluint32,
                             /* length of SQL statement following */
     2 stmt_text             char(1);/* dynamic sql statement text */


 define structure
   1 sqlm_subsection_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,
                             /* Set to SQLM_EVENT_SUBSECTION */
     2 agent_id              type sqluint32,/* Application handle */
     2 ss_number             type sqluint16,/* Subsection number */
     2 ss_node_number        type sqluint16,
                             /* Node where the subsection was executed*/
     /* Execution stats */
     2 ss_exec_time          type sqluint32,
                             /* total (elapsed) Execution time in ms */
     2 ss_usr_cpu_time       type sqlm_time,
                             /* total user CPU time (sec.microsec) */
     2 ss_sys_cpu_time       type sqlm_time,
                             /* total system CPU time (sec.microsec) */
     /* Tablequeue information */
     2 tq_tot_send_spills    type sqluint32,
                             /* total # of buffers overflowed to a */
     /* temp table when sending data on a tq */
     2 tq_max_send_spills    type sqluint32,
                             /* maximum # of tq buffers overflowed */
     2 tq_rows_read          type sqluint32,
                             /* Total # rows received on tablequeues */
     2 tq_rows_written       type sqluint32,
                             /* Total # rows sent on tablequeues */
     2 num_agents            type sqluint16,
                             /* # agents that were executing this ss. */
     2 pad                   char(2);/* Explicit pad bytes */

 /*********************************************************************/
 /*  Event Monitor Transaction Event Record                           */
 /*********************************************************************/
 define structure
   1 sqlm_xaction_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     2 appl_id               char(SQLM_APPLID_SZ),/* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* application id sequence number*/
     2 log_space_used        type sqluint32,
                             /* Log space used in transaction */
     2 status                type sqluint32,
                             /* transaction completion status */
     2 lock_wait_time        type sqluint32,
                             /* transaction lock wait time (ms) */
     2 locks_held_top        type sqluint32,
                             /* max locks held in transaction */
     2 lock_escals           type sqluint32,
                             /* # of lock escalation in transaction*/
     2 x_lock_escals         type sqluint32,
                             /* # of x lock escals in transaction */
     2 rows_read             type sqluint32,
                             /* # of rows read by this transaction */
     2 rows_written          type sqluint32,
                             /* # of rows upd/ins/del for this xact*/
     2 user_cpu_time         type sqlm_time,
                             /* Total user CPU time of transaction */
     2 system_cpu_time       type sqlm_time,
                             /* Total system CPU time of xaction */
     2 prev_stop_time        type sqlm_timestamp,
                             /* prev commit or rollback time */
     2 start_time            type sqlm_timestamp,
                             /* time trans exec started */
     2 stop_time             type sqlm_timestamp,/* trans stop time */
     2 agent_id              type sqluint32;/* Application handle */


 /*********************************************************************/
 /*  Event Monitor Deadlock and Deadlocked Connection Event Records   */
 /*********************************************************************/
 define structure
   1 sqlm_deadlock_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     2 dl_conns              type sqluint32,
                             /* number of conns deadlocked */
     2 start_time            type sqlm_timestamp,
                             /* Time when deadlock detected */
     2 rolled_back_appl_id   char(SQLM_APPLID_SZ),/* victim's appl id */
     2 rolled_back_sequence_no char(SQLM_SEQ_SZ),/* victim's seq no. */
     2 rolled_back_agent_id  type sqluint32;/* Application handle */

 define structure
   1 sqlm_dlconn_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     2 appl_id               char(SQLM_APPLID_SZ),/* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* application id sequence number*/
     2 appl_id_holding_lk    char(SQLM_APPLID_SZ),
                             /* id of appl holding lk */
     2 sequence_no_holding_lk char(SQLM_SEQ_SZ),
                             /* seq no. holding lock */
     2 table_name            char(SQLM_IDENT_SZ),
                             /* name of tb of lock waited on */
     2 table_schema          char(SQLM_IDENT_SZ),
                             /* table schema of lk waited on */
     2 tablespace_name       char(SQLM_IDENT_SZ),
                             /* name of the tablespace */
     2 lock_mode             type sqluint32,/* Mode of Lock waited on */
     2 lock_object_type      type sqluint32,
                             /* Lock Obj type for lock waited on */
     2 lock_object_name      type sqluint32,
                             /* Waited On lock obj name */
     2 lock_wait_start_time  type sqlm_timestamp,
                             /* Time when lock wait started */
     2 start_time            type sqlm_timestamp,
                             /* Time when deadlock detected */
     2 lock_node             type sqluint32,
                             /* Node on which app waited for lock */
     2 agent_id              type sqluint32,/* Application handle */
     2 lock_escalation       char(1);
                             /* Was this lock part of an escalation */

 /*********************************************************************/
 /*  Event Monitor Tablespace Event Record                            */
 /*********************************************************************/
 define structure
   1 sqlm_tablespace_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     2 tablespace_name       char(SQLM_IDENT_SZ),/* name of tablespace*/
     2 pool_data_l_reads     type sqluint32,
                             /* pool data logical reads since conn*/
     2 pool_data_p_reads     type sqluint32,
                             /* pool data physical reads since con*/
     2 pool_async_data_reads type sqluint32,
                             /* asynchronous pool data reads */
     2 pool_data_writes      type sqluint32,
                             /* pool data writes since connect */
     2 pool_async_data_writes type sqluint32,
                             /* asynchronous pool data writes */
     2 pool_index_l_reads    type sqluint32,
                             /* pool index logical reads since con*/
     2 pool_index_p_reads    type sqluint32,
                             /* pool index physical reads since cn*/
     2 pool_index_writes     type sqluint32,
                             /* pool index writes since connect */
     2 pool_async_index_writes type sqluint32,
                             /* asynchronous pool index writes */
     2 pool_read_time        type sqluint32,
                             /* Buff pool read time since 1st conn*/
     2 pool_write_time       type sqluint32,
                             /* Buff pool write time since 1st con*/
     2 pool_async_read_time  type sqluint32,
                             /* asynchronous read time */
     2 pool_async_write_time type sqluint32,
                             /* asynchronous write time */
     2 pool_async_data_read_reqs type sqluint32,
                             /* # async read requests */
     2 direct_reads          type sqluint32,
                             /* direct reads since 1st connect */
     2 direct_writes         type sqluint32,
                             /* direct writes since 1st conn */
     2 direct_read_reqs      type sqluint32,/* direct read requests */
     2 direct_write_reqs     type sqluint32,/* direct write requests */
     2 direct_read_time      type sqluint32,
                             /* direct read time since 1st conn */
     2 direct_write_time     type sqluint32,
                             /* direct write time since 1st conn */
     2 files_closed          type sqluint32,
                             /* files closed since first db conn */
     2 ts_event_time         type sqlm_timestamp,
                             /* Tablespace event date and time */
     /*****************************************************************/
     /* SQLM_DBMON_VERSION5 Buffer Pool and I/O Information           */
     /*****************************************************************/
     2 pool_async_index_reads type sqluint32,
                             /* asynchronous pool index reads */
     2 pool_data_to_estore   type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_to_estore  type sqluint32,
                             /* #pages copied from BP to estore */
     2 pool_index_from_estore type sqluint32,
                             /* #pages copied from estore to BP */
     2 pool_data_from_estore type sqluint32;
                             /* #pages copied from estore to BP */


 /*********************************************************************/
 /*  Event Monitor Database Header Event Record                       */
 /*********************************************************************/
 define structure
   1 sqlm_dbheader_event,
     2 size         type sqluint32,/* event record size */
     2 event_type   type sqluint32,/* event type identifier */
     2 db_name      char(SQLM_IDENT_SZ), /* Database name */
     2 db_path      char(SQLM_DBPATH_SZ),/* Database Path */
     2 conn_time    type sqlm_timestamp;
                             /* Time of 1st database connection */

 /*********************************************************************/
 /*  Event Monitor Start Event Record                                 */
 /*********************************************************************/
 define structure
   1 sqlm_evmon_start_event,
     2 size         type sqluint32,/* event record size */
     2 event_type   type sqluint32,/* event type identifier */
     2 start_time   type sqlm_timestamp; /* Time event monitor started*/

 /*********************************************************************/
 /*  Event Monitor Connection Header Event Record                     */
 /*********************************************************************/
 define structure
   1 sqlm_connheader_event,
     2 size                  type sqluint32,/* event record size */
     2 event_type            type sqluint32,/* event type identifier */
     2 appl_id               char(SQLM_APPLID_SZ),
                             /* Application Id */
     2 sequence_no           char(SQLM_SEQ_SZ),
                             /* application id sequence number*/
     2 corr_token            char(SQLM_APPLID_SZ),
                             /* DRDA AS Correlation Token */
     2 appl_name             char(SQLM_IDENT_SZ),
                             /* Application Program Name */
     2 auth_id               char(SQLM_IDENT_SZ),
                             /* Authorization Id */
     2 execution_id          char(SQLM_IDENT_SZ),
                             /* Login ID */
     2 client_nname          char(SQLM_IDENT_SZ),
                             /* Config NNAME of client */
     2 client_prdid          char(SQLM_IDENT_SZ),
                             /* product/version on client */
     2 client_db_alias       char(SQLM_IDENT_SZ),
                             /* Client Database Alias */
     2 client_pid            type sqluint32,
                             /* PID of client */
     2 agent_id              type sqluint32,
                             /* Application handle */
     2 codepage_id           type sqluint16,
                             /* codepage at client node */
     2 country_code          type sqluint16,
                             /* country code of client app */
     2 client_platform       type sqluint16,
                             /* platform of client app */
     2 client_protocol       type sqluint16,
                             /* Comms protocol of client */
     2 conn_time             type sqlm_timestamp,
                             /* Connect start date/time */
     2 node_number           type sqluint16,
                             /* Node number conn was establ. */
     2 pad                   char(2); /* for 4 bytes memory alignment */

 /*********************************************************************/
 /*  Event Monitor Overflow Event Record                              */
 /*********************************************************************/
 define structure
   1 sqlm_overflow_event,
     2 size                  type sqluint32, /* event record size */
     2 event_type            type sqluint32, /* event type identifier */
     2 count                 type sqluint32,
                             /* The number of overflows */
     2 first_overflow_time   type sqlm_timestamp,
                             /* The time of the first overflow*/
     2 last_overflow_time    type sqlm_timestamp,
                             /* The time of the last overflow */
     2 node_number           type sqluint16,
                             /* Node on which overflow occured*/
     2 pad                   char(2); /* padding for word alignment */

 /*********************************************************************/
 /*  Event Monitor Bufferpool Event Record                            */
 /*********************************************************************/
 define structure
   1 sqlm_bufferpool_event,
     2 size                  type sqluint32,
                      /* Use instead of sizeof(sqlm_bufferpool_event) */
     2 event_type            type sqluint32,
                             /* always set to SQLM_EVENT_BUFFERPOOL */
     2 event_time            type sqlm_timestamp,
                      /* GMT time in seconds.microsec since 01/01/70 */
     2 bp_name               char(SQLM_IDENT_SZ),
                             /* Bufferpool name */
     2 db_name               char(SQLM_IDENT_SZ),
                             /* Database name */
     2 db_path               char(SQLM_DBPATH_SZ),
                             /* Database Path */
     2 bp_info               type sqlm_bp_info;
                      /* total stats from all tspaces for this bp */

 /*********************************************************************/
 /* VERSION 1 - Data structure sizes  - *****OBSOLETE***** -          */
 /* ****DON'T USE THESE CONSTANTS****                                 */
 /* THEY ARE PROVIDED FOR COMPATIBILITY ONLY                          */
 /*********************************************************************/
 dcl SQLM_APPLINFO_SZ          fixed bin(31) value(492);
                               /* size of V1 sqlm_applinfo struct     */
 dcl SQLM_DB2_SZ               fixed bin(31) value(100);
                               /* size of V1 sqlm_db2 structure       */
 dcl SQLM_DBASE_SZ             fixed bin(31) value(548);
                               /* size of V1 sqlm_dbase structure     */
 dcl SQLM_TABLE_HEADER_SZ      fixed bin(31) value(356);
                               /* size of V1 sqlm_table_header struct */
 dcl SQLM_TABLE_SZ             fixed bin(31) value(60);
                               /* size of V1 sqlm_table structure     */
 dcl SQLM_APPL_SZ              fixed bin(31) value(880);
                               /* size of V1 sqlm_appl structure      */
 dcl SQLM_DBASE_LOCK_SZ        fixed bin(31) value(352);
                               /* size of V1 sqlm_dbase_lock struct   */
 dcl SQLM_APPL_LOCK_SZ         fixed bin(31) value(216);
                               /* size of V1 sqlm_appl_lock struct    */
 dcl SQLM_LOCK_SZ              fixed bin(31) value(60);
                               /* size of V1 sqlm_lock structure      */
 dcl SQLM_COLLECTED_SZ         fixed bin(31) value(232);
                               /* size of V1 sqlm_collected structure */
 dcl SQLM_DCS_APPLINFO_SZ      fixed bin(31) value(260);
                               /* size of V1 sqlm_dcs_applinfo struct */
 dcl SQLM_TIMESTAMP_SZ         fixed bin(31)
                               value (size (: sqlm_timestamp :) );

 /*********************************************************************/
 /* Database Monitor APIs                                             */
 /*********************************************************************/

 /* Set or query Database Monitor switch settings */
 dcl sqlmon
     entry (type sqluint32,                      /* Version Id       */
            char(*) varz byaddr optional,        /* reserved         */
            (*) type sqlm_recording_group byaddr,
                             /* monitor switches and current states  */
            pointer)                             /* sqlca            */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlmon');

 /* Take a Snapshot of some Database System Monitor data */
 dcl sqlmonss
     entry (type sqluint32,                       /* Version id       */
            char(*) varz byaddr optional,         /* reserved         */
            type sqlma byaddr,                    /* monitoring area  */
            type sqluint32,                       /* buffer length    */
            pointer,                              /* buffer area      */
            type sqlm_collected byaddr,           /* num collected    */
            pointer)                              /* sqlca            */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlmonss');

 /* Estimate the buffer size that user need to allocate for sqlmonss */
 dcl sqlmonsz
     entry (type sqluint32,                       /* Version id       */
            char(*) varz byaddr optional,         /* reserved         */
            type sqlma byaddr,                    /* sqlma pointer    */
            type sqluint32 byaddr,                /* est. buffer sz   */
            pointer)                              /* sqlca structure  */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlmonsz');

 /* Re-initialize Database System Monitor data */
 dcl sqlmrset
     entry (type sqluint32,                       /* Version Id       */
            char(*) varz byaddr optional,         /* reserved         */
            type sqluint32,                       /* reset db or all  */
            char(*) varz byaddr,                  /* ptr to db_alias  */
            pointer)                              /* sqlca            */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlmrset');

 /*********************************************************************/
 /* Database Monitor Generic APIs                                     */
 /*********************************************************************/

 /* Generic Database Monitor Switch API  */
 dcl sqlgmon
     entry (type sqluint32,              /* length of reserved field  */
            pointer,                     /* pointer to sqlca          */
            (*) type sqlm_recording_group byaddr,
                                         /* ptr to returned states    */
            char(*) varz byaddr optional,/* reserved for future use   */
            type sqluint32)              /* Version id                */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlgmon');


 /* Generic Database Monitor Snapshot API */
 dcl sqlgmnss
     entry (type sqluint32,              /* length of reserved field  */
            pointer,                     /* pointer to sqlca          */
            type sqlm_collected byaddr,  /* pointer to # collected    */
            pointer,                     /* pointer to buffer area    */
            type sqluint32,              /* length of buffer          */
            type sqlma byaddr,           /* pointer to monitor area   */
            char(*) varz byaddr optional,/* reserved for future use   */
            type sqluint32)              /* Version id                */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlgmnss');


 /* Generic Database Monitor Estimate Buffer Size API */
 dcl sqlgmnsz
     entry (type sqluint32,              /* length of reserved field  */
            pointer,                     /* pointer to sqlca          */
            type sqluint32 byaddr,       /* length of buffer          */
            type sqlma byaddr,           /* pointer to sqlma          */
            char(*) varz byaddr optional,/* reserved for future use   */
            type sqluint32)              /* Version id                */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlgmnsz');


 /* Generic Database Monitor Reset API */
 dcl sqlgmrst
     entry (type sqluint16,              /* length of database        */
            type sqluint32,              /* length of reserved field  */
            pointer,                     /* pointer to sqlca          */
            char(*) varz byaddr,         /* database alias            */
            type sqluint32,              /* reset db or all info      */
            char(*) varz byaddr optional,/* reserved for future use   */
            type sqluint32)              /* Version id                */
     returns (fixed bin(31) byvalue optional)
     SQL_API_FN external('sqlgmrst');

 %end; /* SQL_H_SQLMON */
