 /*********************************************************************/
 /*                                                                   */
 /* windowsx.cpy -  Macro APIs, window message crackers,              */
 /*                 and control APIs                                  */
 /*                                                                   */
 /*                 Version Win32 / Windows NT                        */
 /*                                                                   */
 /*                 Copyright (c) 1992 - 1999 Microsoft Corp.         */
 /*                 All rights reserved.                              */
 /*                                                                   */
 /*********************************************************************/

 /* PL/I note. Macros and routines are protected by testing for prior */
 /* inclusion of the base header file. This was not necessary in C    */

 %dcl #INC_WINDOWSX char ext;
 %if #INC_WINDOWSX = '' %then %do;
 %#INC_WINDOWSX = 'Y';

 %dcl WINVER fixed ext;
 %if WINVER = 0 %then %do;
 %WINVER = 1280; /* version 5.0 */
 %end; /* !WINVER */

 %dcl SNDMSG char ext;
 %if SNDMSG = '' %then  %do;
 %SNDMSG = 'SendMessage';
 %end; /* SNDMSG */

 /****** KERNEL Macro APIs ********************************************/

 %dcl #WINBASE_ char ext;
 %if #WINBASE_ = 'Y' %then %do;

 GetInstanceModule: proc (hInstance)
                    returns (type HMODULE byvalue)
                    options (inline reorder) internal;
   dcl hInstance type HINSTANCE byvalue;
   return (hInstance);
 end GetInstanceModule;

 GlobalPtrHandle: proc (lp)
                  returns (type HGLOBAL byvalue)
                  options (inline reorder) internal;
   dcl lp pointer byvalue;
   return (GlobalHandle (lp));
 end GlobalPtrHandle;

 GlobalLockPtr: proc (lp)
                returns (type BOOL byvalue optional)
                options (inline reorder) internal;
   dcl lp pointer byvalue;
   dcl binvalue builtin;
   return (binvalue (GlobalLock (GlobalPtrHandle (lp))));
 end GlobalLockPtr;

 GlobalUnlockPtr: proc (lp)
                  returns (type BOOL byvalue optional)
                  options (inline reorder) internal;
   dcl lp pointer byvalue;
   return (GlobalUnlock (GlobalPtrHandle (lp)));
 end GlobalUnlockPtr;

 GlobalAllocPtr: proc (flags, cb)
                 returns (pointer byvalue)
                 options (inline reorder) internal;
   dcl flags type UINT byvalue,
       cb    type DWORD byvalue;
   return (GlobalLock (GlobalAlloc (flags, cb)));
 end GlobalAllocPtr;

 GlobalReAllocPtr: proc (lp, cbNew, flags)
                   returns (pointer byvalue)
                   options (inline reorder) internal;
   dcl lp    pointer byvalue,
       cbNew type DWORD byvalue,
       flags type UINT byvalue;
   call GlobalUnlockPtr(lp);
   return (GlobalLock (GlobalReAlloc (GlobalPtrHandle (lp),
                                      cbNew, flags)));
 end GlobalReAllocPtr;

 GlobalFreePtr: proc (lp)
                returns (type BOOL byvalue optional)
                options (inline reorder) internal;
   dcl lp pointer byvalue;
   dcl binvalue builtin;
   call GlobalUnlockPtr(lp);
   return (binvalue (GlobalFree (GlobalPtrHandle (lp))));
 end  GlobalFreePtr;

 %end; /* #WINBASE */

 /****** GDI Macro APIs ***********************************************/

 %dcl #WINGDI_ char ext;
 %dcl NOGDI char ext;
 %if #WINGDI_ = 'Y' & NOGDI = '' %then %do;

 /* some of these macros are trivial, as all HANDLES are pointers */

 DeletePen: proc (hpen)
            returns (type BOOL byvalue optional)
            options (inline reorder) internal;
   dcl hpen type HPEN byvalue;
   return (DeleteObject (hpen));
 end DeletePen;

 SelectPen: proc (hdc, hpen)
            returns (type HPEN byvalue optional)
            options (inline reorder) internal;
   dcl hdc  type HDC byvalue,
       hpen type HPEN byvalue;
   return (SelectObject (hdc, hpen));
 end SelectPen;

 GetStockPen: proc (i)
              returns (type HPEN byvalue)
              options (inline reorder) internal;
   dcl i fixed bin(31) byvalue;
   return (GetStockObject(i));
 end GetStockPen;


 DeleteBrush: proc (hbr)
              returns (type BOOL byvalue optional)
              options (inline reorder) internal;
   dcl hbr type HBRUSH byvalue;
   return (DeleteObject (hbr));
 end DeleteBrush;

 SelectBrush: proc (hdc, hbr)
            returns (type HBRUSH byvalue optional)
            options (inline reorder) internal;
   dcl hdc type HDC byvalue,
       hbr type HBRUSH;
   return (SelectObject (hdc, hbr));
 end SelectBrush;

 GetStockBrush: proc (i)
                returns (type HBRUSH byvalue)
                options (inline reorder) internal;
   dcl i fixed bin(31) byvalue;
   return (GetStockObject(i));
 end GetStockBrush;


 DeleteRgn: proc (hrgn)
            returns (type BOOL byvalue optional)
            options (inline reorder) internal;
   dcl hrgn type HRGN byvalue;
   return (DeleteObject (hrgn));
 end DeleteRgn;

 CopyRgn: proc (hrgnDst, hrgnSrc)
          returns (fixed bin(31) byvalue optional)
          options (inline reorder) internal;
   dcl hrgnDst type HRGN byvalue,
       hrgnSrc type HRGN byvalue;
   dcl sysnull builtin;
   return (CombineRgn (hrgnDst, hrgnSrc, sysnull(), RGN_COPY));
 end CopyRgn;

 IntersectRgn: proc (hrgnResult, hrgnA, hrgnB)
               returns (fixed bin(31) byvalue optional)
               options (inline reorder) internal;
   dcl hrgnResult type HRGN byvalue,
       hrgnA      type HRGN byvalue,
       hrgnB      type HRGN byvalue;
   return (CombineRgn (hrgnResult, hrgnA, hrgnB, RGN_AND));
 end IntersectRgn;

 SubtractRgn: proc (hrgnResult, hrgnA, hrgnB)
              returns (fixed bin(31) byvalue optional)
              options (inline reorder) internal;
   dcl hrgnResult type HRGN byvalue,
       hrgnA      type HRGN byvalue,
       hrgnB      type HRGN byvalue;
   return (CombineRgn (hrgnResult, hrgnA, hrgnB, RGN_DIFF));
 end SubtractRgn;

 UnionRgn: proc (hrgnResult, hrgnA, hrgnB)
           returns (fixed bin(31) byvalue optional)
           options (inline reorder) internal;
   dcl hrgnResult type HRGN byvalue,
       hrgnA      type HRGN byvalue,
       hrgnB      type HRGN byvalue;
   return (CombineRgn (hrgnResult, hrgnA, hrgnB, RGN_OR));
 end UnionRgn;

 XorRgn: proc (hrgnResult, hrgnA, hrgnB)
         returns (fixed bin(31) byvalue optional)
         options (inline reorder) internal;
   dcl hrgnResult type HRGN byvalue,
       hrgnA      type HRGN byvalue,
       hrgnB      type HRGN byvalue;
   return (CombineRgn (hrgnResult, hrgnA, hrgnB, RGN_XOR));
 end XorRgn;


 DeletePalette: proc (hpal)
                returns (type BOOL byvalue optional)
                options (inline reorder) internal;
   dcl hpal type HPALETTE byvalue;
   return (DeleteObject (hpal));
 end DeletePalette;


 DeleteFont: proc (hfont)
             returns (type BOOL byvalue optional)
             options (inline reorder) internal;
   dcl hfont type HFONT byvalue;
   return (DeleteObject (hfont));
 end DeleteFont;

 SelectFont: proc (hdc, hfont)
             returns (type HFONT byvalue optional)
             options (inline reorder) internal;
   dcl hdc   type HDC byvalue,
       hfont type HFONT byvalue;
   return (SelectObject (hdc, hfont));
 end SelectFont;

 GetStockFont: proc (i)
               returns (type HFONT byvalue)
               options (inline reorder) internal;
   dcl i fixed bin(31) byvalue;
   return (GetStockObject(i));
 end GetStockFont;


 DeleteBitmap: proc (hbm)
               returns (type BOOL byvalue optional)
               options (inline reorder) internal;
   dcl hbm type HBITMAP byvalue;
   return (DeleteObject (hbm));
 end DeleteBitmap;

 SelectBitmap: proc (hdc, hbm)
             returns (type HBITMAP byvalue optional)
             options (inline reorder) internal;
   dcl hdc type HDC byvalue,
       hbm type HBITMAP byvalue;
   return (SelectObject (hdc, hbm));
 end SelectBitmap;


 InsetRect: proc (lprc, dx, dy)
            returns (type BOOL byvalue optional)
            options (inline reorder) internal;
   dcl lprc type RECT byaddr,
       dx   fixed bin(31) byvalue,
       dy   fixed bin(31) byvalue;
   return (InflateRect (lprc, -dx, -dy));
 end InsetRect;

 %end; /* #WINGDI_ */


 /****** USER Macro APIs **********************************************/

 %dcl #WINUSER_ char ext;
 %if #WINUSER_ = 'Y' %then %do;

 GetWindowInstance: proc (hwnd)
                    returns (type HMODULE byvalue)
                    options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (GetWindowLong (hwnd, GWL_HINSTANCE)));
 end GetWindowInstance;

 GetWindowStyle: proc (hwnd)
                 returns (type DWORD byvalue)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindowLong (hwnd, GWL_STYLE));
 end GetWindowStyle;

 GetWindowExStyle: proc (hwnd)
                   returns (type DWORD byvalue)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindowLong (hwnd, GWL_EXSTYLE));
 end GetWindowExStyle;

 GetWindowOwner: proc (hwnd)
                 returns (type HWND byvalue)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindow (hwnd, GW_OWNER));
 end GetWindowOwner;


 GetFirstChild: proc (hwnd)
                returns (type HWND byvalue)
                options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetTopWindow (hwnd));
 end GetFirstChild;

 GetFirstSibling: proc (hwnd)
                  returns (type HWND byvalue)
                  options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindow (hwnd, GW_HWNDFIRST));
 end GetFirstSibling;

 GetLastSibling: proc (hwnd)
                 returns (type HWND byvalue)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindow (hwnd, GW_HWNDLAST));
 end GetLastSibling;

 GetNextSibling: proc (hwnd)
                 returns (type HWND byvalue)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindow (hwnd, GW_HWNDNEXT));
 end GetNextSibling;

 GetPrevSibling: proc (hwnd)
                 returns (type HWND byvalue)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetWindow (hwnd, GW_HWNDPREV));
 end GetPrevSibling;

 GetWindowID: proc (hwnd)
              returns (fixed bin(31) byvalue)
              options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (GetDlgCtrlID (hwnd));
 end GetWindowID;


 SetWindowRedraw: proc (hwnd, fRedraw)
                  options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       fRedraw type BOOL byvalue;
   call SNDMSG (hwnd, WM_SETREDRAW, (fRedraw), 0);
 end SetWindowRedraw;

 SubclassWindow: proc (hwnd, lpfn)
                 returns (type WNDPROC byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       lpfn type WNDPROC;
   dcl prev_wndproc type WNDPROC;
   dcl (binvalue, entryaddr, ptrvalue) builtin;
   entryaddr (prev_wndproc)
     = ptrvalue (SetWindowLong (hwnd, GWL_WNDPROC,
                                binvalue (entryaddr (lpfn))));
   return (prev_wndproc);
 end SubclassWindow;


 IsMinimized: proc (hwnd)
              returns (bit (1) aligned byvalue)
              options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (IsIconic (hwnd) ^= 0);
 end IsMinimized;

 IsMaximized: proc (hwnd)
              returns (bit (1) aligned byvalue)
              options (inline reorder) internal;
   dcl hwnd  type HWND byvalue;
   return (IsZoomed (hwnd) ^= 0);
 end IsMaximized;

 IsRestored: proc (hwnd)
              returns (bit (1) aligned byvalue)
              options (inline reorder) internal;
   dcl hwnd  type HWND byvalue;
   dcl (iand, ior) builtin;
   return (iand (GetWindowStyle (hwnd),
                 ior (WS_MINIMIZE, WS_MAXIMIZE)) = 0);
 end IsRestored;

 SetWindowFont: proc (hwnd, hfont, fRedraw)
                options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       hfont   type HFONT byvalue,
       fRedraw type BOOL byvalue;
   call FORWARD_WM_SETFONT (hwnd, hfont, fRedraw, SNDMSG);
 end SetWindowFont;

 GetWindowFont: proc (hwnd)
                returns (type HFONT byvalue)
                options (inline reorder) internal;
   dcl hwnd type HWND byvalue;
   return (FORWARD_WM_GETFONT (hwnd, SNDMSG));
 end GetWindowFont;

 %if WINVER >= 778 %then %do;
 MapWindowRect: proc (hwndFrom, hwndTo, lprc)
                returns (fixed bin(31) byvalue optional)
                options(inline reorder) internal;
   dcl hwndFrom type HWND byvalue,
       hwndTo   type HWND byvalue,
       lprc     type RECT byaddr;
   dcl (addr, type) builtin;
   return (MapWindowPoints (hwndFrom, hwndTo,
                            type (BIND (: POINT, addr (lprc) :)), 2));
 end MapWindowRect;
 %end;

 IsLButtonDown: proc
                returns (bit (1) aligned byvalue)
                options (inline reorder) internal;
   return (GetKeyState (VK_LBUTTON) < 0);
 end IsLButtonDown;

 IsRButtonDown: proc
                returns (bit (1) aligned byvalue)
                options (inline reorder) internal;
   return (GetKeyState (VK_RBUTTON) < 0);
 end IsRButtonDown;

 IsMButtonDown: proc
                returns (bit (1) aligned byvalue)
                options (inline reorder) internal;
   return (GetKeyState (VK_MBUTTON) < 0);
 end IsMButtonDown;


 SubclassDialog: proc (hwndDlg, lpfn)
                 returns (type DLGPROC byvalue optional)
                 options (inline reorder) internal;
   dcl hwndDlg type HWND byvalue,
       lpfn    type DLGPROC;
   dcl prev_dlgproc type DLGPROC;
   dcl (binvalue, entryaddr, ptrvalue) builtin;
   entryaddr (prev_dlgproc)
     = ptrvalue (SetWindowLong (hwndDlg, DWL_DLGPROC,
                                binvalue (entryaddr (lpfn))));
   return (prev_dlgproc);
 end SubclassDialog;

 SetDlgMsgResult: proc (hwnd, msg, result)
                  returns (type BOOL byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       msg    type UINT byvalue,
       result type LRESULT byvalue;

   select (msg);
     when (WM_CTLCOLORMSGBOX,
           WM_CTLCOLOREDIT,
           WM_CTLCOLORLISTBOX,
           WM_CTLCOLORBTN,
           WM_CTLCOLORDLG,
           WM_CTLCOLORSCROLLBAR,
           WM_CTLCOLORSTATIC,
           WM_COMPAREITEM,
           WM_VKEYTOITEM,
           WM_CHARTOITEM,
           WM_QUERYDRAGICON,
           WM_INITDIALOG) do;
       return (result);
     end;
     otherwise do;
       call SetWindowLong (hwnd, DWL_MSGRESULT, (result));
       return (TRUE);
     end;
   end; /* select */
 end SetDlgMsgResult;

 DefDlgProcEx: proc (hwnd, msg, wParam, lParam, pfRecursion)
               returns (type LRESULT byvalue optional)
               options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       msg         type UINT byvalue,
       wParam      type WPARAM byvalue,
       lParam      type LPARAM byvalue,
       pfRecursion type BOOL byaddr;
    pfRecursion = TRUE;
    return (DefDlgProc (hwnd, msg, wParam, lParam));
 end DefDlgProcEx;

 %dcl CheckDefDlgRecursion entry; /* must use as a statement */
 %CheckDefDlgRecursion: proc (pfRecursion) returns (char);
   dcl pfRecursion char;
   return ('if ' || pfRecursion || ' ^= FALSE then do; ' ||
              pfRecursion || ' = FALSE; ' ||
             'return (FALSE); '  ||
           'end; ');
 %end CheckDefDlgRecursion;

 %end; /* #WINUSER_ */


 /****** Message crackers *********************************************/

 %dcl HANDLE_MSG entry;
 %HANDLE_MSG: proc (hwnd, message, fn) returns (char);
   dcl (hwnd, message, fn) char;
   dcl i fixed;
   /* trim leading spaces */
   i = verify (message, ' '); /* i = 0 => message is blank => error */
   if i > 1 then
     message = substr (message, i);
   return ('when (' || message || ') ' ||
             'return (HANDLE_' || message || ' (' || hwnd ||
                                               ', wParam , lParam, ' ||
                                                fn || '))');
 %end HANDLE_MSG;

 /* PL/I extension: version of HANDLE_MSG (HANDLE_DLGMSG) that        */
 /* works for dialogue boxes.                                         */
 /* The normal HANDLE_MSG macro above does not work properly for      */
 /* dialog boxes because DlgProc return a BOOL instead of an LRESULT  */
 /*                                                                   */
 /* For C programmers interested in using it in C, the C macro is:    */
 /*                                                                   */
 /* #define HANDLE_DLGMSG(hwnd, message, fn)                  \       */
 /*   case (message): return (SetDlgMsgResult(hwnd, uMsg,     \       */
 /*      HANDLE_##message((hwnd), (wParam), (lParam), (fn))))         */

 %dcl HANDLE_DLGMSG entry;
 %HANDLE_DLGMSG: proc (hwnd, message, fn) returns (char);
   dcl (hwnd, message, fn) char;
   dcl i fixed;
   /* trim leading spaces */
   i = verify (message, ' '); /* i = 0 => message is blank => error */
   if i > 1 then
     message = substr (message, i);
   return ('when (' || message || ') ' ||
             'return (SetDlgMsgResult (' || hwnd || ', ' || message ||
                       ', HANDLE_' || message || ' (' ||
                                  hwnd || ', wParam , lParam, ' ||
                                  fn || ')))');
 %end HANDLE_DLGMSG;


 /* dcl Cls_OnCompacting entry (type HWND, type UINT) */

 HANDLE_WM_COMPACTING: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue);
   call fn (hwnd, (wParam));
   return (0);
 end HANDLE_WM_COMPACTING;

 FORWARD_WM_COMPACTING: proc (hwnd, compactRatio, fn)
                        options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       compactRatio type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_COMPACTING, (compactRatio), 0);
 end FORWARD_WM_COMPACTING;


 /* dcl Cls_OnWinIniChange entry (type HWND,                    */
 /*                               TCHAR(*) varz byaddr nonasgn) */

 HANDLE_WM_WININICHANGE: proc (hwnd, wParam, lParam, fn)
                         returns (type LRESULT byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(*) varz byaddr nonasgn);
   call fn (hwnd, pli_b2z (lParam));
   return (0);
 end HANDLE_WM_WININICHANGE;

 FORWARD_WM_WININICHANGE: proc (hwnd, lpszSectionName, fn)
                          options (inline reorder) internal;
   dcl hwnd            type HWND byvalue,
       lpszSectionName TCHAR(*) varz byaddr nonasgn,
       fn              type WNDPROC;    /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_WININICHANGE, 0,
            binvalue (addr (lpszSectionName)));
 end FORWARD_WM_WININICHANGE;


 /* dcl Cls_OnSysColorChange entry (HWND hwnd) */

 HANDLE_WM_SYSCOLORCHANGE: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_SYSCOLORCHANGE;

 FORWARD_WM_SYSCOLORCHANGE: proc (hwnd, fn)
                            options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_SYSCOLORCHANGE, 0, 0);
 end FORWARD_WM_SYSCOLORCHANGE;


 /* dcl Cls_OnQueryNewPalette entry (type HWND)             */
 /*                           returns (type BOOL optional)  */

 HANDLE_WM_QUERYNEWPALETTE: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (type BOOL byvalue optional);
   return (MAKELRESULT (fn (hwnd), 0));
 end HANDLE_WM_QUERYNEWPALETTE;

 FORWARD_WM_QUERYNEWPALETTE: proc (hwnd, fn)
                             returns (type BOOL byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_QUERYNEWPALETTE, 0, 0));
 end FORWARD_WM_QUERYNEWPALETTE;


 /* dcl Cls_OnPaletteIsChanging entry (type HWND, type HWND) */

 HANDLE_WM_PALETTEISCHANGING: proc (hwnd, wParam, lParam, fn)
                              returns (type LRESULT byvalue optional)
                              options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_PALETTEISCHANGING;

 FORWARD_WM_PALETTEISCHANGING: proc (hwnd, hwndPaletteChange, fn)
                               options (inline reorder) internal;
   dcl hwnd              type HWND byvalue,
       hwndPaletteChange type HWND byvalue,
       fn                type WNDPROC;  /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_PALETTEISCHANGING, binvalue (hwndPaletteChange),
            0);
 end FORWARD_WM_PALETTEISCHANGING;

 /* dcl Cls_OnPaletteChanged entry (type HWND, type HWND) */

 HANDLE_WM_PALETTECHANGED: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_PALETTECHANGED;

 FORWARD_WM_PALETTECHANGED: proc (hwnd, hwndPaletteChange, fn)
                            options (inline reorder) internal;
   dcl hwnd              type HWND byvalue,
       hwndPaletteChange type HWND byvalue,
       fn                type WNDPROC;  /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_PALETTECHANGED, binvalue (hwndPaletteChange), 0);
 end FORWARD_WM_PALETTECHANGED;


 /* dcl Cls_OnFontChange entry (HWND hwnd) */

 HANDLE_WM_FONTCHANGE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_FONTCHANGE;

 FORWARD_WM_FONTCHANGE: proc (hwnd, fn)
                        options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_FONTCHANGE, 0, 0);
 end FORWARD_WM_FONTCHANGE;


 /* dcl Cls_OnSpoolerStatus entry (type HWND, type UINT, */
 /*                                fixed bin(31))        */

 HANDLE_WM_SPOOLERSTATUS: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     fixed bin(31) byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), isigned (LOWORD (lParam)));
   return (0);
 end HANDLE_WM_SPOOLERSTATUS;

 FORWARD_WM_SPOOLERSTATUS: proc (hwnd, status, cJobInQueue, fn)
                           options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       status      type UINT byvalue,
       cJobInQueue fixed bin(31) byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   call fn (hwnd, WM_SPOOLERSTATUS, (status),
            MAKELPARAM (cJobInQueue, 0));
 end FORWARD_WM_SPOOLERSTATUS;


 /* dcl Cls_OnDevModeChange entry (type HWND,                    */
 /*                                TCHAR(*) varz byaddr nonasgn) */

 HANDLE_WM_DEVMODECHANGE: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(*) varz byaddr nonasgn);
   call fn (hwnd, pli_b2z (lParam));
   return (0);
 end HANDLE_WM_DEVMODECHANGE;

 FORWARD_WM_DEVMODECHANGE: proc (hwnd, lpszDeviceName, fn)
                           options (inline reorder) internal;
   dcl hwnd           type HWND byvalue,
       lpszDeviceName TCHAR(*) varz byaddr nonasgn,
       fn             type WNDPROC;     /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_DEVMODECHANGE, 0,
            binvalue (addr (lpszDeviceName)));
 end FORWARD_WM_DEVMODECHANGE;


 /* dcl Cls_OnTimeChange entry (type HWND) */

 HANDLE_WM_TIMECHANGE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_TIMECHANGE;

 FORWARD_WM_TIMECHANGE: proc (hwnd, fn)
                        options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_TIMECHANGE, 0, 0);
 end FORWARD_WM_TIMECHANGE;


 /* dcl Cls_OnPower entry (type HWND, fixed bin(31)) */

 HANDLE_WM_POWER: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue);
   call fn (hwnd, (wParam));
   return (0);
 end HANDLE_WM_POWER;

 FORWARD_WM_POWER: proc (hwnd, code, fn)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       code fixed bin(31),
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_POWER, (code), 0);
 end FORWARD_WM_POWER;


 /* dcl Cls_OnQueryEndSession entry (type HWND)            */
 /*                           returns (type BOOL optional) */

 HANDLE_WM_QUERYENDSESSION: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (type BOOL byvalue optional);
   return (MAKELRESULT (fn (hwnd), 0));
 end HANDLE_WM_QUERYENDSESSION;

 FORWARD_WM_QUERYENDSESSION: proc (hwnd, fn)
                             returns (type BOOL byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_QUERYENDSESSION, 0, 0));
 end FORWARD_WM_QUERYENDSESSION;


 /* dcl Cls_OnEndSession entry (type HWND, type BOOL) */

 HANDLE_WM_ENDSESSION: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue);
   call fn (hwnd, (wParam));
   return (0);
 end HANDLE_WM_ENDSESSION;

 FORWARD_WM_ENDSESSION: proc (hwnd, fEnding, fn)
                        options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       fEnding type BOOL byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   call fn (hwnd, WM_ENDSESSION, (fEnding), 0);
 end FORWARD_WM_ENDSESSION;


 /* dcl Cls_OnQuit entry (type HWND, fixed bin(31)) */

 HANDLE_WM_QUIT: proc (hwnd, wParam, lParam, fn)
                 returns (type LRESULT byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue);
   call fn (hwnd, (wParam));
   return (0);
 end HANDLE_WM_QUIT;

 FORWARD_WM_QUIT: proc (hwnd, exitCode, fn)
                  options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       exitCode fixed bin(31) byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_QUIT, (exitCode), 0);
 end FORWARD_WM_QUIT;


 /* This message is in Windows 3.1 only */
 /* dcl Cls_OnSystemError entry (type HWND, fixed bin(31)) */

 HANDLE_WM_SYSTEMERROR: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue);
   return (0);
 end HANDLE_WM_SYSTEMERROR;

 FORWARD_WM_SYSTEMERROR: proc (hwnd, errCode, fn)
                         options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       errCode fixed bin(31) byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   return;
 end FORWARD_WM_SYSTEMERROR;


 /* dcl Cls_OnCreate entry (type HWND, type CREATESTRUCT byaddr) */
 /*                  returns (type BOOL optional)                */

 HANDLE_WM_CREATE: proc (hwnd, wParam, lParam, fn)
                   returns (type LRESULT byvalue optional)
                   options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type CREATESTRUCT byaddr)
              returns (type BOOL byvalue optional);
   dcl (ptrvalue, type) builtin;
   if fn (hwnd, type (bind (: CREATESTRUCT, ptrvalue (lParam) :) )) ^= 0
   then return (0); /* success */
   else
     return (-1); /* failure */
 end HANDLE_WM_CREATE;

 FORWARD_WM_CREATE: proc (hwnd, lpCreateStruct, fn)
                    returns (type BOOL byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd           type HWND byvalue,
       lpCreateStruct type CREATESTRUCT byaddr,
       fn             type WNDPROC;     /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_CREATE, 0, binvalue (addr (lpCreateStruct))));
 end FORWARD_WM_CREATE;


 /* dcl Cls_OnNCCreate entry (type HWND, type CREATESTRUCT byaddr) */
 /*                    returns (type BOOL optional)                */

 HANDLE_WM_NCCREATE: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type CREATESTRUCT byaddr)
              returns (type BOOL byvalue optional);
   dcl (ptrvalue, type) builtin;
   return (fn (hwnd, type (bind (: CREATESTRUCT,
                                   ptrvalue (lParam) :))));
 end HANDLE_WM_NCCREATE;

 FORWARD_WM_NCCREATE: proc (hwnd, lpCreateStruct, fn)
                      returns (type BOOL byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd           type HWND byvalue,
       lpCreateStruct type CREATESTRUCT byaddr,
       fn             type WNDPROC;     /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_NCCREATE, 0, binvalue (addr (lpCreateStruct))));
 end FORWARD_WM_NCCREATE;


 /* dcl Cls_OnDestroy entry (type HWND) */

 HANDLE_WM_DESTROY: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_DESTROY;

 FORWARD_WM_DESTROY: proc (hwnd, fn)
                     options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_DESTROY, 0, 0);
 end FORWARD_WM_DESTROY;


 /* dcl Cls_OnNCDestroy entry (type HWND) */

 HANDLE_WM_NCDESTROY: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_NCDESTROY;

 FORWARD_WM_NCDESTROY: proc (hwnd, fn)
                       options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_NCDESTROY, 0, 0);
 end FORWARD_WM_NCDESTROY;


 /* dcl Cls_OnShowWindow entry (type HWND, type BOOL, type UINT) */

 HANDLE_WM_SHOWWINDOW: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     type UINT byvalue);
   call fn (hwnd, (wParam), (lParam));
   return (0);
 end HANDLE_WM_SHOWWINDOW;

 FORWARD_WM_SHOWWINDOW: proc (hwnd, fShow, status, fn)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       fShow  type BOOL byvalue,
       status type UINT byvalue,
       fn     type WNDPROC;             /* SendMessage or PostMessage */
   call fn (hwnd, WM_SHOWWINDOW, (fShow), (status));
 end FORWARD_WM_SHOWWINDOW;


 /* dcl Cls_OnSetRedraw entry (type HWND, type BOOL) */

 HANDLE_WM_SETREDRAW: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue);
   call fn (hwnd, (wParam));
   return (0);
 end HANDLE_WM_SETREDRAW;

 FORWARD_WM_SETREDRAW: proc (hwnd, fRedraw, fn)
                       options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       fRedraw type BOOL byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   call fn (hwnd, WM_SETREDRAW, (fRedraw), 0);
 end FORWARD_WM_SETREDRAW;


 /* dcl Cls_OnEnable entry (type HWND, type BOOL) */

 HANDLE_WM_ENABLE: proc (hwnd, wParam, lParam, fn)
                   returns (type LRESULT byvalue optional)
                   options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue);
   call fn (hwnd, (wParam));
   return (0);
 end HANDLE_WM_ENABLE;

 FORWARD_WM_ENABLE: proc (hwnd, fEnable, fn)
                    options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       fEnable type BOOL byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   call fn (hwnd, WM_ENABLE, (fEnable), 0);
 end FORWARD_WM_ENABLE;


 /* dcl Cls_OnSetText entry (type HWND, TCHAR(*) varz byaddr nonasgn) */

 HANDLE_WM_SETTEXT: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(*) varz byaddr nonasgn);
   call fn (hwnd, pli_b2z (lParam));
   return (0);
 end HANDLE_WM_SETTEXT;

 FORWARD_WM_SETTEXT: proc (hwnd, lpszText, fn)
                     options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       lpszText TCHAR(*) varz byaddr nonasgn,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_SETTEXT, 0, binvalue (addr (lpszText)));
 end FORWARD_WM_SETTEXT;


 /* dcl Cls_OnGetText entry (type HWND, fixed bin (31), */
 /*                          TCHAR(*) varz byaddr)      */
 /*                   returns (fixed bin(31) optional)  */

 HANDLE_WM_GETTEXT: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin (31) byvalue,
                     TCHAR(*) varz byaddr)
              returns (fixed bin(31) byvalue optional);
   return (fn (hwnd, (wParam), pli_b2z (lParam)));
 end HANDLE_WM_GETTEXT;

 FORWARD_WM_GETTEXT: proc (hwnd, cchTextMax, lpszText, fn)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       cchTextMax fixed bin(31) byvalue,
       lpszText   TCHAR(*) varz byaddr nonasgn,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_GETTEXT, (cchTextMax),
               binvalue (addr (lpszText))));
 end FORWARD_WM_GETTEXT;

 /* dcl Cls_OnGetTextLength entry (type HWND)                */
 /*                         returns (fixed bin(31) optional) */

 HANDLE_WM_GETTEXTLENGTH: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (fixed bin(31) byvalue optional);
   return (fn (hwnd));
 end HANDLE_WM_GETTEXTLENGTH;

 FORWARD_WM_GETTEXTLENGTH: proc (hwnd, fn)
                           returns (fixed bin(31) byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_GETTEXTLENGTH, 0, 0));
 end;


 /* dcl Cls_OnWindowPosChanging entry (type HWND,             */
 /*                                    type WINDOWPOS byaddr) */
 /*                             returns (type BOOL optional)  */

 HANDLE_WM_WINDOWPOSCHANGING: proc (hwnd, wParam, lParam, fn)
                              returns (type LRESULT byvalue optional)
                              options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type WINDOWPOS byaddr)
              returns (type BOOL byvalue optional);
   dcl (ptrvalue, type) builtin;
   return (fn (hwnd, type (bind (: WINDOWPOS, ptrvalue (lParam) :))));
 end HANDLE_WM_WINDOWPOSCHANGING;

 FORWARD_WM_WINDOWPOSCHANGING: proc (hwnd, lpwpos, fn)
                               returns (type BOOL byvalue optional)
                               options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       lpwpos type WINDOWPOS byaddr,
       fn     type WNDPROC;             /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_WINDOWPOSCHANGING, 0,
               binvalue (addr (lpwpos))));
 end FORWARD_WM_WINDOWPOSCHANGING;


 /* dcl Cls_OnWindowPosChanged entry (type HWND,                     */
 /*                                   type WINDOWPOS byaddr nonasgn) */

 HANDLE_WM_WINDOWPOSCHANGED: proc (hwnd, wParam, lParam, fn)
                             returns (type LRESULT byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type WINDOWPOS byaddr nonasgn);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, type (bind (: WINDOWPOS, ptrvalue (lParam) :)));
   return (0);
 end HANDLE_WM_WINDOWPOSCHANGED;

 FORWARD_WM_WINDOWPOSCHANGED: proc (hwnd, lpwpos, fn)
                              options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       lpwpos type WINDOWPOS byaddr nonasgn,
       fn     type WNDPROC;             /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_WINDOWPOSCHANGED, 0, binvalue (addr (lpwpos)));
 end FORWARD_WM_WINDOWPOSCHANGED;


 /* dcl Cls_OnMove entry (type HWND, fixed bin(31), fixed bin(31)) */

 HANDLE_WM_MOVE: proc (hwnd, wParam, lParam, fn)
                 returns (type LRESULT byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue);
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)), isigned (HIWORD (lParam)));
   return (0);
 end HANDLE_WM_MOVE;

 FORWARD_WM_MOVE: proc (hwnd, x, y, fn)
                  options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       x    fixed bin (31) byvalue,
       y    fixed bin (31) byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_MOVE, 0, MAKELPARAM (x, y));
 end FORWARD_WM_MOVE;


 /* dcl Cls_OnSize entry (type HWND, type UINT, fixed bin(31), */
 /*                       fixed bin(31))                       */

 HANDLE_WM_SIZE: proc (hwnd, wParam, lParam, fn)
                 returns (type LRESULT byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), isigned (LOWORD (lParam)),
                            isigned (HIWORD (lParam)));
   return (0);
 end HANDLE_WM_SIZE;

 FORWARD_WM_SIZE: proc (hwnd, state, cx, cy, fn)
                  options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       state type UINT byvalue,
       cx    fixed bin (31) byvalue,
       cy    fixed bin (31) byvalue,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   call fn (hwnd, WM_SIZE, (state), MAKELPARAM (cx, cy));
 end FORWARD_WM_SIZE;


 /* dcl Cls_OnClose entry (type HWND) */

 HANDLE_WM_CLOSE: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_CLOSE;

 FORWARD_WM_CLOSE: proc (hwnd, fn)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_CLOSE, 0, 0);
 end FORWARD_WM_CLOSE;


 /* dcl Cls_OnQueryOpen entry (type HWND)            */
 /*                     returns (type BOOL optional) */

 HANDLE_WM_QUERYOPEN: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (type BOOL byvalue optional);
   return (MAKELRESULT (fn (hwnd), 0));
 end HANDLE_WM_QUERYOPEN;

 FORWARD_WM_QUERYOPEN: proc (hwnd, fn)
                       returns (type BOOL byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_QUERYOPEN, 0, 0));
 end FORWARD_WM_QUERYOPEN;


 /* dcl Cls_OnGetMinMaxInfo entry (type HWND, type MINMAXINFO byaddr) */

 HANDLE_WM_GETMINMAXINFO: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type MINMAXINFO byaddr);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, type (bind (: MINMAXINFO, ptrvalue (lParam) :)));
   return (0);
 end HANDLE_WM_GETMINMAXINFO;

 FORWARD_WM_GETMINMAXINFO: proc (hwnd, lpMinMaxInfo, fn)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       lpMinMaxInfo type MINMAXINFO byaddr,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_GETMINMAXINFO, 0, binvalue (addr (lpMinMaxInfo)));
 end FORWARD_WM_GETMINMAXINFO;


 /* dcl Cls_OnPaint entry (type HWND) */

 HANDLE_WM_PAINT: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_PAINT;

 FORWARD_WM_PAINT: proc (hwnd, fn)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_PAINT, 0, 0);
 end FORWARD_WM_PAINT;


 /* dcl Cls_OnEraseBkgnd entry (type HWND, type HDC)  */
 /*                      returns (type BOOL optional) */

 HANDLE_WM_ERASEBKGND: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue)
              returns (type BOOL byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, ptrvalue (wParam)));
 end HANDLE_WM_ERASEBKGND;

 FORWARD_WM_ERASEBKGND: proc (hwnd, hdc, fn)
                        returns (type BOOL byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       hdc  type HDC byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_ERASEBKGND, binvalue (hdc), 0));
 end FORWARD_WM_ERASEBKGND;


 /* dcl Cls_OnIconEraseBkgnd entry (type HWND, type HDC)  */
 /*                          returns (type BOOL optional) */
 HANDLE_WM_ICONERASEBKGND: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue)
              returns (type BOOL byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, ptrvalue (wParam)));
 end HANDLE_WM_ICONERASEBKGND;

 FORWARD_WM_ICONERASEBKGND: proc (hwnd, hdc, fn)
                            returns (type BOOL byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       hdc  type HDC byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   dcl binvalue builtin;
   return (fn (hwnd, WM_ICONERASEBKGND, binvalue (hdc), 0));
 end FORWARD_WM_ICONERASEBKGND;


 /* dcl Cls_OnNCPaint entry (type HWND, type HRGN) */

 HANDLE_WM_NCPAINT: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HRGN byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_NCPAINT;

 FORWARD_WM_NCPAINT: proc (hwnd, hrgn, fn)
                     options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       hrgn type HRGN byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_NCPAINT, binvalue (hrgn), 0);
 end FORWARD_WM_NCPAINT;


 /* dcl Cls_OnNCCalcSize entry (type HWND, type BOOL,          */
 /*                             type NCCALCSIZE_PARAMS byaddr) */
 /*                      returns (type UINT optional)          */

 HANDLE_WM_NCCALCSIZE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     type NCCALCSIZE_PARAMS byaddr)
              returns (type UINT byvalue optional);
   dcl (ptrvalue, type) builtin;
   return (fn (hwnd, (wParam), type (bind (: NCCALCSIZE_PARAMS,
                                             ptrvalue (lParam) :))));
 end HANDLE_WM_NCCALCSIZE;

 FORWARD_WM_NCCALCSIZE: proc (hwnd, fCalcValidRects, lpcsp, fn)
                        returns (type UINT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd            type HWND byvalue,
       fCalcValidRects type BOOL byvalue,
       lpcsp           type NCCALCSIZE_PARAMS byaddr,
       fn              type WNDPROC;    /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_NCCALCSIZE, (fCalcValidRects),
                                    binvalue (addr (lpcsp))));
 end FORWARD_WM_NCCALCSIZE;


 /* dcl Cls_OnNCHitTest entry (type HWND, fixed bin(31), */
 /*                            fixed bin(31))            */
 /*                     returns (type UINT optional)     */

 HANDLE_WM_NCHITTEST: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
              fixed bin(31) byvalue)
              returns (type UINT byvalue optional);
   dcl isigned builtin;
   return (fn (hwnd, isigned (LOWORD (lParam)),
                     isigned (HIWORD (lParam))));
 end HANDLE_WM_NCHITTEST;

 FORWARD_WM_NCHITTEST: proc (hwnd, x, y, fn)
                       returns (type UINT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       x    fixed bin (31) byvalue,
       y    fixed bin (31) byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_NCHITTEST, 0, MAKELPARAM (x, y)));
 end FORWARD_WM_NCHITTEST;

 /* dcl Cls_OnQueryDragIcon entry (type HWND)             */
 /*                         returns (type HICON optional) */

 HANDLE_WM_QUERYDRAGICON: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (type HICON byvalue optional);
   dcl binvalue builtin;
   return (binvalue (fn (hwnd)));
 end HANDLE_WM_QUERYDRAGICON;

 FORWARD_WM_QUERYDRAGICON: proc (hwnd, fn)
                           returns (type HICON byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   dcl ptrvalue builtin;
   return (ptrvalue (fn (hwnd, WM_QUERYDRAGICON, 0, 0)));
 end FORWARD_WM_QUERYDRAGICON;


 %dcl #INC_SHELLAPI char ext;
 %if #INC_SHELLAPI ^= '' %then %do;
 /* dcl Cls_OnDropFiles entry (type HWND, type HDROP) */

 HANDLE_WM_DROPFILES: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDROP byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_DROPFILES;

 FORWARD_WM_DROPFILES: proc (hwnd, hdrop, fn)
                       options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       hdrop type HDROP byvalue,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_DROPFILES, binvalue (hdrop), 0);
 end FORWARD_WM_DROPFILES;
 %end; /* _INC_SHELLAPI */

 /* dcl Cls_OnActivate entry (type HWND, type UINT, type HWND, */
 /*                           type BOOL)                       */

 HANDLE_WM_ACTIVATE: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type HWND byvalue, type BOOL byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, LOWORD (wParam), ptrvalue (lParam), HIWORD (wParam));
   return (0);
 end HANDLE_WM_ACTIVATE;

 FORWARD_WM_ACTIVATE: proc (hwnd, state, hwndActDeact, fMinimized, fn)
                      options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       state        type UINT byvalue,
       hwndActDeact type HWND byvalue,
       fMinimized   type BOOL byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_ACTIVATE, MAKEWPARAM (state, fMinimized),
            binvalue (hwndActDeact));
 end FORWARD_WM_ACTIVATE;


 /* dcl Cls_OnActivateApp entry (type HWND, type BOOL, type DWORD) */

 HANDLE_WM_ACTIVATEAPP: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     type DWORD byvalue);
   call fn (hwnd, (wParam), (lParam));
   return (0);
 end HANDLE_WM_ACTIVATEAPP;

 FORWARD_WM_ACTIVATEAPP: proc (hwnd, fActivate, dwThreadId, fn)
                         options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       fActivate  type BOOL byvalue,
       dwThreadId type DWORD byvalue,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   call fn (hwnd, WM_ACTIVATEAPP, (fActivate), (dwThreadId));
 end FORWARD_WM_ACTIVATEAPP;


 /* dcl Cls_OnNCActivate entry (type HWND, type BOOL, type HWND, */
 /*                             type BOOL)                       */
 /*                      returns (type BOOL optional)            */

 HANDLE_WM_NCACTIVATE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type HWND byvalue, type BOOL byvalue);
   dcl sysnull builtin;
   return (fn (hwnd, (wParam), sysnull(), 0));
 end HANDLE_WM_NCACTIVATE;

 FORWARD_WM_NCACTIVATE: proc (hwnd, fActive,
                              hwndActDeact, fMinimized, fn)
                        returns (type BOOL optional)
                        options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fActive      type BOOL byvalue,
       hwndActDeact type HWND byvalue,
       fMinimized   type BOOL byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   return (fn (hwnd, WM_NCACTIVATE, (fActive), 0));
 end FORWARD_WM_NCACTIVATE;


 /* dcl Cls_OnSetFocus entry (type HWND, type HWND) */

 HANDLE_WM_SETFOCUS: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_SETFOCUS;

 FORWARD_WM_SETFOCUS: proc (hwnd, hwndOldFocus, fn)
                      options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndOldFocus type HWND byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_SETFOCUS, binvalue (hwndOldFocus), 0);
 end FORWARD_WM_SETFOCUS;


 /* dcl Cls_OnKillFocus entry (type HWND, type HWND) */

 HANDLE_WM_KILLFOCUS: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_KILLFOCUS;

 FORWARD_WM_KILLFOCUS: proc (hwnd, hwndNewFocus, fn)
                       options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndNewFocus type HWND byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_KILLFOCUS, binvalue (hwndNewFocus), 0);
 end FORWARD_WM_KILLFOCUS;


 /* dcl Cls_OnKey entry (type HWND, type UINT, type BOOL, */
 /*                      fixed bin(31), type UINT)        */

 HANDLE_WM_KEYDOWN: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type BOOL byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), TRUE,
                  isigned (LOWORD (lParam)), HIWORD (lParam));
   return (0);
 end HANDLE_WM_KEYDOWN;

 FORWARD_WM_KEYDOWN: proc (hwnd, vk, cRepeat, flags, fn)
                     options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       vk       type UINT byvalue,
       cRepeat  fixed bin(31) byvalue,
       flags    type UINT byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_KEYDOWN, (vk), MAKELPARAM (cRepeat, flags));
 end FORWARD_WM_KEYDOWN;


 /* dcl Cls_OnKey entry (type HWND, type UINT, type BOOL, */
 /*                      fixed bin(31), type UINT)        */

 HANDLE_WM_KEYUP: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type BOOL byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), FALSE,
            isigned (LOWORD (lParam)), HIWORD (lParam));
   return (0);
 end HANDLE_WM_KEYUP;

 FORWARD_WM_KEYUP: proc (hwnd, vk, cRepeat, flags, fn)
                   options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       vk       type UINT byvalue,
       cRepeat  fixed bin(31) byvalue,
       flags    type UINT byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_KEYUP, (vk), MAKELPARAM (cRepeat, flags));
 end FORWARD_WM_KEYUP;


 /* dcl Cls_OnChar entry (type HWND, TCHAR(1), fixed bin(31)) */

 HANDLE_WM_CHAR: proc (hwnd, wParam, lParam, fn)
                 returns (type LRESULT byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(1) byvalue,
                     fixed bin(31) byvalue);
   dcl (charval, wcharval, isigned) builtin;
   call fn (hwnd, TCHARVAL (wParam), isigned (LOWORD (lParam)));
   return (0);
 end HANDLE_WM_CHAR;

 FORWARD_WM_CHAR: proc (hwnd, ch, cRepeat, fn)
                  options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       ch       TCHAR(1) byvalue,
       cRepeat  fixed bin(31) byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl rank builtin;
   call fn (hwnd, WM_CHAR, rank (ch), MAKELPARAM (cRepeat,0));
 end FORWARD_WM_CHAR;


 /* dcl Cls_OnDeadChar entry (type HWND, TCHAR(1), fixed bin(31)) */

 HANDLE_WM_DEADCHAR: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(1) byvalue,
                     fixed bin(31) byvalue);
   dcl (charval, wcharval, isigned) builtin;
   call fn (hwnd, TCHARVAL (wParam), isigned (LOWORD (lParam)));
   return (0);
 end HANDLE_WM_DEADCHAR;

 FORWARD_WM_DEADCHAR: proc (hwnd, ch, cRepeat, fn)
                      options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       ch       TCHAR(1) byvalue,
       cRepeat  fixed bin(31) byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl rank builtin;
   call fn (hwnd, WM_DEADCHAR, rank (ch), MAKELPARAM (cRepeat,0));
 end FORWARD_WM_DEADCHAR;


 /* dcl Cls_OnSysKey entry (type HWND, type UINT, type BOOL, */
 /*                         fixed bin(31), type UINT)        */

 HANDLE_WM_SYSKEYDOWN: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type BOOL byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), TRUE,
                  isigned (LOWORD (lParam)), HIWORD (lParam));
   return (0);
 end HANDLE_WM_SYSKEYDOWN;

 FORWARD_WM_SYSKEYDOWN: proc (hwnd, vk, cRepeat, flags, fn)
                        options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       vk       type UINT byvalue,
       cRepeat  fixed bin(31) byvalue,
       flags    type UINT byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_SYSKEYDOWN, (vk), MAKELPARAM (cRepeat, flags));
 end FORWARD_WM_SYSKEYDOWN;


 /* dcl Cls_OnSysKey entry (type HWND, type UINT, type BOOL, */
 /*                         fixed bin(31), type UINT)        */

 HANDLE_WM_SYSKEYUP: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type BOOL byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), FALSE,
            isigned (LOWORD (lParam)), HIWORD (lParam));
   return (0);
 end HANDLE_WM_SYSKEYUP;

 FORWARD_WM_SYSKEYUP: proc (hwnd, vk, cRepeat, flags, fn)
                      options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       vk       type UINT byvalue,
       cRepeat  fixed bin(31) byvalue,
       flags    type UINT byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_SYSKEYUP, (vk), MAKELPARAM (cRepeat, flags));
 end FORWARD_WM_SYSKEYUP;


 /* dcl Cls_OnSysChar entry (type HWND, TCHAR(1), fixed bin(31)) */

 HANDLE_WM_SYSCHAR: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(1) byvalue,
                     fixed bin(31) byvalue);
   dcl (charval, wcharval, isigned) builtin;
   call fn (hwnd, TCHARVAL (wParam), isigned (LOWORD (lParam)));
   return (0);
 end HANDLE_WM_SYSCHAR;

 FORWARD_WM_SYSCHAR: proc (hwnd, ch, cRepeat, fn)
                     options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       ch       TCHAR(1) byvalue,
       cRepeat  fixed bin(31) byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl rank builtin;
   call fn (hwnd, WM_SYSCHAR, rank (ch), MAKELPARAM (cRepeat,0));
 end FORWARD_WM_SYSCHAR;


 /* dcl Cls_OnSysDeadChar entry (type HWND, TCHAR(1), fixed bin(31)) */

 HANDLE_WM_SYSDEADCHAR: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, TCHAR(1) byvalue,
                     fixed bin(31) byvalue);
   dcl (charval, wcharval, isigned) builtin;
   call fn (hwnd, TCHARVAL (wParam), isigned (LOWORD (lParam)));
   return (0);
 end HANDLE_WM_SYSDEADCHAR;

 FORWARD_WM_SYSDEADCHAR: proc (hwnd, ch, cRepeat, fn)
                         options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       ch       TCHAR(1) byvalue,
       cRepeat  fixed bin(31) byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl rank builtin;
   call fn (hwnd, WM_SYSDEADCHAR, rank (ch), MAKELPARAM (cRepeat,0));
 end FORWARD_WM_SYSDEADCHAR;


 /* dcl Cls_OnMouseMove entry (type HWND hwnd, fixed bin(31), */
 /*                            fixed bin(31), type UINT)      */

 HANDLE_WM_MOUSEMOVE: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
    call fn (hwnd, isigned (LOWORD (lParam)),
                   isigned (HIWORD (lParam)), (wParam));
    return (0);
 end HANDLE_WM_MOUSEMOVE;

 FORWARD_WM_MOUSEMOVE: proc (hwnd, x, y, keyFlags, fn)
                       options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       x        fixed bin(31) byvalue,
       y        fixed bin(31) byvalue,
       keyFlags type UINT byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_MOUSEMOVE, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_MOUSEMOVE;


 /* dcl Cls_OnLButtonDown entry (type HWND, type BOOL, fixed bin(31), */
 /*                              fixed bin(31), type UINT)            */

 HANDLE_WM_LBUTTONDOWN: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, FALSE, isigned (LOWORD (lParam)),
                         isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_LBUTTONDOWN;

 FORWARD_WM_LBUTTONDOWN: proc (hwnd, fDoubleClick, x, y, keyFlags, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fDoubleClick type BOOL byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       keyFlags     type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl msg type UINT;
   if fDoubleClick ^= 0 then
     msg = WM_LBUTTONDBLCLK;
   else
     msg = WM_LBUTTONDOWN;
   call fn (hwnd, msg, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_LBUTTONDOWN;


 /* dcl Cls_OnLButtonDown entry (type HWND, type BOOL, fixed bin(31), */
 /*                              fixed bin(31), type UINT)            */
 HANDLE_WM_LBUTTONDBLCLK: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, TRUE, isigned (LOWORD (lParam)),
                        isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_LBUTTONDBLCLK;


 /* dcl Cls_OnLButtonUp entry (type HWND, fixed bin(31), */
 /*                            fixed bin(31), type UINT) */

 HANDLE_WM_LBUTTONUP: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_LBUTTONUP;

 FORWARD_WM_LBUTTONUP: proc (hwnd, x, y, keyFlags, fn)
                       options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       keyFlags     type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_LBUTTONUP, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_LBUTTONUP;


 /* dcl Cls_OnRButtonDown entry (type HWND, type BOOL, fixed bin(31), */
 /*                              fixed bin(31), type UINT)            */

 HANDLE_WM_RBUTTONDOWN: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, FALSE, isigned (LOWORD (lParam)),
                         isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_RBUTTONDOWN;

 FORWARD_WM_RBUTTONDOWN: proc (hwnd, fDoubleClick, x, y, keyFlags, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fDoubleClick type BOOL byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       keyFlags     type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl msg type UINT;
   if fDoubleClick ^= 0 then
     msg = WM_RBUTTONDBLCLK;
   else
     msg = WM_RBUTTONDOWN;
   call fn (hwnd, msg, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_RBUTTONDOWN;


 /* dcl Cls_OnRButtonDown entry (type HWND, type BOOL, fixed bin(31), */
 /*                              fixed bin(31), type UINT)            */
 HANDLE_WM_RBUTTONDBLCLK: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, TRUE, isigned (LOWORD (lParam)),
                        isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_RBUTTONDBLCLK;


 /* dcl Cls_OnRButtonUp entry (type HWND, fixed bin(31), */
 /*                            fixed bin(31), type UINT) */

 HANDLE_WM_RBUTTONUP: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT) byvalue;
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_RBUTTONUP;

 FORWARD_WM_RBUTTONUP: proc (hwnd, x, y, keyFlags, fn)
                       options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       x        fixed bin(31) byvalue,
       y        fixed bin(31) byvalue,
       keyFlags type UINT byvalue,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   call fn (hwnd, WM_RBUTTONUP, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_RBUTTONUP;


 /* dcl Cls_OnMButtonDown entry (type HWND, type BOOL, fixed bin(31), */
 /*                              fixed bin(31), type UINT)            */

 HANDLE_WM_MBUTTONDOWN: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, FALSE, isigned (LOWORD (lParam)),
                         isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_MBUTTONDOWN;

 FORWARD_WM_MBUTTONDOWN: proc (hwnd, fDoubleClick, x, y, keyFlags, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fDoubleClick type BOOL byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       keyFlags     type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl msg type UINT;
   if fDoubleClick ^= 0 then
     msg = WM_MBUTTONDBLCLK;
   else
     msg = WM_MBUTTONDOWN;
   call fn (hwnd, msg, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_MBUTTONDOWN;


 /* dcl Cls_OnMButtonDown entry (type HWND, type BOOL, fixed bin(31), */
 /*                              fixed bin(31), type UINT)            */
 HANDLE_WM_MBUTTONDBLCLK: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, TRUE, isigned (LOWORD (lParam)),
                        isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_MBUTTONDBLCLK;


 /* dcl Cls_OnMButtonUp entry (type HWND, fixed bin(31), */
 /*                            fixed bin(31), type UINT) */

 HANDLE_WM_MBUTTONUP: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_MBUTTONUP;

 FORWARD_WM_MBUTTONUP: proc (hwnd, x, y, keyFlags, fn)
                       options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       keyFlags     type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_MBUTTONUP, (keyFlags), MAKELPARAM (x, y));
 end FORWARD_WM_MBUTTONUP;


 /* dcl Cls_OnMouseWheel entry (type HWND, fixed bin(31),     */
 /*                             fixed bin(31), fixed bin(31), */
 /*                             type UINT)                    */

 HANDLE_WM_MOUSEWHEEL: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl (isigned, iunsigned) builtin;

   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)),
                  isigned (HIWORD (wParam)),
                  iunsigned (LOWORD (wParam)));
   return (0); /* Microsoft don't, but that makes no sense - MS bug? */
 end HANDLE_WM_MOUSEWHEEL;

 FORWARD_WM_MOUSEWHEEL: proc (hwnd, xPos, yPos, zDelta, fwKeys, fn)
                        options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       xPos        fixed bin(31) byvalue,
       yPos        fixed bin(31) byvalue,
       zDelta      fixed bin(31) byvalue,
       fwKeys      type UINT byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   call fn (hwnd, WM_MOUSEWHEEL, MAKEWPARAM (fwKeys,zDelta),
                                 MAKELPARAM (xPos, yPos));
 end FORWARD_WM_MOUSEWHEEL;


 /* dcl Cls_OnNCMouseMove entry (type HWND, fixed bin(31), */
 /*                              fixed bin(31), type UINT) */

 HANDLE_WM_NCMOUSEMOVE: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
    call fn (hwnd, isigned (LOWORD (lParam)),
                   isigned (HIWORD (lParam)), (wParam));
    return (0);
 end HANDLE_WM_NCMOUSEMOVE;

 FORWARD_WM_NCMOUSEMOVE: proc (hwnd, x, y, codeHitTest, fn)
                         options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       x           fixed bin(31) byvalue,
       y           fixed bin(31) byvalue,
       codeHitTest type UINT byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   call fn (hwnd, WM_NCMOUSEMOVE, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCMOUSEMOVE;


 /* dcl Cls_OnNCLButtonDown entry (type HWND, type BOOL,         */
 /*                                fixed bin(31), fixed bin(31), */
 /*                                type UINT)                    */

 HANDLE_WM_NCLBUTTONDOWN: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, FALSE, isigned (LOWORD (lParam)),
                         isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCLBUTTONDOWN;

 FORWARD_WM_NCLBUTTONDOWN: proc (hwnd, fDoubleClick, x, y,
                                 codeHitTest, fn)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fDoubleClick type BOOL byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       codeHitTest  type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl msg type UINT;
   if fDoubleClick ^= 0 then
     msg = WM_NCLBUTTONDBLCLK;
   else
     msg = WM_NCLBUTTONDOWN;
   call fn (hwnd, msg, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCLBUTTONDOWN;


 /* dcl Cls_OnNCLButtonDown entry (type HWND, type BOOL,         */
 /*                                fixed bin(31), fixed bin(31), */
 /*                                type UINT)                    */

 HANDLE_WM_NCLBUTTONDBLCLK: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, TRUE, isigned (LOWORD (lParam)),
                        isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCLBUTTONDBLCLK;


 /* dcl Cls_OnNCLButtonUp entry (type HWND, fixed bin(31), */
 /*                              fixed bin(31), type UINT) */

 HANDLE_WM_NCLBUTTONUP: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCLBUTTONUP;

 FORWARD_WM_NCLBUTTONUP: proc (hwnd, x, y, codeHitTest, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       codeHitTest  type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_NCLBUTTONUP, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCLBUTTONUP;


 /* dcl Cls_OnNCRButtonDown entry (type HWND, type BOOL,         */
 /*                                fixed bin(31), fixed bin(31), */
 /*                                type UINT)                    */

 HANDLE_WM_NCRBUTTONDOWN: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, FALSE, isigned (LOWORD (lParam)),
                         isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCRBUTTONDOWN;

 FORWARD_WM_NCRBUTTONDOWN: proc (hwnd, fDoubleClick, x, y,
                                 codeHitTest, fn)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fDoubleClick type BOOL byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       codeHitTest  type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl msg type UINT;
   if fDoubleClick ^= 0 then
     msg = WM_NCRBUTTONDBLCLK;
   else
     msg = WM_NCRBUTTONDOWN;
   call fn (hwnd, msg, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCRBUTTONDOWN;


 /* dcl Cls_OnNCRButtonDown entry (type HWND, type BOOL,         */
 /*                                fixed bin(31), fixed bin(31), */
 /*                                type UINT)                    */

 HANDLE_WM_NCRBUTTONDBLCLK: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, TRUE, isigned (LOWORD (lParam)),
                        isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCRBUTTONDBLCLK;


 /* dcl Cls_OnNCRButtonUp entry (type HWND, fixed bin(31), */
 /*                              fixed bin(31), type UINT) */

 HANDLE_WM_NCRBUTTONUP: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCRBUTTONUP;

 FORWARD_WM_NCRBUTTONUP: proc (hwnd, x, y, codeHitTest, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       codeHitTest  type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_NCRBUTTONUP, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCRBUTTONUP;


 /* dcl Cls_OnNCMButtonDown entry (type HWND, type BOOL,         */
 /*                                fixed bin(31), fixed bin(31), */
 /*                                type UINT)                    */

 HANDLE_WM_NCMBUTTONDOWN: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, FALSE, isigned (LOWORD (lParam)),
                         isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCMBUTTONDOWN;

 FORWARD_WM_NCMBUTTONDOWN: proc (hwnd, fDoubleClick, x, y,
                                 codeHitTest, fn)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       fDoubleClick type BOOL byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       codeHitTest  type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl msg type UINT;
   if fDoubleClick ^= 0 then
     msg = WM_NCMBUTTONDBLCLK;
   else
     msg = WM_NCMBUTTONDOWN;
   call fn (hwnd, msg, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCMBUTTONDOWN;


 /* dcl Cls_OnNCMButtonDown entry (type HWND, type BOOL,         */
 /*                                fixed bin(31), fixed bin(31), */
 /*                                type UINT)                    */

 HANDLE_WM_NCMBUTTONDBLCLK: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, TRUE, isigned (LOWORD (lParam)),
                        isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCMBUTTONDBLCLK;


 /* dcl Cls_OnNCMButtonUp entry (type HWND, fixed bin(31), */
 /*                              fixed bin(31), type UINT) */

 HANDLE_WM_NCMBUTTONUP: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     fixed bin(31) byvalue, type UINT byvalue);
   dcl isigned builtin;
   call fn (hwnd, isigned (LOWORD (lParam)),
                  isigned (HIWORD (lParam)), (wParam));
   return (0);
 end HANDLE_WM_NCMBUTTONUP;

 FORWARD_WM_NCMBUTTONUP: proc (hwnd, x, y, codeHitTest, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       x            fixed bin(31) byvalue,
       y            fixed bin(31) byvalue,
       codeHitTest  type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_NCMBUTTONUP, (codeHitTest), MAKELPARAM (x, y));
 end FORWARD_WM_NCMBUTTONUP;


 /* dcl Cls_OnMouseActivate entry (type HWND, type HWND,     */
 /*                                type UINT, type UINT)     */
 /*                         returns (fixed bin(31) optional) */

 HANDLE_WM_MOUSEACTIVATE: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, type UINT byvalue)
              returns (fixed bin(31) byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, ptrvalue (wParam), LOWORD (lParam),
               HIWORD (lParam)));
 end HANDLE_WM_MOUSEACTIVATE;

 FORWARD_WM_MOUSEACTIVATE: proc (hwnd, hwndTopLevel, codeHitTest,
                                 msg, fn)
                           returns (fixed bin(31) byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndTopLevel type HWND byvalue,
       codeHitTest  type UINT byvalue,
       msg          type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl ptrvalue builtin;
   return (fn (hwnd, WM_MOUSEACTIVATE, binvalue (hwndTopLevel),
               MAKELPARAM (codeHitTest, msg)));
 end FORWARD_WM_MOUSEACTIVATE;


 /* dcl Cls_OnCancelMode entry (type HWND) */

 HANDLE_WM_CANCELMODE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_CANCELMODE;

 FORWARD_WM_CANCELMODE: proc (hwnd, fn)
                        options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_CANCELMODE, 0, 0);
 end FORWARD_WM_CANCELMODE;


 /* dcl Cls_OnTimer entry (type HWND, type UINT) */

 HANDLE_WM_TIMER: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue);
   call fn (hwnd, wParam);
   return (0);
 end HANDLE_WM_TIMER;

 FORWARD_WM_TIMER: proc (hwnd, id, fn)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       id   type UINT byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_TIMER, (id), 0);
 end FORWARD_WM_TIMER;


 /* dcl Cls_OnInitMenu entry (type HWND, type HMENU) */

 HANDLE_WM_INITMENU: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HMENU byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_INITMENU;

 FORWARD_WM_INITMENU: proc (hwnd, hMenu, fn)
                      options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       hMenu type HMENU byvalue,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_INITMENU, binvalue (hMenu), 0);
 end FORWARD_WM_INITMENU;


 /* dcl Cls_OnInitMenuPopup entry (type HWND, type HMENU, */
 /*                                type UINT, type BOOL)  */

 HANDLE_WM_INITMENUPOPUP: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HMENU byvalue,
                     type UINT byvalue, type BOOL byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam), LOWORD (lParam), HIWORD (lParam));
   return (0);
 end HANDLE_WM_INITMENUPOPUP;

 FORWARD_WM_INITMENUPOPUP: proc (hwnd, hMenu, item, fSystemMenu, fn)
                           options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       hMenu       type HMENU byvalue,
       item        type UINT byvalue,
       fSystemMenu type BOOL byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_INITMENUPOPUP, binvalue (hMenu),
            MAKELPARAM (item, fSystemMenu));
 end FORWARD_WM_INITMENUPOPUP;


 /* dcl Cls_OnMenuSelect entry (type HWND, type HMENU, fixed bin(31), */
 /*                             type HMENU, type UINT)                */

 HANDLE_WM_MENUSELECT: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HMENU byvalue,
                     fixed bin(31) byvalue, type HMENU byvalue,
                     type UINT byvalue);
   dcl item       fixed bin (31),
       hMenuPopup type HMENU,
       flags      type UINT;
   dcl (iand, ptrvalue, isigned, sysnull) builtin;

   if iand (HIWORD (wParam), MF_POPUP) ^= 0 then do;
     item = 0;
     hMenuPopup = GetSubMenu (ptrvalue (lParam), LOWORD (wParam));
   end;
   else do;
     item = LOWORD (wParam);
     hMenuPopup = sysnull();
   end;
   if isigned (HIWORD (wParam)) = -1 then
     flags = 'ffffffff'xn;
   else
     flags = HIWORD (wParam);
   call fn (hwnd, ptrvalue (lParam), item, hMenuPopup, flags);
   return (0);
 end HANDLE_WM_MENUSELECT;

 FORWARD_WM_MENUSELECT: proc (hwnd, hmenu, item, hmenuPopup, flags, fn)
                        options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       hmenu      type HMENU byvalue,
       item       fixed bin (31) byvalue,
       hmenuPopup type HMENU byvalue,/* note order of 4th & 5th parms */
       flags      type UINT byvalue,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   dcl whichMenu  type HMENU;
   dcl (binvalue, sysnull) builtin;
   if hmenu ^= sysnull() then
     whichMenu = hmenu;
   else
     whichMenu = hmenuPopup;
   call fn (hwnd, WM_MENUSELECT, MAKEWPARAM (item, flags),
            binvalue (whichMenu));
 end FORWARD_WM_MENUSELECT;


 /* dcl Cls_OnMenuChar entry (type HWND, type UINT,  */
 /*                           type UINT, type HMENU) */
 /*                    returns (type DWORD optional) */

 HANDLE_WM_MENUCHAR: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type UINT byvalue, type HMENU byvalue)
              returns (type DWORD byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, LOWORD (wParam), HIWORD (wParam),
               ptrvalue (lParam)));
 end HANDLE_WM_MENUCHAR;

 FORWARD_WM_MENUCHAR: proc (hwnd, ch, flags, hmenu, fn)
                      returns (type DWORD byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       ch    type UINT byvalue,
       flags type UINT byvalue,
       hmenu type HMENU byvalue,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   dcl binvalue builtin;
   return (fn (hwnd, WM_MENUCHAR, MAKEWPARAM (flags, ch),
               binvalue (hmenu)));
 end FORWARD_WM_MENUCHAR;


 /* dcl Cls_OnCommand entry (type HWND, fixed bin(31), */
 /*                          type HWND, type UINT)     */

 HANDLE_WM_COMMAND: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     type HWND byvalue, type UINT byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, LOWORD (wParam), ptrvalue (lParam), HIWORD (wParam));
   return (0);
 end HANDLE_WM_COMMAND;

 FORWARD_WM_COMMAND: proc (hwnd, id, hwndCtl, codeNotify, fn)
                     options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       id         fixed bin(31) byvalue,
       hwndCtl    type HWND byvalue,
       codeNotify type UINT byvalue,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_COMMAND, MAKEWPARAM (id, codeNotify),
            binvalue (hwndCtl));
 end FORWARD_WM_COMMAND;


 /* dcl Cls_OnHScroll entry (type HWND, type HWND, type UINT, */
 /*                          fixed bin(31))                   */

 HANDLE_WM_HSCROLL: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, fixed bin(31) byvalue);
   dcl (ptrvalue, isigned) builtin;
   call fn (hwnd, ptrvalue (lParam), LOWORD (wParam),
                  isigned (HIWORD (wParam)));
   return (0);
 end HANDLE_WM_HSCROLL;

 FORWARD_WM_HSCROLL: proc (hwnd, hwndCtl, code, pos, fn)
                     options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       hwndCtl type HWND byvalue,
       code    type UINT byvalue,
       pos     fixed bin(31) byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_HSCROLL, MAKEWPARAM (code, pos),
            binvalue (hwndCtl));
 end FORWARD_WM_HSCROLL;


 /* dcl Cls_OnVScroll entry (type HWND, type HWND, type UINT, */
 /*                          fixed bin(31))                   */

 HANDLE_WM_VSCROLL: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, fixed bin(31) byvalue);
   dcl (ptrvalue, isigned) builtin;
   call fn (hwnd, ptrvalue (lParam), LOWORD (wParam),
                  isigned (HIWORD (wParam)));
   return (0);
 end HANDLE_WM_VSCROLL;

 FORWARD_WM_VSCROLL: proc (hwnd, hwndCtl, code, pos, fn)
                     options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       hwndCtl type HWND byvalue,
       code    type UINT byvalue,
       pos     fixed bin(31) byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_VSCROLL, MAKEWPARAM (code, pos),
            binvalue (hwndCtl));
 end FORWARD_WM_VSCROLL;


 /* dcl Cls_OnCut entry (type HWND) */

 HANDLE_WM_CUT: proc (hwnd, wParam, lParam, fn)
                returns (type LRESULT byvalue optional)
                options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_CUT;

 FORWARD_WM_CUT: proc (hwnd, fn)
                 options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_CUT, 0, 0);
 end FORWARD_WM_CUT;


 /* dcl Cls_OnCopy entry (type HWND) */

 HANDLE_WM_COPY: proc (hwnd, wParam, lParam, fn)
                 returns (type LRESULT byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_COPY;

 FORWARD_WM_COPY: proc (hwnd, fn)
                  options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_COPY, 0, 0);
 end FORWARD_WM_COPY;


 /* dcl Cls_OnPaste entry (type HWND) */

 HANDLE_WM_PASTE: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_PASTE;

 FORWARD_WM_PASTE: proc (hwnd, fn)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd,  WM_PASTE, 0, 0);
 end FORWARD_WM_PASTE;


 /* dcl Cls_OnClear entry (type HWND) */

 HANDLE_WM_CLEAR: proc (hwnd, wParam, lParam, fn)
                  returns (type LRESULT byvalue optional)
                  options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_CLEAR;

 FORWARD_WM_CLEAR: proc (hwnd, fn)
                   options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_CLEAR, 0, 0);
 end FORWARD_WM_CLEAR;


 /* dcl Cls_OnUndo entry (HWND) */

 HANDLE_WM_UNDO: proc (hwnd, wParam, lParam, fn)
                 returns (type LRESULT byvalue optional)
                 options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_UNDO;

 FORWARD_WM_UNDO: proc (hwnd, fn)
                  options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_UNDO, 0, 0);
 end FORWARD_WM_UNDO;


 /* dcl Cls_OnRenderFormat entry (type HWND, type UINT)   */
 /*                        returns (type HANDLE optional) */

 HANDLE_WM_RENDERFORMAT: proc (hwnd, wParam, lParam, fn)
                         returns (type LRESULT byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue)
              returns (type HANDLE byvalue optional);
   return (fn (hwnd, (wParam)));
 end HANDLE_WM_RENDERFORMAT;

 FORWARD_WM_RENDERFORMAT: proc (hwnd, fmt, fn)
                          returns (type HANDLE byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fmt  type UINT byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   dcl ptrvalue builtin;
   return (ptrvalue (fn (hwnd, WM_RENDERFORMAT, (fmt), 0)));
 end FORWARD_WM_RENDERFORMAT;


 /* dcl Cls_OnRenderAllFormats entry (type HWND) */

 HANDLE_WM_RENDERALLFORMATS: proc (hwnd, wParam, lParam, fn)
                             returns (type LRESULT byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_RENDERALLFORMATS;

 FORWARD_WM_RENDERALLFORMATS: proc (hwnd, fn)
                              options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_RENDERALLFORMATS, 0, 0);
 end FORWARD_WM_RENDERALLFORMATS;


 /* dcl Cls_OnDestroyClipboard entry (type HWND) */

 HANDLE_WM_DESTROYCLIPBOARD: proc (hwnd, wParam, lParam, fn)
                             returns (type LRESULT byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_DESTROYCLIPBOARD;

 FORWARD_WM_DESTROYCLIPBOARD: proc (hwnd, fn)
                              options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_DESTROYCLIPBOARD, 0, 0);
 end FORWARD_WM_DESTROYCLIPBOARD;


 /* dcl Cls_OnDrawClipboard entry (type HWND) */

 HANDLE_WM_DRAWCLIPBOARD: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_DRAWCLIPBOARD;

 FORWARD_WM_DRAWCLIPBOARD: proc (hwnd, fn)
                           options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_DRAWCLIPBOARD, 0, 0);
 end FORWARD_WM_DRAWCLIPBOARD;


 /* dcl Cls_OnPaintClipboard entry (type HWND, type HWND,            */
 /*                                 type PAINTSTRUCT byaddr nonasgn) */

 HANDLE_WM_PAINTCLIPBOARD: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type PAINTSTRUCT byaddr nonasgn);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, ptrvalue (wParam),
            type (bind (: PAINTSTRUCT,
                          GlobalLock (ptrvalue (lParam)) :) ));
   call GlobalUnlock (ptrvalue (lParam));
   return (0);
 end HANDLE_WM_PAINTCLIPBOARD;

 FORWARD_WM_PAINTCLIPBOARD: proc (hwnd, hwndCBViewer, lpPaintStruct, fn)
                            options (inline reorder) internal;
   dcl hwnd          type HWND byvalue,
       hwndCBViewer  type HWND byvalue,
       lpPaintStruct type PAINTSTRUCT byaddr nonasgn,
       fn            type WNDPROC;      /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_PAINTCLIPBOARD, binvalue (hwndCBViewer),
            binvalue (addr (lpPaintStruct)));
 end FORWARD_WM_PAINTCLIPBOARD;


 /* dcl Cls_OnSizeClipboard entry (type HWND, type HWND,     */
 /*                                type RECT byaddr nonasgn) */

 HANDLE_WM_SIZECLIPBOARD: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type RECT byaddr nonasgn);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, ptrvalue (wParam),
            type (bind (: RECT,
                          GlobalLock (ptrvalue (lParam)) :) ));
   call GlobalUnlock (ptrvalue (lParam));
   return (0);
 end HANDLE_WM_SIZECLIPBOARD;

 FORWARD_WM_SIZECLIPBOARD: proc (hwnd, hwndCBViewer, lprc, fn)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndCBViewer type HWND byvalue,
       lprc         type RECT byaddr nonasgn,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_SIZECLIPBOARD, binvalue (hwndCBViewer),
            binvalue (addr (lprc)));
 end FORWARD_WM_SIZECLIPBOARD;


 /* dcl Cls_OnVScrollClipboard entry (type HWND, type HWND,     */
 /*                                   type UINT, fixed bin(31)) */

 HANDLE_WM_VSCROLLCLIPBOARD: proc (hwnd, wParam, lParam, fn)
                             returns (type LRESULT byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, fixed bin(31) byvalue);
   dcl (ptrvalue, isigned) builtin;
   call fn (hwnd, ptrvalue (wParam), LOWORD (lParam),
                  isigned (HIWORD (lParam)));
   return (0);
 end HANDLE_WM_VSCROLLCLIPBOARD;

 FORWARD_WM_VSCROLLCLIPBOARD: proc (hwnd, hwndCBViewer, code, pos, fn)
                              options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndCBViewer type HWND byvalue,
       code         type UINT byvalue,
       pos          fixed bin(31) byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_VSCROLLCLIPBOARD, binvalue (hwndCBViewer),
            MAKELPARAM (code, pos));
 end FORWARD_WM_VSCROLLCLIPBOARD;


 /* dcl Cls_OnHScrollClipboard entry (type HWND, type HWND,     */
 /*                                   type UINT, fixed bin(31)) */

 HANDLE_WM_HSCROLLCLIPBOARD: proc (hwnd, wParam, lParam, fn)
                             returns (type LRESULT byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, fixed bin(31) byvalue);
   dcl (ptrvalue, isigned) builtin;
   call fn (hwnd, ptrvalue (wParam), LOWORD (lParam),
                  isigned (HIWORD (lParam)));
   return (0);
 end HANDLE_WM_HSCROLLCLIPBOARD;

 FORWARD_WM_HSCROLLCLIPBOARD: proc (hwnd, hwndCBViewer, code, pos, fn)
                              options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndCBViewer type HWND byvalue,
       code         type UINT byvalue,
       pos          fixed bin(31) byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_HSCROLLCLIPBOARD, binvalue (hwndCBViewer),
            MAKELPARAM (code, pos));
 end FORWARD_WM_HSCROLLCLIPBOARD;


 /* dcl Cls_OnAskCBFormatName entry (type HWND, fixed bin(31), */
 /*                                  TCHAR(*) varz byaddr)     */

 HANDLE_WM_ASKCBFORMATNAME: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     TCHAR(*) varz byaddr);
   call fn (hwnd, (wParam), pli_b2z (lParam));
   return (0);
 end HANDLE_WM_ASKCBFORMATNAME;

 FORWARD_WM_ASKCBFORMATNAME: proc (hwnd, cchMax, rgchName, fn)
                             options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       cchMax   fixed bin(31) byvalue,
       rgchName TCHAR(*) varz byaddr,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_ASKCBFORMATNAME, (cchMax),
            binvalue (addr (rgchName)));
 end FORWARD_WM_ASKCBFORMATNAME;


 /* dcl Cls_OnChangeCBChain entry (type HWND, type HWND, type HWND) */

 HANDLE_WM_CHANGECBCHAIN: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam), ptrvalue (lParam));
   return (0);
 end HANDLE_WM_CHANGECBCHAIN;

 FORWARD_WM_CHANGECBCHAIN: proc (hwnd, hwndRemove, hwndNext, fn)
                           options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       hwndRemove type HWND byvalue,
       hwndNext   type HWND byvalue,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_CHANGECBCHAIN, binvalue (hwndRemove),
            binvalue (hwndNext));
 end FORWARD_WM_CHANGECBCHAIN;


 /* dcl Cls_OnSetCursor entry (type HWND, type HWND, */
 /*                            type UINT, type UINT) */
 /*                     returns (type BOOL optional) */

 HANDLE_WM_SETCURSOR: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, type UINT byvalue)
              returns (type BOOL byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, ptrvalue (wParam), LOWORD (lParam),
               HIWORD (lParam)));
 end HANDLE_WM_SETCURSOR;

 FORWARD_WM_SETCURSOR: proc (hwnd, hwndCursor, codeHitTest, msg, fn)
                       returns (type BOOL byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       hwndCursor  type HWND byvalue,
       codeHitTest type UINT byvalue,
       msg         type UINT byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   dcl binvalue builtin;
   return (fn (hwnd, WM_SETCURSOR, binvalue (hwndCursor),
               MAKELPARAM (codeHitTest, msg)));
 end FORWARD_WM_SETCURSOR;


 /* dcl Cls_OnSysCommand entry (type HWND, type UINT,         */
 /*                             fixed bin(31), fixed bin(31)) */

 HANDLE_WM_SYSCOMMAND: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     fixed bin(31) byvalue, fixed bin(31) byvalue);
   dcl isigned builtin;
   call fn (hwnd, (wParam), isigned (LOWORD (lParam)),
                            isigned (HIWORD (lParam)));
   return (0);
 end HANDLE_WM_SYSCOMMAND;

 FORWARD_WM_SYSCOMMAND: proc (hwnd, cmd, x, y, fn)
                        options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       cmd  type UINT byvalue,
       x    fixed bin(31) byvalue,
       y    fixed bin(31) byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_SYSCOMMAND, (cmd), MAKELPARAM (x, y));
 end FORWARD_WM_SYSCOMMAND;


 /* dcl Cls_MDICreate entry (type HWND,                           */
 /*                          type MDICREATESTRUCT byaddr nonasgn) */
 /*                   returns (type HWND optional)                */

 HANDLE_WM_MDICREATE: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue,
                     type MDICREATESTRUCT byaddr nonasgn)
              returns (type HWND byvalue optional);
   dcl (binvalue, ptrvalue, type) builtin;
   return (binvalue (fn (hwnd, type (bind (: MDICREATESTRUCT,
                                     ptrvalue (lParam) :) ))));
 end HANDLE_WM_MDICREATE;

 FORWARD_WM_MDICREATE: proc (hwnd, lpmcs, fn)
                       returns (type HWND byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       lpmcs type MDICREATESTRUCT byaddr nonasgn,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   dcl ptrvalue builtin;
   return (ptrvalue (fn (hwnd, WM_MDICREATE, 0,
                         binvalue (addr (lpmcs)))));
 end FORWARD_WM_MDICREATE;


 /* dcl Cls_MDIDestroy entry (type HWND, type HWND) */

 HANDLE_WM_MDIDESTROY: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_MDIDESTROY;

 FORWARD_WM_MDIDESTROY: proc (hwnd, hwndDestroy, fn)
                        options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       hwndDestroy type HWND byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   dcl binvalue builtin;

   call fn (hwnd, WM_MDIDESTROY, binvalue (hwndDestroy), 0);
 end FORWARD_WM_MDIDESTROY;


 /* NOTE: Usable only by MDI client windows */

 /* dcl Cls_MDIActivate entry (type HWND, type BOOL, */
 /*                            type HWND, type HWND) */

 HANDLE_WM_MDIACTIVATE: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     type HWND byvalue, type HWND byvalue);
   dcl fActive type BOOL;
   dcl ptrvalue builtin;
   if ptrvalue (lParam) = hwnd then
     fActive = TRUE;
   else
     fActive = FALSE;
   call fn (hwnd, fActive, ptrvalue (lParam), ptrvalue (wParam));
   return (0);
 end HANDLE_WM_MDIACTIVATE;

 FORWARD_WM_MDIACTIVATE: proc (hwnd, fActive, hwndActivate,
                               hwndDeactivate, fn)
                         options (inline reorder) internal;
   dcl hwnd           type HWND byvalue,
       fActive        type BOOL byvalue,
       hwndActivate   type HWND byvalue,
       hwndDeactivate type HWND byvalue,
       fn             type WNDPROC;     /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_MDIACTIVATE, binvalue (hwndDeactivate),
            binvalue (hwndActivate));
 end FORWARD_WM_MDIACTIVATE;


 /* dcl Cls_MDIRestore entry (type HWND, type HWND) */

 HANDLE_WM_MDIRESTORE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_MDIRESTORE;

 FORWARD_WM_MDIRESTORE: proc (hwnd, hwndRestore, fn)
                        options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       hwndRestore type HWND byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_MDIRESTORE, binvalue (hwndRestore), 0);
 end FORWARD_WM_MDIRESTORE;


 /* dcl Cls_MDINext entry (type HWND, type HWND, type BOOL) */
 /*                 returns (type HWND optional)            */

 HANDLE_WM_MDINEXT: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type BOOL byvalue)
              returns (type HWND byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, ptrvalue (wParam), (lParam)));
 end HANDLE_WM_MDINEXT;

 FORWARD_WM_MDINEXT: proc (hwnd, hwndCur, fPrev, fn)
                     returns (type HWND byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       hwndCur type HWND byvalue,
       fPrev   type BOOL byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_MDINEXT, binvalue (hwndCur),
                         (fPrev))));
 end FORWARD_WM_MDINEXT;


 /* dcl Cls_MDIMaximize entry (type HWND, type HWND) */

 HANDLE_WM_MDIMAXIMIZE: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam));
   return (0);
 end HANDLE_WM_MDIMAXIMIZE;

 FORWARD_WM_MDIMAXIMIZE: proc (hwnd, hwndMaximize, fn)
                         options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndMaximize type HWND byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_MDIMAXIMIZE, binvalue (hwndMaximize), 0);
 end FORWARD_WM_MDIMAXIMIZE;


 /* dcl Cls_MDITile entry (type HWND, type UINT) */
 /*                 returns (type BOOL optional) */

 HANDLE_WM_MDITILE: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue)
              returns (type BOOL byvalue optional);
   return (fn (hwnd, (wParam)));
 end HANDLE_WM_MDITILE;

 FORWARD_WM_MDITILE: proc (hwnd, cmd, fn)
                     returns (type BOOL byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       cmd  type UINT byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_MDITILE, (cmd), 0));
 end FORWARD_WM_MDITILE;


 /* dcl Cls_MDICascade entry (type HWND, type UINT) */
 /*                    returns (type BOOL optional) */

 HANDLE_WM_MDICASCADE: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue)
              returns (type BOOL byvalue optional);
   return (fn (hwnd, (wParam)));
 end HANDLE_WM_MDICASCADE;

 FORWARD_WM_MDICASCADE: proc (hwnd, cmd, fn)
                        returns (type BOOL byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       cmd  type UINT byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   return (fn (hwnd, WM_MDICASCADE, (cmd), 0));
 end FORWARD_WM_MDICASCADE;


 /* dcl Cls_MDIIconArrange entry (type HWND) */

 HANDLE_WM_MDIICONARRANGE: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_MDIICONARRANGE;

 FORWARD_WM_MDIICONARRANGE: proc (hwnd, fn)
                            options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_MDIICONARRANGE, 0, 0);
 end FORWARD_WM_MDIICONARRANGE;


 /* dcl Cls_MDIGetActive entry (type HWND)            */
 /*                      returns (type HWND optional) */

 HANDLE_WM_MDIGETACTIVE: proc (hwnd, wParam, lParam, fn)
                         returns (type LRESULT byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (type HWND byvalue optional);
   dcl binvalue builtin;
   return (binvalue (fn (hwnd)));
 end HANDLE_WM_MDIGETACTIVE;

 FORWARD_WM_MDIGETACTIVE: proc (hwnd, fn)
                          returns (type HWND byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   dcl ptrvalue builtin;
   return (ptrvalue (fn (hwnd, WM_MDIGETACTIVE, 0, 0)));
 end FORWARD_WM_MDIGETACTIVE;


 /* dcl Cls_MDISetMenu entry (type HWND, type BOOL,   */
 /*                           type HMENU, type HMENU) */
 /*                    returns (type HMENU optional)  */

 HANDLE_WM_MDISETMENU: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type BOOL byvalue,
                     type HMENU byvalue, type HMENU byvalue)
              returns (type HMENU byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, (wParam), ptrvalue (wParam),
                         ptrvalue (lParam))));
 end HANDLE_WM_MDISETMENU;

 FORWARD_WM_MDISETMENU: proc (hwnd, fRefresh, hmenuFrame,
                              hmenuWindow, fn)
                        returns (type HMENU byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       fRefresh    type BOOL byvalue,
       hmenuFrame  type HMENU byvalue,
       hmenuWindow type HMENU byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   dcl hmenu type HMENU;
   if fRefresh ^= 0 then
     hmenu = hmenuFrame;
   else
     hmenu = sysnull();
   dcl ptrvalue builtin;
   return (ptrvalue (fn (hwnd, WM_MDISETMENU, binvalue (hmenu),
                         binvalue (hmenuWindow))));
 end FORWARD_WM_MDISETMENU;


 /* dcl Cls_OnChildActivate entry (HWND) */

 HANDLE_WM_CHILDACTIVATE: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_CHILDACTIVATE;

 FORWARD_WM_CHILDACTIVATE: proc (hwnd, fn)
                           options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_CHILDACTIVATE, 0, 0);
 end FORWARD_WM_CHILDACTIVATE;


 /* dcl Cls_OnInitDialog entry (type HWND, type HWND, type LPARAM) */
 /*                      returns (type BOOL optional)              */

 HANDLE_WM_INITDIALOG: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type LPARAM byvalue)
              returns (type BOOL byvalue optional);
   dcl ptrvalue builtin;
   return (fn (hwnd, ptrvalue (wParam), lParam));
 end HANDLE_WM_INITDIALOG;

 FORWARD_WM_INITDIALOG: proc (hwnd, hwndFocus, lParam, fn)
                        returns (type BOOL byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hwndFocus type HWND byvalue,
       lParam    type LPARAM byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl binvalue builtin;
   return (fn (hwnd, WM_INITDIALOG, binvalue (hwndFocus), lParam));
 end FORWARD_WM_INITDIALOG;


 /* dcl Cls_OnNextDlgCtl entry (type HWND, type HWND, type BOOL) */
 /*                      returns (type HWND optional)            */

 HANDLE_WM_NEXTDLGCTL: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type BOOL byvalue)
              returns (type HWND byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), (lParam))));
 end HANDLE_WM_NEXTDLGCTL;

 FORWARD_WM_NEXTDLGCTL: proc (hwnd, hwndSetFocus, fNext, fn)
                        returns (type HWND byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       hwndSetFocus type HWND byvalue,
       fNext        type BOOL byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_NEXTDLGCTL, ptrvalue (hwndSetFocus),
                         (fNext))));
 end FORWARD_WM_NEXTDLGCTL;


 /* dcl Cls_OnParentNotify entry (type HWND, type UINT, type HWND, */
 /*                               fixed bin(31))                   */

 HANDLE_WM_PARENTNOTIFY: proc (hwnd, wParam, lParam, fn)
                         returns (type LRESULT byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type HWND byvalue, fixed bin(31) byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, LOWORD (wParam), ptrvalue (lParam), HIWORD (wParam));
   return (0);
 end HANDLE_WM_PARENTNOTIFY;

 FORWARD_WM_PARENTNOTIFY: proc (hwnd, msg, hwndChild, idChild, fn)
                          options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       msg       type UINT byvalue,
       hwndChild type HWND byvalue,
       idChild   fixed bin(31) byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   call fn (hwnd, WM_PARENTNOTIFY, MAKEWPARAM (msg, idChild),
            binvalue (hwndChild));
 end FORWARD_WM_PARENTNOTIFY;


 /* dcl Cls_OnEnterIdle entry (type HWND, type UINT, type HWND) */

 HANDLE_WM_ENTERIDLE: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type HWND byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, (wParam), ptrvalue (lParam));
   return (0);
 end HANDLE_WM_ENTERIDLE;

 FORWARD_WM_ENTERIDLE: proc (hwnd, source, hwndSource, fn)
                          options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       source     type UINT byvalue,
       hwndSource type HWND byvalue,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   call fn (hwnd, WM_ENTERIDLE, (source), binvalue (hwndSource));
 end FORWARD_WM_ENTERIDLE;


 /* dcl Cls_OnGetDlgCode entry (type HWND, type MSG byaddr) */
 /*                      returns (type UINT optional)       */

 HANDLE_WM_GETDLGCODE:proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type MSG byaddr)
              returns (type UINT optional);
   dcl (ptrvalue, type) builtin;
   return (fn (hwnd, type (bind (: MSG, ptrvalue (lParam) :) )));
 end HANDLE_WM_GETDLGCODE;

 FORWARD_WM_GETDLGCODE: proc (hwnd, lpmsg, fn)
                        returns (type UINT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       lpmsg type MSG byaddr,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   dcl wParam type WPARAM;
   dcl (addr, binvalue, sysnull) builtin;
   if addr (lpmsg) ^= sysnull() then
     wParam = lpmsg.wParam;
   else
     wParam = 0;
   return (fn (hwnd, WM_GETDLGCODE, wParam, binvalue (addr (lpmsg))));
 end FORWARD_WM_GETDLGCODE;


 /* dcl Cls_OnCtlColor entry (type HWND, type HDC, type HWND, */
 /*                           fixed bin(31))                  */
 /*                    returns (type HBRUSH optional)         */

 HANDLE_WM_CTLCOLORMSGBOX: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_MSGBOX)));
 end HANDLE_WM_CTLCOLORMSGBOX;

 FORWARD_WM_CTLCOLORMSGBOX: proc (hwnd, hdc, hwndChild, fn)
                            returns (type HBRUSH byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLORMSGBOX, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLORMSGBOX;


 HANDLE_WM_CTLCOLOREDIT: proc (hwnd, wParam, lParam, fn)
                         returns (type LRESULT byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_EDIT)));
 end HANDLE_WM_CTLCOLOREDIT;

 FORWARD_WM_CTLCOLOREDIT: proc (hwnd, hdc, hwndChild, fn)
                          returns (type HBRUSH byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLOREDIT, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLOREDIT;


 HANDLE_WM_CTLCOLORLISTBOX: proc (hwnd, wParam, lParam, fn)
                            returns (type LRESULT byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_LISTBOX)));
 end HANDLE_WM_CTLCOLORLISTBOX;

 FORWARD_WM_CTLCOLORLISTBOX: proc (hwnd, hdc, hwndChild, fn)
                             returns (type HBRUSH byvalue optional)
                             options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLORLISTBOX, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLORLISTBOX;


 HANDLE_WM_CTLCOLORBTN: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_BTN)));
 end HANDLE_WM_CTLCOLORBTN;

 FORWARD_WM_CTLCOLORBTN: proc (hwnd, hdc, hwndChild, fn)
                         returns (type HBRUSH byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLORBTN, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLORBTN;


 HANDLE_WM_CTLCOLORDLG: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_DLG)));
 end HANDLE_WM_CTLCOLORDLG;

 FORWARD_WM_CTLCOLORDLG: proc (hwnd, hdc, hwndChild, fn)
                         returns (type HBRUSH byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLORDLG, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLORDLG;


 HANDLE_WM_CTLCOLORSCROLLBAR: proc (hwnd, wParam, lParam, fn)
                              returns (type LRESULT byvalue optional)
                              options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_SCROLLBAR)));
 end HANDLE_WM_CTLCOLORSCROLLBAR;

 FORWARD_WM_CTLCOLORSCROLLBAR: proc (hwnd, hdc, hwndChild, fn)
                               returns (type HBRUSH byvalue optional)
                               options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLORSCROLLBAR, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLORSCROLLBAR;


 HANDLE_WM_CTLCOLORSTATIC: proc (hwnd, wParam, lParam, fn)
                           returns (type LRESULT byvalue optional)
                           options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HDC byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (type HBRUSH byvalue optional);
   dcl (binvalue, ptrvalue) builtin;
   return (binvalue (fn (hwnd, ptrvalue (wParam), ptrvalue (lParam),
                         CTLCOLOR_STATIC)));
 end HANDLE_WM_CTLCOLORSTATIC;

 FORWARD_WM_CTLCOLORSTATIC: proc (hwnd, hdc, hwndChild, fn)
                            returns (type HBRUSH byvalue optional)
                            options (inline reorder) internal;
   dcl hwnd      type HWND byvalue,
       hdc       type HDC byvalue,
       hwndChild type HWND byvalue,
       fn        type WNDPROC;          /* SendMessage or PostMessage */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (fn (hwnd, WM_CTLCOLORSTATIC, binvalue (hdc),
                         binvalue (hwndChild))));
 end FORWARD_WM_CTLCOLORSTATIC;


 /* dcl Cls_OnSetFont entry (type HWND, type HFONT, type BOOL) */

 HANDLE_WM_SETFONT: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HFONT byvalue,
                     type BOOL byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam), (lParam));
   return (0);
 end HANDLE_WM_SETFONT;

 FORWARD_WM_SETFONT: proc (hwnd, hfont, fRedraw, fn)
                     options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       hfont   type HFONT byvalue,
       fRedraw type BOOL byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_SETFONT, binvalue (hfont), (fRedraw));
 end FORWARD_WM_SETFONT;


 /* dcl Cls_OnGetFont entry (type HWND) returns (type HFONT optional) */

 HANDLE_WM_GETFONT: proc (hwnd, wParam, lParam, fn)
                    returns (type LRESULT byvalue optional)
                    options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue)
              returns (type HFONT byvalue optional);
   dcl binvalue builtin;
   return (binvalue (fn (hwnd)));
 end HANDLE_WM_GETFONT;

 FORWARD_WM_GETFONT: proc (hwnd, fn)
                     returns (type HFONT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd    type HWND byvalue,
       fn      type WNDPROC;            /* SendMessage or PostMessage */
   dcl ptrvalue builtin;
   return (ptrvalue (fn (hwnd, WM_GETFONT, 0, 0)));
 end FORWARD_WM_GETFONT;


 /* dcl Cls_OnDrawItem entry (type HWND,                          */
 /*                           type DRAWITEMSTRUCT byaddr nonasgn) */

 HANDLE_WM_DRAWITEM: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue,
                     type DRAWITEMSTRUCT byaddr nonasgn);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, type (bind (: DRAWITEMSTRUCT, ptrvalue (lParam) :) ));
   return (0);
 end HANDLE_WM_DRAWITEM;

 FORWARD_WM_DRAWITEM: proc (hwnd, lpDrawItem, fn)
                      options (inline reorder) internal;
   dcl hwnd       type HWND byvalue,
       lpDrawItem type DRAWITEMSTRUCT byaddr nonasgn,
       fn         type WNDPROC;         /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_DRAWITEM, (lpDrawItem.CtlID),
            binvalue (addr (lpDrawItem)));
 end FORWARD_WM_DRAWITEM;


 /* dcl Cls_OnMeasureItem entry (type HWND,                     */
 /*                              type MEASUREITEMSTRUCT byaddr) */

 HANDLE_WM_MEASUREITEM: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type MEASUREITEMSTRUCT byaddr);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, type (bind (: MEASUREITEMSTRUCT,
                                ptrvalue (lParam) :)));
   return (0);
 end HANDLE_WM_MEASUREITEM;

 FORWARD_WM_MEASUREITEM: proc (hwnd, lpMeasureItem, fn)
                         options (inline reorder) internal;
   dcl hwnd          type HWND byvalue,
       lpMeasureItem type MEASUREITEMSTRUCT byaddr,
       fn            type WNDPROC;      /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_MEASUREITEM, (lpMeasureItem.CtlID),
            binvalue (addr (lpMeasureItem)));
 end FORWARD_WM_MEASUREITEM;


 /* dcl Cls_OnDeleteItem entry (type HWND,                            */
 /*                             type DELETEITEMSTRUCT byaddr nonasgn) */

 HANDLE_WM_DELETEITEM: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue,
                     type DELETEITEMSTRUCT byaddr nonasgn);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, type (bind (: DELETEITEMSTRUCT,
                                ptrvalue (lParam) :)));
   return (0);
 end HANDLE_WM_DELETEITEM;

 FORWARD_WM_DELETEITEM: proc (hwnd, lpDeleteItem, fn)
                        options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       lpDeleteItem type DELETEITEMSTRUCT byaddr,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   call fn (hwnd, WM_DELETEITEM, (lpDeleteItem.CtlID),
            binvalue (addr (lpDeleteItem)));
 end FORWARD_WM_DELETEITEM;


 /* dcl Cls_OnCompareItem entry (type HWND,                           */
 /*                            type COMPAREITEMSTRUCT byaddr nonasgn) */
 /*                       returns (fixed bin(31) optional)            */

 HANDLE_WM_COMPAREITEM: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue,
                     type COMPAREITEMSTRUCT byaddr nonasgn)
              returns (fixed bin(31) byvalue optional);
   dcl (ptrvalue, type) builtin;
   return (fn (hwnd, type (bind (: COMPAREITEMSTRUCT,
                                   ptrvalue (lParam) :))));
 end HANDLE_WM_COMPAREITEM;

 FORWARD_WM_COMPAREITEM: proc (hwnd, lpCompareItem, fn)
                         returns (fixed bin(31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd          type HWND byvalue,
       lpCompareItem type COMPAREITEMSTRUCT byaddr,
       fn            type WNDPROC;      /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_COMPAREITEM, (lpCompareItem.CtlID),
               binvalue (addr (lpCompareItem))));
 end FORWARD_WM_COMPAREITEM;


 /* dcl Cls_OnVkeyToItem entry (type HWND, type UINT, type HWND, */
 /*                             fixed bin(31))                   */
 /*                       returns (fixed bin(31) optional)       */

 HANDLE_WM_VKEYTOITEM: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (fixed bin(31) byvalue optional);
   dcl (ptrvalue, isigned) builtin;
   return (fn (hwnd, LOWORD (wParam), ptrvalue (lParam),
                     isigned (HIWORD (wParam))));
 end HANDLE_WM_VKEYTOITEM;

 FORWARD_WM_VKEYTOITEM: proc (hwnd, vk, hwndListBox, iCaret, fn)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       vk          type UINT byvalue,
       hwndListBox type HWND byvalue,
       iCaret      fixed bin(31) byvalue,
       fn          type WNDPROC;      /* SendMessage or PostMessage */
   dcl binvalue builtin;
   return (fn (hwnd, WM_VKEYTOITEM, MAKEWPARAM (vk, iCaret),
               binvalue (hwndListBox)));
 end FORWARD_WM_VKEYTOITEM;


 /* dcl Cls_OnCharToItem entry (type HWND, type UINT, type HWND, */
 /*                             fixed bin(31))                   */
 /*                      returns (fixed bin(31) optional)        */
 HANDLE_WM_CHARTOITEM: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type HWND byvalue, fixed bin(31) byvalue)
              returns (fixed bin(31) byvalue optional);
   dcl (ptrvalue, isigned) builtin;
   return (fn (hwnd, LOWORD (wParam), ptrvalue (lParam),
                     isigned (HIWORD (wParam))));
 end HANDLE_WM_CHARTOITEM;

 FORWARD_WM_CHARTOITEM: proc (hwnd, ch, hwndListBox, iCaret, fn)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       ch          type UINT byvalue,
       hwndListBox type HWND byvalue,
       iCaret      fixed bin(31) byvalue,
       fn          type WNDPROC;      /* SendMessage or PostMessage */
   dcl binvalue builtin;
   return (fn (hwnd, WM_CHARTOITEM, MAKEWPARAM (ch, iCaret),
               binvalue (hwndListBox)));
 end FORWARD_WM_CHARTOITEM;


 /* dcl Cls_OnQueueSync entry (type HWND) */

 HANDLE_WM_QUEUESYNC: proc (hwnd, wParam, lParam, fn)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue);
   call fn (hwnd);
   return (0);
 end HANDLE_WM_QUEUESYNC;

 FORWARD_WM_QUEUESYNC: proc (hwnd, fn)
                       options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       fn   type WNDPROC;               /* SendMessage or PostMessage */
   call fn (hwnd, WM_QUEUESYNC, 0, 0);
 end FORWARD_WM_QUEUESYNC;


 %if WINVER >= 778 %then %do;
 /* dcl Cls_OnCommNotify entry (type HWND, fixed bin(31), type UINT) */

 HANDLE_WM_COMMNOTIFY: proc (hwnd, wParam, lParam, fn)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin(31) byvalue,
                     type UINT byvalue);
   call fn (hwnd, (wParam), LOWORD (lParam));
   return (0);
 end HANDLE_WM_COMMNOTIFY;

 FORWARD_WM_COMMNOTIFY: proc (hwnd, cid, flags, fn)
                        options (inline reorder) internal;
   dcl hwnd  type HWND byvalue,
       cid   fixed bin(31) byvalue,
       flags type UINT byvalue,
       fn    type WNDPROC;              /* SendMessage or PostMessage */
   call fn (hwnd, WM_COMMNOTIFY, (cid), MAKELPARAM (flags, 0));
 end FORWARD_WM_COMMNOTIFY;

 %end;

 /* dcl Cls_OnDisplayChange entry (type HWND, type UINT, */
 /*                                type UINT, type UINT) */

 HANDLE_WM_DISPLAYCHANGE: proc (hwnd, wParam, lParam, fn)
                          returns (type LRESULT byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type UINT byvalue, type UINT byvalue);
   call fn (hwnd, (wParam), LOWORD (lParam), HIWORD (wParam));
   return (0);
 end HANDLE_WM_DISPLAYCHANGE;

 FORWARD_WM_DISPLAYCHANGE: proc (hwnd, bitsPerPixel,
                                 cxScreen, cyScreen, fn)
                           options (inline reorder) internal;
   dcl hwnd         type HWND byvalue,
       bitsPerPixel type UINT byvalue,
       cxScreen     type UINT byvalue,
       cyScreen     type UINT byvalue,
       fn           type WNDPROC;       /* SendMessage or PostMessage */
   call fn (hwnd, WM_DISPLAYCHANGE, (bitsPerPixel),
            MAKELPARAM (cxScreen, cyScreen));
 end FORWARD_WM_DISPLAYCHANGE;


 /* dcl Cls_OnDeviceChange entry (type HWND, type UINT, type DWORD) */
 /*                        returns (type BOOL optional)             */

 HANDLE_WM_DEVICECHANGE: proc (hwnd, wParam, lParam, fn)
                         returns (type LRESULT byvalue optional)
                         options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type UINT byvalue,
                     type DWORD byvalue)
              returns (type BOOL byvalue optional);
   /* MS say 3rd parm is wParam - this is a bug */
   return (fn (hwnd, (wParam), (lParam)));
 end HANDLE_WM_DEVICECHANGE;

 FORWARD_WM_DEVICECHANGE: proc (hwnd, uEvent, dwEventData, fn)
                          returns (type BOOL byvalue optional)
                          options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       uEvent      type UINT byvalue,
       dwEventData type DWORD byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   return (fn (hwnd, WM_DEVICECHANGE, (uEvent), (dwEventData)));
 end FORWARD_WM_DEVICECHANGE;


 /* dcl Cls_OnContextMenu entry (type HWND, type HWND, */
 /*                              type UINT, type UINT) */

 HANDLE_WM_CONTEXTMENU: proc (hwnd, wParam, lParam, fn)
                        returns (type LRESULT byvalue optional)
                        options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type UINT byvalue, type UINT byvalue);
   dcl ptrvalue builtin;
   call fn (hwnd, ptrvalue (wParam), LOWORD (lParam), HIWORD (lParam));
   return (0);
 end HANDLE_WM_CONTEXTMENU;

 FORWARD_WM_CONTEXTMENU: proc (hwnd, hwndContext, xPos, yPos, fn)
                         options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       hwndContext type HWND byvalue,
       xPos        type UINT byvalue,
       yPos        type UINT byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   dcl binvalue builtin;
   call fn (hwnd, WM_CONTEXTMENU, binvalue (hwndContext),
            MAKELPARAM (xPos, yPos));
 end FORWARD_WM_CONTEXTMENU;


 /* dcl Cls_OnCopyDada entry (type HWND, type HWND,       */
 /*                           type COPYDATASTRUCT byaddr) */

 HANDLE_WM_COPYDATA: proc (hwnd, wParam, lParam, fn)
                     returns (type LRESULT byvalue optional)
                     options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, type HWND byvalue,
                     type COPYDATASTRUCT byaddr);
   dcl (ptrvalue, type) builtin;
   call fn (hwnd, ptrvalue (wParam), type (bind (: COPYDATASTRUCT,
                                           ptrvalue (lParam) :)));
   return (0);
 end HANDLE_WM_COPYDATA;

 FORWARD_WM_COPYDATA: proc (hwnd, hwndFrom, pcds, fn)
                      returns (type BOOL byvalue optional)
                      options (inline reorder) internal;
   dcl hwnd     type HWND byvalue,
       hwndFrom type HWND byvalue,
       pcds     type COPYDATASTRUCT byaddr,
       fn       type WNDPROC;           /* SendMessage or PostMessage */
   dcl (addr, binvalue) builtin;
   return (fn (hwnd, WM_COPYDATA, binvalue (hwndFrom),
                                  binvalue (addr (pcds))));
 end FORWARD_WM_COPYDATA;

 /* dcl Cls_OnHotKey entry (type HWND, fixed bin (31), */
 /*                         type UINT, type UINT)      */

 HANDLE_WM_HOTKEY: proc (hwnd, wParam, lParam, fn)
                   returns (type LRESULT byvalue optional)
                   options (inline reorder) internal;
   dcl hwnd   type HWND byvalue,
       wParam type WPARAM byvalue,
       lParam type LPARAM byvalue,
       fn     entry (type HWND byvalue, fixed bin (31) byvalue,
                     type UINT byvalue, type UINT byvalue);
   call fn (hwnd, (wParam), LOWORD (lParam), HIWORD (lParam));
   return (0);
 end HANDLE_WM_HOTKEY;

 FORWARD_WM_HOTKEY: proc (hwnd, idHotKey, fuModifiers, vk, fn)
                    options (inline reorder) internal;
   dcl hwnd        type HWND byvalue,
       idHotKey    fixed bin(31) byvalue,
       fuModifiers type UINT byvalue,
       vk          type UINT byvalue,
       fn          type WNDPROC;        /* SendMessage or PostMessage */
   call fn (hwnd, WM_HOTKEY, (idHotKey), MAKELPARAM (fuModifiers, vk));
 end FORWARD_WM_HOTKEY;


 %dcl #WINUSER_ char ext;
 %if #WINUSER_ = 'Y' %then %do;

 /****** Static control message APIs **********************************/

 Static_Enable: proc (hwndCtl, fEnable)
                returns (type BOOL byvalue optional)
                options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fEnable type BOOL byvalue;
   return (EnableWindow (hwndCtl, fEnable));
 end Static_Enable;


 Static_GetText: proc (hwndCtl, lpch, cchMax)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpch    TCHAR(*) varz byaddr,
       cchMax  fixed bin(31) byvalue;
   return (GetWindowText (hwndCtl, lpch, cchMax));
 end Static_GetText;

 Static_GetTextLength: proc (hwndCtl)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (GetWindowTextLength (hwndCtl));
 end Static_GetTextLength;

 Static_SetText: proc (hwndCtl, lpsz)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpsz    TCHAR(*) varz byaddr;
   return (SetWindowText (hwndCtl, lpsz));
 end Static_SetText;


 Static_SetIcon: proc (hwndCtl, hIcon)
                 returns (type HICON byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       hIcon   type HICON byvalue;
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (SNDMSG (hwndCtl, STM_SETICON, binvalue(hIcon),
                     0)));
 end Static_SetIcon;

 Static_GetIcon: proc (hwndCtl, hIcon)
                 returns (type HICON byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue byvalue,
       hIcon   type HICON byvalue; /* ??? probable Microsoft typo! */
   dcl (binvalue, ptrvalue) builtin;
   return (ptrvalue (SNDMSG (hwndCtl, STM_GETICON, 0, 0)));
 end Static_GetIcon;


 /****** Button control message APIs **********************************/

 Button_Enable: proc (hwndCtl, fEnable)
                returns (type BOOL byvalue optional)
                options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fEnable type BOOL byvalue;
   return (EnableWindow (hwndCtl, fEnable));
 end Button_Enable;



 Button_GetText: proc (hwndCtl, lpch, cchMax)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpch    TCHAR(*) varz byaddr,
       cchMax  fixed bin(31) byvalue;
   return (GetWindowText (hwndCtl, lpch, cchMax));
 end Button_GetText;

 Button_GetTextLength: proc (hwndCtl)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (GetWindowTextLength (hwndCtl));
 end Button_GetTextLength;

 Button_SetText: proc (hwndCtl, lpsz)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpsz    TCHAR(*) varz byaddr;
   return (SetWindowText (hwndCtl, lpsz));
 end Button_SetText;


 Button_GetCheck: proc (hwndCtl)
                  returns (fixed bin(31) byvalue optional)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, BM_GETCHECK, 0, 0));
 end Button_GetCheck;

 Button_SetCheck: proc (hwndCtl, check)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       check   fixed bin(31) byvalue;
   call SNDMSG (hwndCtl, BM_SETCHECK, (check), 0);
 end Button_SetCheck;


 Button_GetState: proc (hwndCtl)
                  returns (fixed bin(31) byvalue optional)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, BM_GETSTATE, 0, 0));
 end Button_GetState;

 Button_SetState: proc (hwndCtl, state)
                  returns (type UINT byvalue optional)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       state   fixed bin(31) byvalue; /* type BOOL */
   return (SNDMSG (hwndCtl, BM_SETSTATE, (state), 0));
 end Button_SetState;


 Button_SetStyle: proc (hwndCtl, style, fRedraw)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       style   type DWORD byvalue,
       fRedraw type BOOL byvalue;
   dcl redraw  type BOOL;
   if fRedraw ^= FALSE then
     redraw = TRUE;
   else
     redraw = FALSE;
   call SNDMSG (hwndCtl, BM_SETSTYLE, LOWORD (style),
                         MAKELPARAM (redraw, 0));
 end Button_SetStyle;


 /****** Edit control message APIs ************************************/

 Edit_Enable: proc (hwndCtl, fEnable)
              returns (type BOOL byvalue optional)
              options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fEnable type BOOL byvalue;
   return (EnableWindow (hwndCtl, fEnable));
 end Edit_Enable;

 Edit_GetText: proc (hwndCtl, lpch, cchMax)
               returns (fixed bin(31) byvalue optional)
               options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpch    TCHAR(*) varz byaddr,
       cchMax  fixed bin(31) byvalue;
   return (GetWindowText (hwndCtl, lpch, cchMax));
 end Edit_GetText;

 Edit_GetTextLength: proc (hwndCtl)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (GetWindowTextLength (hwndCtl));
 end Edit_GetTextLength;

 Edit_SetText: proc (hwndCtl, lpsz)
               returns (fixed bin(31) byvalue optional)
               options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpsz    TCHAR(*) varz byaddr;
   return (SetWindowText (hwndCtl, lpsz));
 end Edit_SetText;


 Edit_LimitText: proc (hwndCtl, cchMax)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       cchMax  fixed bin(31) byvalue;
   call SNDMSG (hwndCtl, EM_LIMITTEXT, (cchMax), 0);
 end Edit_LimitText;


 Edit_GetLineCount: proc (hwndCtl)
                    returns (fixed bin(31) byvalue optional)
                    options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_GETLINECOUNT, 0, 0));
 end Edit_GetLineCount;

 Edit_GetLine: proc (hwndCtl, line, lpch, cchMax)
               returns (fixed bin(31) byvalue optional)
               options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       line    fixed bin(31) byvalue,
       lpch    TCHAR(*) varz byaddr,
       cchMax  fixed bin(31) byvalue;
   dcl (addr, binvalue) builtin;
   dcl maxchars fixed bin (31) based (addr (lpch));
   maxchars = cchMax;
   return (SNDMSG (hwndCtl, EM_GETLINE, (line),
                   binvalue (addr (lpch))));
 end Edit_GetLine;


 Edit_GetRect: proc (hwndCtl, lprc)
               options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lprc    type RECT byaddr;
   dcl (addr, binvalue) builtin;
   call SNDMSG (hwndCtl, EM_GETRECT, 0, binvalue (addr (lprc)));
 end Edit_GetRect;

 Edit_SetRect: proc (hwndCtl, lprc)
               options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lprc    type RECT byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   call SNDMSG (hwndCtl, EM_SETRECT, 0, binvalue (addr (lprc)));
 end Edit_SetRect;

 Edit_SetRectNoPaint: proc (hwndCtl, lprc)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lprc    type RECT byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   call SNDMSG (hwndCtl, EM_SETRECTNP, 0, binvalue (addr (lprc)));
 end Edit_SetRectNoPaint;


 Edit_GetSel: proc (hwndCtl)
              returns (type DWORD byvalue optional)
              options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_GETSEL, 0, 0));
 end Edit_GetSel;

 Edit_SetSel: proc (hwndCtl, ichStart, ichEnd)
              options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue,
       ichStart fixed bin(31) byvalue,
       ichEnd   fixed bin(31) byvalue;
   call SNDMSG (hwndCtl, EM_SETSEL, (ichStart), (ichEnd));
 end Edit_SetSel;

 Edit_ReplaceSel: proc (hwndCtl, lpszReplace)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpszReplace TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   call SNDMSG (hwndCtl, EM_REPLACESEL, 0,
                binvalue (addr (lpszReplace)));
 end Edit_ReplaceSel;


 Edit_GetModify: proc (hwndCtl)
                 returns (type BOOL byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_GETMODIFY, 0, 0));
 end Edit_GetModify;

 Edit_SetModify: proc (hwndCtl, fModified)
                 options (inline reorder) internal;
   dcl hwndCtl   type HWND byvalue,
       fModified type BOOL byvalue;
   call SNDMSG (hwndCtl, EM_SETMODIFY, (fModified), 0);
 end Edit_SetModify;


 Edit_ScrollCaret: proc (hwndCtl)
                   returns (type BOOL byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_SCROLLCARET, 0, 0));
 end Edit_ScrollCaret;


 Edit_LineFromChar: proc (hwndCtl, ich)
                    returns (fixed bin(31) byvalue optional)
                    options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       ich     fixed bin (31) byvalue;
   return (SNDMSG (hwndCtl, EM_LINEFROMCHAR, (ich), 0));
 end Edit_LineFromChar;

 Edit_LineIndex: proc (hwndCtl, line)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       line    fixed bin (31) byvalue;
   return (SNDMSG (hwndCtl, EM_LINEINDEX, (line), 0));
 end Edit_LineIndex;

 Edit_LineLength: proc (hwndCtl, line)
                  returns (fixed bin(31) byvalue optional)
                  options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       line    fixed bin (31) byvalue;
   return (SNDMSG (hwndCtl, EM_LINELENGTH, (line), 0));
 end Edit_LineLength;


 Edit_Scroll: proc (hwndCtl, dv, dh)
              options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       dv      fixed bin(31) byvalue,
       dh      fixed bin(31) byvalue;
   call SNDMSG (hwndCtl, EM_LINESCROLL, (dh), (dv));
 end Edit_Scroll;


 Edit_CanUndo: proc (hwndCtl)
               returns (type BOOL byvalue optional)
               options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_CANUNDO, 0, 0));
 end Edit_CanUndo;

 Edit_Undo: proc (hwndCtl)
            returns (type BOOL byvalue optional)
            options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_UNDO, 0, 0));
 end Edit_Undo;

 Edit_EmptyUndoBuffer: proc (hwndCtl)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   call SNDMSG (hwndCtl, EM_EMPTYUNDOBUFFER, 0, 0);
 end Edit_EmptyUndoBuffer;


 Edit_SetPasswordChar: proc (hwndCtl, ch)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       ch      TCHAR(1) byvalue;
   dcl rank builtin;
   call SNDMSG (hwndCtl, EM_SETPASSWORDCHAR, rank (ch), 0);
 end Edit_SetPasswordChar;


 Edit_SetTabStops: proc (hwndCtl, cTabs, lpTabs)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       cTabs   fixed bin (31) byvalue,
       lpTabs  (*) fixed bin (31) byaddr nonasgn optional;
   dcl (addr, binvalue) builtin;

   call SNDMSG (hwndCtl, EM_SETTABSTOPS, (cTabs),
                binvalue (addr (lpTabs)));
 end Edit_SetTabStops;


 Edit_FmtLines: proc (hwndCtl, fAddEOL)
                returns (type BOOL byvalue optional)
                options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fAddEOL type BOOL byvalue;
   return (SNDMSG (hwndCtl, EM_FMTLINES, (fAddEOL), 0));
 end Edit_FmtLines;


 Edit_GetHandle: proc (hwndCtl)
                 returns (type HLOCAL byvalue)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (SNDMSG (hwndCtl, EM_GETHANDLE, 0, 0)));
 end Edit_GetHandle;

 Edit_SetHandle: proc (hwndCtl, h)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       h       type HLOCAL byvalue;
   dcl binvalue builtin;
   call SNDMSG (hwndCtl, EM_SETHANDLE, binvalue (h), 0);
 end Edit_SetHandle;


 %if WINVER >= 778 %then %do;
 Edit_GetFirstVisibleLine: proc (hwndCtl)
                           returns (fixed bin(31) byvalue)
                           options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, EM_GETFIRSTVISIBLELINE, 0, 0));
 end Edit_GetFirstVisibleLine;


 Edit_SetReadOnly: proc (hwndCtl, fReadOnly)
                   returns (type BOOL byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl   type HWND byvalue,
       fReadOnly type BOOL byvalue;
   return (SNDMSG (hwndCtl, EM_SETREADONLY, (fReadOnly), 0));
 end Edit_SetReadOnly;


 Edit_GetPasswordChar: proc (hwndCtl)
                       returns (TCHAR(1) byvalue)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   dcl (charval, wcharval) builtin;
   return (TCHARVAL (SNDMSG (hwndCtl, EM_GETPASSWORDCHAR, 0, 0)));
 end Edit_GetPasswordChar;


 Edit_SetWordBreakProc: proc (hwndCtl, lpfnWordBreak)
                        options (inline reorder) internal;
   dcl hwndCtl       type HWND byvalue,
       lpfnWordBreak type EDITWORDBREAKPROC;
   dcl (binvalue, entryaddr) builtin;
   call SNDMSG (hwndCtl, EM_SETWORDBREAKPROC, 0,
                binvalue (entryaddr (lpfnWordBreak)));
 end Edit_SetWordBreakProc;

 Edit_GetWordBreakProc: proc (hwndCtl)
                        returns (type EDITWORDBREAKPROC byvalue)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   dcl lpfnWordBreak type EDITWORDBREAKPROC;
   dcl (entryaddr, ptrvalue) builtin;
   entryaddr (lpfnWordBreak)
     = ptrvalue (SNDMSG (hwndCtl, EM_GETWORDBREAKPROC, 0, 0));
   return (lpfnWordBreak);
 end Edit_GetWordBreakProc;

 %end; /* WINVER >= 0x030a */

 /****** ScrollBar control message APIs *******************************/

 /* NOTE: flags parameter is a collection of ESB_* values, */
 /*       NOT a boolean!                                   */

 ScrollBar_Enable: proc (hwndCtl, flags)
                   returns (type BOOL byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       flags   type UINT byvalue;
   return (EnableScrollBar (hwndCtl, SB_CTL, flags));
 end ScrollBar_Enable;


 ScrollBar_Show: proc (hwndCtl, fShow)
                 returns (type BOOL byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fShow   type BOOL byvalue;
   dcl show    fixed bin (31);
   if fshow ^= FALSE then
     show = SW_SHOWNORMAL;
   else
     show = SW_HIDE;
   return (ShowWindow (hwndCtl, show));
 end ScrollBar_Show;


 ScrollBar_SetPos: proc (hwndCtl, pos, fRedraw)
                   returns (fixed bin(31) byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       pos     fixed bin(31) byvalue,
       fRedraw type BOOL byvalue;
   return (SetScrollPos (hwndCtl, SB_CTL, pos, fRedraw));
 end ScrollBar_SetPos;

 ScrollBar_GetPos: proc (hwndCtl)
                   returns (fixed bin(31) byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (GetScrollPos (hwndCtl, SB_CTL));
 end ScrollBar_GetPos;

 ScrollBar_SetRange: proc (hwndCtl, posMin, posMax, fRedraw)
                     returns (type BOOL byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       posMin  fixed bin(31) byvalue,
       posMax  fixed bin(31) byvalue,
       fRedraw type BOOL;
   return (SetScrollRange (hwndCtl, SB_CTL, posMin, posMax, fRedraw));
 end ScrollBar_SetRange;

 ScrollBar_GetRange: proc (hwndCtl, lpposMin, lpposMax)
                     returns (type BOOL byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl  type HWND,
       lpposMin fixed bin(31) byaddr,
       lpposMax fixed bin(31) byaddr;
   return (GetScrollRange (hwndCtl, SB_CTL, lpposMin, lpposMax));
 end ScrollBar_GetRange;

 /****** ListBox control message APIs *********************************/

 ListBox_Enable: proc (hwndCtl, fEnable)
                 returns (type BOOL byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fEnable type BOOL byvalue;
   return (EnableWindow (hwndCtl, fEnable));
 end ListBox_Enable;


 ListBox_GetCount: proc (hwndCtl)
                   returns (fixed bin(31) byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_GETCOUNT, 0, 0));
 end ListBox_GetCount;

 ListBox_ResetContent: proc (hwndCtl)
                       returns (type BOOL byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_RESETCONTENT, 0, 0));
 end ListBox_ResetContent;


 ListBox_AddString: proc (hwndCtl, lpsz)
                    returns (fixed bin(31) byvalue optional)
                    options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpsz    TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_ADDSTRING, 0, binvalue (addr (lpsz))));
 end ListBox_AddString;

 ListBox_InsertString: proc (hwndCtl, index, lpsz)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       lpsz    TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_INSERTSTRING, (index),
                   binvalue (addr (lpsz))));
 end ListBox_InsertString;


 ListBox_AddItemData: proc (hwndCtl, data)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, LB_ADDSTRING, 0, binvalue (data)));
 end ListBox_AddItemData;

 ListBox_InsertItemData: proc (hwndCtl, index, data)
                         returns (fixed bin(31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       data    pointer; /* to some user specified data format */
   return (SNDMSG (hwndCtl, LB_INSERTSTRING, (index), binvalue (data)));
 end ListBox_InsertItemData;


 ListBox_DeleteString: proc (hwndCtl, index)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_DELETESTRING, (index), 0));
 end ListBox_DeleteString;


 ListBox_GetTextLen: proc (hwndCtl, index)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_GETTEXTLEN, (index), 0));
 end ListBox_GetTextLen;

 ListBox_GetText: proc (hwndCtl, index, lpszBuffer)
                  returns (fixed bin(31) byvalue optional)
                  options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       index      fixed bin(31) byvalue,
       lpszBuffer TCHAR(*) varz byaddr; /* NOT nonasgn, M$ bug */
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_GETTEXT, (index),
                   binvalue (addr (lpszBuffer))));
 end ListBox_GetText;


 ListBox_GetItemData: proc (hwndCtl, index)
                      returns (type LRESULT byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_GETITEMDATA, (index), 0));
 end ListBox_GetItemData;

 ListBox_SetItemData: proc (hwndCtl, index, data)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, LB_SETITEMDATA, (index), binvalue (data)));
 end ListBox_SetItemData;


 %if WINVER >= 778 %then %do;
 ListBox_FindString: proc (hwndCtl, indexStart, lpszFind)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       lpszFind   TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_FINDSTRING, (indexStart),
                   binvalue (addr (lpszFind))));
 end ListBox_FindString;

 ListBox_FindItemData: proc (hwndCtl, indexStart, data)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, LB_FINDSTRING, (indexStart),
                   binvalue (data)));
 end ListBox_FindItemData;


 ListBox_SetSel: proc (hwndCtl, fSelect, index)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fSelect type BOOL byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_SETSEL, (fSelect), (index)));
 end ListBox_SetSel;

 ListBox_SelItemRange: proc (hwndCtl, fSelect, first, last)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fSelect type BOOL byvalue,
       first   fixed bin(31) byvalue,
       last    fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_SELITEMRANGE, (fSelect),
                   MAKELPARAM (first, last)));
 end ListBox_SelItemRange;


 ListBox_GetCurSel: proc (hwndCtl)
                    returns (fixed bin(31) byvalue optional)
                    options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_GETCURSEL, 0, 0));
 end ListBox_GetCurSel;

 ListBox_SetCurSel: proc (hwndCtl, index)
                    returns (fixed bin(31) byvalue optional)
                    options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_SETCURSEL, (index), 0));
 end ListBox_SetCurSel;


 ListBox_SelectString: proc (hwndCtl, indexStart, lpszFind)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       lpszFind   TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_SELECTSTRING, (indexStart),
                   binvalue (addr (lpszFind))));
 end ListBox_SelectString;

 ListBox_SelectItemData: proc (hwndCtl, indexStart, data)
                         returns (fixed bin(31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, LB_SELECTSTRING, (indexStart),
                   binvalue (data)));
 end ListBox_SelectItemData;


 ListBox_GetSel: proc (hwndCtl, index)
                 returns (fixed bin(31) byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_GETSEL, index, 0));
 end ListBox_GetSel;

 ListBox_GetSelCount: proc (hwndCtl)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_GETSELCOUNT, 0, 0));
 end ListBox_GetSelCount;

 ListBox_GetTopIndex: proc (hwndCtl)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_GETTOPINDEX, 0, 0));
 end ListBox_GetTopIndex;

 ListBox_GetSelItems: proc (hwndCtl, cItems, lpItems)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       cItems  fixed bin(31) byvalue,
       lpItems (*) fixed bin(31) byaddr;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_GETSELITEMS, (cItems),
                   binvalue (addr (lpItems))));
 end ListBox_GetSelItems;


 ListBox_SetTopIndex: proc (hwndCtl, indexTop)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue,
       indexTop fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_SETTOPINDEX, (indexTop), 0));
 end ListBox_SetTopIndex;


 ListBox_SetColumnWidth: proc (hwndCtl, cxColumn)
                         options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue,
       cxColumn fixed bin(31) byvalue;
   call SNDMSG (hwndCtl, LB_SETCOLUMNWIDTH, (cxColumn), 0);
 end ListBox_SetColumnWidth;

 ListBox_GetHorizontalExtent: proc (hwndCtl)
                              returns (fixed bin(31) byvalue optional)
                              options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_GETHORIZONTALEXTENT, 0, 0));
 end ListBox_GetHorizontalExtent;

 ListBox_SetHorizontalExtent: proc (hwndCtl, cxExtent)
                              options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue,
       cxExtent fixed bin(31) byvalue;
   call SNDMSG (hwndCtl, LB_SETHORIZONTALEXTENT, (cxExtent), 0);
 end ListBox_SetHorizontalExtent;


 ListBox_SetTabStops: proc (hwndCtl, cTabs, lpTabs)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       cTabs   fixed bin(31) byvalue,
       lpTabs  (*) fixed bin(31) byaddr;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_SETTABSTOPS, (cTabs),
                   binvalue (addr (lpTabs))));
 end ListBox_SetTabStops;


 ListBox_GetItemRect: proc (hwndCtl, index, lprc)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       lprc    type RECT byaddr;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_GETITEMRECT, (index),
                   binvalue (addr (lprc))));
 end ListBox_GetItemRect;


 ListBox_SetCaretIndex: proc (hwndCtl, index)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_SETCARETINDEX, (index), 0));
 end ListBox_SetCaretIndex;

 ListBox_GetCaretIndex: proc (hwndCtl)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, LB_GETCARETINDEX, 0, 0));
 end ListBox_GetCaretIndex;


 ListBox_FindStringExact: proc (hwndCtl, indexStart, lpszFind)
                          returns (fixed bin(31) byvalue optional)
                          options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       lpszFind   TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_FINDSTRINGEXACT, (indexStart),
                   binvalue (addr (lpszFind))));
 end ListBox_FindStringExact;

 ListBox_SetItemHeight: proc (hwndCtl, index, cy)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       cy      fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_SETITEMHEIGHT, (index),
                   MAKELPARAM(cy, 0)));
 end ListBox_SetItemHeight;

 ListBox_GetItemHeight: proc (hwndCtl, index)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, LB_GETITEMHEIGHT, (index), 0));
 end ListBox_GetItemHeight;

 %end; /* WINVER >= 0x030a */

 ListBox_Dir: proc (hwndCtl, attrs, lpszFileSpec)
              returns (fixed bin (31) byvalue optional)
              options (inline reorder) internal;
   dcl hwndCtl      type HWND byvalue,
       attrs        type UINT byvalue,
       lpszFileSpec TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, LB_DIR, (attrs),
                   binvalue (addr (lpszFileSpec))));
 end ListBox_Dir;


 /****** ComboBox control message APIs ********************************/

 ComboBox_Enable: proc (hwndCtl, fEnable)
                 returns (type BOOL byvalue optional)
                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fEnable type BOOL byvalue;
   return (EnableWindow (hwndCtl, fEnable));
 end ComboBox_Enable;


 ComboBox_GetText: proc (hwndCtl, lpch, cchMax)
                   returns (fixed bin(31) byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpch    TCHAR(*) varz byaddr,
       cchmax  fixed bin(31) byvalue;
   dcl (addr, binvalue) builtin;
   return (GetWindowText (hwndCtl, binvalue (addr (lpch)), (cchMax)));
 end;

 ComboBox_GetTextLength: proc (hwndCtl)
                         returns (fixed bin(31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (GetWindowTextLength (hwndCtl));
 end ComboBox_GetTextLength;

 ComboBox_SetText: proc (hwndCtl, lpsz)
                   returns (type BOOL byvalue optional)
                   options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpsz    TCHAR(*) varz byaddr;
   dcl (addr, binvalue) builtin;
   return (SetWindowText (hwndCtl, binvalue (addr (lpsz))));
 end ComboBox_SetText;


 ComboBox_LimitText: proc (hwndCtl, cchLimit)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue,
       cchLimit fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, CB_LIMITTEXT, (cchLimit), 0));
 end ComboBox_LimitText;


 ComboBox_GetEditSel: proc (hwndCtl)
                      returns (type DWORD byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, CB_GETEDITSEL, 0, 0));
 end ComboBox_GetEditSel;

 ComboBox_SetEditSel: proc (hwndCtl, ichStart, ichEnd)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl  type HWND byvalue,
       ichStart fixed bin(31) byvalue,
       ichEnd   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, CB_SETEDITSEL, 0,
                   MAKELPARAM (ichStart, ichEnd)));
 end ComboBox_SetEditSel;


 ComboBox_GetCount: proc (hwndCtl)
                    returns (fixed bin(31) byvalue optional)
                    options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, CB_GETCOUNT, 0, 0));
 end ComboBox_GetCount;

 ComboBox_ResetContent: proc (hwndCtl)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, CB_RESETCONTENT, 0, 0));
 end ComboBox_ResetContent;


 ComboBox_AddString: proc (hwndCtl, lpsz)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lpsz    TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_ADDSTRING, 0, binvalue (addr (lpsz))));
 end ComboBox_AddString;

 ComboBox_InsertString: proc (hwndCtl, index, lpsz)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       lpsz    TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_INSERTSTRING, (index),
                   binvalue (addr (lpsz))));
 end ComboBox_InsertString;


 ComboBox_AddItemData: proc (hwndCtl, data)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, CB_ADDSTRING, 0, binvalue (data)));
 end ComboBox_AddItemData;

 ComboBox_InsertItemData: proc (hwndCtl, index, data)
                          returns (fixed bin(31) byvalue optional)
                          options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, CB_INSERTSTRING, (index), binvalue (data)));
 end ComboBox_InsertItemData;


 ComboBox_DeleteString: proc (hwndCtl, index)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, CB_DELETESTRING, (index), 0));
 end ComboBox_DeleteString;


 ComboBox_GetLBTextLen: proc (hwndCtl, index)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, CB_GETLBTEXTLEN, (index), 0));
 end ComboBox_GetLBTextLen;

 ComboBox_GetLBText: proc (hwndCtl, index, lpszBuffer)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       index      fixed bin(31) byvalue,
       lpszBuffer TCHAR(*) varz byaddr; /* not nonasgn, M$ bug! */
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_GETLBTEXT, (index),
                   binvalue (addr (lpszBuffer))));
 end ComboBox_GetLBText;


 ComboBox_GetItemData: proc (hwndCtl, index)
                       returns (type LRESULT byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, CB_GETITEMDATA, (index), 0));
 end ComboBox_GetItemData;

 ComboBox_SetItemData: proc (hwndCtl, index, data)
                       returns (fixed bin(31) byvalue optional)
                       options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue,
       data    pointer; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, CB_SETITEMDATA, (index), binvalue (data)));
 end ComboBox_SetItemData;


 ComboBox_FindString: proc (hwndCtl, indexStart, lpszFind)
                      returns (fixed bin(31) byvalue optional)
                      options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       lpszFind   TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_FINDSTRING, (indexStart),
                   binvalue (addr (lpszFind))));
 end ComboBox_FindString;

 ComboBox_FindItemData: proc (hwndCtl, indexStart, data)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       data       pointer; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, CB_FINDSTRING, (indexStart),
                   binvalue (data)));
 end ComboBox_FindItemData;


 ComboBox_GetCurSel: proc (hwndCtl)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, CB_GETCURSEL, 0, 0));
 end ComboBox_GetCurSel;

 ComboBox_SetCurSel: proc (hwndCtl, index)
                     returns (fixed bin(31) byvalue optional)
                     options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin(31) byvalue;
   return (SNDMSG (hwndCtl, CB_SETCURSEL, (index), 0));
 end ComboBox_SetCurSel;


 ComboBox_SelectString: proc (hwndCtl, indexStart, lpszSelect)
                        returns (fixed bin(31) byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       lpszSelect TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_SELECTSTRING, (indexStart),
                   binvalue (addr (lpszSelect))));
 end ComboBox_SelectString;

 ComboBox_SelectItemData: proc (hwndCtl, indexStart, data)
                          returns (fixed bin(31) byvalue optional)
                          options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       data    pointer byvalue; /* to some user specified data format */
   dcl binvalue builtin;
   return (SNDMSG (hwndCtl, CB_SELECTSTRING, (indexStart),
                   binvalue (data)));
 end ComboBox_SelectItemData;


 ComboBox_Dir: proc (hwndCtl, attrs, lpszFileSpec)
               returns (fixed bin (31) byvalue optional)
               options (inline reorder) internal;
   dcl hwndCtl      type HWND byvalue,
       attrs        type UINT byvalue,
       lpszFileSpec TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_DIR, (attrs),
                   binvalue (addr (lpszFileSpec))));
 end ComboBox_Dir;


 ComboBox_ShowDropdown: proc (hwndCtl, fShow)
                        returns (type BOOL byvalue optional)
                        options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       fShow   type BOOL byvalue;
   return (SNDMSG (hwndCtl, CB_SHOWDROPDOWN, (fShow), 0));
 end ComboBox_ShowDropdown;



 %if WINVER >= 778 %then %do;
 ComboBox_FindStringExact: proc (hwndCtl, indexStart, lpszFind)
                           returns (fixed bin (31) byvalue optional)
                           options (inline reorder) internal;
   dcl hwndCtl    type HWND byvalue,
       indexStart fixed bin(31) byvalue,
       lpszFind   TCHAR(*) varz byaddr nonasgn;
   dcl (addr, binvalue) builtin;
   return (SNDMSG (hwndCtl, CB_FINDSTRINGEXACT, (indexStart),
                   binvalue (addr (lpszFind))));
 end ComboBox_FindStringExact;


 ComboBox_GetDroppedState: proc (hwndCtl)
                           returns (fixed bin (31) byvalue optional)
                           options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, CB_GETDROPPEDSTATE, 0, 0));
 end ComboBox_GetDroppedState;

 ComboBox_GetDroppedControlRect: proc (hwndCtl, lprc)
                                 options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       lprc    type RECT byaddr;
   dcl (addr, binvalue) builtin;
   call SNDMSG (hwndCtl, CB_GETDROPPEDCONTROLRECT, 0,
                binvalue (addr (lprc)));
 end ComboBox_GetDroppedControlRect;


 ComboBox_GetItemHeight: proc (hwndCtl)
                         returns (fixed bin (31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG (hwndCtl, CB_GETITEMHEIGHT, 0, 0));
 end ComboBox_GetItemHeight;

 ComboBox_SetItemHeight: proc (hwndCtl, index, cyItem)
                         returns (fixed bin (31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       index   fixed bin (31),
       cyItem  fixed bin (31);
   return (SNDMSG (hwndCtl, CB_SETITEMHEIGHT, (index), (cyItem)));
 end ComboBox_SetItemHeight;


 ComboBox_GetExtendedUI: proc (hwndCtl)
                         returns (type UINT byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue;
   return (SNDMSG((hwndCtl), CB_GETEXTENDEDUI, 0, 0));
 end ComboBox_GetExtendedUI;

 ComboBox_SetExtendedUI: proc (hwndCtl, flags)
                         returns (fixed bin (31) byvalue optional)
                         options (inline reorder) internal;
   dcl hwndCtl type HWND byvalue,
       flags   type UINT byvalue;
   return (SNDMSG (hwndCtl, CB_SETEXTENDEDUI, (flags), 0));
 end ComboBox_SetExtendedUI;

 %end; /* WINVER >= 0x030a */
 %end; /* #WINUSER_ */

 /****** Alternate porting layer macros *******************************/

 /* USER MESSAGES: */

 GET_WPARAM: proc (wp, lp)
             returns (type WPARAM byvalue)
             options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (wp);
 end GET_WPARAM;

 GET_LPARAM: proc (wp, lp)
             returns (type LPARAM byvalue)
             options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (lp);
 end GET_LPARAM;

 GET_X_LPARAM: proc (lp)
               returns (fixed bin(31) byvalue)
               options (inline reorder) internal;
   dcl lp type LPARAM byvalue;
   dcl isigned builtin;
   return (isigned (LOWORD (lp)));
 end GET_X_LPARAM;

 GET_Y_LPARAM: proc (lp)
               returns (fixed bin(31) byvalue)
               options (inline reorder) internal;
   dcl lp type LPARAM byvalue;
   dcl isigned builtin;
   return (isigned (HIWORD (lp)));
 end GET_Y_LPARAM;


 GET_WM_ACTIVATE_STATE: proc (wp, lp)
                        returns (type UINT byvalue)
                        options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (LOWORD (wp));
 end GET_WM_ACTIVATE_STATE;

 GET_WM_ACTIVATE_FMINIMIZED: proc (wp, lp)
                             returns (type BOOL byvalue)
                             options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_ACTIVATE_FMINIMIZED;

 GET_WM_ACTIVATE_HWND: proc (wp, lp)
                       returns (type HWND byvalue)
                       options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_ACTIVATE_HWND;

 %dcl GET_WM_ACTIVATE_MPS entry; /* returns "wparam, lparam" */
 %GET_WM_ACTIVATE_MPS: proc (s, fmin, hwnd) returns (char);
   dcl (s, fmin, hwnd) char;
   return ('MAKELONG(' || s || ', ' || fmin || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_ACTIVATE_MPS;


 GET_WM_CHARTOITEM_CHAR: proc (wp, lp)
                         returns (TCHAR(1) byvalue)
                         options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   dcl (charval, wcharval) builtin;
   return (TCHARVAL (LOWORD (wp)));
 end GET_WM_CHARTOITEM_CHAR;

 GET_WM_CHARTOITEM_POS: proc (wp, lp)
                        returns (type UINT byvalue)
                        options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_CHARTOITEM_POS;

 GET_WM_CHARTOITEM_HWND: proc (wp, lp)
                         returns (type HWND byvalue)
                         options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_CHARTOITEM_HWND;

 %dcl GET_WM_CHARTOITEM_MPS entry;
 %GET_WM_CHARTOITEM_MPS: proc (ch, pos, hwnd) returns(char);
   dcl (ch, pos, hwnd) char;
   return ('MAKELONG(' || pos || ', rank(' || ch || ')), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_CHARTOITEM_MPS;


 GET_WM_COMMAND_ID: proc (wp, lp)
                    returns (type UINT byvalue)
                    options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (LOWORD (wp));
 end GET_WM_COMMAND_ID;

 GET_WM_COMMAND_HWND: proc (wp, lp)
                      returns (type HWND byvalue)
                      options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_COMMAND_HWND;

 GET_WM_COMMAND_CMD: proc (wp, lp)
                     returns (fixed bin(15) byvalue)
                     options (inline reorder) internal;
   dcl wp type WPARAM byvalue,
       lp type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_COMMAND_CMD;

 %dcl GET_WM_COMMAND_MPS entry;
 %GET_WM_COMMAND_MPS: proc (id, hwnd, cmd) returns (char);
   dcl (id, hwnd, cmd) char;
   return ('MAKELONG(' || id || ', ' || cmd || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_COMMAND_MPS;


 dcl WM_CTLCOLOR fixed bin(31) value('0019'xn);

 GET_WM_CTLCOLOR_HDC: proc (wp, lp, msg)
                      returns (type HDC byvalue)
                      options (inline reorder) internal;
   dcl wp  type WPARAM byvalue,
       lp  type LPARAM byvalue,
       msg fixed bin (31); /* WM_CTLCOLORxxx */
   dcl ptrvalue builtin;
   return (ptrvalue (wp));
 end GET_WM_CTLCOLOR_HDC;

 GET_WM_CTLCOLOR_HWND: proc (wp, lp, msg)
                       returns (type HWND byvalue)
                       options (inline reorder) internal;
   dcl wp  type WPARAM byvalue,
       lp  type LPARAM byvalue,
       msg fixed bin (31) byvalue; /* WM_CTLCOLORxxx */
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_CTLCOLOR_HWND;

 GET_WM_CTLCOLOR_TYPE: proc (wp, lp, msg)
                       returns (fixed bin(31) byvalue)
                       options (inline reorder) internal;
   dcl wp  type WPARAM byvalue,
       lp  type LPARAM byvalue,
       msg fixed bin (31) byvalue; /* WM_CTLCOLORxxx */
   return (msg - WM_CTLCOLORMSGBOX);
 end GET_WM_CTLCOLOR_TYPE;

 GET_WM_CTLCOLOR_MSG: proc (type)
                      returns (fixed bin(31) byvalue)
                      options (inline reorder) internal;
   dcl type fixed bin (31);
   return (WM_CTLCOLORMSGBOX + type);
 end GET_WM_CTLCOLOR_MSG;

 %dcl GET_WM_CTLCOLOR_MPS entry;
 %GET_WM_CTLCOLOR_MPS: proc (hdc, hwnd, type) returns (char);
   dcl (hdc, hwnd, type) char;
   return ('binvalue(' || hdc || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_CTLCOLOR_MPS;


 GET_WM_MENUSELECT_CMD: proc (wp, lp)
                        returns (type UINT byvalue)
                        options (inline reorder) internal;
   dcl wp  type WPARAM byvalue,
       lp  type LPARAM byvalue;
   return (LOWORD (wp));
 end GET_WM_MENUSELECT_CMD;

 GET_WM_MENUSELECT_FLAGS: proc (wp, lp)
                          returns (type UINT byvalue)
                          options (inline reorder) internal;
   dcl wp  type WPARAM byvalue,
       lp  type LPARAM byvalue;
   dcl isigned builtin;
   return (isigned (HIWORD(wp)));
 end GET_WM_MENUSELECT_FLAGS;

 GET_WM_MENUSELECT_HMENU: proc (wp, lp)
                          returns (type HMENU byvalue)
                          options (inline reorder) internal;
   dcl wp  type WPARAM byvalue,
       lp  type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_MENUSELECT_HMENU;

 %dcl GET_WM_MENUSELECT_MPS entry;
 %GET_WM_MENUSELECT_MPS: proc (cmd, f, hmenu) returns (char);
   dcl (cmd, f, hmenu) char;
   return ('MAKELONG(' || cmd || ', ' || f || '), ' ||
           'binvalue(' || hmenu || ')');
 %end GET_WM_MENUSELECT_MPS;

 /* Note: the following are for interpreting MDIclient to MDI child */
 /*       messages.                                                 */
 GET_WM_MDIACTIVATE_FACTIVATE: proc (hwnd, wp, lp)
                               returns (type BOOL byvalue)
                               options (inline reorder) internal;
   dcl hwnd type HWND byvalue,
       wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl binvalue builtin;
   if lp = binvalue (hwnd) then
     return (1);
   else
     return (0);
 end GET_WM_MDIACTIVATE_FACTIVATE;

 GET_WM_MDIACTIVATE_HWNDDEACT: proc (wp, lp)
                               returns (type HWND byvalue)
                               options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl binvalue builtin;
   return (ptrvalue (wp));
 end GET_WM_MDIACTIVATE_HWNDDEACT;

 GET_WM_MDIACTIVATE_HWNDACTIVATE: proc (wp, lp)
                                  returns (type HWND byvalue)
                                  options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_MDIACTIVATE_HWNDACTIVATE;

 /* Note: the following is for sending to the MDI client window. */
 %dcl GET_WM_MDIACTIVATE_MPS entry;
 %GET_WM_MDIACTIVATE_MPS: proc (f, hwndD, hwndA) returns (char);
   dcl (f, hwndD, hwndA) char;
   return ('binvalue(' || hwndA || '), 0');
 %end GET_WM_MDIACTIVATE_MPS;

 %dcl GET_WM_MDISETMENU_MPS entry;
 %GET_WM_MDISETMENU_MPS: proc (hmenuF, hmenuW) returns (char);
   dcl (hmenuF, hmenuW) char;
   return ('binvalue(' || hmenuF || '), ' ||
           'binvalue(' || hmenuW || ')');
 %end GET_WM_MDISETMENU_MPS;


 GET_WM_MENUCHAR_CHAR: proc (wp, lp)
                       returns (TCHAR(1) byvalue)
                       options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl (charval, wcharval) builtin;
   return (TCHARVAL (LOWORD (wp)));
 end GET_WM_MENUCHAR_CHAR;

 GET_WM_MENUCHAR_HMENU: proc (wp, lp)
                        returns (type HMENU byvalue)
                        options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_MENUCHAR_HMENU;

 GET_WM_MENUCHAR_FMENU: proc (wp, lp)
                        returns (type BOOL byvalue)
                        options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_MENUCHAR_FMENU;

 %dcl GET_WM_MENUCHAR_MPS entry;
 %GET_WM_MENUCHAR_MPS: proc (ch, hmenu, f) returns (char);
   dcl (ch, hmenu, f) char;
   return ('MAKELONG(' || ch || ', ' || f || '), ' ||
           'binvalue(' || hmenu || ')');
 %end GET_WM_MENUCHAR_MPS;


 GET_WM_PARENTNOTIFY_MSG: proc (wp, lp)
                          returns (type UINT byvalue)
                          options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (LOWORD (wp));
 end GET_WM_PARENTNOTIFY_MSG;

 GET_WM_PARENTNOTIFY_ID: proc (wp, lp)
                         returns (fixed bin(31) byvalue)
                         options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_PARENTNOTIFY_ID;

 GET_WM_PARENTNOTIFY_HWNDCHILD: proc (wp, lp)
                                returns (type HWND byvalue)
                                options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_PARENTNOTIFY_HWNDCHILD;

 GET_WM_PARENTNOTIFY_X: proc (wp, lp)
                        returns (fixed bin(31) byvalue)
                        options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl isigned builtin;
   return (isigned (LOWORD (lp)));
 end GET_WM_PARENTNOTIFY_X;

 GET_WM_PARENTNOTIFY_Y: proc (wp, lp)
                        returns (fixed bin(31) byvalue)
                        options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl isigned builtin;
   return (isigned (HIWORD (lp)));
 end GET_WM_PARENTNOTIFY_Y;

 %dcl GET_WM_PARENTNOTIFY_MPS entry;
 %GET_WM_PARENTNOTIFY_MPS: proc (msg, id, hwnd) returns (char);
   dcl (msg, id, hwnd) char;
   return ('MAKELONG(' || id || ', ' || msg || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_PARENTNOTIFY_MPS;

 %dcl GET_WM_PARENTNOTIFY2_MPS entry;
 %GET_WM_PARENTNOTIFY2_MPS: proc (msg, x, y) returns (char);
   dcl (msg, x, y) char;
   return ('MAKELONG(' || 0 || ', ' || msg || '), ' ||
           'MAKELONG(' || x || ', ' || y || ')');
 %end GET_WM_PARENTNOTIFY2_MPS;


 GET_WM_VKEYTOITEM_CODE: proc (wp, lp)
                         returns (fixed bin(31) byvalue)
                         options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl isigned builtin;
   return (isigned (LOWORD (wp)));
 end GET_WM_VKEYTOITEM_CODE;

 GET_WM_VKEYTOITEM_ITEM: proc (wp, lp)
                         returns (fixed bin(31) byvalue)
                         options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_VKEYTOITEM_ITEM;

 GET_WM_VKEYTOITEM_HWND: proc (wp, lp)
                         returns (type HWND byvalue)
                         options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_VKEYTOITEM_HWND;

 %dcl GET_WM_VKEYTOITEM_MPS entry;
 %GET_WM_VKEYTOITEM_MPS: proc (code, item, hwnd) returns (char);
   dcl (code, item, hwnd) char;
   return ('MAKELONG(' || item || ', ' || code || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_VKEYTOITEM_MPS;


 GET_EM_SETSEL_START: proc (wp, lp)
                      returns (fixed bin(31) byvalue)
                      options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (wp);
 end GET_EM_SETSEL_START;

 GET_EM_SETSEL_END: proc (wp, lp)
                    returns (fixed bin(31) byvalue)
                    options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (lp);
 end GET_EM_SETSEL_END;

 %dcl GET_EM_SETSEL_MPS entry;
 %GET_EM_SETSEL_MPS: proc (iStart, iEnd) returns (char);
   dcl (iStart, iEnd) char;
   return (iStart || ', ' || iEnd);
 %end GET_EM_SETSEL_MPS;

 %dcl GET_EM_LINESCROLL_MPS entry;
 %GET_EM_LINESCROLL_MPS: proc (vert, horz) returns (char);
   dcl (vert, horz) char;
   return (vert || ', ' || horz);
 %end GET_EM_LINESCROLL_MPS;


 GET_WM_CHANGECBCHAIN_HWNDNEXT: proc (wp, lp)
                                returns (type HWND byvalue)
                                options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_CHANGECBCHAIN_HWNDNEXT;


 GET_WM_HSCROLL_CODE: proc (wp, lp)
                      returns (fixed bin(31) byvalue)
                      options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (LOWORD (wp));
 end GET_WM_HSCROLL_CODE;

 GET_WM_HSCROLL_POS: proc (wp, lp)
                     returns (fixed bin(31) byvalue)
                     options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_HSCROLL_POS;

 GET_WM_HSCROLL_HWND: proc (wp, lp)
                      returns (type HWND byvalue)
                      options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_HSCROLL_HWND;

 %dcl GET_WM_HSCROLL_MPS entry;
 %GET_WM_HSCROLL_MPS: proc (code, pos, hwnd) returns (char);
   dcl (code, pos, hwnd) char;
   return ('MAKELONG(' || code || ', ' || pos || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_HSCROLL_MPS;


 GET_WM_VSCROLL_CODE: proc (wp, lp)
                      returns (fixed bin(31) byvalue)
                      options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (LOWORD (wp));
 end GET_WM_VSCROLL_CODE;

 GET_WM_VSCROLL_POS: proc (wp, lp)
                     returns (fixed bin(31) byvalue)
                     options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   return (HIWORD (wp));
 end GET_WM_VSCROLL_POS;

 GET_WM_VSCROLL_HWND: proc (wp, lp)
                      returns (type HWND byvalue)
                      options (inline reorder) internal;
   dcl wp   type WPARAM byvalue,
       lp   type LPARAM byvalue;
   dcl ptrvalue builtin;
   return (ptrvalue (lp));
 end GET_WM_VSCROLL_HWND;

 %dcl GET_WM_VSCROLL_MPS entry;
 %GET_WM_VSCROLL_MPS: proc (code, pos, hwnd) returns (char);
   dcl (code, pos, hwnd) char;
   return ('MAKELONG(' || code || ', ' || pos || '), ' ||
           'binvalue(' || hwnd || ')');
 %end GET_WM_VSCROLL_MPS;


 /* >>> The C runtime porting macros are not needed in PL/I <<< */

 %dcl DECLARE_HANDLE32 ENTRY;
 %DECLARE_HANDLE32: proc (name) statement returns (char);
   dcl name char;
   return (DECLARE_HANDLE (name));
 %end DECLARE_HANDLE32;

 %end; /* !_INC_WINDOWSX */
